Class: Google::Apis::DataprocV1::AccessSessionSparkApplicationSqlSparkPlanGraphResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

SparkPlanGraph for a Spark Application execution limited to maximum 10000 clusters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AccessSessionSparkApplicationSqlSparkPlanGraphResponse

Returns a new instance of AccessSessionSparkApplicationSqlSparkPlanGraphResponse.



146
147
148
# File 'lib/google/apis/dataproc_v1/classes.rb', line 146

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#spark_plan_graphGoogle::Apis::DataprocV1::SparkPlanGraph

A graph used for storing information of an executionPlan of DataFrame. Corresponds to the JSON property sparkPlanGraph



144
145
146
# File 'lib/google/apis/dataproc_v1/classes.rb', line 144

def spark_plan_graph
  @spark_plan_graph
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



151
152
153
# File 'lib/google/apis/dataproc_v1/classes.rb', line 151

def update!(**args)
  @spark_plan_graph = args[:spark_plan_graph] if args.key?(:spark_plan_graph)
end