Class: Google::Apis::DataprocV1::AccessSparkApplicationEnvironmentInfoResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::AccessSparkApplicationEnvironmentInfoResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Environment details of a Saprk Application.
Instance Attribute Summary collapse
-
#application_environment_info ⇒ Google::Apis::DataprocV1::ApplicationEnvironmentInfo
Details about the Environment that the application is running in.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AccessSparkApplicationEnvironmentInfoResponse
constructor
A new instance of AccessSparkApplicationEnvironmentInfoResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AccessSparkApplicationEnvironmentInfoResponse
Returns a new instance of AccessSparkApplicationEnvironmentInfoResponse.
242 243 244 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 242 def initialize(**args) update!(**args) end |
Instance Attribute Details
#application_environment_info ⇒ Google::Apis::DataprocV1::ApplicationEnvironmentInfo
Details about the Environment that the application is running in.
Corresponds to the JSON property applicationEnvironmentInfo
240 241 242 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 240 def application_environment_info @application_environment_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
247 248 249 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 247 def update!(**args) @application_environment_info = args[:application_environment_info] if args.key?(:application_environment_info) end |