Class: Google::Apis::DataprocV1::AccessSparkApplicationSqlSparkPlanGraphResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

SparkPlanGraph for a Spark Application execution limited to maximum 10000 clusters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AccessSparkApplicationSqlSparkPlanGraphResponse

Returns a new instance of AccessSparkApplicationSqlSparkPlanGraphResponse.



281
282
283
# File 'lib/google/apis/dataproc_v1/classes.rb', line 281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#spark_plan_graphGoogle::Apis::DataprocV1::SparkPlanGraph

A graph used for storing information of an executionPlan of DataFrame. Corresponds to the JSON property sparkPlanGraph



279
280
281
# File 'lib/google/apis/dataproc_v1/classes.rb', line 279

def spark_plan_graph
  @spark_plan_graph
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



286
287
288
# File 'lib/google/apis/dataproc_v1/classes.rb', line 286

def update!(**args)
  @spark_plan_graph = args[:spark_plan_graph] if args.key?(:spark_plan_graph)
end