Class: Google::Apis::DataprocV1::AnalyzeBatchRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A request to analyze a batch workload.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AnalyzeBatchRequest

Returns a new instance of AnalyzeBatchRequest.



391
392
393
# File 'lib/google/apis/dataproc_v1/classes.rb', line 391

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_idString

Optional. A unique ID used to identify the request. If the service receives two AnalyzeBatchRequest (http://cloud/dataproc/docs/reference/rpc/google.cloud. dataproc.v1#google.cloud.dataproc.v1.AnalyzeBatchRequest)s with the same request_id, the second request is ignored and the Operation that corresponds to the first request created and stored in the backend is returned. Recommendation: Set this value to a UUID (https://en.wikipedia.org/wiki/ Universally_unique_identifier).The value must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters. Corresponds to the JSON property requestId

Returns:

  • (String)


383
384
385
# File 'lib/google/apis/dataproc_v1/classes.rb', line 383

def request_id
  @request_id
end

#requestor_idString

Optional. The requestor ID is used to identify if the request comes from a GCA investigation or the old Ask Gemini Experience. Corresponds to the JSON property requestorId

Returns:

  • (String)


389
390
391
# File 'lib/google/apis/dataproc_v1/classes.rb', line 389

def requestor_id
  @requestor_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



396
397
398
399
# File 'lib/google/apis/dataproc_v1/classes.rb', line 396

def update!(**args)
  @request_id = args[:request_id] if args.key?(:request_id)
  @requestor_id = args[:requestor_id] if args.key?(:requestor_id)
end