Class: Google::Apis::DataprocV1::Cluster

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Describes the identifying information, config, and status of a cluster

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Cluster

Returns a new instance of Cluster.



1393
1394
1395
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1393

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_nameString

Required. The cluster name, which must be unique within a project. The name must start with a lowercase letter, and can contain up to 51 lowercase letters, numbers, and hyphens. It cannot end with a hyphen. The name of a deleted cluster can be reused. Corresponds to the JSON property clusterName

Returns:

  • (String)


1342
1343
1344
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1342

def cluster_name
  @cluster_name
end

#cluster_uuidString

Output only. A cluster UUID (Unique Universal Identifier). The service generates this value when it creates the cluster. Corresponds to the JSON property clusterUuid

Returns:

  • (String)


1348
1349
1350
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1348

def cluster_uuid
  @cluster_uuid
end

#configGoogle::Apis::DataprocV1::ClusterConfig

The cluster config. Corresponds to the JSON property config



1353
1354
1355
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1353

def config
  @config
end

#labelsHash<String,String>

Optional. The labels to associate with this cluster. Label keys must contain 1 to 63 characters, and must conform to RFC 1035 (https://www.ietf.org/rfc/ rfc1035.txt). Label values may be empty, but, if present, must contain 1 to 63 characters, and must conform to RFC 1035 (https://www.ietf.org/rfc/rfc1035.txt) . No more than 32 labels can be associated with a cluster. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1362
1363
1364
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1362

def labels
  @labels
end

#metricsGoogle::Apis::DataprocV1::ClusterMetrics

Contains cluster daemon metrics, such as HDFS and YARN stats.Beta Feature: This report is available for testing purposes only. It may be changed before final release. Corresponds to the JSON property metrics



1369
1370
1371
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1369

def metrics
  @metrics
end

#project_idString

Required. The Google Cloud Platform project ID that the cluster belongs to. Corresponds to the JSON property projectId

Returns:

  • (String)


1374
1375
1376
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1374

def project_id
  @project_id
end

#statusGoogle::Apis::DataprocV1::ClusterStatus

The status of a cluster and its instances. Corresponds to the JSON property status



1379
1380
1381
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1379

def status
  @status
end

#status_historyArray<Google::Apis::DataprocV1::ClusterStatus>

Output only. The previous cluster status. Corresponds to the JSON property statusHistory



1384
1385
1386
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1384

def status_history
  @status_history
end

#virtual_cluster_configGoogle::Apis::DataprocV1::VirtualClusterConfig

The cluster config for a cluster that does not directly control the underlying compute resources, such as a GKE cluster (https://cloud.google.com/dataproc/ docs/guides/dpgke/dataproc-gke-overview). Corresponds to the JSON property virtualClusterConfig



1391
1392
1393
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1391

def virtual_cluster_config
  @virtual_cluster_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1398

def update!(**args)
  @cluster_name = args[:cluster_name] if args.key?(:cluster_name)
  @cluster_uuid = args[:cluster_uuid] if args.key?(:cluster_uuid)
  @config = args[:config] if args.key?(:config)
  @labels = args[:labels] if args.key?(:labels)
  @metrics = args[:metrics] if args.key?(:metrics)
  @project_id = args[:project_id] if args.key?(:project_id)
  @status = args[:status] if args.key?(:status)
  @status_history = args[:status_history] if args.key?(:status_history)
  @virtual_cluster_config = args[:virtual_cluster_config] if args.key?(:virtual_cluster_config)
end