Class: Google::Apis::DataprocV1::ClusterConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::ClusterConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
The cluster config.
Instance Attribute Summary collapse
-
#autoscaling_config ⇒ Google::Apis::DataprocV1::AutoscalingConfig
Autoscaling Policy config associated with the cluster.
-
#auxiliary_node_groups ⇒ Array<Google::Apis::DataprocV1::AuxiliaryNodeGroup>
Optional.
-
#cluster_tier ⇒ String
Optional.
-
#cluster_type ⇒ String
Optional.
-
#config_bucket ⇒ String
Optional.
-
#dataproc_metric_config ⇒ Google::Apis::DataprocV1::DataprocMetricConfig
Metric config.
-
#diagnostic_bucket ⇒ String
Optional.
-
#encryption_config ⇒ Google::Apis::DataprocV1::EncryptionConfig
Encryption settings for the cluster.
-
#endpoint_config ⇒ Google::Apis::DataprocV1::EndpointConfig
Endpoint config for this cluster Corresponds to the JSON property
endpointConfig. -
#engine ⇒ String
Optional.
-
#gce_cluster_config ⇒ Google::Apis::DataprocV1::GceClusterConfig
Common config settings for resources of Compute Engine cluster instances, applicable to all instances in the cluster.
-
#gke_cluster_config ⇒ Google::Apis::DataprocV1::GkeClusterConfig
The cluster's GKE config.
-
#initialization_actions ⇒ Array<Google::Apis::DataprocV1::NodeInitializationAction>
Optional.
-
#lifecycle_config ⇒ Google::Apis::DataprocV1::LifecycleConfig
Specifies the cluster auto-delete schedule configuration.
-
#master_config ⇒ Google::Apis::DataprocV1::InstanceGroupConfig
The config settings for Compute Engine resources in an instance group, such as a master or worker group.
-
#metastore_config ⇒ Google::Apis::DataprocV1::MetastoreConfig
Specifies a Metastore configuration.
-
#secondary_worker_config ⇒ Google::Apis::DataprocV1::InstanceGroupConfig
The config settings for Compute Engine resources in an instance group, such as a master or worker group.
-
#security_config ⇒ Google::Apis::DataprocV1::SecurityConfig
Security related configuration, including encryption, Kerberos, etc.
-
#software_config ⇒ Google::Apis::DataprocV1::SoftwareConfig
Specifies the selection and config of software inside the cluster.
-
#temp_bucket ⇒ String
Optional.
-
#worker_config ⇒ Google::Apis::DataprocV1::InstanceGroupConfig
The config settings for Compute Engine resources in an instance group, such as a master or worker group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClusterConfig
constructor
A new instance of ClusterConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ClusterConfig
Returns a new instance of ClusterConfig.
1689 1690 1691 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1689 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoscaling_config ⇒ Google::Apis::DataprocV1::AutoscalingConfig
Autoscaling Policy config associated with the cluster.
Corresponds to the JSON property autoscalingConfig
1555 1556 1557 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1555 def autoscaling_config @autoscaling_config end |
#auxiliary_node_groups ⇒ Array<Google::Apis::DataprocV1::AuxiliaryNodeGroup>
Optional. The node group settings.
Corresponds to the JSON property auxiliaryNodeGroups
1560 1561 1562 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1560 def auxiliary_node_groups @auxiliary_node_groups end |
#cluster_tier ⇒ String
Optional. The cluster tier.
Corresponds to the JSON property clusterTier
1565 1566 1567 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1565 def cluster_tier @cluster_tier end |
#cluster_type ⇒ String
Optional. The type of the cluster.
Corresponds to the JSON property clusterType
1570 1571 1572 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1570 def cluster_type @cluster_type end |
#config_bucket ⇒ String
Optional. A Cloud Storage bucket used to stage job dependencies, config files,
and job driver console output. If you do not specify a staging bucket, the
service will determine a Cloud Storage location (US, ASIA, or EU) for your
cluster's staging bucket according to the Compute Engine zone where your
cluster is deployed, and then create and manage this project-level, per-
location bucket (see staging and temp buckets (https://cloud.google.com/
dataproc/docs/concepts/configuring-clusters/staging-bucket)). This field
requires a Cloud Storage bucket name, not a gs://... URI to a Cloud Storage
bucket.
Corresponds to the JSON property configBucket
1583 1584 1585 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1583 def config_bucket @config_bucket end |
#dataproc_metric_config ⇒ Google::Apis::DataprocV1::DataprocMetricConfig
Metric config.
Corresponds to the JSON property dataprocMetricConfig
1588 1589 1590 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1588 def dataproc_metric_config @dataproc_metric_config end |
#diagnostic_bucket ⇒ String
Optional. A Cloud Storage bucket used to collect checkpoint diagnostic data (
https://cloud.google.com/dataproc/docs/support/diagnose-clusters#
checkpoint_diagnostic_data). If you do not specify a diagnostic bucket, The
service will use the temp bucket to collect the checkpoint diagnostic data.
This field requires a Cloud Storage bucket name, not a gs://... URI to a Cloud
Storage bucket.
Corresponds to the JSON property diagnosticBucket
1598 1599 1600 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1598 def diagnostic_bucket @diagnostic_bucket end |
#encryption_config ⇒ Google::Apis::DataprocV1::EncryptionConfig
Encryption settings for the cluster.
Corresponds to the JSON property encryptionConfig
1603 1604 1605 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1603 def encryption_config @encryption_config end |
#endpoint_config ⇒ Google::Apis::DataprocV1::EndpointConfig
Endpoint config for this cluster
Corresponds to the JSON property endpointConfig
1608 1609 1610 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1608 def endpoint_config @endpoint_config end |
#engine ⇒ String
Optional. The cluster engine.
Corresponds to the JSON property engine
1613 1614 1615 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1613 def engine @engine end |
#gce_cluster_config ⇒ Google::Apis::DataprocV1::GceClusterConfig
Common config settings for resources of Compute Engine cluster instances,
applicable to all instances in the cluster.
Corresponds to the JSON property gceClusterConfig
1619 1620 1621 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1619 def gce_cluster_config @gce_cluster_config end |
#gke_cluster_config ⇒ Google::Apis::DataprocV1::GkeClusterConfig
The cluster's GKE config.
Corresponds to the JSON property gkeClusterConfig
1624 1625 1626 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1624 def gke_cluster_config @gke_cluster_config end |
#initialization_actions ⇒ Array<Google::Apis::DataprocV1::NodeInitializationAction>
Optional. Commands to execute on each node after config is completed. By
default, executables are run on master and all worker nodes. You can test a
node's role metadata to run an executable on a master or worker node, as shown
below using curl (you can also use wget): ROLE=$(curl -H Metadata-Flavor:
Google http://metadata/computeMetadata/v1/instance/attributes/dataproc-role)
if [[ "$ROLE" == 'Master' ]]; then ... master specific actions ... else ...
worker specific actions ... fi
Corresponds to the JSON property initializationActions
1635 1636 1637 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1635 def initialization_actions @initialization_actions end |
#lifecycle_config ⇒ Google::Apis::DataprocV1::LifecycleConfig
Specifies the cluster auto-delete schedule configuration.
Corresponds to the JSON property lifecycleConfig
1640 1641 1642 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1640 def lifecycle_config @lifecycle_config end |
#master_config ⇒ Google::Apis::DataprocV1::InstanceGroupConfig
The config settings for Compute Engine resources in an instance group, such as
a master or worker group.
Corresponds to the JSON property masterConfig
1646 1647 1648 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1646 def master_config @master_config end |
#metastore_config ⇒ Google::Apis::DataprocV1::MetastoreConfig
Specifies a Metastore configuration.
Corresponds to the JSON property metastoreConfig
1651 1652 1653 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1651 def @metastore_config end |
#secondary_worker_config ⇒ Google::Apis::DataprocV1::InstanceGroupConfig
The config settings for Compute Engine resources in an instance group, such as
a master or worker group.
Corresponds to the JSON property secondaryWorkerConfig
1657 1658 1659 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1657 def secondary_worker_config @secondary_worker_config end |
#security_config ⇒ Google::Apis::DataprocV1::SecurityConfig
Security related configuration, including encryption, Kerberos, etc.
Corresponds to the JSON property securityConfig
1662 1663 1664 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1662 def security_config @security_config end |
#software_config ⇒ Google::Apis::DataprocV1::SoftwareConfig
Specifies the selection and config of software inside the cluster.
Corresponds to the JSON property softwareConfig
1667 1668 1669 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1667 def software_config @software_config end |
#temp_bucket ⇒ String
Optional. A Cloud Storage bucket used to store ephemeral cluster and jobs data,
such as Spark and MapReduce history files. If you do not specify a temp
bucket, the service will determine a Cloud Storage location (US, ASIA, or EU)
for your cluster's temp bucket according to the Compute Engine zone where your
cluster is deployed, and then create and manage this project-level, per-
location bucket. The default bucket has a TTL of 90 days, but you can use any
TTL (or none) if you specify a bucket (see staging and temp buckets (https://
cloud.google.com/dataproc/docs/concepts/configuring-clusters/staging-bucket)).
This field requires a Cloud Storage bucket name, not a gs://... URI to a Cloud
Storage bucket.
Corresponds to the JSON property tempBucket
1681 1682 1683 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1681 def temp_bucket @temp_bucket end |
#worker_config ⇒ Google::Apis::DataprocV1::InstanceGroupConfig
The config settings for Compute Engine resources in an instance group, such as
a master or worker group.
Corresponds to the JSON property workerConfig
1687 1688 1689 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1687 def worker_config @worker_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1694 def update!(**args) @autoscaling_config = args[:autoscaling_config] if args.key?(:autoscaling_config) @auxiliary_node_groups = args[:auxiliary_node_groups] if args.key?(:auxiliary_node_groups) @cluster_tier = args[:cluster_tier] if args.key?(:cluster_tier) @cluster_type = args[:cluster_type] if args.key?(:cluster_type) @config_bucket = args[:config_bucket] if args.key?(:config_bucket) @dataproc_metric_config = args[:dataproc_metric_config] if args.key?(:dataproc_metric_config) @diagnostic_bucket = args[:diagnostic_bucket] if args.key?(:diagnostic_bucket) @encryption_config = args[:encryption_config] if args.key?(:encryption_config) @endpoint_config = args[:endpoint_config] if args.key?(:endpoint_config) @engine = args[:engine] if args.key?(:engine) @gce_cluster_config = args[:gce_cluster_config] if args.key?(:gce_cluster_config) @gke_cluster_config = args[:gke_cluster_config] if args.key?(:gke_cluster_config) @initialization_actions = args[:initialization_actions] if args.key?(:initialization_actions) @lifecycle_config = args[:lifecycle_config] if args.key?(:lifecycle_config) @master_config = args[:master_config] if args.key?(:master_config) @metastore_config = args[:metastore_config] if args.key?(:metastore_config) @secondary_worker_config = args[:secondary_worker_config] if args.key?(:secondary_worker_config) @security_config = args[:security_config] if args.key?(:security_config) @software_config = args[:software_config] if args.key?(:software_config) @temp_bucket = args[:temp_bucket] if args.key?(:temp_bucket) @worker_config = args[:worker_config] if args.key?(:worker_config) end |