Class: Google::Apis::DataprocV1::ConfidentialInstanceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Confidential Instance Config for clusters using Confidential VMs (https:// cloud.google.com/confidential-computing/confidential-vm/docs)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfidentialInstanceConfig

Returns a new instance of ConfidentialInstanceConfig.



1872
1873
1874
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1872

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidential_instance_typeString

Optional. Defines the type of Confidential Compute technology to use. Corresponds to the JSON property confidentialInstanceType

Returns:

  • (String)


1863
1864
1865
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1863

def confidential_instance_type
  @confidential_instance_type
end

#enable_confidential_computeBoolean Also known as: enable_confidential_compute?

Optional. Deprecated: Use 'confidential_instance_type' instead. Defines whether the instance should have confidential compute enabled. Corresponds to the JSON property enableConfidentialCompute

Returns:

  • (Boolean)


1869
1870
1871
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1869

def enable_confidential_compute
  @enable_confidential_compute
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1877
1878
1879
1880
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1877

def update!(**args)
  @confidential_instance_type = args[:confidential_instance_type] if args.key?(:confidential_instance_type)
  @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute)
end