Class: Google::Apis::DataprocV1::GkeClusterConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

The cluster's GKE config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GkeClusterConfig

Returns a new instance of GkeClusterConfig.



3200
3201
3202
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gke_cluster_targetString

Optional. A target GKE cluster to deploy to. It must be in the same project and region as the Dataproc cluster (the GKE cluster can be zonal or regional). Format: 'projects/project/locations/location/clusters/cluster_id' Corresponds to the JSON property gkeClusterTarget

Returns:

  • (String)


3183
3184
3185
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3183

def gke_cluster_target
  @gke_cluster_target
end

#namespaced_gke_deployment_targetGoogle::Apis::DataprocV1::NamespacedGkeDeploymentTarget

Deprecated. Used only for the deprecated beta. A full, namespace-isolated deployment target for an existing GKE cluster. Corresponds to the JSON property namespacedGkeDeploymentTarget



3189
3190
3191
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3189

def namespaced_gke_deployment_target
  @namespaced_gke_deployment_target
end

#node_pool_targetArray<Google::Apis::DataprocV1::GkeNodePoolTarget>

Optional. GKE node pools where workloads will be scheduled. At least one node pool must be assigned the DEFAULT GkeNodePoolTarget.Role. If a GkeNodePoolTarget is not specified, Dataproc constructs a DEFAULT GkeNodePoolTarget. Each role can be given to only one GkeNodePoolTarget. All node pools must have the same location settings. Corresponds to the JSON property nodePoolTarget



3198
3199
3200
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3198

def node_pool_target
  @node_pool_target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3205
3206
3207
3208
3209
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3205

def update!(**args)
  @gke_cluster_target = args[:gke_cluster_target] if args.key?(:gke_cluster_target)
  @namespaced_gke_deployment_target = args[:namespaced_gke_deployment_target] if args.key?(:namespaced_gke_deployment_target)
  @node_pool_target = args[:node_pool_target] if args.key?(:node_pool_target)
end