Class: Google::Apis::DataprocV1::InputQuantileMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InputQuantileMetrics

Returns a new instance of InputQuantileMetrics.



3687
3688
3689
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3687

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bytes_readGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property bytesRead



3679
3680
3681
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3679

def bytes_read
  @bytes_read
end

#records_readGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property recordsRead



3685
3686
3687
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3685

def records_read
  @records_read
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3692
3693
3694
3695
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3692

def update!(**args)
  @bytes_read = args[:bytes_read] if args.key?(:bytes_read)
  @records_read = args[:records_read] if args.key?(:records_read)
end