Class: Google::Apis::DataprocV1::InstanceFlexibilityPolicy
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::InstanceFlexibilityPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Instance flexibility Policy allowing a mixture of VM shapes and provisioning models.
Instance Attribute Summary collapse
-
#instance_machine_types ⇒ Hash<String,String>
Output only.
-
#instance_selection_list ⇒ Array<Google::Apis::DataprocV1::InstanceSelection>
Optional.
-
#instance_selection_results ⇒ Array<Google::Apis::DataprocV1::InstanceSelectionResult>
Output only.
-
#provisioning_model_mix ⇒ Google::Apis::DataprocV1::ProvisioningModelMix
Defines how Dataproc should create VMs with a mixture of provisioning models.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceFlexibilityPolicy
constructor
A new instance of InstanceFlexibilityPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceFlexibilityPolicy
Returns a new instance of InstanceFlexibilityPolicy.
3820 3821 3822 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3820 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_machine_types ⇒ Hash<String,String>
Output only. A map of instance short name to machine type. The key is the
short name of the Compute Engine instance, and the value is the full machine-
type name (e.g., 'n1-standard-16'). See Machine types for more information on
valid machine type strings.
Corresponds to the JSON property instanceMachineTypes
3802 3803 3804 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3802 def instance_machine_types @instance_machine_types end |
#instance_selection_list ⇒ Array<Google::Apis::DataprocV1::InstanceSelection>
Optional. List of instance selection options that the group will use when
creating new VMs.
Corresponds to the JSON property instanceSelectionList
3808 3809 3810 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3808 def instance_selection_list @instance_selection_list end |
#instance_selection_results ⇒ Array<Google::Apis::DataprocV1::InstanceSelectionResult>
Output only. A list of instance selection results in the group.
Corresponds to the JSON property instanceSelectionResults
3813 3814 3815 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3813 def instance_selection_results @instance_selection_results end |
#provisioning_model_mix ⇒ Google::Apis::DataprocV1::ProvisioningModelMix
Defines how Dataproc should create VMs with a mixture of provisioning models.
Corresponds to the JSON property provisioningModelMix
3818 3819 3820 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3818 def provisioning_model_mix @provisioning_model_mix end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3825 3826 3827 3828 3829 3830 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3825 def update!(**args) @instance_machine_types = args[:instance_machine_types] if args.key?(:instance_machine_types) @instance_selection_list = args[:instance_selection_list] if args.key?(:instance_selection_list) @instance_selection_results = args[:instance_selection_results] if args.key?(:instance_selection_results) @provisioning_model_mix = args[:provisioning_model_mix] if args.key?(:provisioning_model_mix) end |