Class: Google::Apis::DataprocV1::InstanceReference
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::InstanceReference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A reference to a Compute Engine instance.
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The unique identifier of the Compute Engine instance.
-
#instance_name ⇒ String
The user-friendly name of the Compute Engine instance.
-
#public_ecies_key ⇒ String
The public ECIES key used for sharing data with this instance.
-
#public_key ⇒ String
The public RSA key used for sharing data with this instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceReference
constructor
A new instance of InstanceReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceReference
Returns a new instance of InstanceReference.
4038 4039 4040 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4038 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_id ⇒ String
The unique identifier of the Compute Engine instance.
Corresponds to the JSON property instanceId
4021 4022 4023 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4021 def instance_id @instance_id end |
#instance_name ⇒ String
The user-friendly name of the Compute Engine instance.
Corresponds to the JSON property instanceName
4026 4027 4028 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4026 def instance_name @instance_name end |
#public_ecies_key ⇒ String
The public ECIES key used for sharing data with this instance.
Corresponds to the JSON property publicEciesKey
4031 4032 4033 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4031 def public_ecies_key @public_ecies_key end |
#public_key ⇒ String
The public RSA key used for sharing data with this instance.
Corresponds to the JSON property publicKey
4036 4037 4038 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4036 def public_key @public_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4043 4044 4045 4046 4047 4048 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4043 def update!(**args) @instance_id = args[:instance_id] if args.key?(:instance_id) @instance_name = args[:instance_name] if args.key?(:instance_name) @public_ecies_key = args[:public_ecies_key] if args.key?(:public_ecies_key) @public_key = args[:public_key] if args.key?(:public_key) end |