Class: Google::Apis::DataprocV1::JobPlacement

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Dataproc job config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobPlacement

Returns a new instance of JobPlacement.



4549
4550
4551
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4549

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_labelsHash<String,String>

Optional. Cluster labels to identify a cluster where the job will be submitted. Corresponds to the JSON property clusterLabels

Returns:

  • (Hash<String,String>)


4536
4537
4538
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4536

def cluster_labels
  @cluster_labels
end

#cluster_nameString

Required. The name of the cluster where the job will be submitted. Corresponds to the JSON property clusterName

Returns:

  • (String)


4541
4542
4543
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4541

def cluster_name
  @cluster_name
end

#cluster_uuidString

Output only. A cluster UUID generated by the Dataproc service when the job is submitted. Corresponds to the JSON property clusterUuid

Returns:

  • (String)


4547
4548
4549
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4547

def cluster_uuid
  @cluster_uuid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4554
4555
4556
4557
4558
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4554

def update!(**args)
  @cluster_labels = args[:cluster_labels] if args.key?(:cluster_labels)
  @cluster_name = args[:cluster_name] if args.key?(:cluster_name)
  @cluster_uuid = args[:cluster_uuid] if args.key?(:cluster_uuid)
end