Class: Google::Apis::DataprocV1::JobReference
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::JobReference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Encapsulates the full scoping used to reference a job.
Instance Attribute Summary collapse
-
#job_id ⇒ String
Optional.
-
#project_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ JobReference
constructor
A new instance of JobReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ JobReference
Returns a new instance of JobReference.
4579 4580 4581 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4579 def initialize(**args) update!(**args) end |
Instance Attribute Details
#job_id ⇒ String
Optional. The job ID, which must be unique within the project.The ID must
contain only letters (a-z, A-Z), numbers (0-9), underscores (_), or hyphens (-)
. The maximum length is 100 characters.If not specified by the caller, the job
ID will be provided by the server.
Corresponds to the JSON property jobId
4571 4572 4573 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4571 def job_id @job_id end |
#project_id ⇒ String
Optional. The ID of the Google Cloud Platform project that the job belongs to.
If specified, must match the request project ID.
Corresponds to the JSON property projectId
4577 4578 4579 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4577 def project_id @project_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4584 4585 4586 4587 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4584 def update!(**args) @job_id = args[:job_id] if args.key?(:job_id) @project_id = args[:project_id] if args.key?(:project_id) end |