Class: Google::Apis::DataprocV1::KubernetesSoftwareConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::KubernetesSoftwareConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
The software configuration for this Dataproc cluster running on Kubernetes.
Instance Attribute Summary collapse
-
#component_version ⇒ Hash<String,String>
The components that should be installed in this Dataproc cluster.
-
#properties ⇒ Hash<String,String>
The properties to set on daemon config files.Property keys are specified in prefix:property format, for example spark:spark.kubernetes.container.image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KubernetesSoftwareConfig
constructor
A new instance of KubernetesSoftwareConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KubernetesSoftwareConfig
Returns a new instance of KubernetesSoftwareConfig.
5105 5106 5107 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5105 def initialize(**args) update!(**args) end |
Instance Attribute Details
#component_version ⇒ Hash<String,String>
The components that should be installed in this Dataproc cluster. The key must
be a string from the KubernetesComponent enumeration. The value is the version
of the software to be installed. At least one entry must be specified.
Corresponds to the JSON property componentVersion
5094 5095 5096 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5094 def component_version @component_version end |
#properties ⇒ Hash<String,String>
The properties to set on daemon config files.Property keys are specified in
prefix:property format, for example spark:spark.kubernetes.container.image.
The following are supported prefixes and their mappings: spark: spark-defaults.
confFor more information, see Cluster properties (https://cloud.google.com/
dataproc/docs/concepts/cluster-properties).
Corresponds to the JSON property properties
5103 5104 5105 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5103 def properties @properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5110 5111 5112 5113 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5110 def update!(**args) @component_version = args[:component_version] if args.key?(:component_version) @properties = args[:properties] if args.key?(:properties) end |