Class: Google::Apis::DataprocV1::ListBatchesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A list of batch workloads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBatchesResponse

Returns a new instance of ListBatchesResponse.



5238
5239
5240
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5238

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#batchesArray<Google::Apis::DataprocV1::Batch>

Output only. The batches from the specified collection. Corresponds to the JSON property batches



5223
5224
5225
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5223

def batches
  @batches
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5229
5230
5231
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5229

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Output only. List of Batches that could not be included in the response. Attempting to get one of these resources may indicate why it was not included in the list response. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


5236
5237
5238
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5236

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5243
5244
5245
5246
5247
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5243

def update!(**args)
  @batches = args[:batches] if args.key?(:batches)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end