Class: Google::Apis::DataprocV1::ListJobsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A list of jobs in a project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListJobsResponse

Returns a new instance of ListJobsResponse.



5300
5301
5302
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5300

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#jobsArray<Google::Apis::DataprocV1::Job>

Output only. Jobs list. Corresponds to the JSON property jobs

Returns:



5284
5285
5286
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5284

def jobs
  @jobs
end

#next_page_tokenString

Optional. This token is included in the response if there are more results to fetch. To fetch additional results, provide this value as the page_token in a subsequent ListJobsRequest. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5291
5292
5293
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5291

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Output only. List of jobs with kms_key-encrypted parameters that could not be decrypted. A response to a jobs.get request may indicate the reason for the decryption failure for a specific job. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


5298
5299
5300
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5298

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5305
5306
5307
5308
5309
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5305

def update!(**args)
  @jobs = args[:jobs] if args.key?(:jobs)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end