Class: Google::Apis::DataprocV1::ManagedGroupConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Specifies the resources used to actively manage an instance group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedGroupConfig

Returns a new instance of ManagedGroupConfig.



5223
5224
5225
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5223

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_group_manager_nameString

Output only. The name of the Instance Group Manager for this group. Corresponds to the JSON property instanceGroupManagerName

Returns:

  • (String)


5209
5210
5211
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5209

def instance_group_manager_name
  @instance_group_manager_name
end

#instance_group_manager_uriString

Output only. The partial URI to the instance group manager for this group. E.g. projects/my-project/regions/us-central1/instanceGroupManagers/my-igm. Corresponds to the JSON property instanceGroupManagerUri

Returns:

  • (String)


5215
5216
5217
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5215

def instance_group_manager_uri
  @instance_group_manager_uri
end

#instance_template_nameString

Output only. The name of the Instance Template used for the Managed Instance Group. Corresponds to the JSON property instanceTemplateName

Returns:

  • (String)


5221
5222
5223
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5221

def instance_template_name
  @instance_template_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5228
5229
5230
5231
5232
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5228

def update!(**args)
  @instance_group_manager_name = args[:instance_group_manager_name] if args.key?(:instance_group_manager_name)
  @instance_group_manager_uri = args[:instance_group_manager_uri] if args.key?(:instance_group_manager_uri)
  @instance_template_name = args[:instance_template_name] if args.key?(:instance_template_name)
end