Class: Google::Apis::DataprocV1::NodePool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

indicating a list of workers of same type

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodePool

Returns a new instance of NodePool.



5709
5710
5711
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5709

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Required. A unique id of the node pool. Primary and Secondary workers can be specified using special reserved ids PRIMARY_WORKER_POOL and SECONDARY_WORKER_POOL respectively. Aux node pools can be referenced using corresponding pool id. Corresponds to the JSON property id

Returns:

  • (String)


5696
5697
5698
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5696

def id
  @id
end

#instance_namesArray<String>

Name of instances to be repaired. These instances must belong to specified node pool. Corresponds to the JSON property instanceNames

Returns:

  • (Array<String>)


5702
5703
5704
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5702

def instance_names
  @instance_names
end

#repair_actionString

Required. Repair action to take on specified resources of the node pool. Corresponds to the JSON property repairAction

Returns:

  • (String)


5707
5708
5709
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5707

def repair_action
  @repair_action
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5714
5715
5716
5717
5718
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5714

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @instance_names = args[:instance_names] if args.key?(:instance_names)
  @repair_action = args[:repair_action] if args.key?(:repair_action)
end