Class: Google::Apis::DataprocV1::OutputQuantileMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OutputQuantileMetrics

Returns a new instance of OutputQuantileMetrics.



5955
5956
5957
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5955

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bytes_writtenGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property bytesWritten



5947
5948
5949
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5947

def bytes_written
  @bytes_written
end

#records_writtenGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property recordsWritten



5953
5954
5955
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5953

def records_written
  @records_written
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5960
5961
5962
5963
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5960

def update!(**args)
  @bytes_written = args[:bytes_written] if args.key?(:bytes_written)
  @records_written = args[:records_written] if args.key?(:records_written)
end