Class: Google::Apis::DataprocV1::PySparkBatch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A configuration for running an Apache PySpark (https://spark.apache.org/docs/ latest/api/python/getting_started/quickstart.html) batch workload.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PySparkBatch

Returns a new instance of PySparkBatch.



6327
6328
6329
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6327

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#archive_urisArray<String>

Optional. HCFS URIs of archives to be extracted into the working directory of each executor. Supported file types: .jar, .tar, .tar.gz, .tgz, and .zip. Corresponds to the JSON property archiveUris

Returns:

  • (Array<String>)


6294
6295
6296
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6294

def archive_uris
  @archive_uris
end

#argsArray<String>

Optional. The arguments to pass to the driver. Do not include arguments that can be set as batch properties, such as --conf, since a collision can occur that causes an incorrect batch submission. Corresponds to the JSON property args

Returns:

  • (Array<String>)


6301
6302
6303
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6301

def args
  @args
end

#file_urisArray<String>

Optional. HCFS URIs of files to be placed in the working directory of each executor. Corresponds to the JSON property fileUris

Returns:

  • (Array<String>)


6307
6308
6309
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6307

def file_uris
  @file_uris
end

#jar_file_urisArray<String>

Optional. HCFS URIs of jar files to add to the classpath of the Spark driver and tasks. Corresponds to the JSON property jarFileUris

Returns:

  • (Array<String>)


6313
6314
6315
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6313

def jar_file_uris
  @jar_file_uris
end

#main_python_file_uriString

Required. The HCFS URI of the main Python file to use as the Spark driver. Must be a .py file. Corresponds to the JSON property mainPythonFileUri

Returns:

  • (String)


6319
6320
6321
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6319

def main_python_file_uri
  @main_python_file_uri
end

#python_file_urisArray<String>

Optional. HCFS file URIs of Python files to pass to the PySpark framework. Supported file types: .py, .egg, and .zip. Corresponds to the JSON property pythonFileUris

Returns:

  • (Array<String>)


6325
6326
6327
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6325

def python_file_uris
  @python_file_uris
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6332
6333
6334
6335
6336
6337
6338
6339
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6332

def update!(**args)
  @archive_uris = args[:archive_uris] if args.key?(:archive_uris)
  @args = args[:args] if args.key?(:args)
  @file_uris = args[:file_uris] if args.key?(:file_uris)
  @jar_file_uris = args[:jar_file_uris] if args.key?(:jar_file_uris)
  @main_python_file_uri = args[:main_python_file_uri] if args.key?(:main_python_file_uri)
  @python_file_uris = args[:python_file_uris] if args.key?(:python_file_uris)
end