Class: Google::Apis::DataprocV1::PySparkNotebookBatch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A configuration for running a PySpark Notebook batch workload.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PySparkNotebookBatch

Returns a new instance of PySparkNotebookBatch.



6742
6743
6744
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6742

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#archive_urisArray<String>

Optional. HCFS URIs of archives to be extracted into the working directory of each executor. Supported file types: .jar, .tar, .tar.gz, .tgz, and .zip. Corresponds to the JSON property archiveUris

Returns:

  • (Array<String>)


6714
6715
6716
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6714

def archive_uris
  @archive_uris
end

#file_urisArray<String>

Optional. HCFS URIs of files to be placed in the working directory of each executor Corresponds to the JSON property fileUris

Returns:

  • (Array<String>)


6720
6721
6722
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6720

def file_uris
  @file_uris
end

#jar_file_urisArray<String>

Optional. HCFS URIs of jar files to be added to the Spark CLASSPATH. Corresponds to the JSON property jarFileUris

Returns:

  • (Array<String>)


6725
6726
6727
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6725

def jar_file_uris
  @jar_file_uris
end

#notebook_file_uriString

Required. The HCFS URI of the notebook file to execute. Corresponds to the JSON property notebookFileUri

Returns:

  • (String)


6730
6731
6732
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6730

def notebook_file_uri
  @notebook_file_uri
end

#paramsHash<String,String>

Optional. The parameters to pass to the notebook. Corresponds to the JSON property params

Returns:

  • (Hash<String,String>)


6735
6736
6737
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6735

def params
  @params
end

#python_file_urisArray<String>

Optional. HCFS URIs of Python files to pass to the PySpark framework. Corresponds to the JSON property pythonFileUris

Returns:

  • (Array<String>)


6740
6741
6742
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6740

def python_file_uris
  @python_file_uris
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6747
6748
6749
6750
6751
6752
6753
6754
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6747

def update!(**args)
  @archive_uris = args[:archive_uris] if args.key?(:archive_uris)
  @file_uris = args[:file_uris] if args.key?(:file_uris)
  @jar_file_uris = args[:jar_file_uris] if args.key?(:jar_file_uris)
  @notebook_file_uri = args[:notebook_file_uri] if args.key?(:notebook_file_uri)
  @params = args[:params] if args.key?(:params)
  @python_file_uris = args[:python_file_uris] if args.key?(:python_file_uris)
end