Class: Google::Apis::DataprocV1::ResizeNodeGroupRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A request to resize a node group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResizeNodeGroupRequest

Returns a new instance of ResizeNodeGroupRequest.



7221
7222
7223
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7221

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#graceful_decommission_timeoutString

Optional. Timeout for graceful YARN decommissioning. Graceful decommissioning ( https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/scaling- clusters#graceful_decommissioning) allows the removal of nodes from the Compute Engine node group without interrupting jobs in progress. This timeout specifies how long to wait for jobs in progress to finish before forcefully removing nodes (and potentially interrupting jobs). Default timeout is 0 (for forceful decommission), and the maximum allowed timeout is 1 day. (see JSON representation of Duration (https://developers.google.com/protocol-buffers/ docs/proto3#json)).Only supported on Dataproc image versions 1.2 and higher. Corresponds to the JSON property gracefulDecommissionTimeout

Returns:

  • (String)


7194
7195
7196
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7194

def graceful_decommission_timeout
  @graceful_decommission_timeout
end

#parent_operation_idString

Optional. operation id of the parent operation sending the resize request Corresponds to the JSON property parentOperationId

Returns:

  • (String)


7199
7200
7201
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7199

def parent_operation_id
  @parent_operation_id
end

#request_idString

Optional. A unique ID used to identify the request. If the server receives two ResizeNodeGroupRequest (https://cloud.google.com/dataproc/docs/reference/rpc/ google.cloud.dataproc.v1#google.cloud.dataproc.v1.ResizeNodeGroupRequests) with the same ID, the second request is ignored and the first google. longrunning.Operation created and stored in the backend is returned. Recommendation: Set this value to a UUID (https://en.wikipedia.org/wiki/ Universally_unique_identifier).The ID must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters. Corresponds to the JSON property requestId

Returns:

  • (String)


7212
7213
7214
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7212

def request_id
  @request_id
end

#sizeFixnum

Required. The number of running instances for the node group to maintain. The group adds or removes instances to maintain the number of instances specified by this parameter. Corresponds to the JSON property size

Returns:

  • (Fixnum)


7219
7220
7221
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7219

def size
  @size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7226
7227
7228
7229
7230
7231
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7226

def update!(**args)
  @graceful_decommission_timeout = args[:graceful_decommission_timeout] if args.key?(:graceful_decommission_timeout)
  @parent_operation_id = args[:parent_operation_id] if args.key?(:parent_operation_id)
  @request_id = args[:request_id] if args.key?(:request_id)
  @size = args[:size] if args.key?(:size)
end