Class: Google::Apis::DataprocV1::RuntimeConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::RuntimeConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Runtime configuration for a workload.
Instance Attribute Summary collapse
-
#autotuning_config ⇒ Google::Apis::DataprocV1::AutotuningConfig
Autotuning configuration of the workload.
-
#cohort ⇒ String
Optional.
-
#container_image ⇒ String
Optional.
-
#properties ⇒ Hash<String,String>
Optional.
-
#repository_config ⇒ Google::Apis::DataprocV1::RepositoryConfig
Configuration for dependency repositories Corresponds to the JSON property
repositoryConfig. -
#version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RuntimeConfig
constructor
A new instance of RuntimeConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RuntimeConfig
Returns a new instance of RuntimeConfig.
7308 7309 7310 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7308 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autotuning_config ⇒ Google::Apis::DataprocV1::AutotuningConfig
Autotuning configuration of the workload.
Corresponds to the JSON property autotuningConfig
7278 7279 7280 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7278 def autotuning_config @autotuning_config end |
#cohort ⇒ String
Optional. Cohort identifier. Identifies families of the workloads that have
the same shape, for example, daily ETL jobs.
Corresponds to the JSON property cohort
7284 7285 7286 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7284 def cohort @cohort end |
#container_image ⇒ String
Optional. Optional custom container image for the job runtime environment. If
not specified, a default container image will be used.
Corresponds to the JSON property containerImage
7290 7291 7292 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7290 def container_image @container_image end |
#properties ⇒ Hash<String,String>
Optional. A mapping of property names to values, which are used to configure
workload execution.
Corresponds to the JSON property properties
7296 7297 7298 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7296 def properties @properties end |
#repository_config ⇒ Google::Apis::DataprocV1::RepositoryConfig
Configuration for dependency repositories
Corresponds to the JSON property repositoryConfig
7301 7302 7303 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7301 def repository_config @repository_config end |
#version ⇒ String
Optional. Version of the batch runtime.
Corresponds to the JSON property version
7306 7307 7308 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7306 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7313 7314 7315 7316 7317 7318 7319 7320 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7313 def update!(**args) @autotuning_config = args[:autotuning_config] if args.key?(:autotuning_config) @cohort = args[:cohort] if args.key?(:cohort) @container_image = args[:container_image] if args.key?(:container_image) @properties = args[:properties] if args.key?(:properties) @repository_config = args[:repository_config] if args.key?(:repository_config) @version = args[:version] if args.key?(:version) end |