Class: Google::Apis::DataprocV1::RuntimeInfo
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::RuntimeInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Runtime information about workload execution.
Instance Attribute Summary collapse
-
#approximate_usage ⇒ Google::Apis::DataprocV1::UsageMetrics
Usage metrics represent approximate total resources consumed by a workload.
-
#cohort_info ⇒ Google::Apis::DataprocV1::CohortInfo
Information about the cohort that the workload belongs to.
-
#current_usage ⇒ Google::Apis::DataprocV1::UsageSnapshot
The usage snapshot represents the resources consumed by a workload at a specified time.
-
#diagnostic_output_uri ⇒ String
Output only.
-
#endpoints ⇒ Hash<String,String>
Output only.
-
#output_uri ⇒ String
Output only.
-
#properties_info ⇒ Google::Apis::DataprocV1::PropertiesInfo
Properties of the workload organized by origin.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RuntimeInfo
constructor
A new instance of RuntimeInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RuntimeInfo
Returns a new instance of RuntimeInfo.
7552 7553 7554 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7552 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approximate_usage ⇒ Google::Apis::DataprocV1::UsageMetrics
Usage metrics represent approximate total resources consumed by a workload.
Corresponds to the JSON property approximateUsage
7517 7518 7519 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7517 def approximate_usage @approximate_usage end |
#cohort_info ⇒ Google::Apis::DataprocV1::CohortInfo
Information about the cohort that the workload belongs to.
Corresponds to the JSON property cohortInfo
7522 7523 7524 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7522 def cohort_info @cohort_info end |
#current_usage ⇒ Google::Apis::DataprocV1::UsageSnapshot
The usage snapshot represents the resources consumed by a workload at a
specified time.
Corresponds to the JSON property currentUsage
7528 7529 7530 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7528 def current_usage @current_usage end |
#diagnostic_output_uri ⇒ String
Output only. A URI pointing to the location of the diagnostics tarball.
Corresponds to the JSON property diagnosticOutputUri
7533 7534 7535 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7533 def diagnostic_output_uri @diagnostic_output_uri end |
#endpoints ⇒ Hash<String,String>
Output only. Map of remote access endpoints (such as web interfaces and APIs)
to their URIs.
Corresponds to the JSON property endpoints
7539 7540 7541 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7539 def endpoints @endpoints end |
#output_uri ⇒ String
Output only. A URI pointing to the location of the stdout and stderr of the
workload.
Corresponds to the JSON property outputUri
7545 7546 7547 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7545 def output_uri @output_uri end |
#properties_info ⇒ Google::Apis::DataprocV1::PropertiesInfo
Properties of the workload organized by origin.
Corresponds to the JSON property propertiesInfo
7550 7551 7552 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7550 def properties_info @properties_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7557 7558 7559 7560 7561 7562 7563 7564 7565 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7557 def update!(**args) @approximate_usage = args[:approximate_usage] if args.key?(:approximate_usage) @cohort_info = args[:cohort_info] if args.key?(:cohort_info) @current_usage = args[:current_usage] if args.key?(:current_usage) @diagnostic_output_uri = args[:diagnostic_output_uri] if args.key?(:diagnostic_output_uri) @endpoints = args[:endpoints] if args.key?(:endpoints) @output_uri = args[:output_uri] if args.key?(:output_uri) @properties_info = args[:properties_info] if args.key?(:properties_info) end |