Class: Google::Apis::DataprocV1::SearchSessionSparkApplicationExecutorsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

List of Executors associated with a Spark Application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchSessionSparkApplicationExecutorsResponse

Returns a new instance of SearchSessionSparkApplicationExecutorsResponse.



7264
7265
7266
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7264

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

This token is included in the response if there are more results to fetch. To fetch additional results, provide this value as the page_token in a subsequent SearchSessionSparkApplicationExecutorsRequest. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7257
7258
7259
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7257

def next_page_token
  @next_page_token
end

#spark_application_executorsArray<Google::Apis::DataprocV1::ExecutorSummary>

Details about executors used by the application. Corresponds to the JSON property sparkApplicationExecutors



7262
7263
7264
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7262

def spark_application_executors
  @spark_application_executors
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7269
7270
7271
7272
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7269

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @spark_application_executors = args[:spark_application_executors] if args.key?(:spark_application_executors)
end