Class: Google::Apis::DataprocV1::SearchSessionSparkApplicationJobsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A list of Jobs associated with a Spark Application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchSessionSparkApplicationJobsResponse

Returns a new instance of SearchSessionSparkApplicationJobsResponse.



7442
7443
7444
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7442

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

This token is included in the response if there are more results to fetch. To fetch additional results, provide this value as the page_token in a subsequent SearchSessionSparkApplicationJobsRequest. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7435
7436
7437
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7435

def next_page_token
  @next_page_token
end

#spark_application_jobsArray<Google::Apis::DataprocV1::JobData>

Output only. Data corresponding to a spark job. Corresponds to the JSON property sparkApplicationJobs



7440
7441
7442
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7440

def spark_application_jobs
  @spark_application_jobs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7447
7448
7449
7450
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7447

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @spark_application_jobs = args[:spark_application_jobs] if args.key?(:spark_application_jobs)
end