Class: Google::Apis::DataprocV1::SearchSessionSparkApplicationNativeSqlQueriesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

List of all Native queries for a Spark Application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchSessionSparkApplicationNativeSqlQueriesResponse

Returns a new instance of SearchSessionSparkApplicationNativeSqlQueriesResponse.



7665
7666
7667
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

This token is included in the response if there are more results to fetch. To fetch additional results, provide this value as the page_token in a subsequent SearchSessionSparkApplicationSqlQueriesRequest. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7658
7659
7660
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7658

def next_page_token
  @next_page_token
end

#spark_application_native_sql_queriesArray<Google::Apis::DataprocV1::NativeSqlExecutionUiData>

Output only. Native SQL Execution Data Corresponds to the JSON property sparkApplicationNativeSqlQueries



7663
7664
7665
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7663

def spark_application_native_sql_queries
  @spark_application_native_sql_queries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7670
7671
7672
7673
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7670

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @spark_application_native_sql_queries = args[:spark_application_native_sql_queries] if args.key?(:spark_application_native_sql_queries)
end