Class: Google::Apis::DataprocV1::SearchSessionSparkApplicationSqlQueriesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

List of all queries for a Spark Application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchSessionSparkApplicationSqlQueriesResponse

Returns a new instance of SearchSessionSparkApplicationSqlQueriesResponse.



7478
7479
7480
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7478

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

This token is included in the response if there are more results to fetch. To fetch additional results, provide this value as the page_token in a subsequent SearchSessionSparkApplicationSqlQueriesRequest. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7471
7472
7473
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7471

def next_page_token
  @next_page_token
end

#spark_application_sql_queriesArray<Google::Apis::DataprocV1::SqlExecutionUiData>

Output only. SQL Execution Data Corresponds to the JSON property sparkApplicationSqlQueries



7476
7477
7478
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7476

def spark_application_sql_queries
  @spark_application_sql_queries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7483
7484
7485
7486
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7483

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @spark_application_sql_queries = args[:spark_application_sql_queries] if args.key?(:spark_application_sql_queries)
end