Class: Google::Apis::DataprocV1::SearchSessionSparkApplicationStageAttemptsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A list of Stage Attempts for a Stage of a Spark Application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchSessionSparkApplicationStageAttemptsResponse

Returns a new instance of SearchSessionSparkApplicationStageAttemptsResponse.



7523
7524
7525
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7523

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

This token is included in the response if there are more results to fetch. To fetch additional results, provide this value as the page_token in a subsequent SearchSessionSparkApplicationStageAttemptsRequest. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7516
7517
7518
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7516

def next_page_token
  @next_page_token
end

#spark_application_stage_attemptsArray<Google::Apis::DataprocV1::StageData>

Output only. Data corresponding to a stage attempts Corresponds to the JSON property sparkApplicationStageAttempts



7521
7522
7523
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7521

def spark_application_stage_attempts
  @spark_application_stage_attempts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7528
7529
7530
7531
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7528

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @spark_application_stage_attempts = args[:spark_application_stage_attempts] if args.key?(:spark_application_stage_attempts)
end