Class: Google::Apis::DataprocV1::SearchSessionSparkApplicationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A list of summary of Spark Applications

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchSessionSparkApplicationsResponse

Returns a new instance of SearchSessionSparkApplicationsResponse.



7586
7587
7588
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7586

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

This token is included in the response if there are more results to fetch. To fetch additional results, provide this value as the page_token in a subsequent SearchSessionSparkApplicationsRequest. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7579
7580
7581
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7579

def next_page_token
  @next_page_token
end

#spark_applicationsArray<Google::Apis::DataprocV1::SparkApplication>

Output only. High level information corresponding to an application. Corresponds to the JSON property sparkApplications



7584
7585
7586
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7584

def spark_applications
  @spark_applications
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7591
7592
7593
7594
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7591

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @spark_applications = args[:spark_applications] if args.key?(:spark_applications)
end