Class: Google::Apis::DataprocV1::SearchSparkApplicationExecutorsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

List of Executors associated with a Spark Application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchSparkApplicationExecutorsResponse

Returns a new instance of SearchSparkApplicationExecutorsResponse.



7653
7654
7655
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7653

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

This token is included in the response if there are more results to fetch. To fetch additional results, provide this value as the page_token in a subsequent SearchSparkApplicationExecutorsListRequest. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7646
7647
7648
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7646

def next_page_token
  @next_page_token
end

#spark_application_executorsArray<Google::Apis::DataprocV1::ExecutorSummary>

Details about executors used by the application. Corresponds to the JSON property sparkApplicationExecutors



7651
7652
7653
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7651

def spark_application_executors
  @spark_application_executors
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7658
7659
7660
7661
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7658

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @spark_application_executors = args[:spark_application_executors] if args.key?(:spark_application_executors)
end