Class: Google::Apis::DataprocV1::SearchSparkApplicationJobsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A list of Jobs associated with a Spark Application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchSparkApplicationJobsResponse

Returns a new instance of SearchSparkApplicationJobsResponse.



7658
7659
7660
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7658

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

This token is included in the response if there are more results to fetch. To fetch additional results, provide this value as the page_token in a subsequent SearchSparkApplicationJobsRequest. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7651
7652
7653
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7651

def next_page_token
  @next_page_token
end

#spark_application_jobsArray<Google::Apis::DataprocV1::JobData>

Output only. Data corresponding to a spark job. Corresponds to the JSON property sparkApplicationJobs



7656
7657
7658
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7656

def spark_application_jobs
  @spark_application_jobs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7663
7664
7665
7666
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7663

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @spark_application_jobs = args[:spark_application_jobs] if args.key?(:spark_application_jobs)
end