Class: Google::Apis::DataprocV1::SearchSparkApplicationNativeSqlQueriesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

List of all Native SQL queries details for a Spark Application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchSparkApplicationNativeSqlQueriesResponse

Returns a new instance of SearchSparkApplicationNativeSqlQueriesResponse.



7908
7909
7910
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7908

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

This token is included in the response if there are more results to fetch. To fetch additional results, provide this value as the page_token in a subsequent SearchSparkApplicationNativeSqlQueriesRequest. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7901
7902
7903
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7901

def next_page_token
  @next_page_token
end

#spark_application_native_sql_queriesArray<Google::Apis::DataprocV1::NativeSqlExecutionUiData>

Output only. Native SQL Execution Data Corresponds to the JSON property sparkApplicationNativeSqlQueries



7906
7907
7908
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7906

def spark_application_native_sql_queries
  @spark_application_native_sql_queries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7913
7914
7915
7916
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7913

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @spark_application_native_sql_queries = args[:spark_application_native_sql_queries] if args.key?(:spark_application_native_sql_queries)
end