Class: Google::Apis::DataprocV1::SearchSparkApplicationSqlQueriesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::SearchSparkApplicationSqlQueriesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
List of all queries for a Spark Application.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
This token is included in the response if there are more results to fetch.
-
#spark_application_sql_queries ⇒ Array<Google::Apis::DataprocV1::SqlExecutionUiData>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchSparkApplicationSqlQueriesResponse
constructor
A new instance of SearchSparkApplicationSqlQueriesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchSparkApplicationSqlQueriesResponse
Returns a new instance of SearchSparkApplicationSqlQueriesResponse.
7534 7535 7536 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7534 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
This token is included in the response if there are more results to fetch. To
fetch additional results, provide this value as the page_token in a subsequent
SearchSparkApplicationSqlQueriesRequest.
Corresponds to the JSON property nextPageToken
7527 7528 7529 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7527 def next_page_token @next_page_token end |
#spark_application_sql_queries ⇒ Array<Google::Apis::DataprocV1::SqlExecutionUiData>
Output only. SQL Execution Data
Corresponds to the JSON property sparkApplicationSqlQueries
7532 7533 7534 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7532 def spark_application_sql_queries @spark_application_sql_queries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7539 7540 7541 7542 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7539 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @spark_application_sql_queries = args[:spark_application_sql_queries] if args.key?(:spark_application_sql_queries) end |