Class: Google::Apis::DataprocV1::SearchSparkApplicationStageAttemptTasksResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

List of tasks for a stage of a Spark Application

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchSparkApplicationStageAttemptTasksResponse

Returns a new instance of SearchSparkApplicationStageAttemptTasksResponse.



7561
7562
7563
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

This token is included in the response if there are more results to fetch. To fetch additional results, provide this value as the page_token in a subsequent ListSparkApplicationStageAttemptTasksRequest. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7554
7555
7556
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7554

def next_page_token
  @next_page_token
end

#spark_application_stage_attempt_tasksArray<Google::Apis::DataprocV1::TaskData>

Output only. Data corresponding to tasks created by spark. Corresponds to the JSON property sparkApplicationStageAttemptTasks



7559
7560
7561
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7559

def spark_application_stage_attempt_tasks
  @spark_application_stage_attempt_tasks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7566
7567
7568
7569
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7566

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @spark_application_stage_attempt_tasks = args[:spark_application_stage_attempt_tasks] if args.key?(:spark_application_stage_attempt_tasks)
end