Class: Google::Apis::DataprocV1::SearchSparkApplicationStageAttemptsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A list of Stage Attempts for a Stage of a Spark Application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchSparkApplicationStageAttemptsResponse

Returns a new instance of SearchSparkApplicationStageAttemptsResponse.



7588
7589
7590
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7588

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

This token is included in the response if there are more results to fetch. To fetch additional results, provide this value as the page_token in a subsequent ListSparkApplicationStageAttemptsRequest. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7581
7582
7583
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7581

def next_page_token
  @next_page_token
end

#spark_application_stage_attemptsArray<Google::Apis::DataprocV1::StageData>

Output only. Data corresponding to a stage attempts Corresponds to the JSON property sparkApplicationStageAttempts



7586
7587
7588
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7586

def spark_application_stage_attempts
  @spark_application_stage_attempts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7593
7594
7595
7596
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7593

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @spark_application_stage_attempts = args[:spark_application_stage_attempts] if args.key?(:spark_application_stage_attempts)
end