Class: Google::Apis::DataprocV1::SearchSparkApplicationStagesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A list of stages associated with a Spark Application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchSparkApplicationStagesResponse

Returns a new instance of SearchSparkApplicationStagesResponse.



8016
8017
8018
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8016

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

This token is included in the response if there are more results to fetch. To fetch additional results, provide this value as the page_token in a subsequent SearchSparkApplicationStages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8009
8010
8011
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8009

def next_page_token
  @next_page_token
end

#spark_application_stagesArray<Google::Apis::DataprocV1::StageData>

Output only. Data corresponding to a stage. Corresponds to the JSON property sparkApplicationStages



8014
8015
8016
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8014

def spark_application_stages
  @spark_application_stages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8021
8022
8023
8024
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8021

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @spark_application_stages = args[:spark_application_stages] if args.key?(:spark_application_stages)
end