Class: Google::Apis::DataprocV1::Session

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A representation of a session.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Session

Returns a new instance of Session.



8175
8176
8177
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8175

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the session was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8087
8088
8089
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8087

def create_time
  @create_time
end

#creatorString

Output only. The email address of the user who created the session. Corresponds to the JSON property creator

Returns:

  • (String)


8092
8093
8094
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8092

def creator
  @creator
end

#environment_configGoogle::Apis::DataprocV1::EnvironmentConfig

Environment configuration for a workload. Corresponds to the JSON property environmentConfig



8097
8098
8099
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8097

def environment_config
  @environment_config
end

#jupyter_sessionGoogle::Apis::DataprocV1::JupyterConfig

Jupyter configuration for an interactive session. Corresponds to the JSON property jupyterSession



8102
8103
8104
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8102

def jupyter_session
  @jupyter_session
end

#labelsHash<String,String>

Optional. The labels to associate with the session. Label keys must contain 1 to 63 characters, and must conform to RFC 1035 (https://www.ietf.org/rfc/ rfc1035.txt). Label values may be empty, but, if present, must contain 1 to 63 characters, and must conform to RFC 1035 (https://www.ietf.org/rfc/rfc1035.txt) . No more than 32 labels can be associated with a session. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


8111
8112
8113
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8111

def labels
  @labels
end

#nameString

Identifier. The resource name of the session. Corresponds to the JSON property name

Returns:

  • (String)


8116
8117
8118
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8116

def name
  @name
end

#runtime_configGoogle::Apis::DataprocV1::RuntimeConfig

Runtime configuration for a workload. Corresponds to the JSON property runtimeConfig



8121
8122
8123
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8121

def runtime_config
  @runtime_config
end

#runtime_infoGoogle::Apis::DataprocV1::RuntimeInfo

Runtime information about workload execution. Corresponds to the JSON property runtimeInfo



8126
8127
8128
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8126

def runtime_info
  @runtime_info
end

#session_templateString

Optional. The session template used by the session.Only resource names, including project ID and location, are valid.Example: * https://www.googleapis. com/compute/v1/projects/[project_id]/locations/[dataproc_region]/ sessionTemplates/[template_id] * projects/[project_id]/locations/[ dataproc_region]/sessionTemplates/[template_id]The template must be in the same project and Dataproc region as the session. Corresponds to the JSON property sessionTemplate

Returns:

  • (String)


8136
8137
8138
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8136

def session_template
  @session_template
end

#spark_connect_sessionGoogle::Apis::DataprocV1::SparkConnectConfig

Spark connect configuration for an interactive session. Corresponds to the JSON property sparkConnectSession



8141
8142
8143
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8141

def spark_connect_session
  @spark_connect_session
end

#stateString

Output only. A state of the session. Corresponds to the JSON property state

Returns:

  • (String)


8146
8147
8148
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8146

def state
  @state
end

#state_historyArray<Google::Apis::DataprocV1::SessionStateHistory>

Output only. Historical state information for the session. Corresponds to the JSON property stateHistory



8151
8152
8153
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8151

def state_history
  @state_history
end

#state_messageString

Output only. Session state details, such as the failure description if the state is FAILED. Corresponds to the JSON property stateMessage

Returns:

  • (String)


8157
8158
8159
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8157

def state_message
  @state_message
end

#state_timeString

Output only. The time when the session entered the current state. Corresponds to the JSON property stateTime

Returns:

  • (String)


8162
8163
8164
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8162

def state_time
  @state_time
end

#userString

Optional. The email address of the user who owns the session. Corresponds to the JSON property user

Returns:

  • (String)


8167
8168
8169
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8167

def user
  @user
end

#uuidString

Output only. A session UUID (Unique Universal Identifier). The service generates this value when it creates the session. Corresponds to the JSON property uuid

Returns:

  • (String)


8173
8174
8175
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8173

def uuid
  @uuid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8180
8181
8182
8183
8184
8185
8186
8187
8188
8189
8190
8191
8192
8193
8194
8195
8196
8197
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8180

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creator = args[:creator] if args.key?(:creator)
  @environment_config = args[:environment_config] if args.key?(:environment_config)
  @jupyter_session = args[:jupyter_session] if args.key?(:jupyter_session)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @runtime_config = args[:runtime_config] if args.key?(:runtime_config)
  @runtime_info = args[:runtime_info] if args.key?(:runtime_info)
  @session_template = args[:session_template] if args.key?(:session_template)
  @spark_connect_session = args[:spark_connect_session] if args.key?(:spark_connect_session)
  @state = args[:state] if args.key?(:state)
  @state_history = args[:state_history] if args.key?(:state_history)
  @state_message = args[:state_message] if args.key?(:state_message)
  @state_time = args[:state_time] if args.key?(:state_time)
  @user = args[:user] if args.key?(:user)
  @uuid = args[:uuid] if args.key?(:uuid)
end