Class: Google::Apis::DataprocV1::SessionStateHistory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Historical state information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SessionStateHistory

Returns a new instance of SessionStateHistory.



8052
8053
8054
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8052

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stateString

Output only. The state of the session at this point in the session history. Corresponds to the JSON property state

Returns:

  • (String)


8040
8041
8042
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8040

def state
  @state
end

#state_messageString

Output only. Details about the state at this point in the session history. Corresponds to the JSON property stateMessage

Returns:

  • (String)


8045
8046
8047
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8045

def state_message
  @state_message
end

#state_start_timeString

Output only. The time when the session entered the historical state. Corresponds to the JSON property stateStartTime

Returns:

  • (String)


8050
8051
8052
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8050

def state_start_time
  @state_start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8057
8058
8059
8060
8061
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8057

def update!(**args)
  @state = args[:state] if args.key?(:state)
  @state_message = args[:state_message] if args.key?(:state_message)
  @state_start_time = args[:state_start_time] if args.key?(:state_start_time)
end