Class: Google::Apis::DataprocV1::ShuffleReadQuantileMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ShuffleReadQuantileMetrics

Returns a new instance of ShuffleReadQuantileMetrics.



8729
8730
8731
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8729

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fetch_wait_time_millisGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property fetchWaitTimeMillis



8674
8675
8676
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8674

def fetch_wait_time_millis
  @fetch_wait_time_millis
end

#local_blocks_fetchedGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property localBlocksFetched



8680
8681
8682
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8680

def local_blocks_fetched
  @local_blocks_fetched
end

#read_bytesGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property readBytes



8686
8687
8688
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8686

def read_bytes
  @read_bytes
end

#read_recordsGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property readRecords



8692
8693
8694
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8692

def read_records
  @read_records
end

#remote_blocks_fetchedGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property remoteBlocksFetched



8698
8699
8700
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8698

def remote_blocks_fetched
  @remote_blocks_fetched
end

#remote_bytes_readGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property remoteBytesRead



8704
8705
8706
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8704

def remote_bytes_read
  @remote_bytes_read
end

#remote_bytes_read_to_diskGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property remoteBytesReadToDisk



8710
8711
8712
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8710

def remote_bytes_read_to_disk
  @remote_bytes_read_to_disk
end

#remote_reqs_durationGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property remoteReqsDuration



8716
8717
8718
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8716

def remote_reqs_duration
  @remote_reqs_duration
end

#shuffle_push_read_metricsGoogle::Apis::DataprocV1::ShufflePushReadQuantileMetrics

Corresponds to the JSON property shufflePushReadMetrics



8721
8722
8723
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8721

def shuffle_push_read_metrics
  @shuffle_push_read_metrics
end

#total_blocks_fetchedGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property totalBlocksFetched



8727
8728
8729
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8727

def total_blocks_fetched
  @total_blocks_fetched
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
8744
8745
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8734

def update!(**args)
  @fetch_wait_time_millis = args[:fetch_wait_time_millis] if args.key?(:fetch_wait_time_millis)
  @local_blocks_fetched = args[:local_blocks_fetched] if args.key?(:local_blocks_fetched)
  @read_bytes = args[:read_bytes] if args.key?(:read_bytes)
  @read_records = args[:read_records] if args.key?(:read_records)
  @remote_blocks_fetched = args[:remote_blocks_fetched] if args.key?(:remote_blocks_fetched)
  @remote_bytes_read = args[:remote_bytes_read] if args.key?(:remote_bytes_read)
  @remote_bytes_read_to_disk = args[:remote_bytes_read_to_disk] if args.key?(:remote_bytes_read_to_disk)
  @remote_reqs_duration = args[:remote_reqs_duration] if args.key?(:remote_reqs_duration)
  @shuffle_push_read_metrics = args[:shuffle_push_read_metrics] if args.key?(:shuffle_push_read_metrics)
  @total_blocks_fetched = args[:total_blocks_fetched] if args.key?(:total_blocks_fetched)
end