Class: Google::Apis::DataprocV1::SparkConnectExecutionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Represents the lifecycle and details of an Execution via Spark Connect

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SparkConnectExecutionInfo

Returns a new instance of SparkConnectExecutionInfo.



9111
9112
9113
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9111

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#close_timestampFixnum

Timestamp when the execution was closed. Corresponds to the JSON property closeTimestamp

Returns:

  • (Fixnum)


9049
9050
9051
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9049

def close_timestamp
  @close_timestamp
end

#detailString

Detailed information about the execution. Corresponds to the JSON property detail

Returns:

  • (String)


9054
9055
9056
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9054

def detail
  @detail
end

#finish_timestampFixnum

Timestamp when the execution finished. Corresponds to the JSON property finishTimestamp

Returns:

  • (Fixnum)


9059
9060
9061
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9059

def finish_timestamp
  @finish_timestamp
end

#job_idsArray<String>

Optional. List of job ids associated with the execution. Corresponds to the JSON property jobIds

Returns:

  • (Array<String>)


9064
9065
9066
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9064

def job_ids
  @job_ids
end

#job_tagString

Required. Job tag of the execution. Corresponds to the JSON property jobTag

Returns:

  • (String)


9069
9070
9071
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9069

def job_tag
  @job_tag
end

#operation_idString

Unique identifier for the operation. Corresponds to the JSON property operationId

Returns:

  • (String)


9074
9075
9076
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9074

def operation_id
  @operation_id
end

#session_idString

Required. Session ID, ties the execution to a specific Spark Connect session. Corresponds to the JSON property sessionId

Returns:

  • (String)


9079
9080
9081
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9079

def session_id
  @session_id
end

#spark_session_tagsArray<String>

Optional. Tags associated with the Spark session. Corresponds to the JSON property sparkSessionTags

Returns:

  • (Array<String>)


9084
9085
9086
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9084

def spark_session_tags
  @spark_session_tags
end

#sql_exec_idsArray<String>

Optional. List of sql execution ids associated with the execution. Corresponds to the JSON property sqlExecIds

Returns:

  • (Array<String>)


9089
9090
9091
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9089

def sql_exec_ids
  @sql_exec_ids
end

#start_timestampFixnum

Timestamp when the execution started. Corresponds to the JSON property startTimestamp

Returns:

  • (Fixnum)


9094
9095
9096
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9094

def start_timestamp
  @start_timestamp
end

#stateString

Output only. Current state of the execution. Corresponds to the JSON property state

Returns:

  • (String)


9099
9100
9101
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9099

def state
  @state
end

#statementString

statement of the execution. Corresponds to the JSON property statement

Returns:

  • (String)


9104
9105
9106
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9104

def statement
  @statement
end

#user_idString

User ID of the user who started the execution. Corresponds to the JSON property userId

Returns:

  • (String)


9109
9110
9111
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9109

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9116
9117
9118
9119
9120
9121
9122
9123
9124
9125
9126
9127
9128
9129
9130
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9116

def update!(**args)
  @close_timestamp = args[:close_timestamp] if args.key?(:close_timestamp)
  @detail = args[:detail] if args.key?(:detail)
  @finish_timestamp = args[:finish_timestamp] if args.key?(:finish_timestamp)
  @job_ids = args[:job_ids] if args.key?(:job_ids)
  @job_tag = args[:job_tag] if args.key?(:job_tag)
  @operation_id = args[:operation_id] if args.key?(:operation_id)
  @session_id = args[:session_id] if args.key?(:session_id)
  @spark_session_tags = args[:spark_session_tags] if args.key?(:spark_session_tags)
  @sql_exec_ids = args[:sql_exec_ids] if args.key?(:sql_exec_ids)
  @start_timestamp = args[:start_timestamp] if args.key?(:start_timestamp)
  @state = args[:state] if args.key?(:state)
  @statement = args[:statement] if args.key?(:statement)
  @user_id = args[:user_id] if args.key?(:user_id)
end