Class: Google::Apis::DataprocV1::SparkRBatch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A configuration for running an Apache SparkR (https://spark.apache.org/docs/ latest/sparkr.html) batch workload.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SparkRBatch

Returns a new instance of SparkRBatch.



9221
9222
9223
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9221

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#archive_urisArray<String>

Optional. HCFS URIs of archives to be extracted into the working directory of each executor. Supported file types: .jar, .tar, .tar.gz, .tgz, and .zip. Corresponds to the JSON property archiveUris

Returns:

  • (Array<String>)


9200
9201
9202
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9200

def archive_uris
  @archive_uris
end

#argsArray<String>

Optional. The arguments to pass to the Spark driver. Do not include arguments that can be set as batch properties, such as --conf, since a collision can occur that causes an incorrect batch submission. Corresponds to the JSON property args

Returns:

  • (Array<String>)


9207
9208
9209
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9207

def args
  @args
end

#file_urisArray<String>

Optional. HCFS URIs of files to be placed in the working directory of each executor. Corresponds to the JSON property fileUris

Returns:

  • (Array<String>)


9213
9214
9215
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9213

def file_uris
  @file_uris
end

#main_r_file_uriString

Required. The HCFS URI of the main R file to use as the driver. Must be a .R or .r file. Corresponds to the JSON property mainRFileUri

Returns:

  • (String)


9219
9220
9221
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9219

def main_r_file_uri
  @main_r_file_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9226
9227
9228
9229
9230
9231
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9226

def update!(**args)
  @archive_uris = args[:archive_uris] if args.key?(:archive_uris)
  @args = args[:args] if args.key?(:args)
  @file_uris = args[:file_uris] if args.key?(:file_uris)
  @main_r_file_uri = args[:main_r_file_uri] if args.key?(:main_r_file_uri)
end