Class: Google::Apis::DataprocV1::StartClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A request to start a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StartClusterRequest

Returns a new instance of StartClusterRequest.



10189
10190
10191
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10189

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_uuidString

Optional. Specifying the cluster_uuid means the RPC will fail (with error NOT_FOUND) if a cluster with the specified UUID does not exist. Corresponds to the JSON property clusterUuid

Returns:

  • (String)


10174
10175
10176
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10174

def cluster_uuid
  @cluster_uuid
end

#request_idString

Optional. A unique ID used to identify the request. If the server receives two StartClusterRequest (https://cloud.google.com/dataproc/docs/reference/rpc/ google.cloud.dataproc.v1#google.cloud.dataproc.v1.StartClusterRequest)s with the same id, then the second request will be ignored and the first google. longrunning.Operation created and stored in the backend is returned. Recommendation: Set this value to a UUID (https://en.wikipedia.org/wiki/ Universally_unique_identifier).The ID must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters. Corresponds to the JSON property requestId

Returns:

  • (String)


10187
10188
10189
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10187

def request_id
  @request_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10194
10195
10196
10197
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10194

def update!(**args)
  @cluster_uuid = args[:cluster_uuid] if args.key?(:cluster_uuid)
  @request_id = args[:request_id] if args.key?(:request_id)
end