Class: Google::Apis::DataprocV1::StateHistory
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::StateHistory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Historical state information.
Instance Attribute Summary collapse
-
#state ⇒ String
Output only.
-
#state_message ⇒ String
Output only.
-
#state_start_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StateHistory
constructor
A new instance of StateHistory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StateHistory
Returns a new instance of StateHistory.
10244 10245 10246 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10244 def initialize(**args) update!(**args) end |
Instance Attribute Details
#state ⇒ String
Output only. The state of the batch at this point in history.
Corresponds to the JSON property state
10232 10233 10234 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10232 def state @state end |
#state_message ⇒ String
Output only. Details about the state at this point in history.
Corresponds to the JSON property stateMessage
10237 10238 10239 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10237 def @state_message end |
#state_start_time ⇒ String
Output only. The time when the batch entered the historical state.
Corresponds to the JSON property stateStartTime
10242 10243 10244 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10242 def state_start_time @state_start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10249 10250 10251 10252 10253 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10249 def update!(**args) @state = args[:state] if args.key?(:state) @state_message = args[:state_message] if args.key?(:state_message) @state_start_time = args[:state_start_time] if args.key?(:state_start_time) end |