Class: Google::Apis::DataprocV1::SummarizeSessionSparkApplicationStageAttemptTasksResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Summary of tasks for a Spark Application stage attempt.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SummarizeSessionSparkApplicationStageAttemptTasksResponse

Returns a new instance of SummarizeSessionSparkApplicationStageAttemptTasksResponse.



11040
11041
11042
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11040

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stage_attempt_tasks_summaryGoogle::Apis::DataprocV1::StageAttemptTasksSummary

Data related to tasks summary for a Spark Stage Attempt Corresponds to the JSON property stageAttemptTasksSummary



11038
11039
11040
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11038

def stage_attempt_tasks_summary
  @stage_attempt_tasks_summary
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11045
11046
11047
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11045

def update!(**args)
  @stage_attempt_tasks_summary = args[:stage_attempt_tasks_summary] if args.key?(:stage_attempt_tasks_summary)
end