Class: Google::Apis::DataprocV1::SummarizeSparkApplicationStageAttemptTasksResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Summary of tasks for a Spark Application stage attempt.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SummarizeSparkApplicationStageAttemptTasksResponse

Returns a new instance of SummarizeSparkApplicationStageAttemptTasksResponse.



10816
10817
10818
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10816

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stage_attempt_tasks_summaryGoogle::Apis::DataprocV1::StageAttemptTasksSummary

Data related to tasks summary for a Spark Stage Attempt Corresponds to the JSON property stageAttemptTasksSummary



10814
10815
10816
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10814

def stage_attempt_tasks_summary
  @stage_attempt_tasks_summary
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10821
10822
10823
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10821

def update!(**args)
  @stage_attempt_tasks_summary = args[:stage_attempt_tasks_summary] if args.key?(:stage_attempt_tasks_summary)
end