Class: Google::Apis::DataprocV1::TemplateParameter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A configurable parameter that replaces one or more fields in the template. Parameterizable fields: - Labels - File uris - Job properties - Job arguments - Script variables - Main class (in HadoopJob and SparkJob) - Zone (in ClusterSelector)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TemplateParameter

Returns a new instance of TemplateParameter.



11846
11847
11848
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11846

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. Brief description of the parameter. Must not exceed 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


11805
11806
11807
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11805

def description
  @description
end

#fieldsArray<String>

Required. Paths to all fields that the parameter replaces. A field is allowed to appear in at most one parameter's list of field paths.A field path is similar in syntax to a google.protobuf.FieldMask. For example, a field path that references the zone field of a workflow template's cluster selector would be specified as placement.clusterSelector.zone.Also, field paths can reference fields using the following syntax: Values in maps can be referenced by key: labels'key' placement.clusterSelector.clusterLabels'key' placement. managedCluster.labels'key' placement.clusterSelector.clusterLabels'key' jobs' step-id'.labels'key' Jobs in the jobs list can be referenced by step-id: jobs' step-id'.hadoopJob.mainJarFileUri jobs'step-id'.hiveJob.queryFileUri jobs'step- id'.pySparkJob.mainPythonFileUri jobs'step-id'.hadoopJob.jarFileUris0 jobs' step-id'.hadoopJob.archiveUris0 jobs'step-id'.hadoopJob.fileUris0 jobs'step-id' .pySparkJob.pythonFileUris0 Items in repeated fields can be referenced by a zero-based index: jobs'step-id'.sparkJob.args0 Other examples: jobs'step-id'. hadoopJob.properties'key' jobs'step-id'.hadoopJob.args0 jobs'step-id'.hiveJob. scriptVariables'key' jobs'step-id'.hadoopJob.mainJarFileUri placement. clusterSelector.zoneIt may not be possible to parameterize maps and repeated fields in their entirety since only individual map values and individual items in repeated fields can be referenced. For example, the following field paths are invalid: placement.clusterSelector.clusterLabels jobs'step-id'.sparkJob. args Corresponds to the JSON property fields

Returns:

  • (Array<String>)


11830
11831
11832
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11830

def fields
  @fields
end

#nameString

Required. Parameter name. The parameter name is used as the key, and paired with the parameter value, which are passed to the template when the template is instantiated. The name must contain only capital letters (A-Z), numbers (0- 9), and underscores (_), and must not start with a number. The maximum length is 40 characters. Corresponds to the JSON property name

Returns:

  • (String)


11839
11840
11841
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11839

def name
  @name
end

#validationGoogle::Apis::DataprocV1::ParameterValidation

Configuration for parameter validation. Corresponds to the JSON property validation



11844
11845
11846
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11844

def validation
  @validation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11851
11852
11853
11854
11855
11856
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11851

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @fields = args[:fields] if args.key?(:fields)
  @name = args[:name] if args.key?(:name)
  @validation = args[:validation] if args.key?(:validation)
end