Class: Google::Apis::DataprocV1::WorkflowMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::WorkflowMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A Dataproc workflow template resource.
Instance Attribute Summary collapse
-
#cluster_name ⇒ String
Output only.
-
#cluster_uuid ⇒ String
Output only.
-
#create_cluster ⇒ Google::Apis::DataprocV1::ClusterOperation
The cluster operation triggered by a workflow.
-
#dag_end_time ⇒ String
Output only.
-
#dag_start_time ⇒ String
Output only.
-
#dag_timeout ⇒ String
Output only.
-
#delete_cluster ⇒ Google::Apis::DataprocV1::ClusterOperation
The cluster operation triggered by a workflow.
-
#end_time ⇒ String
Output only.
-
#graph ⇒ Google::Apis::DataprocV1::WorkflowGraph
The workflow graph.
-
#parameters ⇒ Hash<String,String>
Map from parameter names to values that were used for those parameters.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#template ⇒ String
Output only.
-
#version ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkflowMetadata
constructor
A new instance of WorkflowMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkflowMetadata
Returns a new instance of WorkflowMetadata.
12101 12102 12103 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12101 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_name ⇒ String
Output only. The name of the target cluster.
Corresponds to the JSON property clusterName
12024 12025 12026 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12024 def cluster_name @cluster_name end |
#cluster_uuid ⇒ String
Output only. The UUID of target cluster.
Corresponds to the JSON property clusterUuid
12029 12030 12031 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12029 def cluster_uuid @cluster_uuid end |
#create_cluster ⇒ Google::Apis::DataprocV1::ClusterOperation
The cluster operation triggered by a workflow.
Corresponds to the JSON property createCluster
12034 12035 12036 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12034 def create_cluster @create_cluster end |
#dag_end_time ⇒ String
Output only. DAG end time, only set for workflows with dag_timeout when DAG
ends.
Corresponds to the JSON property dagEndTime
12040 12041 12042 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12040 def dag_end_time @dag_end_time end |
#dag_start_time ⇒ String
Output only. DAG start time, only set for workflows with dag_timeout when DAG
begins.
Corresponds to the JSON property dagStartTime
12046 12047 12048 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12046 def dag_start_time @dag_start_time end |
#dag_timeout ⇒ String
Output only. The timeout duration for the DAG of jobs, expressed in seconds (
see JSON representation of duration (https://developers.google.com/protocol-
buffers/docs/proto3#json)).
Corresponds to the JSON property dagTimeout
12053 12054 12055 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12053 def dag_timeout @dag_timeout end |
#delete_cluster ⇒ Google::Apis::DataprocV1::ClusterOperation
The cluster operation triggered by a workflow.
Corresponds to the JSON property deleteCluster
12058 12059 12060 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12058 def delete_cluster @delete_cluster end |
#end_time ⇒ String
Output only. Workflow end time.
Corresponds to the JSON property endTime
12063 12064 12065 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12063 def end_time @end_time end |
#graph ⇒ Google::Apis::DataprocV1::WorkflowGraph
The workflow graph.
Corresponds to the JSON property graph
12068 12069 12070 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12068 def graph @graph end |
#parameters ⇒ Hash<String,String>
Map from parameter names to values that were used for those parameters.
Corresponds to the JSON property parameters
12073 12074 12075 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12073 def parameters @parameters end |
#start_time ⇒ String
Output only. Workflow start time.
Corresponds to the JSON property startTime
12078 12079 12080 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12078 def start_time @start_time end |
#state ⇒ String
Output only. The workflow state.
Corresponds to the JSON property state
12083 12084 12085 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12083 def state @state end |
#template ⇒ String
Output only. The resource name of the workflow template as described in https:/
/cloud.google.com/apis/design/resource_names. For projects.regions.
workflowTemplates, the resource name of the template has the following format:
projects/project_id/regions/region/workflowTemplates/template_id For
projects.locations.workflowTemplates, the resource name of the template has
the following format: projects/project_id/locations/location/
workflowTemplates/template_id
Corresponds to the JSON property template
12094 12095 12096 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12094 def template @template end |
#version ⇒ Fixnum
Output only. The version of template at the time of workflow instantiation.
Corresponds to the JSON property version
12099 12100 12101 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12099 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12106 12107 12108 12109 12110 12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12106 def update!(**args) @cluster_name = args[:cluster_name] if args.key?(:cluster_name) @cluster_uuid = args[:cluster_uuid] if args.key?(:cluster_uuid) @create_cluster = args[:create_cluster] if args.key?(:create_cluster) @dag_end_time = args[:dag_end_time] if args.key?(:dag_end_time) @dag_start_time = args[:dag_start_time] if args.key?(:dag_start_time) @dag_timeout = args[:dag_timeout] if args.key?(:dag_timeout) @delete_cluster = args[:delete_cluster] if args.key?(:delete_cluster) @end_time = args[:end_time] if args.key?(:end_time) @graph = args[:graph] if args.key?(:graph) @parameters = args[:parameters] if args.key?(:parameters) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @template = args[:template] if args.key?(:template) @version = args[:version] if args.key?(:version) end |