Class: Google::Apis::DataprocV1::WorkflowTemplatePlacement
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::WorkflowTemplatePlacement
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Specifies workflow execution target.Either managed_cluster or cluster_selector is required.
Instance Attribute Summary collapse
-
#cluster_selector ⇒ Google::Apis::DataprocV1::ClusterSelector
A selector that chooses target cluster for jobs based on metadata.
-
#managed_cluster ⇒ Google::Apis::DataprocV1::ManagedCluster
Cluster that is managed by the workflow.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkflowTemplatePlacement
constructor
A new instance of WorkflowTemplatePlacement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkflowTemplatePlacement
Returns a new instance of WorkflowTemplatePlacement.
12287 12288 12289 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12287 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_selector ⇒ Google::Apis::DataprocV1::ClusterSelector
A selector that chooses target cluster for jobs based on metadata.
Corresponds to the JSON property clusterSelector
12280 12281 12282 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12280 def cluster_selector @cluster_selector end |
#managed_cluster ⇒ Google::Apis::DataprocV1::ManagedCluster
Cluster that is managed by the workflow.
Corresponds to the JSON property managedCluster
12285 12286 12287 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12285 def managed_cluster @managed_cluster end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12292 12293 12294 12295 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12292 def update!(**args) @cluster_selector = args[:cluster_selector] if args.key?(:cluster_selector) @managed_cluster = args[:managed_cluster] if args.key?(:managed_cluster) end |