Class: Google::Apis::DataprocV1::AttachedDiskConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Specifies the config of attached disk options for single VM instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AttachedDiskConfig

Returns a new instance of AttachedDiskConfig.



700
701
702
# File 'lib/google/apis/dataproc_v1/classes.rb', line 700

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disk_size_gbFixnum

Optional. Disk size in GB. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


679
680
681
# File 'lib/google/apis/dataproc_v1/classes.rb', line 679

def disk_size_gb
  @disk_size_gb
end

#disk_typeString

Optional. Disk type. Corresponds to the JSON property diskType

Returns:

  • (String)


684
685
686
# File 'lib/google/apis/dataproc_v1/classes.rb', line 684

def disk_type
  @disk_type
end

#provisioned_iopsFixnum

Optional. Indicates how many IOPS to provision for the attached disk. This sets the number of I/O operations per second that the disk can handle. See https://cloud.google.com/compute/docs/disks/hyperdisks#hyperdisk-features Corresponds to the JSON property provisionedIops

Returns:

  • (Fixnum)


691
692
693
# File 'lib/google/apis/dataproc_v1/classes.rb', line 691

def provisioned_iops
  @provisioned_iops
end

#provisioned_throughputFixnum

Optional. Indicates how much throughput to provision for the attached disk. This sets the number of throughput mb per second that the disk can handle. See https://cloud.google.com/compute/docs/disks/hyperdisks#hyperdisk-features Corresponds to the JSON property provisionedThroughput

Returns:

  • (Fixnum)


698
699
700
# File 'lib/google/apis/dataproc_v1/classes.rb', line 698

def provisioned_throughput
  @provisioned_throughput
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



705
706
707
708
709
710
# File 'lib/google/apis/dataproc_v1/classes.rb', line 705

def update!(**args)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @disk_type = args[:disk_type] if args.key?(:disk_type)
  @provisioned_iops = args[:provisioned_iops] if args.key?(:provisioned_iops)
  @provisioned_throughput = args[:provisioned_throughput] if args.key?(:provisioned_throughput)
end