Class: Google::Apis::DataprocV1::AttachedDiskConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::AttachedDiskConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Specifies the config of attached disk options for single VM instance.
Instance Attribute Summary collapse
-
#disk_size_gb ⇒ Fixnum
Optional.
-
#disk_type ⇒ String
Optional.
-
#provisioned_iops ⇒ Fixnum
Optional.
-
#provisioned_throughput ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AttachedDiskConfig
constructor
A new instance of AttachedDiskConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AttachedDiskConfig
Returns a new instance of AttachedDiskConfig.
701 702 703 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 701 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disk_size_gb ⇒ Fixnum
Optional. Disk size in GB.
Corresponds to the JSON property diskSizeGb
680 681 682 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 680 def disk_size_gb @disk_size_gb end |
#disk_type ⇒ String
Optional. Disk type.
Corresponds to the JSON property diskType
685 686 687 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 685 def disk_type @disk_type end |
#provisioned_iops ⇒ Fixnum
Optional. Indicates how many IOPS to provision for the attached disk. This
sets the number of I/O operations per second that the disk can handle. See
https://cloud.google.com/compute/docs/disks/hyperdisks#hyperdisk-features
Corresponds to the JSON property provisionedIops
692 693 694 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 692 def provisioned_iops @provisioned_iops end |
#provisioned_throughput ⇒ Fixnum
Optional. Indicates how much throughput to provision for the attached disk.
This sets the number of throughput mb per second that the disk can handle. See
https://cloud.google.com/compute/docs/disks/hyperdisks#hyperdisk-features
Corresponds to the JSON property provisionedThroughput
699 700 701 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 699 def provisioned_throughput @provisioned_throughput end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
706 707 708 709 710 711 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 706 def update!(**args) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @disk_type = args[:disk_type] if args.key?(:disk_type) @provisioned_iops = args[:provisioned_iops] if args.key?(:provisioned_iops) @provisioned_throughput = args[:provisioned_throughput] if args.key?(:provisioned_throughput) end |