Class: Google::Apis::DataprocV1::AuthenticationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Authentication configuration for a workload is used to set the default identity for the workload execution. The config specifies the type of identity (service account or user) that will be used by workloads to access resources on the project(s).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthenticationConfig

Returns a new instance of AuthenticationConfig.



685
686
687
# File 'lib/google/apis/dataproc_v1/classes.rb', line 685

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#user_workload_authentication_typeString

Optional. Authentication type for the user workload running in containers. Corresponds to the JSON property userWorkloadAuthenticationType

Returns:

  • (String)


683
684
685
# File 'lib/google/apis/dataproc_v1/classes.rb', line 683

def user_workload_authentication_type
  @user_workload_authentication_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



690
691
692
# File 'lib/google/apis/dataproc_v1/classes.rb', line 690

def update!(**args)
  @user_workload_authentication_type = args[:user_workload_authentication_type] if args.key?(:user_workload_authentication_type)
end