Class: Google::Apis::DataprocV1::BasicYarnAutoscalingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Basic autoscaling configurations for YARN.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BasicYarnAutoscalingConfig

Returns a new instance of BasicYarnAutoscalingConfig.



988
989
990
# File 'lib/google/apis/dataproc_v1/classes.rb', line 988

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#graceful_decommission_timeoutString

Required. Timeout for YARN graceful decommissioning of Node Managers. Specifies the duration to wait for jobs to complete before forcefully removing workers (and potentially interrupting jobs). Only applicable to downscaling operations.Bounds: 0s, 1d. Corresponds to the JSON property gracefulDecommissionTimeout

Returns:

  • (String)


946
947
948
# File 'lib/google/apis/dataproc_v1/classes.rb', line 946

def graceful_decommission_timeout
  @graceful_decommission_timeout
end

#scale_down_factorFloat

Required. Fraction of average YARN pending memory in the last cooldown period for which to remove workers. A scale-down factor of 1 will result in scaling down so that there is no available memory remaining after the update (more aggressive scaling). A scale-down factor of 0 disables removing workers, which can be beneficial for autoscaling a single job. See How autoscaling works ( https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/ autoscaling#how_autoscaling_works) for more information.Bounds: 0.0, 1.0. Corresponds to the JSON property scaleDownFactor

Returns:

  • (Float)


957
958
959
# File 'lib/google/apis/dataproc_v1/classes.rb', line 957

def scale_down_factor
  @scale_down_factor
end

#scale_down_min_worker_fractionFloat

Optional. Minimum scale-down threshold as a fraction of total cluster size before scaling occurs. For example, in a 20-worker cluster, a threshold of 0.1 means the autoscaler must recommend at least a 2 worker scale-down for the cluster to scale. A threshold of 0 means the autoscaler will scale down on any recommended change.Bounds: 0.0, 1.0. Default: 0.0. Corresponds to the JSON property scaleDownMinWorkerFraction

Returns:

  • (Float)


966
967
968
# File 'lib/google/apis/dataproc_v1/classes.rb', line 966

def scale_down_min_worker_fraction
  @scale_down_min_worker_fraction
end

#scale_up_factorFloat

Required. Fraction of average YARN pending memory in the last cooldown period for which to add workers. A scale-up factor of 1.0 will result in scaling up so that there is no pending memory remaining after the update (more aggressive scaling). A scale-up factor closer to 0 will result in a smaller magnitude of scaling up (less aggressive scaling). See How autoscaling works (https://cloud. google.com/dataproc/docs/concepts/configuring-clusters/autoscaling# how_autoscaling_works) for more information.Bounds: 0.0, 1.0. Corresponds to the JSON property scaleUpFactor

Returns:

  • (Float)


977
978
979
# File 'lib/google/apis/dataproc_v1/classes.rb', line 977

def scale_up_factor
  @scale_up_factor
end

#scale_up_min_worker_fractionFloat

Optional. Minimum scale-up threshold as a fraction of total cluster size before scaling occurs. For example, in a 20-worker cluster, a threshold of 0.1 means the autoscaler must recommend at least a 2-worker scale-up for the cluster to scale. A threshold of 0 means the autoscaler will scale up on any recommended change.Bounds: 0.0, 1.0. Default: 0.0. Corresponds to the JSON property scaleUpMinWorkerFraction

Returns:

  • (Float)


986
987
988
# File 'lib/google/apis/dataproc_v1/classes.rb', line 986

def scale_up_min_worker_fraction
  @scale_up_min_worker_fraction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



993
994
995
996
997
998
999
# File 'lib/google/apis/dataproc_v1/classes.rb', line 993

def update!(**args)
  @graceful_decommission_timeout = args[:graceful_decommission_timeout] if args.key?(:graceful_decommission_timeout)
  @scale_down_factor = args[:scale_down_factor] if args.key?(:scale_down_factor)
  @scale_down_min_worker_fraction = args[:scale_down_min_worker_fraction] if args.key?(:scale_down_min_worker_fraction)
  @scale_up_factor = args[:scale_up_factor] if args.key?(:scale_up_factor)
  @scale_up_min_worker_fraction = args[:scale_up_min_worker_fraction] if args.key?(:scale_up_min_worker_fraction)
end