Class: Google::Apis::DataprocV1::BasicYarnAutoscalingConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::BasicYarnAutoscalingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Basic autoscaling configurations for YARN.
Instance Attribute Summary collapse
-
#graceful_decommission_timeout ⇒ String
Required.
-
#scale_down_factor ⇒ Float
Required.
-
#scale_down_min_worker_fraction ⇒ Float
Optional.
-
#scale_up_factor ⇒ Float
Required.
-
#scale_up_min_worker_fraction ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BasicYarnAutoscalingConfig
constructor
A new instance of BasicYarnAutoscalingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BasicYarnAutoscalingConfig
Returns a new instance of BasicYarnAutoscalingConfig.
948 949 950 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 948 def initialize(**args) update!(**args) end |
Instance Attribute Details
#graceful_decommission_timeout ⇒ String
Required. Timeout for YARN graceful decommissioning of Node Managers.
Specifies the duration to wait for jobs to complete before forcefully removing
workers (and potentially interrupting jobs). Only applicable to downscaling
operations.Bounds: 0s, 1d.
Corresponds to the JSON property gracefulDecommissionTimeout
906 907 908 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 906 def graceful_decommission_timeout @graceful_decommission_timeout end |
#scale_down_factor ⇒ Float
Required. Fraction of average YARN pending memory in the last cooldown period
for which to remove workers. A scale-down factor of 1 will result in scaling
down so that there is no available memory remaining after the update (more
aggressive scaling). A scale-down factor of 0 disables removing workers, which
can be beneficial for autoscaling a single job. See How autoscaling works (
https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/
autoscaling#how_autoscaling_works) for more information.Bounds: 0.0, 1.0.
Corresponds to the JSON property scaleDownFactor
917 918 919 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 917 def scale_down_factor @scale_down_factor end |
#scale_down_min_worker_fraction ⇒ Float
Optional. Minimum scale-down threshold as a fraction of total cluster size
before scaling occurs. For example, in a 20-worker cluster, a threshold of 0.1
means the autoscaler must recommend at least a 2 worker scale-down for the
cluster to scale. A threshold of 0 means the autoscaler will scale down on any
recommended change.Bounds: 0.0, 1.0. Default: 0.0.
Corresponds to the JSON property scaleDownMinWorkerFraction
926 927 928 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 926 def scale_down_min_worker_fraction @scale_down_min_worker_fraction end |
#scale_up_factor ⇒ Float
Required. Fraction of average YARN pending memory in the last cooldown period
for which to add workers. A scale-up factor of 1.0 will result in scaling up
so that there is no pending memory remaining after the update (more aggressive
scaling). A scale-up factor closer to 0 will result in a smaller magnitude of
scaling up (less aggressive scaling). See How autoscaling works (https://cloud.
google.com/dataproc/docs/concepts/configuring-clusters/autoscaling#
how_autoscaling_works) for more information.Bounds: 0.0, 1.0.
Corresponds to the JSON property scaleUpFactor
937 938 939 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 937 def scale_up_factor @scale_up_factor end |
#scale_up_min_worker_fraction ⇒ Float
Optional. Minimum scale-up threshold as a fraction of total cluster size
before scaling occurs. For example, in a 20-worker cluster, a threshold of 0.1
means the autoscaler must recommend at least a 2-worker scale-up for the
cluster to scale. A threshold of 0 means the autoscaler will scale up on any
recommended change.Bounds: 0.0, 1.0. Default: 0.0.
Corresponds to the JSON property scaleUpMinWorkerFraction
946 947 948 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 946 def scale_up_min_worker_fraction @scale_up_min_worker_fraction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
953 954 955 956 957 958 959 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 953 def update!(**args) @graceful_decommission_timeout = args[:graceful_decommission_timeout] if args.key?(:graceful_decommission_timeout) @scale_down_factor = args[:scale_down_factor] if args.key?(:scale_down_factor) @scale_down_min_worker_fraction = args[:scale_down_min_worker_fraction] if args.key?(:scale_down_min_worker_fraction) @scale_up_factor = args[:scale_up_factor] if args.key?(:scale_up_factor) @scale_up_min_worker_fraction = args[:scale_up_min_worker_fraction] if args.key?(:scale_up_min_worker_fraction) end |