Class: Google::Apis::DataprocV1::Cluster
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::Cluster
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Describes the identifying information, config, and status of a Dataproc cluster
Instance Attribute Summary collapse
-
#cluster_name ⇒ String
Required.
-
#cluster_uuid ⇒ String
Output only.
-
#config ⇒ Google::Apis::DataprocV1::ClusterConfig
The cluster config.
-
#labels ⇒ Hash<String,String>
Optional.
-
#metrics ⇒ Google::Apis::DataprocV1::ClusterMetrics
Contains cluster daemon metrics, such as HDFS and YARN stats.Beta Feature: This report is available for testing purposes only.
-
#project_id ⇒ String
Required.
-
#status ⇒ Google::Apis::DataprocV1::ClusterStatus
The status of a cluster and its instances.
-
#status_history ⇒ Array<Google::Apis::DataprocV1::ClusterStatus>
Output only.
-
#virtual_cluster_config ⇒ Google::Apis::DataprocV1::VirtualClusterConfig
The Dataproc cluster config for a cluster that does not directly control the underlying compute resources, such as a Dataproc-on-GKE cluster (https://cloud. google.com/dataproc/docs/guides/dpgke/dataproc-gke-overview).
Instance Method Summary collapse
-
#initialize(**args) ⇒ Cluster
constructor
A new instance of Cluster.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Cluster
Returns a new instance of Cluster.
1348 1349 1350 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1348 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_name ⇒ String
Required. The cluster name, which must be unique within a project. The name
must start with a lowercase letter, and can contain up to 51 lowercase letters,
numbers, and hyphens. It cannot end with a hyphen. The name of a deleted
cluster can be reused.
Corresponds to the JSON property clusterName
1297 1298 1299 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1297 def cluster_name @cluster_name end |
#cluster_uuid ⇒ String
Output only. A cluster UUID (Unique Universal Identifier). Dataproc generates
this value when it creates the cluster.
Corresponds to the JSON property clusterUuid
1303 1304 1305 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1303 def cluster_uuid @cluster_uuid end |
#config ⇒ Google::Apis::DataprocV1::ClusterConfig
The cluster config.
Corresponds to the JSON property config
1308 1309 1310 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1308 def config @config end |
#labels ⇒ Hash<String,String>
Optional. The labels to associate with this cluster. Label keys must contain 1
to 63 characters, and must conform to RFC 1035 (https://www.ietf.org/rfc/
rfc1035.txt). Label values may be empty, but, if present, must contain 1 to 63
characters, and must conform to RFC 1035 (https://www.ietf.org/rfc/rfc1035.txt)
. No more than 32 labels can be associated with a cluster.
Corresponds to the JSON property labels
1317 1318 1319 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1317 def labels @labels end |
#metrics ⇒ Google::Apis::DataprocV1::ClusterMetrics
Contains cluster daemon metrics, such as HDFS and YARN stats.Beta Feature:
This report is available for testing purposes only. It may be changed before
final release.
Corresponds to the JSON property metrics
1324 1325 1326 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1324 def metrics @metrics end |
#project_id ⇒ String
Required. The Google Cloud Platform project ID that the cluster belongs to.
Corresponds to the JSON property projectId
1329 1330 1331 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1329 def project_id @project_id end |
#status ⇒ Google::Apis::DataprocV1::ClusterStatus
The status of a cluster and its instances.
Corresponds to the JSON property status
1334 1335 1336 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1334 def status @status end |
#status_history ⇒ Array<Google::Apis::DataprocV1::ClusterStatus>
Output only. The previous cluster status.
Corresponds to the JSON property statusHistory
1339 1340 1341 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1339 def status_history @status_history end |
#virtual_cluster_config ⇒ Google::Apis::DataprocV1::VirtualClusterConfig
The Dataproc cluster config for a cluster that does not directly control the
underlying compute resources, such as a Dataproc-on-GKE cluster (https://cloud.
google.com/dataproc/docs/guides/dpgke/dataproc-gke-overview).
Corresponds to the JSON property virtualClusterConfig
1346 1347 1348 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1346 def virtual_cluster_config @virtual_cluster_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1353 def update!(**args) @cluster_name = args[:cluster_name] if args.key?(:cluster_name) @cluster_uuid = args[:cluster_uuid] if args.key?(:cluster_uuid) @config = args[:config] if args.key?(:config) @labels = args[:labels] if args.key?(:labels) @metrics = args[:metrics] if args.key?(:metrics) @project_id = args[:project_id] if args.key?(:project_id) @status = args[:status] if args.key?(:status) @status_history = args[:status_history] if args.key?(:status_history) @virtual_cluster_config = args[:virtual_cluster_config] if args.key?(:virtual_cluster_config) end |