Class: Google::Apis::DataprocV1::ClusterConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::ClusterConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
The cluster config.
Instance Attribute Summary collapse
-
#autoscaling_config ⇒ Google::Apis::DataprocV1::AutoscalingConfig
Autoscaling Policy config associated with the cluster.
-
#auxiliary_node_groups ⇒ Array<Google::Apis::DataprocV1::AuxiliaryNodeGroup>
Optional.
-
#cluster_tier ⇒ String
Optional.
-
#cluster_type ⇒ String
Optional.
-
#config_bucket ⇒ String
Optional.
-
#dataproc_metric_config ⇒ Google::Apis::DataprocV1::DataprocMetricConfig
Metric config.
-
#diagnostic_bucket ⇒ String
Optional.
-
#encryption_config ⇒ Google::Apis::DataprocV1::EncryptionConfig
Encryption settings for the cluster.
-
#endpoint_config ⇒ Google::Apis::DataprocV1::EndpointConfig
Endpoint config for this cluster Corresponds to the JSON property
endpointConfig. -
#engine ⇒ String
Optional.
-
#gce_cluster_config ⇒ Google::Apis::DataprocV1::GceClusterConfig
Common config settings for resources of Compute Engine cluster instances, applicable to all instances in the cluster.
-
#gke_cluster_config ⇒ Google::Apis::DataprocV1::GkeClusterConfig
The cluster's GKE config.
-
#initialization_actions ⇒ Array<Google::Apis::DataprocV1::NodeInitializationAction>
Optional.
-
#lifecycle_config ⇒ Google::Apis::DataprocV1::LifecycleConfig
Specifies the cluster auto-delete schedule configuration.
-
#master_config ⇒ Google::Apis::DataprocV1::InstanceGroupConfig
The config settings for Compute Engine resources in an instance group, such as a master or worker group.
-
#metastore_config ⇒ Google::Apis::DataprocV1::MetastoreConfig
Specifies a Metastore configuration.
-
#secondary_worker_config ⇒ Google::Apis::DataprocV1::InstanceGroupConfig
The config settings for Compute Engine resources in an instance group, such as a master or worker group.
-
#security_config ⇒ Google::Apis::DataprocV1::SecurityConfig
Security related configuration, including encryption, Kerberos, etc.
-
#software_config ⇒ Google::Apis::DataprocV1::SoftwareConfig
Specifies the selection and config of software inside the cluster.
-
#temp_bucket ⇒ String
Optional.
-
#worker_config ⇒ Google::Apis::DataprocV1::InstanceGroupConfig
The config settings for Compute Engine resources in an instance group, such as a master or worker group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClusterConfig
constructor
A new instance of ClusterConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ClusterConfig
Returns a new instance of ClusterConfig.
1552 1553 1554 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1552 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoscaling_config ⇒ Google::Apis::DataprocV1::AutoscalingConfig
Autoscaling Policy config associated with the cluster.
Corresponds to the JSON property autoscalingConfig
1418 1419 1420 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1418 def autoscaling_config @autoscaling_config end |
#auxiliary_node_groups ⇒ Array<Google::Apis::DataprocV1::AuxiliaryNodeGroup>
Optional. The node group settings.
Corresponds to the JSON property auxiliaryNodeGroups
1423 1424 1425 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1423 def auxiliary_node_groups @auxiliary_node_groups end |
#cluster_tier ⇒ String
Optional. The cluster tier.
Corresponds to the JSON property clusterTier
1428 1429 1430 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1428 def cluster_tier @cluster_tier end |
#cluster_type ⇒ String
Optional. The type of the cluster.
Corresponds to the JSON property clusterType
1433 1434 1435 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1433 def cluster_type @cluster_type end |
#config_bucket ⇒ String
Optional. A Cloud Storage bucket used to stage job dependencies, config files,
and job driver console output. If you do not specify a staging bucket, the
service will determine a Cloud Storage location (US, ASIA, or EU) for your
cluster's staging bucket according to the Compute Engine zone where your
cluster is deployed, and then create and manage this project-level, per-
location bucket (see staging and temp buckets (https://cloud.google.com/
dataproc/docs/concepts/configuring-clusters/staging-bucket)). This field
requires a Cloud Storage bucket name, not a gs://... URI to a Cloud Storage
bucket.
Corresponds to the JSON property configBucket
1446 1447 1448 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1446 def config_bucket @config_bucket end |
#dataproc_metric_config ⇒ Google::Apis::DataprocV1::DataprocMetricConfig
Metric config.
Corresponds to the JSON property dataprocMetricConfig
1451 1452 1453 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1451 def dataproc_metric_config @dataproc_metric_config end |
#diagnostic_bucket ⇒ String
Optional. A Cloud Storage bucket used to collect checkpoint diagnostic data (
https://cloud.google.com/dataproc/docs/support/diagnose-clusters#
checkpoint_diagnostic_data). If you do not specify a diagnostic bucket, The
service will use the temp bucket to collect the checkpoint diagnostic data.
This field requires a Cloud Storage bucket name, not a gs://... URI to a Cloud
Storage bucket.
Corresponds to the JSON property diagnosticBucket
1461 1462 1463 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1461 def diagnostic_bucket @diagnostic_bucket end |
#encryption_config ⇒ Google::Apis::DataprocV1::EncryptionConfig
Encryption settings for the cluster.
Corresponds to the JSON property encryptionConfig
1466 1467 1468 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1466 def encryption_config @encryption_config end |
#endpoint_config ⇒ Google::Apis::DataprocV1::EndpointConfig
Endpoint config for this cluster
Corresponds to the JSON property endpointConfig
1471 1472 1473 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1471 def endpoint_config @endpoint_config end |
#engine ⇒ String
Optional. The cluster engine.
Corresponds to the JSON property engine
1476 1477 1478 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1476 def engine @engine end |
#gce_cluster_config ⇒ Google::Apis::DataprocV1::GceClusterConfig
Common config settings for resources of Compute Engine cluster instances,
applicable to all instances in the cluster.
Corresponds to the JSON property gceClusterConfig
1482 1483 1484 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1482 def gce_cluster_config @gce_cluster_config end |
#gke_cluster_config ⇒ Google::Apis::DataprocV1::GkeClusterConfig
The cluster's GKE config.
Corresponds to the JSON property gkeClusterConfig
1487 1488 1489 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1487 def gke_cluster_config @gke_cluster_config end |
#initialization_actions ⇒ Array<Google::Apis::DataprocV1::NodeInitializationAction>
Optional. Commands to execute on each node after config is completed. By
default, executables are run on master and all worker nodes. You can test a
node's role metadata to run an executable on a master or worker node, as shown
below using curl (you can also use wget): ROLE=$(curl -H Metadata-Flavor:
Google http://metadata/computeMetadata/v1/instance/attributes/dataproc-role)
if [[ "$ROLE" == 'Master' ]]; then ... master specific actions ... else ...
worker specific actions ... fi
Corresponds to the JSON property initializationActions
1498 1499 1500 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1498 def initialization_actions @initialization_actions end |
#lifecycle_config ⇒ Google::Apis::DataprocV1::LifecycleConfig
Specifies the cluster auto-delete schedule configuration.
Corresponds to the JSON property lifecycleConfig
1503 1504 1505 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1503 def lifecycle_config @lifecycle_config end |
#master_config ⇒ Google::Apis::DataprocV1::InstanceGroupConfig
The config settings for Compute Engine resources in an instance group, such as
a master or worker group.
Corresponds to the JSON property masterConfig
1509 1510 1511 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1509 def master_config @master_config end |
#metastore_config ⇒ Google::Apis::DataprocV1::MetastoreConfig
Specifies a Metastore configuration.
Corresponds to the JSON property metastoreConfig
1514 1515 1516 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1514 def @metastore_config end |
#secondary_worker_config ⇒ Google::Apis::DataprocV1::InstanceGroupConfig
The config settings for Compute Engine resources in an instance group, such as
a master or worker group.
Corresponds to the JSON property secondaryWorkerConfig
1520 1521 1522 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1520 def secondary_worker_config @secondary_worker_config end |
#security_config ⇒ Google::Apis::DataprocV1::SecurityConfig
Security related configuration, including encryption, Kerberos, etc.
Corresponds to the JSON property securityConfig
1525 1526 1527 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1525 def security_config @security_config end |
#software_config ⇒ Google::Apis::DataprocV1::SoftwareConfig
Specifies the selection and config of software inside the cluster.
Corresponds to the JSON property softwareConfig
1530 1531 1532 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1530 def software_config @software_config end |
#temp_bucket ⇒ String
Optional. A Cloud Storage bucket used to store ephemeral cluster and jobs data,
such as Spark and MapReduce history files. If you do not specify a temp
bucket, the service will determine a Cloud Storage location (US, ASIA, or EU)
for your cluster's temp bucket according to the Compute Engine zone where your
cluster is deployed, and then create and manage this project-level, per-
location bucket. The default bucket has a TTL of 90 days, but you can use any
TTL (or none) if you specify a bucket (see staging and temp buckets (https://
cloud.google.com/dataproc/docs/concepts/configuring-clusters/staging-bucket)).
This field requires a Cloud Storage bucket name, not a gs://... URI to a Cloud
Storage bucket.
Corresponds to the JSON property tempBucket
1544 1545 1546 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1544 def temp_bucket @temp_bucket end |
#worker_config ⇒ Google::Apis::DataprocV1::InstanceGroupConfig
The config settings for Compute Engine resources in an instance group, such as
a master or worker group.
Corresponds to the JSON property workerConfig
1550 1551 1552 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1550 def worker_config @worker_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1557 def update!(**args) @autoscaling_config = args[:autoscaling_config] if args.key?(:autoscaling_config) @auxiliary_node_groups = args[:auxiliary_node_groups] if args.key?(:auxiliary_node_groups) @cluster_tier = args[:cluster_tier] if args.key?(:cluster_tier) @cluster_type = args[:cluster_type] if args.key?(:cluster_type) @config_bucket = args[:config_bucket] if args.key?(:config_bucket) @dataproc_metric_config = args[:dataproc_metric_config] if args.key?(:dataproc_metric_config) @diagnostic_bucket = args[:diagnostic_bucket] if args.key?(:diagnostic_bucket) @encryption_config = args[:encryption_config] if args.key?(:encryption_config) @endpoint_config = args[:endpoint_config] if args.key?(:endpoint_config) @engine = args[:engine] if args.key?(:engine) @gce_cluster_config = args[:gce_cluster_config] if args.key?(:gce_cluster_config) @gke_cluster_config = args[:gke_cluster_config] if args.key?(:gke_cluster_config) @initialization_actions = args[:initialization_actions] if args.key?(:initialization_actions) @lifecycle_config = args[:lifecycle_config] if args.key?(:lifecycle_config) @master_config = args[:master_config] if args.key?(:master_config) @metastore_config = args[:metastore_config] if args.key?(:metastore_config) @secondary_worker_config = args[:secondary_worker_config] if args.key?(:secondary_worker_config) @security_config = args[:security_config] if args.key?(:security_config) @software_config = args[:software_config] if args.key?(:software_config) @temp_bucket = args[:temp_bucket] if args.key?(:temp_bucket) @worker_config = args[:worker_config] if args.key?(:worker_config) end |