Class: Google::Apis::DataprocV1::CohortInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Information about the cohort that the workload belongs to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CohortInfo

Returns a new instance of CohortInfo.



1846
1847
1848
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1846

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cohortString

Output only. Final cohort that was used to tune the workload. Corresponds to the JSON property cohort

Returns:

  • (String)


1839
1840
1841
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1839

def cohort
  @cohort
end

#cohort_sourceString

Output only. Source of the cohort. Corresponds to the JSON property cohortSource

Returns:

  • (String)


1844
1845
1846
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1844

def cohort_source
  @cohort_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1851
1852
1853
1854
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1851

def update!(**args)
  @cohort = args[:cohort] if args.key?(:cohort)
  @cohort_source = args[:cohort_source] if args.key?(:cohort_source)
end