Class: Google::Apis::DataprocV1::DiagnoseClusterRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::DiagnoseClusterRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A request to collect cluster diagnostic information.
Instance Attribute Summary collapse
-
#diagnosis_interval ⇒ Google::Apis::DataprocV1::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).The start must be less than or equal to the end.
-
#job ⇒ String
Optional.
-
#jobs ⇒ Array<String>
Optional.
-
#tarball_access ⇒ String
Optional.
-
#tarball_gcs_dir ⇒ String
Optional.
-
#yarn_application_id ⇒ String
Optional.
-
#yarn_application_ids ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiagnoseClusterRequest
constructor
A new instance of DiagnoseClusterRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiagnoseClusterRequest
Returns a new instance of DiagnoseClusterRequest.
2066 2067 2068 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2066 def initialize(**args) update!(**args) end |
Instance Attribute Details
#diagnosis_interval ⇒ Google::Apis::DataprocV1::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive).The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property diagnosisInterval
2027 2028 2029 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2027 def diagnosis_interval @diagnosis_interval end |
#job ⇒ String
Optional. DEPRECATED Specifies the job on which diagnosis is to be performed.
Format: projects/project/regions/region/jobs/job
Corresponds to the JSON property job
2033 2034 2035 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2033 def job @job end |
#jobs ⇒ Array<String>
Optional. Specifies a list of jobs on which diagnosis is to be performed.
Format: projects/project/regions/region/jobs/job
Corresponds to the JSON property jobs
2039 2040 2041 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2039 def jobs @jobs end |
#tarball_access ⇒ String
Optional. (Optional) The access type to the diagnostic tarball. If not
specified, falls back to default access of the bucket
Corresponds to the JSON property tarballAccess
2045 2046 2047 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2045 def tarball_access @tarball_access end |
#tarball_gcs_dir ⇒ String
Optional. (Optional) The output Cloud Storage directory for the diagnostic
tarball. If not specified, a task-specific directory in the cluster's staging
bucket will be used.
Corresponds to the JSON property tarballGcsDir
2052 2053 2054 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2052 def tarball_gcs_dir @tarball_gcs_dir end |
#yarn_application_id ⇒ String
Optional. DEPRECATED Specifies the yarn application on which diagnosis is to
be performed.
Corresponds to the JSON property yarnApplicationId
2058 2059 2060 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2058 def yarn_application_id @yarn_application_id end |
#yarn_application_ids ⇒ Array<String>
Optional. Specifies a list of yarn applications on which diagnosis is to be
performed.
Corresponds to the JSON property yarnApplicationIds
2064 2065 2066 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2064 def yarn_application_ids @yarn_application_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2071 2072 2073 2074 2075 2076 2077 2078 2079 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2071 def update!(**args) @diagnosis_interval = args[:diagnosis_interval] if args.key?(:diagnosis_interval) @job = args[:job] if args.key?(:job) @jobs = args[:jobs] if args.key?(:jobs) @tarball_access = args[:tarball_access] if args.key?(:tarball_access) @tarball_gcs_dir = args[:tarball_gcs_dir] if args.key?(:tarball_gcs_dir) @yarn_application_id = args[:yarn_application_id] if args.key?(:yarn_application_id) @yarn_application_ids = args[:yarn_application_ids] if args.key?(:yarn_application_ids) end |