Class: Google::Apis::DataprocV1::DiagnoseClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A request to collect cluster diagnostic information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiagnoseClusterRequest

Returns a new instance of DiagnoseClusterRequest.



1984
1985
1986
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1984

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#diagnosis_intervalGoogle::Apis::DataprocV1::Interval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property diagnosisInterval



1945
1946
1947
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1945

def diagnosis_interval
  @diagnosis_interval
end

#jobString

Optional. DEPRECATED Specifies the job on which diagnosis is to be performed. Format: projects/project/regions/region/jobs/job Corresponds to the JSON property job

Returns:

  • (String)


1951
1952
1953
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1951

def job
  @job
end

#jobsArray<String>

Optional. Specifies a list of jobs on which diagnosis is to be performed. Format: projects/project/regions/region/jobs/job Corresponds to the JSON property jobs

Returns:

  • (Array<String>)


1957
1958
1959
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1957

def jobs
  @jobs
end

#tarball_accessString

Optional. (Optional) The access type to the diagnostic tarball. If not specified, falls back to default access of the bucket Corresponds to the JSON property tarballAccess

Returns:

  • (String)


1963
1964
1965
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1963

def tarball_access
  @tarball_access
end

#tarball_gcs_dirString

Optional. (Optional) The output Cloud Storage directory for the diagnostic tarball. If not specified, a task-specific directory in the cluster's staging bucket will be used. Corresponds to the JSON property tarballGcsDir

Returns:

  • (String)


1970
1971
1972
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1970

def tarball_gcs_dir
  @tarball_gcs_dir
end

#yarn_application_idString

Optional. DEPRECATED Specifies the yarn application on which diagnosis is to be performed. Corresponds to the JSON property yarnApplicationId

Returns:

  • (String)


1976
1977
1978
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1976

def yarn_application_id
  @yarn_application_id
end

#yarn_application_idsArray<String>

Optional. Specifies a list of yarn applications on which diagnosis is to be performed. Corresponds to the JSON property yarnApplicationIds

Returns:

  • (Array<String>)


1982
1983
1984
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1982

def yarn_application_ids
  @yarn_application_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1989
1990
1991
1992
1993
1994
1995
1996
1997
# File 'lib/google/apis/dataproc_v1/classes.rb', line 1989

def update!(**args)
  @diagnosis_interval = args[:diagnosis_interval] if args.key?(:diagnosis_interval)
  @job = args[:job] if args.key?(:job)
  @jobs = args[:jobs] if args.key?(:jobs)
  @tarball_access = args[:tarball_access] if args.key?(:tarball_access)
  @tarball_gcs_dir = args[:tarball_gcs_dir] if args.key?(:tarball_gcs_dir)
  @yarn_application_id = args[:yarn_application_id] if args.key?(:yarn_application_id)
  @yarn_application_ids = args[:yarn_application_ids] if args.key?(:yarn_application_ids)
end