Class: Google::Apis::DataprocV1::DiskConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Specifies the config of boot disk and attached disk options for a group of VM instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskConfig

Returns a new instance of DiskConfig.



2153
2154
2155
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2153

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attached_disk_configsArray<Google::Apis::DataprocV1::AttachedDiskConfig>

Optional. A list of attached disk configs for a group of VM instances. Corresponds to the JSON property attachedDiskConfigs



2105
2106
2107
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2105

def attached_disk_configs
  @attached_disk_configs
end

#boot_disk_provisioned_iopsFixnum

Optional. Indicates how many IOPS to provision for the disk. This sets the number of I/O operations per second that the disk can handle. This field is supported only if boot_disk_type is hyperdisk-balanced. Corresponds to the JSON property bootDiskProvisionedIops

Returns:

  • (Fixnum)


2112
2113
2114
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2112

def boot_disk_provisioned_iops
  @boot_disk_provisioned_iops
end

#boot_disk_provisioned_throughputFixnum

Optional. Indicates how much throughput to provision for the disk. This sets the number of throughput mb per second that the disk can handle. Values must be greater than or equal to 1. This field is supported only if boot_disk_type is hyperdisk-balanced. Corresponds to the JSON property bootDiskProvisionedThroughput

Returns:

  • (Fixnum)


2120
2121
2122
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2120

def boot_disk_provisioned_throughput
  @boot_disk_provisioned_throughput
end

#boot_disk_size_gbFixnum

Optional. Size in GB of the boot disk (default is 500GB). Corresponds to the JSON property bootDiskSizeGb

Returns:

  • (Fixnum)


2125
2126
2127
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2125

def boot_disk_size_gb
  @boot_disk_size_gb
end

#boot_disk_typeString

Optional. Type of the boot disk (default is pd-standard). Valid values: pd- balanced (Persistent Disk Balanced Solid State Drive), pd-ssd (Persistent Disk Solid State Drive), or pd-standard (Persistent Disk Hard Disk Drive). See Disk types (https://cloud.google.com/compute/docs/disks#disk-types). Corresponds to the JSON property bootDiskType

Returns:

  • (String)


2133
2134
2135
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2133

def boot_disk_type
  @boot_disk_type
end

#local_ssd_interfaceString

Optional. Interface type of local SSDs (default is scsi). Valid values: scsi ( Small Computer System Interface), nvme (Non-Volatile Memory Express). See local SSD performance (https://cloud.google.com/compute/docs/disks/local-ssd# performance). Corresponds to the JSON property localSsdInterface

Returns:

  • (String)


2141
2142
2143
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2141

def local_ssd_interface
  @local_ssd_interface
end

#num_local_ssdsFixnum

Optional. Number of attached SSDs, from 0 to 8 (default is 0). If SSDs are not attached, the boot disk is used to store runtime logs and HDFS (https://hadoop. apache.org/docs/r1.2.1/hdfs_user_guide.html) data. If one or more SSDs are attached, this runtime bulk data is spread across them, and the boot disk contains only basic config and installed binaries.Note: Local SSD options may vary by machine type and number of vCPUs selected. Corresponds to the JSON property numLocalSsds

Returns:

  • (Fixnum)


2151
2152
2153
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2151

def num_local_ssds
  @num_local_ssds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2158
2159
2160
2161
2162
2163
2164
2165
2166
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2158

def update!(**args)
  @attached_disk_configs = args[:attached_disk_configs] if args.key?(:attached_disk_configs)
  @boot_disk_provisioned_iops = args[:boot_disk_provisioned_iops] if args.key?(:boot_disk_provisioned_iops)
  @boot_disk_provisioned_throughput = args[:boot_disk_provisioned_throughput] if args.key?(:boot_disk_provisioned_throughput)
  @boot_disk_size_gb = args[:boot_disk_size_gb] if args.key?(:boot_disk_size_gb)
  @boot_disk_type = args[:boot_disk_type] if args.key?(:boot_disk_type)
  @local_ssd_interface = args[:local_ssd_interface] if args.key?(:local_ssd_interface)
  @num_local_ssds = args[:num_local_ssds] if args.key?(:num_local_ssds)
end