Class: Google::Apis::DataprocV1::DiskConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Specifies the config of boot disk and attached disk options for a group of VM instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskConfig

Returns a new instance of DiskConfig.



2071
2072
2073
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2071

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boot_disk_provisioned_iopsFixnum

Optional. Indicates how many IOPS to provision for the disk. This sets the number of I/O operations per second that the disk can handle. This field is supported only if boot_disk_type is hyperdisk-balanced. Corresponds to the JSON property bootDiskProvisionedIops

Returns:

  • (Fixnum)


2030
2031
2032
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2030

def boot_disk_provisioned_iops
  @boot_disk_provisioned_iops
end

#boot_disk_provisioned_throughputFixnum

Optional. Indicates how much throughput to provision for the disk. This sets the number of throughput mb per second that the disk can handle. Values must be greater than or equal to 1. This field is supported only if boot_disk_type is hyperdisk-balanced. Corresponds to the JSON property bootDiskProvisionedThroughput

Returns:

  • (Fixnum)


2038
2039
2040
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2038

def boot_disk_provisioned_throughput
  @boot_disk_provisioned_throughput
end

#boot_disk_size_gbFixnum

Optional. Size in GB of the boot disk (default is 500GB). Corresponds to the JSON property bootDiskSizeGb

Returns:

  • (Fixnum)


2043
2044
2045
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2043

def boot_disk_size_gb
  @boot_disk_size_gb
end

#boot_disk_typeString

Optional. Type of the boot disk (default is "pd-standard"). Valid values: "pd- balanced" (Persistent Disk Balanced Solid State Drive), "pd-ssd" (Persistent Disk Solid State Drive), or "pd-standard" (Persistent Disk Hard Disk Drive). See Disk types (https://cloud.google.com/compute/docs/disks#disk-types). Corresponds to the JSON property bootDiskType

Returns:

  • (String)


2051
2052
2053
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2051

def boot_disk_type
  @boot_disk_type
end

#local_ssd_interfaceString

Optional. Interface type of local SSDs (default is "scsi"). Valid values: " scsi" (Small Computer System Interface), "nvme" (Non-Volatile Memory Express). See local SSD performance (https://cloud.google.com/compute/docs/disks/local- ssd#performance). Corresponds to the JSON property localSsdInterface

Returns:

  • (String)


2059
2060
2061
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2059

def local_ssd_interface
  @local_ssd_interface
end

#num_local_ssdsFixnum

Optional. Number of attached SSDs, from 0 to 8 (default is 0). If SSDs are not attached, the boot disk is used to store runtime logs and HDFS (https://hadoop. apache.org/docs/r1.2.1/hdfs_user_guide.html) data. If one or more SSDs are attached, this runtime bulk data is spread across them, and the boot disk contains only basic config and installed binaries.Note: Local SSD options may vary by machine type and number of vCPUs selected. Corresponds to the JSON property numLocalSsds

Returns:

  • (Fixnum)


2069
2070
2071
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2069

def num_local_ssds
  @num_local_ssds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2076
2077
2078
2079
2080
2081
2082
2083
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2076

def update!(**args)
  @boot_disk_provisioned_iops = args[:boot_disk_provisioned_iops] if args.key?(:boot_disk_provisioned_iops)
  @boot_disk_provisioned_throughput = args[:boot_disk_provisioned_throughput] if args.key?(:boot_disk_provisioned_throughput)
  @boot_disk_size_gb = args[:boot_disk_size_gb] if args.key?(:boot_disk_size_gb)
  @boot_disk_type = args[:boot_disk_type] if args.key?(:boot_disk_type)
  @local_ssd_interface = args[:local_ssd_interface] if args.key?(:local_ssd_interface)
  @num_local_ssds = args[:num_local_ssds] if args.key?(:num_local_ssds)
end