Class: Google::Apis::DataprocV1::ExecutionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Execution configuration for a workload.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExecutionConfig

Returns a new instance of ExecutionConfig.



2302
2303
2304
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2302

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_configGoogle::Apis::DataprocV1::AuthenticationConfig

Authentication configuration for a workload is used to set the default identity for the workload execution. The config specifies the type of identity (service account or user) that will be used by workloads to access resources on the project(s). Corresponds to the JSON property authenticationConfig



2235
2236
2237
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2235

def authentication_config
  @authentication_config
end

#idle_ttlString

Optional. Applies to sessions only. The duration to keep the session alive while it's idling. Exceeding this threshold causes the session to terminate. This field cannot be set on a batch workload. Minimum value is 10 minutes; maximum value is 14 days (see JSON representation of Duration (https:// developers.google.com/protocol-buffers/docs/proto3#json)). Defaults to 1 hour if not set. If both ttl and idle_ttl are specified for an interactive session, the conditions are treated as OR conditions: the workload will be terminated when it has been idle for idle_ttl or when ttl has been exceeded, whichever occurs first. Corresponds to the JSON property idleTtl

Returns:

  • (String)


2248
2249
2250
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2248

def idle_ttl
  @idle_ttl
end

#kms_keyString

Optional. The Cloud KMS key to use for encryption. Corresponds to the JSON property kmsKey

Returns:

  • (String)


2253
2254
2255
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2253

def kms_key
  @kms_key
end

#network_tagsArray<String>

Optional. Tags used for network traffic control. Corresponds to the JSON property networkTags

Returns:

  • (Array<String>)


2258
2259
2260
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2258

def network_tags
  @network_tags
end

#network_uriString

Optional. Network URI to connect workload to. Corresponds to the JSON property networkUri

Returns:

  • (String)


2263
2264
2265
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2263

def network_uri
  @network_uri
end

#service_accountString

Optional. Service account that used to execute workload. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


2268
2269
2270
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2268

def 
  @service_account
end

#staging_bucketString

Optional. A Cloud Storage bucket used to stage workload dependencies, config files, and store workload output and other ephemeral data, such as Spark history files. If you do not specify a staging bucket, Cloud Dataproc will determine a Cloud Storage location according to the region where your workload is running, and then create and manage project-level, per-location staging and temporary buckets. This field requires a Cloud Storage bucket name, not a gs:// ... URI to a Cloud Storage bucket. Corresponds to the JSON property stagingBucket

Returns:

  • (String)


2279
2280
2281
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2279

def staging_bucket
  @staging_bucket
end

#subnetwork_uriString

Optional. Subnetwork URI to connect workload to. Corresponds to the JSON property subnetworkUri

Returns:

  • (String)


2284
2285
2286
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2284

def subnetwork_uri
  @subnetwork_uri
end

#ttlString

Optional. The duration after which the workload will be terminated, specified as the JSON representation for Duration (https://protobuf.dev/programming- guides/proto3/#json). When the workload exceeds this duration, it will be unconditionally terminated without waiting for ongoing work to finish. If ttl is not specified for a batch workload, the workload will be allowed to run until it exits naturally (or run forever without exiting). If ttl is not specified for an interactive session, it defaults to 24 hours. If ttl is not specified for a batch that uses 2.1+ runtime version, it defaults to 4 hours. Minimum value is 10 minutes; maximum value is 14 days. If both ttl and idle_ttl are specified (for an interactive session), the conditions are treated as OR conditions: the workload will be terminated when it has been idle for idle_ttl or when ttl has been exceeded, whichever occurs first. Corresponds to the JSON property ttl

Returns:

  • (String)


2300
2301
2302
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2300

def ttl
  @ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2307

def update!(**args)
  @authentication_config = args[:authentication_config] if args.key?(:authentication_config)
  @idle_ttl = args[:idle_ttl] if args.key?(:idle_ttl)
  @kms_key = args[:kms_key] if args.key?(:kms_key)
  @network_tags = args[:network_tags] if args.key?(:network_tags)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @service_account = args[:service_account] if args.key?(:service_account)
  @staging_bucket = args[:staging_bucket] if args.key?(:staging_bucket)
  @subnetwork_uri = args[:subnetwork_uri] if args.key?(:subnetwork_uri)
  @ttl = args[:ttl] if args.key?(:ttl)
end