Class: Google::Apis::DataprocV1::FlinkJob
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::FlinkJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A Dataproc job for running Apache Flink applications on YARN.
Instance Attribute Summary collapse
-
#args ⇒ Array<String>
Optional.
-
#jar_file_uris ⇒ Array<String>
Optional.
-
#logging_config ⇒ Google::Apis::DataprocV1::LoggingConfig
The runtime logging config of the job.
-
#main_class ⇒ String
The name of the driver's main class.
-
#main_jar_file_uri ⇒ String
The HCFS URI of the jar file that contains the main class.
-
#properties ⇒ Hash<String,String>
Optional.
-
#savepoint_uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FlinkJob
constructor
A new instance of FlinkJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FlinkJob
Returns a new instance of FlinkJob.
3045 3046 3047 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3045 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Array<String>
Optional. The arguments to pass to the driver. Do not include arguments, such
as --conf, that can be set as job properties, since a collision might occur
that causes an incorrect job submission.
Corresponds to the JSON property args
3007 3008 3009 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3007 def args @args end |
#jar_file_uris ⇒ Array<String>
Optional. HCFS URIs of jar files to add to the CLASSPATHs of the Flink driver
and tasks.
Corresponds to the JSON property jarFileUris
3013 3014 3015 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3013 def jar_file_uris @jar_file_uris end |
#logging_config ⇒ Google::Apis::DataprocV1::LoggingConfig
The runtime logging config of the job.
Corresponds to the JSON property loggingConfig
3018 3019 3020 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3018 def logging_config @logging_config end |
#main_class ⇒ String
The name of the driver's main class. The jar file that contains the class must
be in the default CLASSPATH or specified in jarFileUris.
Corresponds to the JSON property mainClass
3024 3025 3026 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3024 def main_class @main_class end |
#main_jar_file_uri ⇒ String
The HCFS URI of the jar file that contains the main class.
Corresponds to the JSON property mainJarFileUri
3029 3030 3031 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3029 def main_jar_file_uri @main_jar_file_uri end |
#properties ⇒ Hash<String,String>
Optional. A mapping of property names to values, used to configure Flink.
Properties that conflict with values set by the Dataproc API might be
overwritten. Can include properties set in /etc/flink/conf/flink-defaults.conf
and classes in user code.
Corresponds to the JSON property properties
3037 3038 3039 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3037 def properties @properties end |
#savepoint_uri ⇒ String
Optional. HCFS URI of the savepoint, which contains the last saved progress
for starting the current job.
Corresponds to the JSON property savepointUri
3043 3044 3045 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3043 def savepoint_uri @savepoint_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3050 3051 3052 3053 3054 3055 3056 3057 3058 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3050 def update!(**args) @args = args[:args] if args.key?(:args) @jar_file_uris = args[:jar_file_uris] if args.key?(:jar_file_uris) @logging_config = args[:logging_config] if args.key?(:logging_config) @main_class = args[:main_class] if args.key?(:main_class) @main_jar_file_uri = args[:main_jar_file_uri] if args.key?(:main_jar_file_uri) @properties = args[:properties] if args.key?(:properties) @savepoint_uri = args[:savepoint_uri] if args.key?(:savepoint_uri) end |