Class: Google::Apis::DataprocV1::FlinkJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A Dataproc job for running Apache Flink applications on YARN.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FlinkJob

Returns a new instance of FlinkJob.



3037
3038
3039
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3037

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsArray<String>

Optional. The arguments to pass to the driver. Do not include arguments, such as --conf, that can be set as job properties, since a collision might occur that causes an incorrect job submission. Corresponds to the JSON property args

Returns:

  • (Array<String>)


2999
3000
3001
# File 'lib/google/apis/dataproc_v1/classes.rb', line 2999

def args
  @args
end

#jar_file_urisArray<String>

Optional. HCFS URIs of jar files to add to the CLASSPATHs of the Flink driver and tasks. Corresponds to the JSON property jarFileUris

Returns:

  • (Array<String>)


3005
3006
3007
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3005

def jar_file_uris
  @jar_file_uris
end

#logging_configGoogle::Apis::DataprocV1::LoggingConfig

The runtime logging config of the job. Corresponds to the JSON property loggingConfig



3010
3011
3012
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3010

def logging_config
  @logging_config
end

#main_classString

The name of the driver's main class. The jar file that contains the class must be in the default CLASSPATH or specified in jarFileUris. Corresponds to the JSON property mainClass

Returns:

  • (String)


3016
3017
3018
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3016

def main_class
  @main_class
end

#main_jar_file_uriString

The HCFS URI of the jar file that contains the main class. Corresponds to the JSON property mainJarFileUri

Returns:

  • (String)


3021
3022
3023
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3021

def main_jar_file_uri
  @main_jar_file_uri
end

#propertiesHash<String,String>

Optional. A mapping of property names to values, used to configure Flink. Properties that conflict with values set by the Dataproc API might be overwritten. Can include properties set in /etc/flink/conf/flink-defaults.conf and classes in user code. Corresponds to the JSON property properties

Returns:

  • (Hash<String,String>)


3029
3030
3031
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3029

def properties
  @properties
end

#savepoint_uriString

Optional. HCFS URI of the savepoint, which contains the last saved progress for starting the current job. Corresponds to the JSON property savepointUri

Returns:

  • (String)


3035
3036
3037
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3035

def savepoint_uri
  @savepoint_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3042
3043
3044
3045
3046
3047
3048
3049
3050
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3042

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @jar_file_uris = args[:jar_file_uris] if args.key?(:jar_file_uris)
  @logging_config = args[:logging_config] if args.key?(:logging_config)
  @main_class = args[:main_class] if args.key?(:main_class)
  @main_jar_file_uri = args[:main_jar_file_uri] if args.key?(:main_jar_file_uri)
  @properties = args[:properties] if args.key?(:properties)
  @savepoint_uri = args[:savepoint_uri] if args.key?(:savepoint_uri)
end