Class: Google::Apis::DataprocV1::GkeNodeConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::GkeNodeConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Parameters that describe cluster nodes.
Instance Attribute Summary collapse
-
#accelerators ⇒ Array<Google::Apis::DataprocV1::GkeNodePoolAcceleratorConfig>
Optional.
-
#boot_disk_kms_key ⇒ String
Optional.
-
#local_ssd_count ⇒ Fixnum
Optional.
-
#machine_type ⇒ String
Optional.
-
#min_cpu_platform ⇒ String
Optional.
-
#preemptible ⇒ Boolean
(also: #preemptible?)
Optional.
-
#service_account ⇒ String
Optional.
-
#spot ⇒ Boolean
(also: #spot?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GkeNodeConfig
constructor
A new instance of GkeNodeConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GkeNodeConfig
Returns a new instance of GkeNodeConfig.
3379 3380 3381 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3379 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerators ⇒ Array<Google::Apis::DataprocV1::GkeNodePoolAcceleratorConfig>
Optional. A list of hardware accelerators (https://cloud.google.com/compute/
docs/gpus) to attach to each node.
Corresponds to the JSON property accelerators
3315 3316 3317 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3315 def accelerators @accelerators end |
#boot_disk_kms_key ⇒ String
Optional. The Customer Managed Encryption Key (CMEK) (https://cloud.google.com/
kubernetes-engine/docs/how-to/using-cmek) used to encrypt the boot disk
attached to each node in the node pool. Specify the key using the following
format: projects/project/locations/location/keyRings/key_ring/cryptoKeys/
crypto_key
Corresponds to the JSON property bootDiskKmsKey
3324 3325 3326 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3324 def boot_disk_kms_key @boot_disk_kms_key end |
#local_ssd_count ⇒ Fixnum
Optional. The number of local SSD disks to attach to the node, which is
limited by the maximum number of disks allowable per zone (see Adding Local
SSDs (https://cloud.google.com/compute/docs/disks/local-ssd)).
Corresponds to the JSON property localSsdCount
3331 3332 3333 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3331 def local_ssd_count @local_ssd_count end |
#machine_type ⇒ String
Optional. The name of a Compute Engine machine type (https://cloud.google.com/
compute/docs/machine-types).
Corresponds to the JSON property machineType
3337 3338 3339 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3337 def machine_type @machine_type end |
#min_cpu_platform ⇒ String
Optional. Minimum CPU platform (https://cloud.google.com/compute/docs/
instances/specify-min-cpu-platform) to be used by this instance. The instance
may be scheduled on the specified or a newer CPU platform. Specify the
friendly names of CPU platforms, such as "Intel Haswell"or Intel Sandy
Bridge".
Corresponds to the JSON propertyminCpuPlatform`
3346 3347 3348 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3346 def min_cpu_platform @min_cpu_platform end |
#preemptible ⇒ Boolean Also known as: preemptible?
Optional. Whether the nodes are created as legacy preemptible VM instances (
https://cloud.google.com/compute/docs/instances/preemptible). Also see Spot
VMs, preemptible VM instances without a maximum lifetime. Legacy and Spot
preemptible nodes cannot be used in a node pool with the CONTROLLER role or in
the DEFAULT node pool if the CONTROLLER role is not assigned (the DEFAULT node
pool will assume the CONTROLLER role).
Corresponds to the JSON property preemptible
3356 3357 3358 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3356 def preemptible @preemptible end |
#service_account ⇒ String
Optional. Specifies the service account (https://cloud.google.com/dataproc/
docs/guides/dpgke/dataproc-gke-iam) to be used by the node pools. Specify the
email address of the service account or its full resource name.Format:
projects/project/serviceAccounts/service_account_email or
service_account_email.
Corresponds to the JSON property serviceAccount
3366 3367 3368 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3366 def service_account @service_account end |
#spot ⇒ Boolean Also known as: spot?
Optional. Whether the nodes are created as Spot VM instances (https://cloud.
google.com/compute/docs/instances/spot). Spot VMs are the latest update to
legacy preemptible VMs. Spot VMs do not have a maximum lifetime. Legacy and
Spot preemptible nodes cannot be used in a node pool with the CONTROLLER role
or in the DEFAULT node pool if the CONTROLLER role is not assigned (the
DEFAULT node pool will assume the CONTROLLER role).
Corresponds to the JSON property spot
3376 3377 3378 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3376 def spot @spot end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3384 def update!(**args) @accelerators = args[:accelerators] if args.key?(:accelerators) @boot_disk_kms_key = args[:boot_disk_kms_key] if args.key?(:boot_disk_kms_key) @local_ssd_count = args[:local_ssd_count] if args.key?(:local_ssd_count) @machine_type = args[:machine_type] if args.key?(:machine_type) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) @preemptible = args[:preemptible] if args.key?(:preemptible) @service_account = args[:service_account] if args.key?(:service_account) @spot = args[:spot] if args.key?(:spot) end |