Class: Google::Apis::DataprocV1::GkeNodeConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::GkeNodeConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Parameters that describe cluster nodes.
Instance Attribute Summary collapse
-
#accelerators ⇒ Array<Google::Apis::DataprocV1::GkeNodePoolAcceleratorConfig>
Optional.
-
#boot_disk_kms_key ⇒ String
Optional.
-
#local_ssd_count ⇒ Fixnum
Optional.
-
#machine_type ⇒ String
Optional.
-
#min_cpu_platform ⇒ String
Optional.
-
#preemptible ⇒ Boolean
(also: #preemptible?)
Optional.
-
#spot ⇒ Boolean
(also: #spot?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GkeNodeConfig
constructor
A new instance of GkeNodeConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GkeNodeConfig
Returns a new instance of GkeNodeConfig.
3367 3368 3369 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3367 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerators ⇒ Array<Google::Apis::DataprocV1::GkeNodePoolAcceleratorConfig>
Optional. A list of hardware accelerators (https://cloud.google.com/compute/
docs/gpus) to attach to each node.
Corresponds to the JSON property accelerators
3312 3313 3314 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3312 def accelerators @accelerators end |
#boot_disk_kms_key ⇒ String
Optional. The Customer Managed Encryption Key (CMEK) (https://cloud.google.com/
kubernetes-engine/docs/how-to/using-cmek) used to encrypt the boot disk
attached to each node in the node pool. Specify the key using the following
format: projects/project/locations/location/keyRings/key_ring/cryptoKeys/
crypto_key
Corresponds to the JSON property bootDiskKmsKey
3321 3322 3323 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3321 def boot_disk_kms_key @boot_disk_kms_key end |
#local_ssd_count ⇒ Fixnum
Optional. The number of local SSD disks to attach to the node, which is
limited by the maximum number of disks allowable per zone (see Adding Local
SSDs (https://cloud.google.com/compute/docs/disks/local-ssd)).
Corresponds to the JSON property localSsdCount
3328 3329 3330 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3328 def local_ssd_count @local_ssd_count end |
#machine_type ⇒ String
Optional. The name of a Compute Engine machine type (https://cloud.google.com/
compute/docs/machine-types).
Corresponds to the JSON property machineType
3334 3335 3336 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3334 def machine_type @machine_type end |
#min_cpu_platform ⇒ String
Optional. Minimum CPU platform (https://cloud.google.com/compute/docs/
instances/specify-min-cpu-platform) to be used by this instance. The instance
may be scheduled on the specified or a newer CPU platform. Specify the
friendly names of CPU platforms, such as "Intel Haswell"or Intel Sandy
Bridge".
Corresponds to the JSON propertyminCpuPlatform`
3343 3344 3345 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3343 def min_cpu_platform @min_cpu_platform end |
#preemptible ⇒ Boolean Also known as: preemptible?
Optional. Whether the nodes are created as legacy preemptible VM instances (
https://cloud.google.com/compute/docs/instances/preemptible). Also see Spot
VMs, preemptible VM instances without a maximum lifetime. Legacy and Spot
preemptible nodes cannot be used in a node pool with the CONTROLLER role or in
the DEFAULT node pool if the CONTROLLER role is not assigned (the DEFAULT node
pool will assume the CONTROLLER role).
Corresponds to the JSON property preemptible
3353 3354 3355 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3353 def preemptible @preemptible end |
#spot ⇒ Boolean Also known as: spot?
Optional. Whether the nodes are created as Spot VM instances (https://cloud.
google.com/compute/docs/instances/spot). Spot VMs are the latest update to
legacy preemptible VMs. Spot VMs do not have a maximum lifetime. Legacy and
Spot preemptible nodes cannot be used in a node pool with the CONTROLLER role
or in the DEFAULT node pool if the CONTROLLER role is not assigned (the
DEFAULT node pool will assume the CONTROLLER role).
Corresponds to the JSON property spot
3364 3365 3366 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3364 def spot @spot end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3372 3373 3374 3375 3376 3377 3378 3379 3380 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3372 def update!(**args) @accelerators = args[:accelerators] if args.key?(:accelerators) @boot_disk_kms_key = args[:boot_disk_kms_key] if args.key?(:boot_disk_kms_key) @local_ssd_count = args[:local_ssd_count] if args.key?(:local_ssd_count) @machine_type = args[:machine_type] if args.key?(:machine_type) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) @preemptible = args[:preemptible] if args.key?(:preemptible) @spot = args[:spot] if args.key?(:spot) end |