Class: Google::Apis::DataprocV1::GkeNodeConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::GkeNodeConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Parameters that describe cluster nodes.
Instance Attribute Summary collapse
-
#accelerators ⇒ Array<Google::Apis::DataprocV1::GkeNodePoolAcceleratorConfig>
Optional.
-
#boot_disk_kms_key ⇒ String
Optional.
-
#local_ssd_count ⇒ Fixnum
Optional.
-
#machine_type ⇒ String
Optional.
-
#min_cpu_platform ⇒ String
Optional.
-
#preemptible ⇒ Boolean
(also: #preemptible?)
Optional.
-
#spot ⇒ Boolean
(also: #spot?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GkeNodeConfig
constructor
A new instance of GkeNodeConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GkeNodeConfig
Returns a new instance of GkeNodeConfig.
3275 3276 3277 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3275 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerators ⇒ Array<Google::Apis::DataprocV1::GkeNodePoolAcceleratorConfig>
Optional. A list of hardware accelerators (https://cloud.google.com/compute/
docs/gpus) to attach to each node.
Corresponds to the JSON property accelerators
3220 3221 3222 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3220 def accelerators @accelerators end |
#boot_disk_kms_key ⇒ String
Optional. The Customer Managed Encryption Key (CMEK) (https://cloud.google.com/
kubernetes-engine/docs/how-to/using-cmek) used to encrypt the boot disk
attached to each node in the node pool. Specify the key using the following
format: projects/project/locations/location/keyRings/key_ring/cryptoKeys/
crypto_key
Corresponds to the JSON property bootDiskKmsKey
3229 3230 3231 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3229 def boot_disk_kms_key @boot_disk_kms_key end |
#local_ssd_count ⇒ Fixnum
Optional. The number of local SSD disks to attach to the node, which is
limited by the maximum number of disks allowable per zone (see Adding Local
SSDs (https://cloud.google.com/compute/docs/disks/local-ssd)).
Corresponds to the JSON property localSsdCount
3236 3237 3238 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3236 def local_ssd_count @local_ssd_count end |
#machine_type ⇒ String
Optional. The name of a Compute Engine machine type (https://cloud.google.com/
compute/docs/machine-types).
Corresponds to the JSON property machineType
3242 3243 3244 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3242 def machine_type @machine_type end |
#min_cpu_platform ⇒ String
Optional. Minimum CPU platform (https://cloud.google.com/compute/docs/
instances/specify-min-cpu-platform) to be used by this instance. The instance
may be scheduled on the specified or a newer CPU platform. Specify the
friendly names of CPU platforms, such as "Intel Haswell"or Intel Sandy
Bridge".
Corresponds to the JSON propertyminCpuPlatform`
3251 3252 3253 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3251 def min_cpu_platform @min_cpu_platform end |
#preemptible ⇒ Boolean Also known as: preemptible?
Optional. Whether the nodes are created as legacy preemptible VM instances (
https://cloud.google.com/compute/docs/instances/preemptible). Also see Spot
VMs, preemptible VM instances without a maximum lifetime. Legacy and Spot
preemptible nodes cannot be used in a node pool with the CONTROLLER role or in
the DEFAULT node pool if the CONTROLLER role is not assigned (the DEFAULT node
pool will assume the CONTROLLER role).
Corresponds to the JSON property preemptible
3261 3262 3263 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3261 def preemptible @preemptible end |
#spot ⇒ Boolean Also known as: spot?
Optional. Whether the nodes are created as Spot VM instances (https://cloud.
google.com/compute/docs/instances/spot). Spot VMs are the latest update to
legacy preemptible VMs. Spot VMs do not have a maximum lifetime. Legacy and
Spot preemptible nodes cannot be used in a node pool with the CONTROLLER role
or in the DEFAULT node pool if the CONTROLLER role is not assigned (the
DEFAULT node pool will assume the CONTROLLER role).
Corresponds to the JSON property spot
3272 3273 3274 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3272 def spot @spot end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3280 3281 3282 3283 3284 3285 3286 3287 3288 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3280 def update!(**args) @accelerators = args[:accelerators] if args.key?(:accelerators) @boot_disk_kms_key = args[:boot_disk_kms_key] if args.key?(:boot_disk_kms_key) @local_ssd_count = args[:local_ssd_count] if args.key?(:local_ssd_count) @machine_type = args[:machine_type] if args.key?(:machine_type) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) @preemptible = args[:preemptible] if args.key?(:preemptible) @spot = args[:spot] if args.key?(:spot) end |