Class: Google::Apis::DataprocV1::GkeNodePoolAcceleratorConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::GkeNodePoolAcceleratorConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A GkeNodeConfigAcceleratorConfig represents a Hardware Accelerator request for a node pool.
Instance Attribute Summary collapse
-
#accelerator_count ⇒ Fixnum
The number of accelerator cards exposed to an instance.
-
#accelerator_type ⇒ String
The accelerator type resource namename (see GPUs on Compute Engine).
-
#gpu_partition_size ⇒ String
Size of partitions to create on the GPU.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GkeNodePoolAcceleratorConfig
constructor
A new instance of GkeNodePoolAcceleratorConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GkeNodePoolAcceleratorConfig
Returns a new instance of GkeNodePoolAcceleratorConfig.
3313 3314 3315 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3313 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_count ⇒ Fixnum
The number of accelerator cards exposed to an instance.
Corresponds to the JSON property acceleratorCount
3299 3300 3301 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3299 def accelerator_count @accelerator_count end |
#accelerator_type ⇒ String
The accelerator type resource namename (see GPUs on Compute Engine).
Corresponds to the JSON property acceleratorType
3304 3305 3306 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3304 def accelerator_type @accelerator_type end |
#gpu_partition_size ⇒ String
Size of partitions to create on the GPU. Valid values are described in the NVIDIA mig user guide (https://docs.nvidia.com/datacenter/tesla/mig-user-guide/
partitioning).
Corresponds to the JSON property gpuPartitionSize
3311 3312 3313 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3311 def gpu_partition_size @gpu_partition_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3318 3319 3320 3321 3322 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3318 def update!(**args) @accelerator_count = args[:accelerator_count] if args.key?(:accelerator_count) @accelerator_type = args[:accelerator_type] if args.key?(:accelerator_type) @gpu_partition_size = args[:gpu_partition_size] if args.key?(:gpu_partition_size) end |