Class: Google::Apis::DataprocV1::GkeNodePoolAutoscalingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

GkeNodePoolAutoscaling contains information the cluster autoscaler needs to adjust the size of the node pool to the current cluster usage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GkeNodePoolAutoscalingConfig

Returns a new instance of GkeNodePoolAutoscalingConfig.



3434
3435
3436
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3434

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_node_countFixnum

The maximum number of nodes in the node pool. Must be >= min_node_count, and must be > 0. Note: Quota must be sufficient to scale up the cluster. Corresponds to the JSON property maxNodeCount

Returns:

  • (Fixnum)


3426
3427
3428
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3426

def max_node_count
  @max_node_count
end

#min_node_countFixnum

The minimum number of nodes in the node pool. Must be >= 0 and <= max_node_count. Corresponds to the JSON property minNodeCount

Returns:

  • (Fixnum)


3432
3433
3434
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3432

def min_node_count
  @min_node_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3439
3440
3441
3442
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3439

def update!(**args)
  @max_node_count = args[:max_node_count] if args.key?(:max_node_count)
  @min_node_count = args[:min_node_count] if args.key?(:min_node_count)
end