Class: Google::Apis::DataprocV1::HadoopJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A Dataproc job for running Apache Hadoop MapReduce (https://hadoop.apache.org/ docs/current/hadoop-mapreduce-client/hadoop-mapreduce-client-core/ MapReduceTutorial.html) jobs on Apache Hadoop YARN (https://hadoop.apache.org/ docs/r2.7.1/hadoop-yarn/hadoop-yarn-site/YARN.html).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HadoopJob

Returns a new instance of HadoopJob.



3607
3608
3609
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3607

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#archive_urisArray<String>

Optional. HCFS URIs of archives to be extracted in the working directory of Hadoop drivers and tasks. Supported file types: .jar, .tar, .tar.gz, .tgz, or . zip. Corresponds to the JSON property archiveUris

Returns:

  • (Array<String>)


3558
3559
3560
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3558

def archive_uris
  @archive_uris
end

#argsArray<String>

Optional. The arguments to pass to the driver. Do not include arguments, such as -libjars or -Dfoo=bar, that can be set as job properties, since a collision might occur that causes an incorrect job submission. Corresponds to the JSON property args

Returns:

  • (Array<String>)


3565
3566
3567
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3565

def args
  @args
end

#file_urisArray<String>

Optional. HCFS (Hadoop Compatible Filesystem) URIs of files to be copied to the working directory of Hadoop drivers and distributed tasks. Useful for naively parallel tasks. Corresponds to the JSON property fileUris

Returns:

  • (Array<String>)


3572
3573
3574
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3572

def file_uris
  @file_uris
end

#jar_file_urisArray<String>

Optional. Jar file URIs to add to the CLASSPATHs of the Hadoop driver and tasks. Corresponds to the JSON property jarFileUris

Returns:

  • (Array<String>)


3578
3579
3580
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3578

def jar_file_uris
  @jar_file_uris
end

#logging_configGoogle::Apis::DataprocV1::LoggingConfig

The runtime logging config of the job. Corresponds to the JSON property loggingConfig



3583
3584
3585
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3583

def logging_config
  @logging_config
end

#main_classString

The name of the driver's main class. The jar file containing the class must be in the default CLASSPATH or specified in jar_file_uris. Corresponds to the JSON property mainClass

Returns:

  • (String)


3589
3590
3591
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3589

def main_class
  @main_class
end

#main_jar_file_uriString

The HCFS URI of the jar file containing the main class. Examples: 'gs://foo- bucket/analytics-binaries/extract-useful-metrics-mr.jar' 'hdfs:/tmp/test- samples/custom-wordcount.jar' 'file:///home/usr/lib/hadoop-mapreduce/hadoop- mapreduce-examples.jar' Corresponds to the JSON property mainJarFileUri

Returns:

  • (String)


3597
3598
3599
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3597

def main_jar_file_uri
  @main_jar_file_uri
end

#propertiesHash<String,String>

Optional. A mapping of property names to values, used to configure Hadoop. Properties that conflict with values set by the Dataproc API might be overwritten. Can include properties set in /etc/hadoop/conf/*-site and classes in user code. Corresponds to the JSON property properties

Returns:

  • (Hash<String,String>)


3605
3606
3607
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3605

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3612
3613
3614
3615
3616
3617
3618
3619
3620
3621
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3612

def update!(**args)
  @archive_uris = args[:archive_uris] if args.key?(:archive_uris)
  @args = args[:args] if args.key?(:args)
  @file_uris = args[:file_uris] if args.key?(:file_uris)
  @jar_file_uris = args[:jar_file_uris] if args.key?(:jar_file_uris)
  @logging_config = args[:logging_config] if args.key?(:logging_config)
  @main_class = args[:main_class] if args.key?(:main_class)
  @main_jar_file_uri = args[:main_jar_file_uri] if args.key?(:main_jar_file_uri)
  @properties = args[:properties] if args.key?(:properties)
end