Class: Google::Apis::DataprocV1::HiveJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A Dataproc job for running Apache Hive (https://hive.apache.org/) queries on YARN.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HiveJob

Returns a new instance of HiveJob.



3675
3676
3677
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3675

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#continue_on_failureBoolean Also known as: continue_on_failure?

Optional. Whether to continue executing queries if a query fails. The default value is false. Setting to true can be useful when executing independent parallel queries. Corresponds to the JSON property continueOnFailure

Returns:

  • (Boolean)


3642
3643
3644
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3642

def continue_on_failure
  @continue_on_failure
end

#jar_file_urisArray<String>

Optional. HCFS URIs of jar files to add to the CLASSPATH of the Hive server and Hadoop MapReduce (MR) tasks. Can contain Hive SerDes and UDFs. Corresponds to the JSON property jarFileUris

Returns:

  • (Array<String>)


3649
3650
3651
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3649

def jar_file_uris
  @jar_file_uris
end

#propertiesHash<String,String>

Optional. A mapping of property names and values, used to configure Hive. Properties that conflict with values set by the Dataproc API might be overwritten. Can include properties set in /etc/hadoop/conf/*-site.xml, /etc/ hive/conf/hive-site.xml, and classes in user code. Corresponds to the JSON property properties

Returns:

  • (Hash<String,String>)


3657
3658
3659
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3657

def properties
  @properties
end

#query_file_uriString

The HCFS URI of the script that contains Hive queries. Corresponds to the JSON property queryFileUri

Returns:

  • (String)


3662
3663
3664
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3662

def query_file_uri
  @query_file_uri
end

#query_listGoogle::Apis::DataprocV1::QueryList

A list of queries to run on a cluster. Corresponds to the JSON property queryList



3667
3668
3669
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3667

def query_list
  @query_list
end

#script_variablesHash<String,String>

Optional. Mapping of query variable names to values (equivalent to the Hive command: SET name="value";). Corresponds to the JSON property scriptVariables

Returns:

  • (Hash<String,String>)


3673
3674
3675
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3673

def script_variables
  @script_variables
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3680
3681
3682
3683
3684
3685
3686
3687
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3680

def update!(**args)
  @continue_on_failure = args[:continue_on_failure] if args.key?(:continue_on_failure)
  @jar_file_uris = args[:jar_file_uris] if args.key?(:jar_file_uris)
  @properties = args[:properties] if args.key?(:properties)
  @query_file_uri = args[:query_file_uri] if args.key?(:query_file_uri)
  @query_list = args[:query_list] if args.key?(:query_list)
  @script_variables = args[:script_variables] if args.key?(:script_variables)
end