Class: Google::Apis::DataprocV1::IdentityConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::IdentityConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Identity related configuration, including service account based secure multi- tenancy user mappings.
Instance Attribute Summary collapse
-
#enable_ssh ⇒ Boolean
(also: #enable_ssh?)
Optional.
-
#user_service_account_mapping ⇒ Hash<String,String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IdentityConfig
constructor
A new instance of IdentityConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IdentityConfig
Returns a new instance of IdentityConfig.
3879 3880 3881 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3879 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_ssh ⇒ Boolean Also known as: enable_ssh?
Optional. Whether to enable SSH access for the cluster. The default is true
for image versions prior to 3.1 and false for image versions 3.1 and later.
The default behavior can be changed when creating clusters using image
versions 2.3.30 and later.
Corresponds to the JSON property enableSsh
3871 3872 3873 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3871 def enable_ssh @enable_ssh end |
#user_service_account_mapping ⇒ Hash<String,String>
Required. Map of user to service account.
Corresponds to the JSON property userServiceAccountMapping
3877 3878 3879 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3877 def user_service_account_mapping @user_service_account_mapping end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3884 3885 3886 3887 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3884 def update!(**args) @enable_ssh = args[:enable_ssh] if args.key?(:enable_ssh) @user_service_account_mapping = args[:user_service_account_mapping] if args.key?(:user_service_account_mapping) end |