Class: Google::Apis::DataprocV1::InjectCredentialsRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::InjectCredentialsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A request to inject credentials into a cluster.
Instance Attribute Summary collapse
-
#cluster_uuid ⇒ String
Required.
-
#credentials_ciphertext ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InjectCredentialsRequest
constructor
A new instance of InjectCredentialsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InjectCredentialsRequest
Returns a new instance of InjectCredentialsRequest.
3907 3908 3909 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3907 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_uuid ⇒ String
Required. The cluster UUID.
Corresponds to the JSON property clusterUuid
3897 3898 3899 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3897 def cluster_uuid @cluster_uuid end |
#credentials_ciphertext ⇒ String
Required. The encrypted credentials being injected in to the cluster.The
client is responsible for encrypting the credentials in a way that is
supported by the cluster.A wrapped value is used here so that the actual
contents of the encrypted credentials are not written to audit logs.
Corresponds to the JSON property credentialsCiphertext
3905 3906 3907 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3905 def credentials_ciphertext @credentials_ciphertext end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3912 3913 3914 3915 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3912 def update!(**args) @cluster_uuid = args[:cluster_uuid] if args.key?(:cluster_uuid) @credentials_ciphertext = args[:credentials_ciphertext] if args.key?(:credentials_ciphertext) end |