Class: Google::Apis::DataprocV1::InjectCredentialsRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::InjectCredentialsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A request to inject credentials into a cluster.
Instance Attribute Summary collapse
-
#cluster_uuid ⇒ String
Required.
-
#credentials_ciphertext ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InjectCredentialsRequest
constructor
A new instance of InjectCredentialsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InjectCredentialsRequest
Returns a new instance of InjectCredentialsRequest.
3728 3729 3730 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3728 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_uuid ⇒ String
Required. The cluster UUID.
Corresponds to the JSON property clusterUuid
3718 3719 3720 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3718 def cluster_uuid @cluster_uuid end |
#credentials_ciphertext ⇒ String
Required. The encrypted credentials being injected in to the cluster.The
client is responsible for encrypting the credentials in a way that is
supported by the cluster.A wrapped value is used here so that the actual
contents of the encrypted credentials are not written to audit logs.
Corresponds to the JSON property credentialsCiphertext
3726 3727 3728 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3726 def credentials_ciphertext @credentials_ciphertext end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3733 3734 3735 3736 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3733 def update!(**args) @cluster_uuid = args[:cluster_uuid] if args.key?(:cluster_uuid) @credentials_ciphertext = args[:credentials_ciphertext] if args.key?(:credentials_ciphertext) end |