Class: Google::Apis::DataprocV1::InjectCredentialsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A request to inject credentials into a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InjectCredentialsRequest

Returns a new instance of InjectCredentialsRequest.



3719
3720
3721
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3719

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_uuidString

Required. The cluster UUID. Corresponds to the JSON property clusterUuid

Returns:

  • (String)


3709
3710
3711
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3709

def cluster_uuid
  @cluster_uuid
end

#credentials_ciphertextString

Required. The encrypted credentials being injected in to the cluster.The client is responsible for encrypting the credentials in a way that is supported by the cluster.A wrapped value is used here so that the actual contents of the encrypted credentials are not written to audit logs. Corresponds to the JSON property credentialsCiphertext

Returns:

  • (String)


3717
3718
3719
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3717

def credentials_ciphertext
  @credentials_ciphertext
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3724
3725
3726
3727
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3724

def update!(**args)
  @cluster_uuid = args[:cluster_uuid] if args.key?(:cluster_uuid)
  @credentials_ciphertext = args[:credentials_ciphertext] if args.key?(:credentials_ciphertext)
end