Class: Google::Apis::DataprocV1::InstanceGroupAutoscalingPolicyConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Configuration for the size bounds of an instance group, including its proportional size to other groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupAutoscalingPolicyConfig

Returns a new instance of InstanceGroupAutoscalingPolicyConfig.



3770
3771
3772
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3770

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_instancesFixnum

Required. Maximum number of instances for this group. Required for primary workers. Note that by default, clusters will not use secondary workers. Required for secondary workers if the minimum secondary instances is set. Primary workers - Bounds: [min_instances, ). Secondary workers - Bounds: [ min_instances, ). Default: 0. Corresponds to the JSON property maxInstances

Returns:

  • (Fixnum)


3743
3744
3745
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3743

def max_instances
  @max_instances
end

#min_instancesFixnum

Optional. Minimum number of instances for this group.Primary workers - Bounds: 2, max_instances. Default: 2. Secondary workers - Bounds: 0, max_instances. Default: 0. Corresponds to the JSON property minInstances

Returns:

  • (Fixnum)


3750
3751
3752
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3750

def min_instances
  @min_instances
end

#weightFixnum

Optional. Weight for the instance group, which is used to determine the fraction of total workers in the cluster from this instance group. For example, if primary workers have weight 2, and secondary workers have weight 1, the cluster will have approximately 2 primary workers for each secondary worker. The cluster may not reach the specified balance if constrained by min/max bounds or other autoscaling settings. For example, if max_instances for secondary workers is 0, then only primary workers will be added. The cluster can also be out of balance when created.If weight is not set on any instance group, the cluster will default to equal weight for all groups: the cluster will attempt to maintain an equal number of workers in each group within the configured size bounds for each group. If weight is set for one group only, the cluster will default to zero weight on the unset group. For example if weight is set only on primary workers, the cluster will use primary workers only and no secondary workers. Corresponds to the JSON property weight

Returns:

  • (Fixnum)


3768
3769
3770
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3768

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3775
3776
3777
3778
3779
# File 'lib/google/apis/dataproc_v1/classes.rb', line 3775

def update!(**args)
  @max_instances = args[:max_instances] if args.key?(:max_instances)
  @min_instances = args[:min_instances] if args.key?(:min_instances)
  @weight = args[:weight] if args.key?(:weight)
end