Class: Google::Apis::DataprocV1::InstanceSelection
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::InstanceSelection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Defines machines types and a rank to which the machines types belong.
Instance Attribute Summary collapse
-
#disk_config ⇒ Google::Apis::DataprocV1::DiskConfig
Specifies the config of boot disk and attached disk options for a group of VM instances.
-
#machine_types ⇒ Array<String>
Optional.
-
#rank ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceSelection
constructor
A new instance of InstanceSelection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceSelection
Returns a new instance of InstanceSelection.
4088 4089 4090 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4088 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disk_config ⇒ Google::Apis::DataprocV1::DiskConfig
Specifies the config of boot disk and attached disk options for a group of VM
instances.
Corresponds to the JSON property diskConfig
4072 4073 4074 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4072 def disk_config @disk_config end |
#machine_types ⇒ Array<String>
Optional. Full machine-type names, e.g. "n1-standard-16".
Corresponds to the JSON property machineTypes
4077 4078 4079 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4077 def machine_types @machine_types end |
#rank ⇒ Fixnum
Optional. Preference of this instance selection. Lower number means higher
preference. The service will first try to create a VM based on the machine-
type with priority rank and fallback to next rank based on availability.
Machine types and instance selections with the same priority have the same
preference.
Corresponds to the JSON property rank
4086 4087 4088 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4086 def rank @rank end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4093 4094 4095 4096 4097 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4093 def update!(**args) @disk_config = args[:disk_config] if args.key?(:disk_config) @machine_types = args[:machine_types] if args.key?(:machine_types) @rank = args[:rank] if args.key?(:rank) end |