Class: Google::Apis::DataprocV1::InstanceSelection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Defines machines types and a rank to which the machines types belong.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceSelection

Returns a new instance of InstanceSelection.



4066
4067
4068
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4066

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#machine_typesArray<String>

Optional. Full machine-type names, e.g. "n1-standard-16". Corresponds to the JSON property machineTypes

Returns:

  • (Array<String>)


4055
4056
4057
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4055

def machine_types
  @machine_types
end

#rankFixnum

Optional. Preference of this instance selection. Lower number means higher preference. The service will first try to create a VM based on the machine- type with priority rank and fallback to next rank based on availability. Machine types and instance selections with the same priority have the same preference. Corresponds to the JSON property rank

Returns:

  • (Fixnum)


4064
4065
4066
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4064

def rank
  @rank
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4071
4072
4073
4074
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4071

def update!(**args)
  @machine_types = args[:machine_types] if args.key?(:machine_types)
  @rank = args[:rank] if args.key?(:rank)
end