Class: Google::Apis::DataprocV1::InstanceSelection
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::InstanceSelection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Defines machines types and a rank to which the machines types belong.
Instance Attribute Summary collapse
-
#machine_types ⇒ Array<String>
Optional.
-
#rank ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceSelection
constructor
A new instance of InstanceSelection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceSelection
Returns a new instance of InstanceSelection.
4069 4070 4071 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4069 def initialize(**args) update!(**args) end |
Instance Attribute Details
#machine_types ⇒ Array<String>
Optional. Full machine-type names, e.g. "n1-standard-16".
Corresponds to the JSON property machineTypes
4059 4060 4061 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4059 def machine_types @machine_types end |
#rank ⇒ Fixnum
Optional. Preference of this instance selection. Lower number means higher
preference. Dataproc will first try to create a VM based on the machine-type
with priority rank and fallback to next rank based on availability. Machine
types and instance selections with the same priority have the same preference.
Corresponds to the JSON property rank
4067 4068 4069 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4067 def rank @rank end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4074 4075 4076 4077 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4074 def update!(**args) @machine_types = args[:machine_types] if args.key?(:machine_types) @rank = args[:rank] if args.key?(:rank) end |