Class: Google::Apis::DataprocV1::InstantiateWorkflowTemplateRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::InstantiateWorkflowTemplateRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A request to instantiate a workflow template.
Instance Attribute Summary collapse
-
#parameters ⇒ Hash<String,String>
Optional.
-
#request_id ⇒ String
Optional.
-
#version ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstantiateWorkflowTemplateRequest
constructor
A new instance of InstantiateWorkflowTemplateRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstantiateWorkflowTemplateRequest
Returns a new instance of InstantiateWorkflowTemplateRequest.
4147 4148 4149 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4147 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parameters ⇒ Hash<String,String>
Optional. Map from parameter names to values that should be used for those
parameters. Values may not exceed 1000 characters.
Corresponds to the JSON property parameters
4127 4128 4129 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4127 def parameters @parameters end |
#request_id ⇒ String
Optional. A tag that prevents multiple concurrent workflow instances with the
same tag from running. This mitigates risk of concurrent instances started due
to retries.It is recommended to always set this value to a UUID (https://en.
wikipedia.org/wiki/Universally_unique_identifier).The tag must contain only
letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The
maximum length is 40 characters.
Corresponds to the JSON property requestId
4137 4138 4139 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4137 def request_id @request_id end |
#version ⇒ Fixnum
Optional. The version of workflow template to instantiate. If specified, the
workflow will be instantiated only if the current version of the workflow
template has the supplied version.This option cannot be used to instantiate a
previous version of workflow template.
Corresponds to the JSON property version
4145 4146 4147 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4145 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4152 4153 4154 4155 4156 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4152 def update!(**args) @parameters = args[:parameters] if args.key?(:parameters) @request_id = args[:request_id] if args.key?(:request_id) @version = args[:version] if args.key?(:version) end |