Class: Google::Apis::DataprocV1::InstantiateWorkflowTemplateRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A request to instantiate a workflow template.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstantiateWorkflowTemplateRequest

Returns a new instance of InstantiateWorkflowTemplateRequest.



4131
4132
4133
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4131

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parametersHash<String,String>

Optional. Map from parameter names to values that should be used for those parameters. Values may not exceed 1000 characters. Corresponds to the JSON property parameters

Returns:

  • (Hash<String,String>)


4111
4112
4113
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4111

def parameters
  @parameters
end

#request_idString

Optional. A tag that prevents multiple concurrent workflow instances with the same tag from running. This mitigates risk of concurrent instances started due to retries.It is recommended to always set this value to a UUID (https://en. wikipedia.org/wiki/Universally_unique_identifier).The tag must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters. Corresponds to the JSON property requestId

Returns:

  • (String)


4121
4122
4123
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4121

def request_id
  @request_id
end

#versionFixnum

Optional. The version of workflow template to instantiate. If specified, the workflow will be instantiated only if the current version of the workflow template has the supplied version.This option cannot be used to instantiate a previous version of workflow template. Corresponds to the JSON property version

Returns:

  • (Fixnum)


4129
4130
4131
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4129

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4136
4137
4138
4139
4140
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4136

def update!(**args)
  @parameters = args[:parameters] if args.key?(:parameters)
  @request_id = args[:request_id] if args.key?(:request_id)
  @version = args[:version] if args.key?(:version)
end