Class: Google::Apis::DataprocV1::JobReference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Encapsulates the full scoping used to reference a job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobReference

Returns a new instance of JobReference.



4573
4574
4575
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#job_idString

Optional. The job ID, which must be unique within the project.The ID must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), or hyphens (-) . The maximum length is 100 characters.If not specified by the caller, the job ID will be provided by the server. Corresponds to the JSON property jobId

Returns:

  • (String)


4565
4566
4567
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4565

def job_id
  @job_id
end

#project_idString

Optional. The ID of the Google Cloud Platform project that the job belongs to. If specified, must match the request project ID. Corresponds to the JSON property projectId

Returns:

  • (String)


4571
4572
4573
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4571

def project_id
  @project_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4578
4579
4580
4581
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4578

def update!(**args)
  @job_id = args[:job_id] if args.key?(:job_id)
  @project_id = args[:project_id] if args.key?(:project_id)
end