Class: Google::Apis::DataprocV1::KerberosConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Specifies Kerberos related configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KerberosConfig

Returns a new instance of KerberosConfig.



4860
4861
4862
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4860

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cross_realm_trust_admin_serverString

Optional. The admin server (IP or hostname) for the remote trusted realm in a cross realm trust relationship. Corresponds to the JSON property crossRealmTrustAdminServer

Returns:

  • (String)


4770
4771
4772
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4770

def cross_realm_trust_admin_server
  @cross_realm_trust_admin_server
end

#cross_realm_trust_kdcString

Optional. The KDC (IP or hostname) for the remote trusted realm in a cross realm trust relationship. Corresponds to the JSON property crossRealmTrustKdc

Returns:

  • (String)


4776
4777
4778
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4776

def cross_realm_trust_kdc
  @cross_realm_trust_kdc
end

#cross_realm_trust_realmString

Optional. The remote realm the on-cluster KDC will trust, should the user enable cross realm trust. Corresponds to the JSON property crossRealmTrustRealm

Returns:

  • (String)


4782
4783
4784
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4782

def cross_realm_trust_realm
  @cross_realm_trust_realm
end

#cross_realm_trust_shared_password_uriString

Optional. The Cloud Storage URI of a KMS encrypted file containing the shared password between the on-cluster Kerberos realm and the remote trusted realm, in a cross realm trust relationship. Corresponds to the JSON property crossRealmTrustSharedPasswordUri

Returns:

  • (String)


4789
4790
4791
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4789

def cross_realm_trust_shared_password_uri
  @cross_realm_trust_shared_password_uri
end

#enable_kerberosBoolean Also known as: enable_kerberos?

Optional. Flag to indicate whether to Kerberize the cluster (default: false). Set this field to true to enable Kerberos on a cluster. Corresponds to the JSON property enableKerberos

Returns:

  • (Boolean)


4795
4796
4797
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4795

def enable_kerberos
  @enable_kerberos
end

#kdc_db_key_uriString

Optional. The Cloud Storage URI of a KMS encrypted file containing the master key of the KDC database. Corresponds to the JSON property kdcDbKeyUri

Returns:

  • (String)


4802
4803
4804
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4802

def kdc_db_key_uri
  @kdc_db_key_uri
end

#key_password_uriString

Optional. The Cloud Storage URI of a KMS encrypted file containing the password to the user provided key. For the self-signed certificate, this password is generated by the service. Corresponds to the JSON property keyPasswordUri

Returns:

  • (String)


4809
4810
4811
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4809

def key_password_uri
  @key_password_uri
end

#keystore_password_uriString

Optional. The Cloud Storage URI of a KMS encrypted file containing the password to the user provided keystore. For the self-signed certificate, this password is generated by the service. Corresponds to the JSON property keystorePasswordUri

Returns:

  • (String)


4816
4817
4818
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4816

def keystore_password_uri
  @keystore_password_uri
end

#keystore_uriString

Optional. The Cloud Storage URI of the keystore file used for SSL encryption. If not provided, the service will provide a self-signed certificate. Corresponds to the JSON property keystoreUri

Returns:

  • (String)


4822
4823
4824
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4822

def keystore_uri
  @keystore_uri
end

#kms_key_uriString

Optional. The URI of the KMS key used to encrypt sensitive files. Corresponds to the JSON property kmsKeyUri

Returns:

  • (String)


4827
4828
4829
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4827

def kms_key_uri
  @kms_key_uri
end

#realmString

Optional. The name of the on-cluster Kerberos realm. If not specified, the uppercased domain of hostnames will be the realm. Corresponds to the JSON property realm

Returns:

  • (String)


4833
4834
4835
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4833

def realm
  @realm
end

#root_principal_password_uriString

Optional. The Cloud Storage URI of a KMS encrypted file containing the root principal password. Corresponds to the JSON property rootPrincipalPasswordUri

Returns:

  • (String)


4839
4840
4841
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4839

def root_principal_password_uri
  @root_principal_password_uri
end

#tgt_lifetime_hoursFixnum

Optional. The lifetime of the ticket granting ticket, in hours. If not specified, or user specifies 0, then default value 10 will be used. Corresponds to the JSON property tgtLifetimeHours

Returns:

  • (Fixnum)


4845
4846
4847
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4845

def tgt_lifetime_hours
  @tgt_lifetime_hours
end

#truststore_password_uriString

Optional. The Cloud Storage URI of a KMS encrypted file containing the password to the user provided truststore. For the self-signed certificate, this password is generated by the service. Corresponds to the JSON property truststorePasswordUri

Returns:

  • (String)


4852
4853
4854
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4852

def truststore_password_uri
  @truststore_password_uri
end

#truststore_uriString

Optional. The Cloud Storage URI of the truststore file used for SSL encryption. If not provided, the service will provide a self-signed certificate. Corresponds to the JSON property truststoreUri

Returns:

  • (String)


4858
4859
4860
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4858

def truststore_uri
  @truststore_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4865
4866
4867
4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4865

def update!(**args)
  @cross_realm_trust_admin_server = args[:cross_realm_trust_admin_server] if args.key?(:cross_realm_trust_admin_server)
  @cross_realm_trust_kdc = args[:cross_realm_trust_kdc] if args.key?(:cross_realm_trust_kdc)
  @cross_realm_trust_realm = args[:cross_realm_trust_realm] if args.key?(:cross_realm_trust_realm)
  @cross_realm_trust_shared_password_uri = args[:cross_realm_trust_shared_password_uri] if args.key?(:cross_realm_trust_shared_password_uri)
  @enable_kerberos = args[:enable_kerberos] if args.key?(:enable_kerberos)
  @kdc_db_key_uri = args[:kdc_db_key_uri] if args.key?(:kdc_db_key_uri)
  @key_password_uri = args[:key_password_uri] if args.key?(:key_password_uri)
  @keystore_password_uri = args[:keystore_password_uri] if args.key?(:keystore_password_uri)
  @keystore_uri = args[:keystore_uri] if args.key?(:keystore_uri)
  @kms_key_uri = args[:kms_key_uri] if args.key?(:kms_key_uri)
  @realm = args[:realm] if args.key?(:realm)
  @root_principal_password_uri = args[:root_principal_password_uri] if args.key?(:root_principal_password_uri)
  @tgt_lifetime_hours = args[:tgt_lifetime_hours] if args.key?(:tgt_lifetime_hours)
  @truststore_password_uri = args[:truststore_password_uri] if args.key?(:truststore_password_uri)
  @truststore_uri = args[:truststore_uri] if args.key?(:truststore_uri)
end