Class: Google::Apis::DataprocV1::KerberosConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::KerberosConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Specifies Kerberos related configuration.
Instance Attribute Summary collapse
-
#cross_realm_trust_admin_server ⇒ String
Optional.
-
#cross_realm_trust_kdc ⇒ String
Optional.
-
#cross_realm_trust_realm ⇒ String
Optional.
-
#cross_realm_trust_shared_password_uri ⇒ String
Optional.
-
#enable_kerberos ⇒ Boolean
(also: #enable_kerberos?)
Optional.
-
#kdc_db_key_uri ⇒ String
Optional.
-
#key_password_uri ⇒ String
Optional.
-
#keystore_password_uri ⇒ String
Optional.
-
#keystore_uri ⇒ String
Optional.
-
#kms_key_uri ⇒ String
Optional.
-
#realm ⇒ String
Optional.
-
#root_principal_password_uri ⇒ String
Optional.
-
#tgt_lifetime_hours ⇒ Fixnum
Optional.
-
#truststore_password_uri ⇒ String
Optional.
-
#truststore_uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KerberosConfig
constructor
A new instance of KerberosConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KerberosConfig
Returns a new instance of KerberosConfig.
4853 4854 4855 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4853 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cross_realm_trust_admin_server ⇒ String
Optional. The admin server (IP or hostname) for the remote trusted realm in a
cross realm trust relationship.
Corresponds to the JSON property crossRealmTrustAdminServer
4763 4764 4765 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4763 def cross_realm_trust_admin_server @cross_realm_trust_admin_server end |
#cross_realm_trust_kdc ⇒ String
Optional. The KDC (IP or hostname) for the remote trusted realm in a cross
realm trust relationship.
Corresponds to the JSON property crossRealmTrustKdc
4769 4770 4771 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4769 def cross_realm_trust_kdc @cross_realm_trust_kdc end |
#cross_realm_trust_realm ⇒ String
Optional. The remote realm the on-cluster KDC will trust, should the user
enable cross realm trust.
Corresponds to the JSON property crossRealmTrustRealm
4775 4776 4777 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4775 def cross_realm_trust_realm @cross_realm_trust_realm end |
#cross_realm_trust_shared_password_uri ⇒ String
Optional. The Cloud Storage URI of a KMS encrypted file containing the shared
password between the on-cluster Kerberos realm and the remote trusted realm,
in a cross realm trust relationship.
Corresponds to the JSON property crossRealmTrustSharedPasswordUri
4782 4783 4784 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4782 def cross_realm_trust_shared_password_uri @cross_realm_trust_shared_password_uri end |
#enable_kerberos ⇒ Boolean Also known as: enable_kerberos?
Optional. Flag to indicate whether to Kerberize the cluster (default: false).
Set this field to true to enable Kerberos on a cluster.
Corresponds to the JSON property enableKerberos
4788 4789 4790 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4788 def enable_kerberos @enable_kerberos end |
#kdc_db_key_uri ⇒ String
Optional. The Cloud Storage URI of a KMS encrypted file containing the master
key of the KDC database.
Corresponds to the JSON property kdcDbKeyUri
4795 4796 4797 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4795 def kdc_db_key_uri @kdc_db_key_uri end |
#key_password_uri ⇒ String
Optional. The Cloud Storage URI of a KMS encrypted file containing the
password to the user provided key. For the self-signed certificate, this
password is generated by the service.
Corresponds to the JSON property keyPasswordUri
4802 4803 4804 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4802 def key_password_uri @key_password_uri end |
#keystore_password_uri ⇒ String
Optional. The Cloud Storage URI of a KMS encrypted file containing the
password to the user provided keystore. For the self-signed certificate, this
password is generated by the service.
Corresponds to the JSON property keystorePasswordUri
4809 4810 4811 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4809 def keystore_password_uri @keystore_password_uri end |
#keystore_uri ⇒ String
Optional. The Cloud Storage URI of the keystore file used for SSL encryption.
If not provided, the service will provide a self-signed certificate.
Corresponds to the JSON property keystoreUri
4815 4816 4817 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4815 def keystore_uri @keystore_uri end |
#kms_key_uri ⇒ String
Optional. The URI of the KMS key used to encrypt sensitive files.
Corresponds to the JSON property kmsKeyUri
4820 4821 4822 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4820 def kms_key_uri @kms_key_uri end |
#realm ⇒ String
Optional. The name of the on-cluster Kerberos realm. If not specified, the
uppercased domain of hostnames will be the realm.
Corresponds to the JSON property realm
4826 4827 4828 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4826 def realm @realm end |
#root_principal_password_uri ⇒ String
Optional. The Cloud Storage URI of a KMS encrypted file containing the root
principal password.
Corresponds to the JSON property rootPrincipalPasswordUri
4832 4833 4834 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4832 def root_principal_password_uri @root_principal_password_uri end |
#tgt_lifetime_hours ⇒ Fixnum
Optional. The lifetime of the ticket granting ticket, in hours. If not
specified, or user specifies 0, then default value 10 will be used.
Corresponds to the JSON property tgtLifetimeHours
4838 4839 4840 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4838 def tgt_lifetime_hours @tgt_lifetime_hours end |
#truststore_password_uri ⇒ String
Optional. The Cloud Storage URI of a KMS encrypted file containing the
password to the user provided truststore. For the self-signed certificate,
this password is generated by the service.
Corresponds to the JSON property truststorePasswordUri
4845 4846 4847 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4845 def truststore_password_uri @truststore_password_uri end |
#truststore_uri ⇒ String
Optional. The Cloud Storage URI of the truststore file used for SSL encryption.
If not provided, the service will provide a self-signed certificate.
Corresponds to the JSON property truststoreUri
4851 4852 4853 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4851 def truststore_uri @truststore_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4858 def update!(**args) @cross_realm_trust_admin_server = args[:cross_realm_trust_admin_server] if args.key?(:cross_realm_trust_admin_server) @cross_realm_trust_kdc = args[:cross_realm_trust_kdc] if args.key?(:cross_realm_trust_kdc) @cross_realm_trust_realm = args[:cross_realm_trust_realm] if args.key?(:cross_realm_trust_realm) @cross_realm_trust_shared_password_uri = args[:cross_realm_trust_shared_password_uri] if args.key?(:cross_realm_trust_shared_password_uri) @enable_kerberos = args[:enable_kerberos] if args.key?(:enable_kerberos) @kdc_db_key_uri = args[:kdc_db_key_uri] if args.key?(:kdc_db_key_uri) @key_password_uri = args[:key_password_uri] if args.key?(:key_password_uri) @keystore_password_uri = args[:keystore_password_uri] if args.key?(:keystore_password_uri) @keystore_uri = args[:keystore_uri] if args.key?(:keystore_uri) @kms_key_uri = args[:kms_key_uri] if args.key?(:kms_key_uri) @realm = args[:realm] if args.key?(:realm) @root_principal_password_uri = args[:root_principal_password_uri] if args.key?(:root_principal_password_uri) @tgt_lifetime_hours = args[:tgt_lifetime_hours] if args.key?(:tgt_lifetime_hours) @truststore_password_uri = args[:truststore_password_uri] if args.key?(:truststore_password_uri) @truststore_uri = args[:truststore_uri] if args.key?(:truststore_uri) end |