Class: Google::Apis::DataprocV1::KubernetesClusterConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::KubernetesClusterConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
The configuration for running the Dataproc cluster on Kubernetes.
Instance Attribute Summary collapse
-
#gke_cluster_config ⇒ Google::Apis::DataprocV1::GkeClusterConfig
The cluster's GKE config.
-
#kubernetes_namespace ⇒ String
Optional.
-
#kubernetes_software_config ⇒ Google::Apis::DataprocV1::KubernetesSoftwareConfig
The software configuration for this Dataproc cluster running on Kubernetes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KubernetesClusterConfig
constructor
A new instance of KubernetesClusterConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KubernetesClusterConfig
Returns a new instance of KubernetesClusterConfig.
4906 4907 4908 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4906 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gke_cluster_config ⇒ Google::Apis::DataprocV1::GkeClusterConfig
The cluster's GKE config.
Corresponds to the JSON property gkeClusterConfig
4891 4892 4893 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4891 def gke_cluster_config @gke_cluster_config end |
#kubernetes_namespace ⇒ String
Optional. A namespace within the Kubernetes cluster to deploy into. If this
namespace does not exist, it is created. If it exists, Dataproc verifies that
another Dataproc VirtualCluster is not installed into it. If not specified,
the name of the Dataproc Cluster is used.
Corresponds to the JSON property kubernetesNamespace
4899 4900 4901 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4899 def kubernetes_namespace @kubernetes_namespace end |
#kubernetes_software_config ⇒ Google::Apis::DataprocV1::KubernetesSoftwareConfig
The software configuration for this Dataproc cluster running on Kubernetes.
Corresponds to the JSON property kubernetesSoftwareConfig
4904 4905 4906 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4904 def kubernetes_software_config @kubernetes_software_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4911 4912 4913 4914 4915 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4911 def update!(**args) @gke_cluster_config = args[:gke_cluster_config] if args.key?(:gke_cluster_config) @kubernetes_namespace = args[:kubernetes_namespace] if args.key?(:kubernetes_namespace) @kubernetes_software_config = args[:kubernetes_software_config] if args.key?(:kubernetes_software_config) end |