Class: Google::Apis::DataprocV1::KubernetesClusterConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

The configuration for running the Dataproc cluster on Kubernetes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KubernetesClusterConfig

Returns a new instance of KubernetesClusterConfig.



4885
4886
4887
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4885

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gke_cluster_configGoogle::Apis::DataprocV1::GkeClusterConfig

The cluster's GKE config. Corresponds to the JSON property gkeClusterConfig



4870
4871
4872
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4870

def gke_cluster_config
  @gke_cluster_config
end

#kubernetes_namespaceString

Optional. A namespace within the Kubernetes cluster to deploy into. If this namespace does not exist, it is created. If it exists, Dataproc verifies that another Dataproc VirtualCluster is not installed into it. If not specified, the name of the Dataproc Cluster is used. Corresponds to the JSON property kubernetesNamespace

Returns:

  • (String)


4878
4879
4880
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4878

def kubernetes_namespace
  @kubernetes_namespace
end

#kubernetes_software_configGoogle::Apis::DataprocV1::KubernetesSoftwareConfig

The software configuration for this Dataproc cluster running on Kubernetes. Corresponds to the JSON property kubernetesSoftwareConfig



4883
4884
4885
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4883

def kubernetes_software_config
  @kubernetes_software_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4890
4891
4892
4893
4894
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4890

def update!(**args)
  @gke_cluster_config = args[:gke_cluster_config] if args.key?(:gke_cluster_config)
  @kubernetes_namespace = args[:kubernetes_namespace] if args.key?(:kubernetes_namespace)
  @kubernetes_software_config = args[:kubernetes_software_config] if args.key?(:kubernetes_software_config)
end