Class: Google::Apis::DataprocV1::LifecycleConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::LifecycleConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Specifies the cluster auto-delete schedule configuration.
Instance Attribute Summary collapse
-
#auto_delete_time ⇒ String
Optional.
-
#auto_delete_ttl ⇒ String
Optional.
-
#auto_stop_time ⇒ String
Optional.
-
#auto_stop_ttl ⇒ String
Optional.
-
#idle_delete_ttl ⇒ String
Optional.
-
#idle_start_time ⇒ String
Output only.
-
#idle_stop_ttl ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LifecycleConfig
constructor
A new instance of LifecycleConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LifecycleConfig
Returns a new instance of LifecycleConfig.
4987 4988 4989 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4987 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_delete_time ⇒ String
Optional. The time when cluster will be auto-deleted (see JSON representation
of Timestamp (https://developers.google.com/protocol-buffers/docs/proto3#json))
.
Corresponds to the JSON property autoDeleteTime
4938 4939 4940 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4938 def auto_delete_time @auto_delete_time end |
#auto_delete_ttl ⇒ String
Optional. The lifetime duration of cluster. The cluster will be auto-deleted
at the end of this period. Minimum value is 10 minutes; maximum value is 14
days (see JSON representation of Duration (https://developers.google.com/
protocol-buffers/docs/proto3#json)).
Corresponds to the JSON property autoDeleteTtl
4946 4947 4948 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4946 def auto_delete_ttl @auto_delete_ttl end |
#auto_stop_time ⇒ String
Optional. The time when cluster will be auto-stopped (see JSON representation
of Timestamp (https://developers.google.com/protocol-buffers/docs/proto3#json))
.
Corresponds to the JSON property autoStopTime
4953 4954 4955 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4953 def auto_stop_time @auto_stop_time end |
#auto_stop_ttl ⇒ String
Optional. The lifetime duration of the cluster. The cluster will be auto-
stopped at the end of this period, calculated from the time of submission of
the create or update cluster request. Minimum value is 10 minutes; maximum
value is 14 days (see JSON representation of Duration (https://developers.
google.com/protocol-buffers/docs/proto3#json)).
Corresponds to the JSON property autoStopTtl
4962 4963 4964 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4962 def auto_stop_ttl @auto_stop_ttl end |
#idle_delete_ttl ⇒ String
Optional. The duration to keep the cluster alive while idling (when no jobs
are running). Passing this threshold will cause the cluster to be deleted.
Minimum value is 5 minutes; maximum value is 14 days (see JSON representation
of Duration (https://developers.google.com/protocol-buffers/docs/proto3#json)).
Corresponds to the JSON property idleDeleteTtl
4970 4971 4972 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4970 def idle_delete_ttl @idle_delete_ttl end |
#idle_start_time ⇒ String
Output only. The time when cluster became idle (most recent job finished) and
became eligible for deletion due to idleness (see JSON representation of
Timestamp (https://developers.google.com/protocol-buffers/docs/proto3#json)).
Corresponds to the JSON property idleStartTime
4977 4978 4979 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4977 def idle_start_time @idle_start_time end |
#idle_stop_ttl ⇒ String
Optional. The duration to keep the cluster started while idling (when no jobs
are running). Passing this threshold will cause the cluster to be stopped.
Minimum value is 5 minutes; maximum value is 14 days (see JSON representation
of Duration (https://developers.google.com/protocol-buffers/docs/proto3#json)).
Corresponds to the JSON property idleStopTtl
4985 4986 4987 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4985 def idle_stop_ttl @idle_stop_ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4992 4993 4994 4995 4996 4997 4998 4999 5000 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4992 def update!(**args) @auto_delete_time = args[:auto_delete_time] if args.key?(:auto_delete_time) @auto_delete_ttl = args[:auto_delete_ttl] if args.key?(:auto_delete_ttl) @auto_stop_time = args[:auto_stop_time] if args.key?(:auto_stop_time) @auto_stop_ttl = args[:auto_stop_ttl] if args.key?(:auto_stop_ttl) @idle_delete_ttl = args[:idle_delete_ttl] if args.key?(:idle_delete_ttl) @idle_start_time = args[:idle_start_time] if args.key?(:idle_start_time) @idle_stop_ttl = args[:idle_stop_ttl] if args.key?(:idle_stop_ttl) end |