Class: Google::Apis::DataprocV1::LifecycleConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Specifies the cluster auto-delete schedule configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LifecycleConfig

Returns a new instance of LifecycleConfig.



4885
4886
4887
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4885

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_delete_timeString

Optional. The time when cluster will be auto-deleted (see JSON representation of Timestamp (https://developers.google.com/protocol-buffers/docs/proto3#json)) . Corresponds to the JSON property autoDeleteTime

Returns:

  • (String)


4836
4837
4838
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4836

def auto_delete_time
  @auto_delete_time
end

#auto_delete_ttlString

Optional. The lifetime duration of cluster. The cluster will be auto-deleted at the end of this period. Minimum value is 10 minutes; maximum value is 14 days (see JSON representation of Duration (https://developers.google.com/ protocol-buffers/docs/proto3#json)). Corresponds to the JSON property autoDeleteTtl

Returns:

  • (String)


4844
4845
4846
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4844

def auto_delete_ttl
  @auto_delete_ttl
end

#auto_stop_timeString

Optional. The time when cluster will be auto-stopped (see JSON representation of Timestamp (https://developers.google.com/protocol-buffers/docs/proto3#json)) . Corresponds to the JSON property autoStopTime

Returns:

  • (String)


4851
4852
4853
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4851

def auto_stop_time
  @auto_stop_time
end

#auto_stop_ttlString

Optional. The lifetime duration of the cluster. The cluster will be auto- stopped at the end of this period, calculated from the time of submission of the create or update cluster request. Minimum value is 10 minutes; maximum value is 14 days (see JSON representation of Duration (https://developers. google.com/protocol-buffers/docs/proto3#json)). Corresponds to the JSON property autoStopTtl

Returns:

  • (String)


4860
4861
4862
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4860

def auto_stop_ttl
  @auto_stop_ttl
end

#idle_delete_ttlString

Optional. The duration to keep the cluster alive while idling (when no jobs are running). Passing this threshold will cause the cluster to be deleted. Minimum value is 5 minutes; maximum value is 14 days (see JSON representation of Duration (https://developers.google.com/protocol-buffers/docs/proto3#json)). Corresponds to the JSON property idleDeleteTtl

Returns:

  • (String)


4868
4869
4870
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4868

def idle_delete_ttl
  @idle_delete_ttl
end

#idle_start_timeString

Output only. The time when cluster became idle (most recent job finished) and became eligible for deletion due to idleness (see JSON representation of Timestamp (https://developers.google.com/protocol-buffers/docs/proto3#json)). Corresponds to the JSON property idleStartTime

Returns:

  • (String)


4875
4876
4877
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4875

def idle_start_time
  @idle_start_time
end

#idle_stop_ttlString

Optional. The duration to keep the cluster started while idling (when no jobs are running). Passing this threshold will cause the cluster to be stopped. Minimum value is 5 minutes; maximum value is 14 days (see JSON representation of Duration (https://developers.google.com/protocol-buffers/docs/proto3#json)). Corresponds to the JSON property idleStopTtl

Returns:

  • (String)


4883
4884
4885
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4883

def idle_stop_ttl
  @idle_stop_ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4890
4891
4892
4893
4894
4895
4896
4897
4898
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4890

def update!(**args)
  @auto_delete_time = args[:auto_delete_time] if args.key?(:auto_delete_time)
  @auto_delete_ttl = args[:auto_delete_ttl] if args.key?(:auto_delete_ttl)
  @auto_stop_time = args[:auto_stop_time] if args.key?(:auto_stop_time)
  @auto_stop_ttl = args[:auto_stop_ttl] if args.key?(:auto_stop_ttl)
  @idle_delete_ttl = args[:idle_delete_ttl] if args.key?(:idle_delete_ttl)
  @idle_start_time = args[:idle_start_time] if args.key?(:idle_start_time)
  @idle_stop_ttl = args[:idle_stop_ttl] if args.key?(:idle_stop_ttl)
end