Class: Google::Apis::DataprocV1::ListBatchesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A list of batch workloads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBatchesResponse

Returns a new instance of ListBatchesResponse.



5048
5049
5050
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5048

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#batchesArray<Google::Apis::DataprocV1::Batch>

Output only. The batches from the specified collection. Corresponds to the JSON property batches



5033
5034
5035
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5033

def batches
  @batches
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5039
5040
5041
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5039

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Output only. List of Batches that could not be included in the response. Attempting to get one of these resources may indicate why it was not included in the list response. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


5046
5047
5048
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5046

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5053
5054
5055
5056
5057
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5053

def update!(**args)
  @batches = args[:batches] if args.key?(:batches)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end