Class: Google::Apis::DataprocV1::ListBatchesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::ListBatchesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A list of batch workloads.
Instance Attribute Summary collapse
-
#batches ⇒ Array<Google::Apis::DataprocV1::Batch>
Output only.
-
#next_page_token ⇒ String
A token, which can be sent as page_token to retrieve the next page.
-
#unreachable ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBatchesResponse
constructor
A new instance of ListBatchesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBatchesResponse
Returns a new instance of ListBatchesResponse.
4949 4950 4951 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4949 def initialize(**args) update!(**args) end |
Instance Attribute Details
#batches ⇒ Array<Google::Apis::DataprocV1::Batch>
Output only. The batches from the specified collection.
Corresponds to the JSON property batches
4934 4935 4936 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4934 def batches @batches end |
#next_page_token ⇒ String
A token, which can be sent as page_token to retrieve the next page. If this
field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
4940 4941 4942 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4940 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Output only. List of Batches that could not be included in the response.
Attempting to get one of these resources may indicate why it was not included
in the list response.
Corresponds to the JSON property unreachable
4947 4948 4949 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4947 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4954 4955 4956 4957 4958 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 4954 def update!(**args) @batches = args[:batches] if args.key?(:batches) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |