Class: Google::Apis::DataprocV1::ListWorkflowTemplatesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A response to a request to list workflow templates in a project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListWorkflowTemplatesResponse

Returns a new instance of ListWorkflowTemplatesResponse.



5253
5254
5255
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5253

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Output only. This token is included in the response if there are more results to fetch. To fetch additional results, provide this value as the page_token in a subsequent ListWorkflowTemplatesRequest. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5239
5240
5241
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5239

def next_page_token
  @next_page_token
end

#templatesArray<Google::Apis::DataprocV1::WorkflowTemplate>

Output only. WorkflowTemplates list. Corresponds to the JSON property templates



5244
5245
5246
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5244

def templates
  @templates
end

#unreachableArray<String>

Output only. List of workflow templates that could not be included in the response. Attempting to get one of these resources may indicate why it was not included in the list response. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


5251
5252
5253
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5251

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5258
5259
5260
5261
5262
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5258

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @templates = args[:templates] if args.key?(:templates)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end