Class: Google::Apis::DataprocV1::ListWorkflowTemplatesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::ListWorkflowTemplatesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A response to a request to list workflow templates in a project.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Output only.
-
#templates ⇒ Array<Google::Apis::DataprocV1::WorkflowTemplate>
Output only.
-
#unreachable ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListWorkflowTemplatesResponse
constructor
A new instance of ListWorkflowTemplatesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListWorkflowTemplatesResponse
Returns a new instance of ListWorkflowTemplatesResponse.
5232 5233 5234 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5232 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Output only. This token is included in the response if there are more results
to fetch. To fetch additional results, provide this value as the page_token in
a subsequent ListWorkflowTemplatesRequest.
Corresponds to the JSON property nextPageToken
5218 5219 5220 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5218 def next_page_token @next_page_token end |
#templates ⇒ Array<Google::Apis::DataprocV1::WorkflowTemplate>
Output only. WorkflowTemplates list.
Corresponds to the JSON property templates
5223 5224 5225 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5223 def templates @templates end |
#unreachable ⇒ Array<String>
Output only. List of workflow templates that could not be included in the
response. Attempting to get one of these resources may indicate why it was not
included in the list response.
Corresponds to the JSON property unreachable
5230 5231 5232 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5230 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5237 5238 5239 5240 5241 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5237 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @templates = args[:templates] if args.key?(:templates) @unreachable = args[:unreachable] if args.key?(:unreachable) end |