Class: Google::Apis::DataprocV1::Metric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A Dataproc custom metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Metric

Returns a new instance of Metric.



5423
5424
5425
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5423

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metric_overridesArray<String>

Optional. Specify one or more Custom metrics (https://cloud.google.com/ dataproc/docs/guides/dataproc-metrics#custom_metrics) to collect for the metric course (for the SPARK metric source (any Spark metric (https://spark. apache.org/docs/latest/monitoring.html#metrics) can be specified).Provide metrics in the following format: METRIC_SOURCE: INSTANCE:GROUP:METRIC Use camelcase as appropriate.Examples: yarn:ResourceManager:QueueMetrics: AppsCompleted spark:driver:DAGScheduler:job.allJobs sparkHistoryServer:JVM: Memory:NonHeapMemoryUsage.committed hiveserver2:JVM:Memory:NonHeapMemoryUsage. used Notes: Only the specified overridden metrics are collected for the metric source. For example, if one or more spark:executive metrics are listed as metric overrides, other SPARK metrics are not collected. The collection of the metrics for other enabled custom metric sources is unaffected. For example, if both SPARK and YARN metric sources are enabled, and overrides are provided for Spark metrics only, all YARN metrics are collected. Corresponds to the JSON property metricOverrides

Returns:

  • (Array<String>)


5414
5415
5416
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5414

def metric_overrides
  @metric_overrides
end

#metric_sourceString

Required. A standard set of metrics is collected unless metricOverrides are specified for the metric source (see Custom metrics (https://cloud.google.com/ dataproc/docs/guides/dataproc-metrics#custom_metrics) for more information). Corresponds to the JSON property metricSource

Returns:

  • (String)


5421
5422
5423
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5421

def metric_source
  @metric_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5428
5429
5430
5431
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5428

def update!(**args)
  @metric_overrides = args[:metric_overrides] if args.key?(:metric_overrides)
  @metric_source = args[:metric_source] if args.key?(:metric_source)
end