Class: Google::Apis::DataprocV1::NodeGroup
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::NodeGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Dataproc Node Group. The Dataproc NodeGroup resource is not related to the Dataproc NodeGroupAffinity resource.
Instance Attribute Summary collapse
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
The Node group resource name (https://aip.dev/122).
-
#node_group_config ⇒ Google::Apis::DataprocV1::InstanceGroupConfig
The config settings for Compute Engine resources in an instance group, such as a master or worker group.
-
#roles ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroup
constructor
A new instance of NodeGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroup
Returns a new instance of NodeGroup.
5463 5464 5465 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5463 def initialize(**args) update!(**args) end |
Instance Attribute Details
#labels ⇒ Hash<String,String>
Optional. Node group labels. Label keys must consist of from 1 to 63
characters and conform to RFC 1035 (https://www.ietf.org/rfc/rfc1035.txt).
Label values can be empty. If specified, they must consist of from 1 to 63
characters and conform to RFC 1035 (https://www.ietf.org/rfc/rfc1035.txt). The
node group must have no more than 32 labels.
Corresponds to the JSON property labels
5445 5446 5447 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5445 def labels @labels end |
#name ⇒ String
The Node group resource name (https://aip.dev/122).
Corresponds to the JSON property name
5450 5451 5452 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5450 def name @name end |
#node_group_config ⇒ Google::Apis::DataprocV1::InstanceGroupConfig
The config settings for Compute Engine resources in an instance group, such as
a master or worker group.
Corresponds to the JSON property nodeGroupConfig
5456 5457 5458 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5456 def node_group_config @node_group_config end |
#roles ⇒ Array<String>
Required. Node group roles.
Corresponds to the JSON property roles
5461 5462 5463 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5461 def roles @roles end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5468 5469 5470 5471 5472 5473 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5468 def update!(**args) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @node_group_config = args[:node_group_config] if args.key?(:node_group_config) @roles = args[:roles] if args.key?(:roles) end |