Class: Google::Apis::DataprocV1::NodeInitializationAction
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::NodeInitializationAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Specifies an executable to run on a fully configured node and a timeout period for executable completion.
Instance Attribute Summary collapse
-
#executable_file ⇒ String
Required.
-
#execution_timeout ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeInitializationAction
constructor
A new instance of NodeInitializationAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeInitializationAction
Returns a new instance of NodeInitializationAction.
5871 5872 5873 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5871 def initialize(**args) update!(**args) end |
Instance Attribute Details
#executable_file ⇒ String
Required. Cloud Storage URI of executable file.
Corresponds to the JSON property executableFile
5859 5860 5861 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5859 def executable_file @executable_file end |
#execution_timeout ⇒ String
Optional. Amount of time executable has to complete. Default is 10 minutes (
see JSON representation of Duration (https://developers.google.com/protocol-
buffers/docs/proto3#json)).Cluster creation fails with an explanatory error
message (the name of the executable that caused the error and the exceeded
timeout period) if the executable is not completed at end of the timeout
period.
Corresponds to the JSON property executionTimeout
5869 5870 5871 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5869 def execution_timeout @execution_timeout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5876 5877 5878 5879 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5876 def update!(**args) @executable_file = args[:executable_file] if args.key?(:executable_file) @execution_timeout = args[:execution_timeout] if args.key?(:execution_timeout) end |