Class: Google::Apis::DataprocV1::NodeInitializationAction
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::NodeInitializationAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Specifies an executable to run on a fully configured node and a timeout period for executable completion.
Instance Attribute Summary collapse
-
#executable_file ⇒ String
Required.
-
#execution_timeout ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeInitializationAction
constructor
A new instance of NodeInitializationAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeInitializationAction
Returns a new instance of NodeInitializationAction.
5683 5684 5685 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5683 def initialize(**args) update!(**args) end |
Instance Attribute Details
#executable_file ⇒ String
Required. Cloud Storage URI of executable file.
Corresponds to the JSON property executableFile
5671 5672 5673 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5671 def executable_file @executable_file end |
#execution_timeout ⇒ String
Optional. Amount of time executable has to complete. Default is 10 minutes (
see JSON representation of Duration (https://developers.google.com/protocol-
buffers/docs/proto3#json)).Cluster creation fails with an explanatory error
message (the name of the executable that caused the error and the exceeded
timeout period) if the executable is not completed at end of the timeout
period.
Corresponds to the JSON property executionTimeout
5681 5682 5683 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5681 def execution_timeout @execution_timeout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5688 5689 5690 5691 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5688 def update!(**args) @executable_file = args[:executable_file] if args.key?(:executable_file) @execution_timeout = args[:execution_timeout] if args.key?(:execution_timeout) end |