Class: Google::Apis::DataprocV1::NodeInitializationAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Specifies an executable to run on a fully configured node and a timeout period for executable completion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeInitializationAction

Returns a new instance of NodeInitializationAction.



5684
5685
5686
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5684

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#executable_fileString

Required. Cloud Storage URI of executable file. Corresponds to the JSON property executableFile

Returns:

  • (String)


5672
5673
5674
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5672

def executable_file
  @executable_file
end

#execution_timeoutString

Optional. Amount of time executable has to complete. Default is 10 minutes ( see JSON representation of Duration (https://developers.google.com/protocol- buffers/docs/proto3#json)).Cluster creation fails with an explanatory error message (the name of the executable that caused the error and the exceeded timeout period) if the executable is not completed at end of the timeout period. Corresponds to the JSON property executionTimeout

Returns:

  • (String)


5682
5683
5684
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5682

def execution_timeout
  @execution_timeout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5689
5690
5691
5692
# File 'lib/google/apis/dataproc_v1/classes.rb', line 5689

def update!(**args)
  @executable_file = args[:executable_file] if args.key?(:executable_file)
  @execution_timeout = args[:execution_timeout] if args.key?(:execution_timeout)
end