Class: Google::Apis::DataprocV1::ProvisioningModelMix

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Defines how to create VMs with a mixture of provisioning models.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProvisioningModelMix

Returns a new instance of ProvisioningModelMix.



6370
6371
6372
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6370

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#standard_capacity_baseFixnum

Optional. The base capacity that will always use Standard VMs to avoid risk of more preemption than the minimum capacity you need. The service will create only standard VMs until it reaches standard_capacity_base, then it will start using standard_capacity_percent_above_base to mix Spot with Standard VMs. eg. If 15 instances are requested and standard_capacity_base is 5, the service will create 5 standard VMs and thenstart mixing spot and standard VMs for remaining 10 instances. Corresponds to the JSON property standardCapacityBase

Returns:

  • (Fixnum)


6358
6359
6360
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6358

def standard_capacity_base
  @standard_capacity_base
end

#standard_capacity_percent_above_baseFixnum

Optional. The percentage of target capacity that should use Standard VM. The remaining percentage will use Spot VMs. The percentage applies only to the capacity above standard_capacity_base. eg. If 15 instances are requested and standard_capacity_base is 5 and standard_capacity_percent_above_base is 30, the service will create 5 standard VMs and then start mixing spot and standard VMs for remaining 10 instances. The mix will be 30% standard and 70% spot. Corresponds to the JSON property standardCapacityPercentAboveBase

Returns:

  • (Fixnum)


6368
6369
6370
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6368

def standard_capacity_percent_above_base
  @standard_capacity_percent_above_base
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6375
6376
6377
6378
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6375

def update!(**args)
  @standard_capacity_base = args[:standard_capacity_base] if args.key?(:standard_capacity_base)
  @standard_capacity_percent_above_base = args[:standard_capacity_percent_above_base] if args.key?(:standard_capacity_percent_above_base)
end