Class: Google::Apis::DataprocV1::PySparkNotebookBatch
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::PySparkNotebookBatch
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A configuration for running a PySpark Notebook batch workload.
Instance Attribute Summary collapse
-
#archive_uris ⇒ Array<String>
Optional.
-
#file_uris ⇒ Array<String>
Optional.
-
#jar_file_uris ⇒ Array<String>
Optional.
-
#notebook_file_uri ⇒ String
Required.
-
#params ⇒ Hash<String,String>
Optional.
-
#python_file_uris ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PySparkNotebookBatch
constructor
A new instance of PySparkNotebookBatch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PySparkNotebookBatch
Returns a new instance of PySparkNotebookBatch.
6546 6547 6548 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6546 def initialize(**args) update!(**args) end |
Instance Attribute Details
#archive_uris ⇒ Array<String>
Optional. HCFS URIs of archives to be extracted into the working directory of
each executor. Supported file types: .jar, .tar, .tar.gz, .tgz, and .zip.
Corresponds to the JSON property archiveUris
6518 6519 6520 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6518 def archive_uris @archive_uris end |
#file_uris ⇒ Array<String>
Optional. HCFS URIs of files to be placed in the working directory of each
executor
Corresponds to the JSON property fileUris
6524 6525 6526 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6524 def file_uris @file_uris end |
#jar_file_uris ⇒ Array<String>
Optional. HCFS URIs of jar files to be added to the Spark CLASSPATH.
Corresponds to the JSON property jarFileUris
6529 6530 6531 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6529 def jar_file_uris @jar_file_uris end |
#notebook_file_uri ⇒ String
Required. The HCFS URI of the notebook file to execute.
Corresponds to the JSON property notebookFileUri
6534 6535 6536 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6534 def notebook_file_uri @notebook_file_uri end |
#params ⇒ Hash<String,String>
Optional. The parameters to pass to the notebook.
Corresponds to the JSON property params
6539 6540 6541 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6539 def params @params end |
#python_file_uris ⇒ Array<String>
Optional. HCFS URIs of Python files to pass to the PySpark framework.
Corresponds to the JSON property pythonFileUris
6544 6545 6546 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6544 def python_file_uris @python_file_uris end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6551 6552 6553 6554 6555 6556 6557 6558 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6551 def update!(**args) @archive_uris = args[:archive_uris] if args.key?(:archive_uris) @file_uris = args[:file_uris] if args.key?(:file_uris) @jar_file_uris = args[:jar_file_uris] if args.key?(:jar_file_uris) @notebook_file_uri = args[:notebook_file_uri] if args.key?(:notebook_file_uri) @params = args[:params] if args.key?(:params) @python_file_uris = args[:python_file_uris] if args.key?(:python_file_uris) end |