Class: Google::Apis::DataprocV1::RddOperationGraph
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::RddOperationGraph
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Graph representing RDD dependencies. Consists of edges and a root cluster.
Instance Attribute Summary collapse
-
#edges ⇒ Array<Google::Apis::DataprocV1::RddOperationEdge>
Corresponds to the JSON property
edges. -
#incoming_edges ⇒ Array<Google::Apis::DataprocV1::RddOperationEdge>
Corresponds to the JSON property
incomingEdges. -
#outgoing_edges ⇒ Array<Google::Apis::DataprocV1::RddOperationEdge>
Corresponds to the JSON property
outgoingEdges. -
#root_cluster ⇒ Google::Apis::DataprocV1::RddOperationCluster
A grouping of nodes representing higher level constructs (stage, job etc.).
-
#stage_id ⇒ Fixnum
Corresponds to the JSON property
stageId.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RddOperationGraph
constructor
A new instance of RddOperationGraph.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RddOperationGraph
Returns a new instance of RddOperationGraph.
6798 6799 6800 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6798 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edges ⇒ Array<Google::Apis::DataprocV1::RddOperationEdge>
Corresponds to the JSON property edges
6776 6777 6778 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6776 def edges @edges end |
#incoming_edges ⇒ Array<Google::Apis::DataprocV1::RddOperationEdge>
Corresponds to the JSON property incomingEdges
6781 6782 6783 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6781 def incoming_edges @incoming_edges end |
#outgoing_edges ⇒ Array<Google::Apis::DataprocV1::RddOperationEdge>
Corresponds to the JSON property outgoingEdges
6786 6787 6788 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6786 def outgoing_edges @outgoing_edges end |
#root_cluster ⇒ Google::Apis::DataprocV1::RddOperationCluster
A grouping of nodes representing higher level constructs (stage, job etc.).
Corresponds to the JSON property rootCluster
6791 6792 6793 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6791 def root_cluster @root_cluster end |
#stage_id ⇒ Fixnum
Corresponds to the JSON property stageId
6796 6797 6798 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6796 def stage_id @stage_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6803 6804 6805 6806 6807 6808 6809 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6803 def update!(**args) @edges = args[:edges] if args.key?(:edges) @incoming_edges = args[:incoming_edges] if args.key?(:incoming_edges) @outgoing_edges = args[:outgoing_edges] if args.key?(:outgoing_edges) @root_cluster = args[:root_cluster] if args.key?(:root_cluster) @stage_id = args[:stage_id] if args.key?(:stage_id) end |