Class: Google::Apis::DataprocV1::RepairClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A request to repair a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RepairClusterRequest

Returns a new instance of RepairClusterRequest.



7054
7055
7056
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7054

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusterGoogle::Apis::DataprocV1::ClusterToRepair

Cluster to be repaired Corresponds to the JSON property cluster



7003
7004
7005
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7003

def cluster
  @cluster
end

#cluster_uuidString

Optional. Specifying the cluster_uuid means the RPC will fail (with error NOT_FOUND) if a cluster with the specified UUID does not exist. Corresponds to the JSON property clusterUuid

Returns:

  • (String)


7009
7010
7011
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7009

def cluster_uuid
  @cluster_uuid
end

#dataproc_super_userBoolean Also known as: dataproc_super_user?

Optional. Whether the request is submitted by Dataproc super user. If true, IAM will check 'dataproc.clusters.repair' permission instead of 'dataproc. clusters.update' permission. This is to give Dataproc superuser the ability to repair clusters without granting the overly broad update permission. Corresponds to the JSON property dataprocSuperUser

Returns:

  • (Boolean)


7017
7018
7019
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7017

def dataproc_super_user
  @dataproc_super_user
end

#graceful_decommission_timeoutString

Optional. Timeout for graceful YARN decommissioning. Graceful decommissioning facilitates the removal of cluster nodes without interrupting jobs in progress. The timeout specifies the amount of time to wait for jobs finish before forcefully removing nodes. The default timeout is 0 for forceful decommissioning, and the maximum timeout period is 1 day. (see JSON Mapping— Duration (https://developers.google.com/protocol-buffers/docs/proto3#json)). graceful_decommission_timeout is supported in Dataproc image versions 1.2+. Corresponds to the JSON property gracefulDecommissionTimeout

Returns:

  • (String)


7029
7030
7031
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7029

def graceful_decommission_timeout
  @graceful_decommission_timeout
end

#node_poolsArray<Google::Apis::DataprocV1::NodePool>

Optional. Node pools and corresponding repair action to be taken. All node pools should be unique in this request. i.e. Multiple entries for the same node pool id are not allowed. Corresponds to the JSON property nodePools



7036
7037
7038
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7036

def node_pools
  @node_pools
end

#parent_operation_idString

Optional. operation id of the parent operation sending the repair request Corresponds to the JSON property parentOperationId

Returns:

  • (String)


7041
7042
7043
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7041

def parent_operation_id
  @parent_operation_id
end

#request_idString

Optional. A unique ID used to identify the request. If the server receives two RepairClusterRequests with the same ID, the second request is ignored, and the first google.longrunning.Operation created and stored in the backend is returned.Recommendation: Set this value to a UUID (https://en.wikipedia.org/ wiki/Universally_unique_identifier).The ID must contain only letters (a-z, A-Z) , numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters. Corresponds to the JSON property requestId

Returns:

  • (String)


7052
7053
7054
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7052

def request_id
  @request_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7059
7060
7061
7062
7063
7064
7065
7066
7067
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7059

def update!(**args)
  @cluster = args[:cluster] if args.key?(:cluster)
  @cluster_uuid = args[:cluster_uuid] if args.key?(:cluster_uuid)
  @dataproc_super_user = args[:dataproc_super_user] if args.key?(:dataproc_super_user)
  @graceful_decommission_timeout = args[:graceful_decommission_timeout] if args.key?(:graceful_decommission_timeout)
  @node_pools = args[:node_pools] if args.key?(:node_pools)
  @parent_operation_id = args[:parent_operation_id] if args.key?(:parent_operation_id)
  @request_id = args[:request_id] if args.key?(:request_id)
end