Class: Google::Apis::DataprocV1::RepairClusterRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::RepairClusterRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A request to repair a cluster.
Instance Attribute Summary collapse
-
#cluster ⇒ Google::Apis::DataprocV1::ClusterToRepair
Cluster to be repaired Corresponds to the JSON property
cluster. -
#cluster_uuid ⇒ String
Optional.
-
#dataproc_super_user ⇒ Boolean
(also: #dataproc_super_user?)
Optional.
-
#graceful_decommission_timeout ⇒ String
Optional.
-
#node_pools ⇒ Array<Google::Apis::DataprocV1::NodePool>
Optional.
-
#parent_operation_id ⇒ String
Optional.
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RepairClusterRequest
constructor
A new instance of RepairClusterRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RepairClusterRequest
Returns a new instance of RepairClusterRequest.
6901 6902 6903 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6901 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster ⇒ Google::Apis::DataprocV1::ClusterToRepair
Cluster to be repaired
Corresponds to the JSON property cluster
6850 6851 6852 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6850 def cluster @cluster end |
#cluster_uuid ⇒ String
Optional. Specifying the cluster_uuid means the RPC will fail (with error
NOT_FOUND) if a cluster with the specified UUID does not exist.
Corresponds to the JSON property clusterUuid
6856 6857 6858 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6856 def cluster_uuid @cluster_uuid end |
#dataproc_super_user ⇒ Boolean Also known as: dataproc_super_user?
Optional. Whether the request is submitted by Dataproc super user. If true,
IAM will check 'dataproc.clusters.repair' permission instead of 'dataproc.
clusters.update' permission. This is to give Dataproc superuser the ability to
repair clusters without granting the overly broad update permission.
Corresponds to the JSON property dataprocSuperUser
6864 6865 6866 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6864 def dataproc_super_user @dataproc_super_user end |
#graceful_decommission_timeout ⇒ String
Optional. Timeout for graceful YARN decommissioning. Graceful decommissioning
facilitates the removal of cluster nodes without interrupting jobs in progress.
The timeout specifies the amount of time to wait for jobs finish before
forcefully removing nodes. The default timeout is 0 for forceful
decommissioning, and the maximum timeout period is 1 day. (see JSON Mapping—
Duration (https://developers.google.com/protocol-buffers/docs/proto3#json)).
graceful_decommission_timeout is supported in Dataproc image versions 1.2+.
Corresponds to the JSON property gracefulDecommissionTimeout
6876 6877 6878 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6876 def graceful_decommission_timeout @graceful_decommission_timeout end |
#node_pools ⇒ Array<Google::Apis::DataprocV1::NodePool>
Optional. Node pools and corresponding repair action to be taken. All node
pools should be unique in this request. i.e. Multiple entries for the same
node pool id are not allowed.
Corresponds to the JSON property nodePools
6883 6884 6885 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6883 def node_pools @node_pools end |
#parent_operation_id ⇒ String
Optional. operation id of the parent operation sending the repair request
Corresponds to the JSON property parentOperationId
6888 6889 6890 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6888 def parent_operation_id @parent_operation_id end |
#request_id ⇒ String
Optional. A unique ID used to identify the request. If the server receives two
RepairClusterRequests with the same ID, the second request is ignored, and the
first google.longrunning.Operation created and stored in the backend is
returned.Recommendation: Set this value to a UUID (https://en.wikipedia.org/
wiki/Universally_unique_identifier).The ID must contain only letters (a-z, A-Z)
, numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40
characters.
Corresponds to the JSON property requestId
6899 6900 6901 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6899 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 6906 def update!(**args) @cluster = args[:cluster] if args.key?(:cluster) @cluster_uuid = args[:cluster_uuid] if args.key?(:cluster_uuid) @dataproc_super_user = args[:dataproc_super_user] if args.key?(:dataproc_super_user) @graceful_decommission_timeout = args[:graceful_decommission_timeout] if args.key?(:graceful_decommission_timeout) @node_pools = args[:node_pools] if args.key?(:node_pools) @parent_operation_id = args[:parent_operation_id] if args.key?(:parent_operation_id) @request_id = args[:request_id] if args.key?(:request_id) end |