Class: Google::Apis::DataprocV1::RepairNodeGroupRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RepairNodeGroupRequest

Returns a new instance of RepairNodeGroupRequest.



7097
7098
7099
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7097

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_namesArray<String>

Required. Name of instances to be repaired. These instances must belong to specified node pool. Corresponds to the JSON property instanceNames

Returns:

  • (Array<String>)


7079
7080
7081
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7079

def instance_names
  @instance_names
end

#repair_actionString

Required. Repair action to take on specified resources of the node pool. Corresponds to the JSON property repairAction

Returns:

  • (String)


7084
7085
7086
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7084

def repair_action
  @repair_action
end

#request_idString

Optional. A unique ID used to identify the request. If the server receives two RepairNodeGroupRequest with the same ID, the second request is ignored and the first google.longrunning.Operation created and stored in the backend is returned.Recommendation: Set this value to a UUID (https://en.wikipedia.org/ wiki/Universally_unique_identifier).The ID must contain only letters (a-z, A-Z) , numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters. Corresponds to the JSON property requestId

Returns:

  • (String)


7095
7096
7097
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7095

def request_id
  @request_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7102
7103
7104
7105
7106
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7102

def update!(**args)
  @instance_names = args[:instance_names] if args.key?(:instance_names)
  @repair_action = args[:repair_action] if args.key?(:repair_action)
  @request_id = args[:request_id] if args.key?(:request_id)
end