Class: Google::Apis::DataprocV1::ResizeNodeGroupRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::ResizeNodeGroupRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A request to resize a node group.
Instance Attribute Summary collapse
-
#graceful_decommission_timeout ⇒ String
Optional.
-
#parent_operation_id ⇒ String
Optional.
-
#request_id ⇒ String
Optional.
-
#size ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResizeNodeGroupRequest
constructor
A new instance of ResizeNodeGroupRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResizeNodeGroupRequest
Returns a new instance of ResizeNodeGroupRequest.
7198 7199 7200 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7198 def initialize(**args) update!(**args) end |
Instance Attribute Details
#graceful_decommission_timeout ⇒ String
Optional. Timeout for graceful YARN decommissioning. Graceful decommissioning (
https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/scaling-
clusters#graceful_decommissioning) allows the removal of nodes from the
Compute Engine node group without interrupting jobs in progress. This timeout
specifies how long to wait for jobs in progress to finish before forcefully
removing nodes (and potentially interrupting jobs). Default timeout is 0 (for
forceful decommission), and the maximum allowed timeout is 1 day. (see JSON
representation of Duration (https://developers.google.com/protocol-buffers/
docs/proto3#json)).Only supported on Dataproc image versions 1.2 and higher.
Corresponds to the JSON property gracefulDecommissionTimeout
7171 7172 7173 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7171 def graceful_decommission_timeout @graceful_decommission_timeout end |
#parent_operation_id ⇒ String
Optional. operation id of the parent operation sending the resize request
Corresponds to the JSON property parentOperationId
7176 7177 7178 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7176 def parent_operation_id @parent_operation_id end |
#request_id ⇒ String
Optional. A unique ID used to identify the request. If the server receives two
ResizeNodeGroupRequest (https://cloud.google.com/dataproc/docs/reference/rpc/
google.cloud.dataproc.v1#google.cloud.dataproc.v1.ResizeNodeGroupRequests)
with the same ID, the second request is ignored and the first google.
longrunning.Operation created and stored in the backend is returned.
Recommendation: Set this value to a UUID (https://en.wikipedia.org/wiki/
Universally_unique_identifier).The ID must contain only letters (a-z, A-Z),
numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40
characters.
Corresponds to the JSON property requestId
7189 7190 7191 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7189 def request_id @request_id end |
#size ⇒ Fixnum
Required. The number of running instances for the node group to maintain. The
group adds or removes instances to maintain the number of instances specified
by this parameter.
Corresponds to the JSON property size
7196 7197 7198 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7196 def size @size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7203 7204 7205 7206 7207 7208 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7203 def update!(**args) @graceful_decommission_timeout = args[:graceful_decommission_timeout] if args.key?(:graceful_decommission_timeout) @parent_operation_id = args[:parent_operation_id] if args.key?(:parent_operation_id) @request_id = args[:request_id] if args.key?(:request_id) @size = args[:size] if args.key?(:size) end |