Class: Google::Apis::DataprocV1::RuntimeConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Runtime configuration for a workload.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RuntimeConfig

Returns a new instance of RuntimeConfig.



7299
7300
7301
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7299

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autotuning_configGoogle::Apis::DataprocV1::AutotuningConfig

Autotuning configuration of the workload. Corresponds to the JSON property autotuningConfig



7269
7270
7271
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7269

def autotuning_config
  @autotuning_config
end

#cohortString

Optional. Cohort identifier. Identifies families of the workloads that have the same shape, for example, daily ETL jobs. Corresponds to the JSON property cohort

Returns:

  • (String)


7275
7276
7277
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7275

def cohort
  @cohort
end

#container_imageString

Optional. Optional custom container image for the job runtime environment. If not specified, a default container image will be used. Corresponds to the JSON property containerImage

Returns:

  • (String)


7281
7282
7283
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7281

def container_image
  @container_image
end

#propertiesHash<String,String>

Optional. A mapping of property names to values, which are used to configure workload execution. Corresponds to the JSON property properties

Returns:

  • (Hash<String,String>)


7287
7288
7289
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7287

def properties
  @properties
end

#repository_configGoogle::Apis::DataprocV1::RepositoryConfig

Configuration for dependency repositories Corresponds to the JSON property repositoryConfig



7292
7293
7294
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7292

def repository_config
  @repository_config
end

#versionString

Optional. Version of the batch runtime. Corresponds to the JSON property version

Returns:

  • (String)


7297
7298
7299
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7297

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7304
7305
7306
7307
7308
7309
7310
7311
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7304

def update!(**args)
  @autotuning_config = args[:autotuning_config] if args.key?(:autotuning_config)
  @cohort = args[:cohort] if args.key?(:cohort)
  @container_image = args[:container_image] if args.key?(:container_image)
  @properties = args[:properties] if args.key?(:properties)
  @repository_config = args[:repository_config] if args.key?(:repository_config)
  @version = args[:version] if args.key?(:version)
end