Class: Google::Apis::DataprocV1::RuntimeConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::RuntimeConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Runtime configuration for a workload.
Instance Attribute Summary collapse
-
#autotuning_config ⇒ Google::Apis::DataprocV1::AutotuningConfig
Autotuning configuration of the workload.
-
#cohort ⇒ String
Optional.
-
#container_image ⇒ String
Optional.
-
#properties ⇒ Hash<String,String>
Optional.
-
#repository_config ⇒ Google::Apis::DataprocV1::RepositoryConfig
Configuration for dependency repositories Corresponds to the JSON property
repositoryConfig. -
#version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RuntimeConfig
constructor
A new instance of RuntimeConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RuntimeConfig
Returns a new instance of RuntimeConfig.
7154 7155 7156 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7154 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autotuning_config ⇒ Google::Apis::DataprocV1::AutotuningConfig
Autotuning configuration of the workload.
Corresponds to the JSON property autotuningConfig
7124 7125 7126 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7124 def autotuning_config @autotuning_config end |
#cohort ⇒ String
Optional. Cohort identifier. Identifies families of the workloads having the
same shape, e.g. daily ETL jobs.
Corresponds to the JSON property cohort
7130 7131 7132 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7130 def cohort @cohort end |
#container_image ⇒ String
Optional. Optional custom container image for the job runtime environment. If
not specified, a default container image will be used.
Corresponds to the JSON property containerImage
7136 7137 7138 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7136 def container_image @container_image end |
#properties ⇒ Hash<String,String>
Optional. A mapping of property names to values, which are used to configure
workload execution.
Corresponds to the JSON property properties
7142 7143 7144 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7142 def properties @properties end |
#repository_config ⇒ Google::Apis::DataprocV1::RepositoryConfig
Configuration for dependency repositories
Corresponds to the JSON property repositoryConfig
7147 7148 7149 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7147 def repository_config @repository_config end |
#version ⇒ String
Optional. Version of the batch runtime.
Corresponds to the JSON property version
7152 7153 7154 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7152 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7159 7160 7161 7162 7163 7164 7165 7166 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7159 def update!(**args) @autotuning_config = args[:autotuning_config] if args.key?(:autotuning_config) @cohort = args[:cohort] if args.key?(:cohort) @container_image = args[:container_image] if args.key?(:container_image) @properties = args[:properties] if args.key?(:properties) @repository_config = args[:repository_config] if args.key?(:repository_config) @version = args[:version] if args.key?(:version) end |