Class: Google::Apis::DataprocV1::RuntimeInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Runtime information about workload execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RuntimeInfo

Returns a new instance of RuntimeInfo.



7385
7386
7387
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7385

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approximate_usageGoogle::Apis::DataprocV1::UsageMetrics

Usage metrics represent approximate total resources consumed by a workload. Corresponds to the JSON property approximateUsage



7350
7351
7352
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7350

def approximate_usage
  @approximate_usage
end

#cohort_infoGoogle::Apis::DataprocV1::CohortInfo

Information about the cohort that the workload belongs to. Corresponds to the JSON property cohortInfo



7355
7356
7357
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7355

def cohort_info
  @cohort_info
end

#current_usageGoogle::Apis::DataprocV1::UsageSnapshot

The usage snapshot represents the resources consumed by a workload at a specified time. Corresponds to the JSON property currentUsage



7361
7362
7363
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7361

def current_usage
  @current_usage
end

#diagnostic_output_uriString

Output only. A URI pointing to the location of the diagnostics tarball. Corresponds to the JSON property diagnosticOutputUri

Returns:

  • (String)


7366
7367
7368
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7366

def diagnostic_output_uri
  @diagnostic_output_uri
end

#endpointsHash<String,String>

Output only. Map of remote access endpoints (such as web interfaces and APIs) to their URIs. Corresponds to the JSON property endpoints

Returns:

  • (Hash<String,String>)


7372
7373
7374
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7372

def endpoints
  @endpoints
end

#output_uriString

Output only. A URI pointing to the location of the stdout and stderr of the workload. Corresponds to the JSON property outputUri

Returns:

  • (String)


7378
7379
7380
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7378

def output_uri
  @output_uri
end

#properties_infoGoogle::Apis::DataprocV1::PropertiesInfo

Properties of the workload organized by origin. Corresponds to the JSON property propertiesInfo



7383
7384
7385
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7383

def properties_info
  @properties_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7390
7391
7392
7393
7394
7395
7396
7397
7398
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7390

def update!(**args)
  @approximate_usage = args[:approximate_usage] if args.key?(:approximate_usage)
  @cohort_info = args[:cohort_info] if args.key?(:cohort_info)
  @current_usage = args[:current_usage] if args.key?(:current_usage)
  @diagnostic_output_uri = args[:diagnostic_output_uri] if args.key?(:diagnostic_output_uri)
  @endpoints = args[:endpoints] if args.key?(:endpoints)
  @output_uri = args[:output_uri] if args.key?(:output_uri)
  @properties_info = args[:properties_info] if args.key?(:properties_info)
end