Class: Google::Apis::DataprocV1::RuntimeInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Runtime information about workload execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RuntimeInfo

Returns a new instance of RuntimeInfo.



7378
7379
7380
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approximate_usageGoogle::Apis::DataprocV1::UsageMetrics

Usage metrics represent approximate total resources consumed by a workload. Corresponds to the JSON property approximateUsage



7343
7344
7345
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7343

def approximate_usage
  @approximate_usage
end

#cohort_infoGoogle::Apis::DataprocV1::CohortInfo

Information about the cohort that the workload belongs to. Corresponds to the JSON property cohortInfo



7348
7349
7350
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7348

def cohort_info
  @cohort_info
end

#current_usageGoogle::Apis::DataprocV1::UsageSnapshot

The usage snapshot represents the resources consumed by a workload at a specified time. Corresponds to the JSON property currentUsage



7354
7355
7356
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7354

def current_usage
  @current_usage
end

#diagnostic_output_uriString

Output only. A URI pointing to the location of the diagnostics tarball. Corresponds to the JSON property diagnosticOutputUri

Returns:

  • (String)


7359
7360
7361
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7359

def diagnostic_output_uri
  @diagnostic_output_uri
end

#endpointsHash<String,String>

Output only. Map of remote access endpoints (such as web interfaces and APIs) to their URIs. Corresponds to the JSON property endpoints

Returns:

  • (Hash<String,String>)


7365
7366
7367
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7365

def endpoints
  @endpoints
end

#output_uriString

Output only. A URI pointing to the location of the stdout and stderr of the workload. Corresponds to the JSON property outputUri

Returns:

  • (String)


7371
7372
7373
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7371

def output_uri
  @output_uri
end

#properties_infoGoogle::Apis::DataprocV1::PropertiesInfo

Properties of the workload organized by origin. Corresponds to the JSON property propertiesInfo



7376
7377
7378
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7376

def properties_info
  @properties_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7383
7384
7385
7386
7387
7388
7389
7390
7391
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7383

def update!(**args)
  @approximate_usage = args[:approximate_usage] if args.key?(:approximate_usage)
  @cohort_info = args[:cohort_info] if args.key?(:cohort_info)
  @current_usage = args[:current_usage] if args.key?(:current_usage)
  @diagnostic_output_uri = args[:diagnostic_output_uri] if args.key?(:diagnostic_output_uri)
  @endpoints = args[:endpoints] if args.key?(:endpoints)
  @output_uri = args[:output_uri] if args.key?(:output_uri)
  @properties_info = args[:properties_info] if args.key?(:properties_info)
end