Class: Google::Apis::DataprocV1::RuntimeInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Runtime information about workload execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RuntimeInfo

Returns a new instance of RuntimeInfo.



7364
7365
7366
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7364

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approximate_usageGoogle::Apis::DataprocV1::UsageMetrics

Usage metrics represent approximate total resources consumed by a workload. Corresponds to the JSON property approximateUsage



7329
7330
7331
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7329

def approximate_usage
  @approximate_usage
end

#cohort_infoGoogle::Apis::DataprocV1::CohortInfo

Information about the cohort that the workload belongs to. Corresponds to the JSON property cohortInfo



7334
7335
7336
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7334

def cohort_info
  @cohort_info
end

#current_usageGoogle::Apis::DataprocV1::UsageSnapshot

The usage snapshot represents the resources consumed by a workload at a specified time. Corresponds to the JSON property currentUsage



7340
7341
7342
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7340

def current_usage
  @current_usage
end

#diagnostic_output_uriString

Output only. A URI pointing to the location of the diagnostics tarball. Corresponds to the JSON property diagnosticOutputUri

Returns:

  • (String)


7345
7346
7347
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7345

def diagnostic_output_uri
  @diagnostic_output_uri
end

#endpointsHash<String,String>

Output only. Map of remote access endpoints (such as web interfaces and APIs) to their URIs. Corresponds to the JSON property endpoints

Returns:

  • (Hash<String,String>)


7351
7352
7353
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7351

def endpoints
  @endpoints
end

#output_uriString

Output only. A URI pointing to the location of the stdout and stderr of the workload. Corresponds to the JSON property outputUri

Returns:

  • (String)


7357
7358
7359
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7357

def output_uri
  @output_uri
end

#properties_infoGoogle::Apis::DataprocV1::PropertiesInfo

Properties of the workload organized by origin. Corresponds to the JSON property propertiesInfo



7362
7363
7364
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7362

def properties_info
  @properties_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7369
7370
7371
7372
7373
7374
7375
7376
7377
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7369

def update!(**args)
  @approximate_usage = args[:approximate_usage] if args.key?(:approximate_usage)
  @cohort_info = args[:cohort_info] if args.key?(:cohort_info)
  @current_usage = args[:current_usage] if args.key?(:current_usage)
  @diagnostic_output_uri = args[:diagnostic_output_uri] if args.key?(:diagnostic_output_uri)
  @endpoints = args[:endpoints] if args.key?(:endpoints)
  @output_uri = args[:output_uri] if args.key?(:output_uri)
  @properties_info = args[:properties_info] if args.key?(:properties_info)
end