Class: Google::Apis::DataprocV1::RuntimeInfo
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::RuntimeInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Runtime information about workload execution.
Instance Attribute Summary collapse
-
#approximate_usage ⇒ Google::Apis::DataprocV1::UsageMetrics
Usage metrics represent approximate total resources consumed by a workload.
-
#current_usage ⇒ Google::Apis::DataprocV1::UsageSnapshot
The usage snapshot represents the resources consumed by a workload at a specified time.
-
#diagnostic_output_uri ⇒ String
Output only.
-
#endpoints ⇒ Hash<String,String>
Output only.
-
#output_uri ⇒ String
Output only.
-
#properties_info ⇒ Google::Apis::DataprocV1::PropertiesInfo
Properties of the workload organized by origin.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RuntimeInfo
constructor
A new instance of RuntimeInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RuntimeInfo
Returns a new instance of RuntimeInfo.
7206 7207 7208 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approximate_usage ⇒ Google::Apis::DataprocV1::UsageMetrics
Usage metrics represent approximate total resources consumed by a workload.
Corresponds to the JSON property approximateUsage
7176 7177 7178 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7176 def approximate_usage @approximate_usage end |
#current_usage ⇒ Google::Apis::DataprocV1::UsageSnapshot
The usage snapshot represents the resources consumed by a workload at a
specified time.
Corresponds to the JSON property currentUsage
7182 7183 7184 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7182 def current_usage @current_usage end |
#diagnostic_output_uri ⇒ String
Output only. A URI pointing to the location of the diagnostics tarball.
Corresponds to the JSON property diagnosticOutputUri
7187 7188 7189 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7187 def diagnostic_output_uri @diagnostic_output_uri end |
#endpoints ⇒ Hash<String,String>
Output only. Map of remote access endpoints (such as web interfaces and APIs)
to their URIs.
Corresponds to the JSON property endpoints
7193 7194 7195 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7193 def endpoints @endpoints end |
#output_uri ⇒ String
Output only. A URI pointing to the location of the stdout and stderr of the
workload.
Corresponds to the JSON property outputUri
7199 7200 7201 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7199 def output_uri @output_uri end |
#properties_info ⇒ Google::Apis::DataprocV1::PropertiesInfo
Properties of the workload organized by origin.
Corresponds to the JSON property propertiesInfo
7204 7205 7206 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7204 def properties_info @properties_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7211 7212 7213 7214 7215 7216 7217 7218 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7211 def update!(**args) @approximate_usage = args[:approximate_usage] if args.key?(:approximate_usage) @current_usage = args[:current_usage] if args.key?(:current_usage) @diagnostic_output_uri = args[:diagnostic_output_uri] if args.key?(:diagnostic_output_uri) @endpoints = args[:endpoints] if args.key?(:endpoints) @output_uri = args[:output_uri] if args.key?(:output_uri) @properties_info = args[:properties_info] if args.key?(:properties_info) end |