Class: Google::Apis::DataprocV1::SearchSessionSparkApplicationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A list of summary of Spark Applications

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchSessionSparkApplicationsResponse

Returns a new instance of SearchSessionSparkApplicationsResponse.



7577
7578
7579
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

This token is included in the response if there are more results to fetch. To fetch additional results, provide this value as the page_token in a subsequent SearchSessionSparkApplicationsRequest. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7570
7571
7572
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7570

def next_page_token
  @next_page_token
end

#spark_applicationsArray<Google::Apis::DataprocV1::SparkApplication>

Output only. High level information corresponding to an application. Corresponds to the JSON property sparkApplications



7575
7576
7577
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7575

def spark_applications
  @spark_applications
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7582
7583
7584
7585
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7582

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @spark_applications = args[:spark_applications] if args.key?(:spark_applications)
end