Class: Google::Apis::DataprocV1::SearchSessionSparkApplicationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::SearchSessionSparkApplicationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A list of summary of Spark Applications
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
This token is included in the response if there are more results to fetch.
-
#spark_applications ⇒ Array<Google::Apis::DataprocV1::SparkApplication>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchSessionSparkApplicationsResponse
constructor
A new instance of SearchSessionSparkApplicationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchSessionSparkApplicationsResponse
Returns a new instance of SearchSessionSparkApplicationsResponse.
7426 7427 7428 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7426 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
This token is included in the response if there are more results to fetch. To
fetch additional results, provide this value as the page_token in a subsequent
SearchSessionSparkApplicationsRequest.
Corresponds to the JSON property nextPageToken
7419 7420 7421 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7419 def next_page_token @next_page_token end |
#spark_applications ⇒ Array<Google::Apis::DataprocV1::SparkApplication>
Output only. High level information corresponding to an application.
Corresponds to the JSON property sparkApplications
7424 7425 7426 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7424 def spark_applications @spark_applications end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7431 7432 7433 7434 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7431 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @spark_applications = args[:spark_applications] if args.key?(:spark_applications) end |