Class: Google::Apis::DataprocV1::SearchSparkApplicationExecutorsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

List of Executors associated with a Spark Application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchSparkApplicationExecutorsResponse

Returns a new instance of SearchSparkApplicationExecutorsResponse.



7480
7481
7482
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7480

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

This token is included in the response if there are more results to fetch. To fetch additional results, provide this value as the page_token in a subsequent SearchSparkApplicationExecutorsListRequest. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7473
7474
7475
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7473

def next_page_token
  @next_page_token
end

#spark_application_executorsArray<Google::Apis::DataprocV1::ExecutorSummary>

Details about executors used by the application. Corresponds to the JSON property sparkApplicationExecutors



7478
7479
7480
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7478

def spark_application_executors
  @spark_application_executors
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7485
7486
7487
7488
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7485

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @spark_application_executors = args[:spark_application_executors] if args.key?(:spark_application_executors)
end