Class: Google::Apis::DataprocV1::Session

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A representation of a session.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Session

Returns a new instance of Session.



7925
7926
7927
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7925

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the session was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7837
7838
7839
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7837

def create_time
  @create_time
end

#creatorString

Output only. The email address of the user who created the session. Corresponds to the JSON property creator

Returns:

  • (String)


7842
7843
7844
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7842

def creator
  @creator
end

#environment_configGoogle::Apis::DataprocV1::EnvironmentConfig

Environment configuration for a workload. Corresponds to the JSON property environmentConfig



7847
7848
7849
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7847

def environment_config
  @environment_config
end

#jupyter_sessionGoogle::Apis::DataprocV1::JupyterConfig

Jupyter configuration for an interactive session. Corresponds to the JSON property jupyterSession



7852
7853
7854
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7852

def jupyter_session
  @jupyter_session
end

#labelsHash<String,String>

Optional. The labels to associate with the session. Label keys must contain 1 to 63 characters, and must conform to RFC 1035 (https://www.ietf.org/rfc/ rfc1035.txt). Label values may be empty, but, if present, must contain 1 to 63 characters, and must conform to RFC 1035 (https://www.ietf.org/rfc/rfc1035.txt) . No more than 32 labels can be associated with a session. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


7861
7862
7863
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7861

def labels
  @labels
end

#nameString

Identifier. The resource name of the session. Corresponds to the JSON property name

Returns:

  • (String)


7866
7867
7868
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7866

def name
  @name
end

#runtime_configGoogle::Apis::DataprocV1::RuntimeConfig

Runtime configuration for a workload. Corresponds to the JSON property runtimeConfig



7871
7872
7873
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7871

def runtime_config
  @runtime_config
end

#runtime_infoGoogle::Apis::DataprocV1::RuntimeInfo

Runtime information about workload execution. Corresponds to the JSON property runtimeInfo



7876
7877
7878
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7876

def runtime_info
  @runtime_info
end

#session_templateString

Optional. The session template used by the session.Only resource names, including project ID and location, are valid.Example: * https://www.googleapis. com/compute/v1/projects/[project_id]/locations/[dataproc_region]/ sessionTemplates/[template_id] * projects/[project_id]/locations/[ dataproc_region]/sessionTemplates/[template_id]The template must be in the same project and Dataproc region as the session. Corresponds to the JSON property sessionTemplate

Returns:

  • (String)


7886
7887
7888
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7886

def session_template
  @session_template
end

#spark_connect_sessionGoogle::Apis::DataprocV1::SparkConnectConfig

Spark connect configuration for an interactive session. Corresponds to the JSON property sparkConnectSession



7891
7892
7893
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7891

def spark_connect_session
  @spark_connect_session
end

#stateString

Output only. A state of the session. Corresponds to the JSON property state

Returns:

  • (String)


7896
7897
7898
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7896

def state
  @state
end

#state_historyArray<Google::Apis::DataprocV1::SessionStateHistory>

Output only. Historical state information for the session. Corresponds to the JSON property stateHistory



7901
7902
7903
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7901

def state_history
  @state_history
end

#state_messageString

Output only. Session state details, such as the failure description if the state is FAILED. Corresponds to the JSON property stateMessage

Returns:

  • (String)


7907
7908
7909
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7907

def state_message
  @state_message
end

#state_timeString

Output only. The time when the session entered the current state. Corresponds to the JSON property stateTime

Returns:

  • (String)


7912
7913
7914
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7912

def state_time
  @state_time
end

#userString

Optional. The email address of the user who owns the session. Corresponds to the JSON property user

Returns:

  • (String)


7917
7918
7919
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7917

def user
  @user
end

#uuidString

Output only. A session UUID (Unique Universal Identifier). The service generates this value when it creates the session. Corresponds to the JSON property uuid

Returns:

  • (String)


7923
7924
7925
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7923

def uuid
  @uuid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7930
7931
7932
7933
7934
7935
7936
7937
7938
7939
7940
7941
7942
7943
7944
7945
7946
7947
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7930

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creator = args[:creator] if args.key?(:creator)
  @environment_config = args[:environment_config] if args.key?(:environment_config)
  @jupyter_session = args[:jupyter_session] if args.key?(:jupyter_session)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @runtime_config = args[:runtime_config] if args.key?(:runtime_config)
  @runtime_info = args[:runtime_info] if args.key?(:runtime_info)
  @session_template = args[:session_template] if args.key?(:session_template)
  @spark_connect_session = args[:spark_connect_session] if args.key?(:spark_connect_session)
  @state = args[:state] if args.key?(:state)
  @state_history = args[:state_history] if args.key?(:state_history)
  @state_message = args[:state_message] if args.key?(:state_message)
  @state_time = args[:state_time] if args.key?(:state_time)
  @user = args[:user] if args.key?(:user)
  @uuid = args[:uuid] if args.key?(:uuid)
end