Class: Google::Apis::DataprocV1::Session
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::Session
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A representation of a session.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#creator ⇒ String
Output only.
-
#environment_config ⇒ Google::Apis::DataprocV1::EnvironmentConfig
Environment configuration for a workload.
-
#jupyter_session ⇒ Google::Apis::DataprocV1::JupyterConfig
Jupyter configuration for an interactive session.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#runtime_config ⇒ Google::Apis::DataprocV1::RuntimeConfig
Runtime configuration for a workload.
-
#runtime_info ⇒ Google::Apis::DataprocV1::RuntimeInfo
Runtime information about workload execution.
-
#session_template ⇒ String
Optional.
-
#spark_connect_session ⇒ Google::Apis::DataprocV1::SparkConnectConfig
Spark connect configuration for an interactive session.
-
#state ⇒ String
Output only.
-
#state_history ⇒ Array<Google::Apis::DataprocV1::SessionStateHistory>
Output only.
-
#state_message ⇒ String
Output only.
-
#state_time ⇒ String
Output only.
-
#user ⇒ String
Optional.
-
#uuid ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Session
constructor
A new instance of Session.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Session
Returns a new instance of Session.
7774 7775 7776 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7774 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the session was created.
Corresponds to the JSON property createTime
7686 7687 7688 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7686 def create_time @create_time end |
#creator ⇒ String
Output only. The email address of the user who created the session.
Corresponds to the JSON property creator
7691 7692 7693 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7691 def creator @creator end |
#environment_config ⇒ Google::Apis::DataprocV1::EnvironmentConfig
Environment configuration for a workload.
Corresponds to the JSON property environmentConfig
7696 7697 7698 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7696 def environment_config @environment_config end |
#jupyter_session ⇒ Google::Apis::DataprocV1::JupyterConfig
Jupyter configuration for an interactive session.
Corresponds to the JSON property jupyterSession
7701 7702 7703 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7701 def jupyter_session @jupyter_session end |
#labels ⇒ Hash<String,String>
Optional. The labels to associate with the session. Label keys must contain 1
to 63 characters, and must conform to RFC 1035 (https://www.ietf.org/rfc/
rfc1035.txt). Label values may be empty, but, if present, must contain 1 to 63
characters, and must conform to RFC 1035 (https://www.ietf.org/rfc/rfc1035.txt)
. No more than 32 labels can be associated with a session.
Corresponds to the JSON property labels
7710 7711 7712 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7710 def labels @labels end |
#name ⇒ String
Identifier. The resource name of the session.
Corresponds to the JSON property name
7715 7716 7717 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7715 def name @name end |
#runtime_config ⇒ Google::Apis::DataprocV1::RuntimeConfig
Runtime configuration for a workload.
Corresponds to the JSON property runtimeConfig
7720 7721 7722 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7720 def runtime_config @runtime_config end |
#runtime_info ⇒ Google::Apis::DataprocV1::RuntimeInfo
Runtime information about workload execution.
Corresponds to the JSON property runtimeInfo
7725 7726 7727 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7725 def runtime_info @runtime_info end |
#session_template ⇒ String
Optional. The session template used by the session.Only resource names,
including project ID and location, are valid.Example: * https://www.googleapis.
com/compute/v1/projects/[project_id]/locations/[dataproc_region]/
sessionTemplates/[template_id] * projects/[project_id]/locations/[
dataproc_region]/sessionTemplates/[template_id]The template must be in the
same project and Dataproc region as the session.
Corresponds to the JSON property sessionTemplate
7735 7736 7737 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7735 def session_template @session_template end |
#spark_connect_session ⇒ Google::Apis::DataprocV1::SparkConnectConfig
Spark connect configuration for an interactive session.
Corresponds to the JSON property sparkConnectSession
7740 7741 7742 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7740 def spark_connect_session @spark_connect_session end |
#state ⇒ String
Output only. A state of the session.
Corresponds to the JSON property state
7745 7746 7747 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7745 def state @state end |
#state_history ⇒ Array<Google::Apis::DataprocV1::SessionStateHistory>
Output only. Historical state information for the session.
Corresponds to the JSON property stateHistory
7750 7751 7752 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7750 def state_history @state_history end |
#state_message ⇒ String
Output only. Session state details, such as the failure description if the
state is FAILED.
Corresponds to the JSON property stateMessage
7756 7757 7758 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7756 def @state_message end |
#state_time ⇒ String
Output only. The time when the session entered the current state.
Corresponds to the JSON property stateTime
7761 7762 7763 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7761 def state_time @state_time end |
#user ⇒ String
Optional. The email address of the user who owns the session.
Corresponds to the JSON property user
7766 7767 7768 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7766 def user @user end |
#uuid ⇒ String
Output only. A session UUID (Unique Universal Identifier). The service
generates this value when it creates the session.
Corresponds to the JSON property uuid
7772 7773 7774 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7772 def uuid @uuid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7779 7780 7781 7782 7783 7784 7785 7786 7787 7788 7789 7790 7791 7792 7793 7794 7795 7796 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7779 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @creator = args[:creator] if args.key?(:creator) @environment_config = args[:environment_config] if args.key?(:environment_config) @jupyter_session = args[:jupyter_session] if args.key?(:jupyter_session) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @runtime_config = args[:runtime_config] if args.key?(:runtime_config) @runtime_info = args[:runtime_info] if args.key?(:runtime_info) @session_template = args[:session_template] if args.key?(:session_template) @spark_connect_session = args[:spark_connect_session] if args.key?(:spark_connect_session) @state = args[:state] if args.key?(:state) @state_history = args[:state_history] if args.key?(:state_history) @state_message = args[:state_message] if args.key?(:state_message) @state_time = args[:state_time] if args.key?(:state_time) @user = args[:user] if args.key?(:user) @uuid = args[:uuid] if args.key?(:uuid) end |