Class: Google::Apis::DataprocV1::SessionStateHistory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Historical state information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SessionStateHistory

Returns a new instance of SessionStateHistory.



7879
7880
7881
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7879

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stateString

Output only. The state of the session at this point in the session history. Corresponds to the JSON property state

Returns:

  • (String)


7867
7868
7869
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7867

def state
  @state
end

#state_messageString

Output only. Details about the state at this point in the session history. Corresponds to the JSON property stateMessage

Returns:

  • (String)


7872
7873
7874
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7872

def state_message
  @state_message
end

#state_start_timeString

Output only. The time when the session entered the historical state. Corresponds to the JSON property stateStartTime

Returns:

  • (String)


7877
7878
7879
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7877

def state_start_time
  @state_start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7884
7885
7886
7887
7888
# File 'lib/google/apis/dataproc_v1/classes.rb', line 7884

def update!(**args)
  @state = args[:state] if args.key?(:state)
  @state_message = args[:state_message] if args.key?(:state_message)
  @state_start_time = args[:state_start_time] if args.key?(:state_start_time)
end