Class: Google::Apis::DataprocV1::SessionTemplate
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::SessionTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A representation of a session template.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#creator ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#environment_config ⇒ Google::Apis::DataprocV1::EnvironmentConfig
Environment configuration for a workload.
-
#jupyter_session ⇒ Google::Apis::DataprocV1::JupyterConfig
Jupyter configuration for an interactive session.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Required.
-
#runtime_config ⇒ Google::Apis::DataprocV1::RuntimeConfig
Runtime configuration for a workload.
-
#spark_connect_session ⇒ Google::Apis::DataprocV1::SparkConnectConfig
Spark connect configuration for an interactive session.
-
#update_time ⇒ String
Output only.
-
#uuid ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SessionTemplate
constructor
A new instance of SessionTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SessionTemplate
Returns a new instance of SessionTemplate.
8128 8129 8130 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8128 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the template was created.
Corresponds to the JSON property createTime
8071 8072 8073 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8071 def create_time @create_time end |
#creator ⇒ String
Output only. The email address of the user who created the template.
Corresponds to the JSON property creator
8076 8077 8078 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8076 def creator @creator end |
#description ⇒ String
Optional. Brief description of the template.
Corresponds to the JSON property description
8081 8082 8083 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8081 def description @description end |
#environment_config ⇒ Google::Apis::DataprocV1::EnvironmentConfig
Environment configuration for a workload.
Corresponds to the JSON property environmentConfig
8086 8087 8088 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8086 def environment_config @environment_config end |
#jupyter_session ⇒ Google::Apis::DataprocV1::JupyterConfig
Jupyter configuration for an interactive session.
Corresponds to the JSON property jupyterSession
8091 8092 8093 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8091 def jupyter_session @jupyter_session end |
#labels ⇒ Hash<String,String>
Optional. Labels to associate with sessions created using this template. Label
keys must contain 1 to 63 characters, and must conform to RFC 1035 (https://
www.ietf.org/rfc/rfc1035.txt). Label values can be empty, but, if present,
must contain 1 to 63 characters and conform to RFC 1035 (https://www.ietf.org/
rfc/rfc1035.txt). No more than 32 labels can be associated with a session.
Corresponds to the JSON property labels
8100 8101 8102 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8100 def labels @labels end |
#name ⇒ String
Required. Identifier. The resource name of the session template.
Corresponds to the JSON property name
8105 8106 8107 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8105 def name @name end |
#runtime_config ⇒ Google::Apis::DataprocV1::RuntimeConfig
Runtime configuration for a workload.
Corresponds to the JSON property runtimeConfig
8110 8111 8112 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8110 def runtime_config @runtime_config end |
#spark_connect_session ⇒ Google::Apis::DataprocV1::SparkConnectConfig
Spark connect configuration for an interactive session.
Corresponds to the JSON property sparkConnectSession
8115 8116 8117 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8115 def spark_connect_session @spark_connect_session end |
#update_time ⇒ String
Output only. The time the template was last updated.
Corresponds to the JSON property updateTime
8120 8121 8122 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8120 def update_time @update_time end |
#uuid ⇒ String
Output only. A session template UUID (Unique Universal Identifier). The
service generates this value when it creates the session template.
Corresponds to the JSON property uuid
8126 8127 8128 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8126 def uuid @uuid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 8144 8145 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8133 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @creator = args[:creator] if args.key?(:creator) @description = args[:description] if args.key?(:description) @environment_config = args[:environment_config] if args.key?(:environment_config) @jupyter_session = args[:jupyter_session] if args.key?(:jupyter_session) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @runtime_config = args[:runtime_config] if args.key?(:runtime_config) @spark_connect_session = args[:spark_connect_session] if args.key?(:spark_connect_session) @update_time = args[:update_time] if args.key?(:update_time) @uuid = args[:uuid] if args.key?(:uuid) end |