Class: Google::Apis::DataprocV1::ShuffleReadQuantileMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ShuffleReadQuantileMetrics

Returns a new instance of ShuffleReadQuantileMetrics.



8487
8488
8489
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8487

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fetch_wait_time_millisGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property fetchWaitTimeMillis



8432
8433
8434
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8432

def fetch_wait_time_millis
  @fetch_wait_time_millis
end

#local_blocks_fetchedGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property localBlocksFetched



8438
8439
8440
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8438

def local_blocks_fetched
  @local_blocks_fetched
end

#read_bytesGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property readBytes



8444
8445
8446
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8444

def read_bytes
  @read_bytes
end

#read_recordsGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property readRecords



8450
8451
8452
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8450

def read_records
  @read_records
end

#remote_blocks_fetchedGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property remoteBlocksFetched



8456
8457
8458
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8456

def remote_blocks_fetched
  @remote_blocks_fetched
end

#remote_bytes_readGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property remoteBytesRead



8462
8463
8464
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8462

def remote_bytes_read
  @remote_bytes_read
end

#remote_bytes_read_to_diskGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property remoteBytesReadToDisk



8468
8469
8470
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8468

def remote_bytes_read_to_disk
  @remote_bytes_read_to_disk
end

#remote_reqs_durationGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property remoteReqsDuration



8474
8475
8476
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8474

def remote_reqs_duration
  @remote_reqs_duration
end

#shuffle_push_read_metricsGoogle::Apis::DataprocV1::ShufflePushReadQuantileMetrics

Corresponds to the JSON property shufflePushReadMetrics



8479
8480
8481
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8479

def shuffle_push_read_metrics
  @shuffle_push_read_metrics
end

#total_blocks_fetchedGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property totalBlocksFetched



8485
8486
8487
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8485

def total_blocks_fetched
  @total_blocks_fetched
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8492

def update!(**args)
  @fetch_wait_time_millis = args[:fetch_wait_time_millis] if args.key?(:fetch_wait_time_millis)
  @local_blocks_fetched = args[:local_blocks_fetched] if args.key?(:local_blocks_fetched)
  @read_bytes = args[:read_bytes] if args.key?(:read_bytes)
  @read_records = args[:read_records] if args.key?(:read_records)
  @remote_blocks_fetched = args[:remote_blocks_fetched] if args.key?(:remote_blocks_fetched)
  @remote_bytes_read = args[:remote_bytes_read] if args.key?(:remote_bytes_read)
  @remote_bytes_read_to_disk = args[:remote_bytes_read_to_disk] if args.key?(:remote_bytes_read_to_disk)
  @remote_reqs_duration = args[:remote_reqs_duration] if args.key?(:remote_reqs_duration)
  @shuffle_push_read_metrics = args[:shuffle_push_read_metrics] if args.key?(:shuffle_push_read_metrics)
  @total_blocks_fetched = args[:total_blocks_fetched] if args.key?(:total_blocks_fetched)
end