Class: Google::Apis::DataprocV1::ShuffleReadQuantileMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ShuffleReadQuantileMetrics

Returns a new instance of ShuffleReadQuantileMetrics.



8488
8489
8490
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8488

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fetch_wait_time_millisGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property fetchWaitTimeMillis



8433
8434
8435
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8433

def fetch_wait_time_millis
  @fetch_wait_time_millis
end

#local_blocks_fetchedGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property localBlocksFetched



8439
8440
8441
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8439

def local_blocks_fetched
  @local_blocks_fetched
end

#read_bytesGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property readBytes



8445
8446
8447
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8445

def read_bytes
  @read_bytes
end

#read_recordsGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property readRecords



8451
8452
8453
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8451

def read_records
  @read_records
end

#remote_blocks_fetchedGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property remoteBlocksFetched



8457
8458
8459
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8457

def remote_blocks_fetched
  @remote_blocks_fetched
end

#remote_bytes_readGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property remoteBytesRead



8463
8464
8465
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8463

def remote_bytes_read
  @remote_bytes_read
end

#remote_bytes_read_to_diskGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property remoteBytesReadToDisk



8469
8470
8471
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8469

def remote_bytes_read_to_disk
  @remote_bytes_read_to_disk
end

#remote_reqs_durationGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property remoteReqsDuration



8475
8476
8477
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8475

def remote_reqs_duration
  @remote_reqs_duration
end

#shuffle_push_read_metricsGoogle::Apis::DataprocV1::ShufflePushReadQuantileMetrics

Corresponds to the JSON property shufflePushReadMetrics



8480
8481
8482
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8480

def shuffle_push_read_metrics
  @shuffle_push_read_metrics
end

#total_blocks_fetchedGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property totalBlocksFetched



8486
8487
8488
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8486

def total_blocks_fetched
  @total_blocks_fetched
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8493

def update!(**args)
  @fetch_wait_time_millis = args[:fetch_wait_time_millis] if args.key?(:fetch_wait_time_millis)
  @local_blocks_fetched = args[:local_blocks_fetched] if args.key?(:local_blocks_fetched)
  @read_bytes = args[:read_bytes] if args.key?(:read_bytes)
  @read_records = args[:read_records] if args.key?(:read_records)
  @remote_blocks_fetched = args[:remote_blocks_fetched] if args.key?(:remote_blocks_fetched)
  @remote_bytes_read = args[:remote_bytes_read] if args.key?(:remote_bytes_read)
  @remote_bytes_read_to_disk = args[:remote_bytes_read_to_disk] if args.key?(:remote_bytes_read_to_disk)
  @remote_reqs_duration = args[:remote_reqs_duration] if args.key?(:remote_reqs_duration)
  @shuffle_push_read_metrics = args[:shuffle_push_read_metrics] if args.key?(:shuffle_push_read_metrics)
  @total_blocks_fetched = args[:total_blocks_fetched] if args.key?(:total_blocks_fetched)
end