Class: Google::Apis::DataprocV1::ShuffleReadQuantileMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ShuffleReadQuantileMetrics

Returns a new instance of ShuffleReadQuantileMetrics.



8328
8329
8330
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8328

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fetch_wait_time_millisGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property fetchWaitTimeMillis



8273
8274
8275
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8273

def fetch_wait_time_millis
  @fetch_wait_time_millis
end

#local_blocks_fetchedGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property localBlocksFetched



8279
8280
8281
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8279

def local_blocks_fetched
  @local_blocks_fetched
end

#read_bytesGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property readBytes



8285
8286
8287
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8285

def read_bytes
  @read_bytes
end

#read_recordsGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property readRecords



8291
8292
8293
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8291

def read_records
  @read_records
end

#remote_blocks_fetchedGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property remoteBlocksFetched



8297
8298
8299
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8297

def remote_blocks_fetched
  @remote_blocks_fetched
end

#remote_bytes_readGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property remoteBytesRead



8303
8304
8305
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8303

def remote_bytes_read
  @remote_bytes_read
end

#remote_bytes_read_to_diskGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property remoteBytesReadToDisk



8309
8310
8311
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8309

def remote_bytes_read_to_disk
  @remote_bytes_read_to_disk
end

#remote_reqs_durationGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property remoteReqsDuration



8315
8316
8317
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8315

def remote_reqs_duration
  @remote_reqs_duration
end

#shuffle_push_read_metricsGoogle::Apis::DataprocV1::ShufflePushReadQuantileMetrics

Corresponds to the JSON property shufflePushReadMetrics



8320
8321
8322
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8320

def shuffle_push_read_metrics
  @shuffle_push_read_metrics
end

#total_blocks_fetchedGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property totalBlocksFetched



8326
8327
8328
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8326

def total_blocks_fetched
  @total_blocks_fetched
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8333
8334
8335
8336
8337
8338
8339
8340
8341
8342
8343
8344
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8333

def update!(**args)
  @fetch_wait_time_millis = args[:fetch_wait_time_millis] if args.key?(:fetch_wait_time_millis)
  @local_blocks_fetched = args[:local_blocks_fetched] if args.key?(:local_blocks_fetched)
  @read_bytes = args[:read_bytes] if args.key?(:read_bytes)
  @read_records = args[:read_records] if args.key?(:read_records)
  @remote_blocks_fetched = args[:remote_blocks_fetched] if args.key?(:remote_blocks_fetched)
  @remote_bytes_read = args[:remote_bytes_read] if args.key?(:remote_bytes_read)
  @remote_bytes_read_to_disk = args[:remote_bytes_read_to_disk] if args.key?(:remote_bytes_read_to_disk)
  @remote_reqs_duration = args[:remote_reqs_duration] if args.key?(:remote_reqs_duration)
  @shuffle_push_read_metrics = args[:shuffle_push_read_metrics] if args.key?(:shuffle_push_read_metrics)
  @total_blocks_fetched = args[:total_blocks_fetched] if args.key?(:total_blocks_fetched)
end