Class: Google::Apis::DataprocV1::ShuffleWriteQuantileMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ShuffleWriteQuantileMetrics

Returns a new instance of ShuffleWriteQuantileMetrics.



8560
8561
8562
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8560

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#write_bytesGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property writeBytes



8546
8547
8548
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8546

def write_bytes
  @write_bytes
end

#write_recordsGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property writeRecords



8552
8553
8554
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8552

def write_records
  @write_records
end

#write_time_nanosGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property writeTimeNanos



8558
8559
8560
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8558

def write_time_nanos
  @write_time_nanos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8565
8566
8567
8568
8569
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8565

def update!(**args)
  @write_bytes = args[:write_bytes] if args.key?(:write_bytes)
  @write_records = args[:write_records] if args.key?(:write_records)
  @write_time_nanos = args[:write_time_nanos] if args.key?(:write_time_nanos)
end