Class: Google::Apis::DataprocV1::ShuffleWriteQuantileMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ShuffleWriteQuantileMetrics

Returns a new instance of ShuffleWriteQuantileMetrics.



8551
8552
8553
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8551

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#write_bytesGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property writeBytes



8537
8538
8539
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8537

def write_bytes
  @write_bytes
end

#write_recordsGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property writeRecords



8543
8544
8545
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8543

def write_records
  @write_records
end

#write_time_nanosGoogle::Apis::DataprocV1::Quantiles

Quantile metrics data related to Tasks. Units can be seconds, bytes, milliseconds, etc depending on the message type. Corresponds to the JSON property writeTimeNanos



8549
8550
8551
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8549

def write_time_nanos
  @write_time_nanos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8556
8557
8558
8559
8560
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8556

def update!(**args)
  @write_bytes = args[:write_bytes] if args.key?(:write_bytes)
  @write_records = args[:write_records] if args.key?(:write_records)
  @write_time_nanos = args[:write_time_nanos] if args.key?(:write_time_nanos)
end