Class: Google::Apis::DataprocV1::SparkBatch
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::SparkBatch
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A configuration for running an Apache Spark (https://spark.apache.org/) batch workload.
Instance Attribute Summary collapse
-
#archive_uris ⇒ Array<String>
Optional.
-
#args ⇒ Array<String>
Optional.
-
#file_uris ⇒ Array<String>
Optional.
-
#jar_file_uris ⇒ Array<String>
Optional.
-
#main_class ⇒ String
Optional.
-
#main_jar_file_uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SparkBatch
constructor
A new instance of SparkBatch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SparkBatch
Returns a new instance of SparkBatch.
8613 8614 8615 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8613 def initialize(**args) update!(**args) end |
Instance Attribute Details
#archive_uris ⇒ Array<String>
Optional. HCFS URIs of archives to be extracted into the working directory of
each executor. Supported file types: .jar, .tar, .tar.gz, .tgz, and .zip.
Corresponds to the JSON property archiveUris
8581 8582 8583 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8581 def archive_uris @archive_uris end |
#args ⇒ Array<String>
Optional. The arguments to pass to the driver. Do not include arguments that
can be set as batch properties, such as --conf, since a collision can occur
that causes an incorrect batch submission.
Corresponds to the JSON property args
8588 8589 8590 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8588 def args @args end |
#file_uris ⇒ Array<String>
Optional. HCFS URIs of files to be placed in the working directory of each
executor.
Corresponds to the JSON property fileUris
8594 8595 8596 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8594 def file_uris @file_uris end |
#jar_file_uris ⇒ Array<String>
Optional. HCFS URIs of jar files to add to the classpath of the Spark driver
and tasks.
Corresponds to the JSON property jarFileUris
8600 8601 8602 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8600 def jar_file_uris @jar_file_uris end |
#main_class ⇒ String
Optional. The name of the driver main class. The jar file that contains the
class must be in the classpath or specified in jar_file_uris.
Corresponds to the JSON property mainClass
8606 8607 8608 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8606 def main_class @main_class end |
#main_jar_file_uri ⇒ String
Optional. The HCFS URI of the jar file that contains the main class.
Corresponds to the JSON property mainJarFileUri
8611 8612 8613 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8611 def main_jar_file_uri @main_jar_file_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8618 8619 8620 8621 8622 8623 8624 8625 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8618 def update!(**args) @archive_uris = args[:archive_uris] if args.key?(:archive_uris) @args = args[:args] if args.key?(:args) @file_uris = args[:file_uris] if args.key?(:file_uris) @jar_file_uris = args[:jar_file_uris] if args.key?(:jar_file_uris) @main_class = args[:main_class] if args.key?(:main_class) @main_jar_file_uri = args[:main_jar_file_uri] if args.key?(:main_jar_file_uri) end |