Class: Google::Apis::DataprocV1::SparkConnectExecutionInfo
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::SparkConnectExecutionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Represents the lifecycle and details of an Execution via Spark Connect
Instance Attribute Summary collapse
-
#close_timestamp ⇒ Fixnum
Timestamp when the execution was closed.
-
#detail ⇒ String
Detailed information about the execution.
-
#finish_timestamp ⇒ Fixnum
Timestamp when the execution finished.
-
#job_ids ⇒ Array<String>
Optional.
-
#job_tag ⇒ String
Required.
-
#operation_id ⇒ String
Unique identifier for the operation.
-
#session_id ⇒ String
Required.
-
#spark_session_tags ⇒ Array<String>
Optional.
-
#sql_exec_ids ⇒ Array<String>
Optional.
-
#start_timestamp ⇒ Fixnum
Timestamp when the execution started.
-
#state ⇒ String
Output only.
-
#statement ⇒ String
statement of the execution.
-
#user_id ⇒ String
User ID of the user who started the execution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SparkConnectExecutionInfo
constructor
A new instance of SparkConnectExecutionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SparkConnectExecutionInfo
Returns a new instance of SparkConnectExecutionInfo.
9111 9112 9113 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9111 def initialize(**args) update!(**args) end |
Instance Attribute Details
#close_timestamp ⇒ Fixnum
Timestamp when the execution was closed.
Corresponds to the JSON property closeTimestamp
9049 9050 9051 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9049 def @close_timestamp end |
#detail ⇒ String
Detailed information about the execution.
Corresponds to the JSON property detail
9054 9055 9056 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9054 def detail @detail end |
#finish_timestamp ⇒ Fixnum
Timestamp when the execution finished.
Corresponds to the JSON property finishTimestamp
9059 9060 9061 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9059 def @finish_timestamp end |
#job_ids ⇒ Array<String>
Optional. List of job ids associated with the execution.
Corresponds to the JSON property jobIds
9064 9065 9066 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9064 def job_ids @job_ids end |
#job_tag ⇒ String
Required. Job tag of the execution.
Corresponds to the JSON property jobTag
9069 9070 9071 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9069 def job_tag @job_tag end |
#operation_id ⇒ String
Unique identifier for the operation.
Corresponds to the JSON property operationId
9074 9075 9076 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9074 def operation_id @operation_id end |
#session_id ⇒ String
Required. Session ID, ties the execution to a specific Spark Connect session.
Corresponds to the JSON property sessionId
9079 9080 9081 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9079 def session_id @session_id end |
#spark_session_tags ⇒ Array<String>
Optional. Tags associated with the Spark session.
Corresponds to the JSON property sparkSessionTags
9084 9085 9086 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9084 def @spark_session_tags end |
#sql_exec_ids ⇒ Array<String>
Optional. List of sql execution ids associated with the execution.
Corresponds to the JSON property sqlExecIds
9089 9090 9091 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9089 def sql_exec_ids @sql_exec_ids end |
#start_timestamp ⇒ Fixnum
Timestamp when the execution started.
Corresponds to the JSON property startTimestamp
9094 9095 9096 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9094 def @start_timestamp end |
#state ⇒ String
Output only. Current state of the execution.
Corresponds to the JSON property state
9099 9100 9101 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9099 def state @state end |
#statement ⇒ String
statement of the execution.
Corresponds to the JSON property statement
9104 9105 9106 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9104 def statement @statement end |
#user_id ⇒ String
User ID of the user who started the execution.
Corresponds to the JSON property userId
9109 9110 9111 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9109 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9116 9117 9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 9130 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9116 def update!(**args) @close_timestamp = args[:close_timestamp] if args.key?(:close_timestamp) @detail = args[:detail] if args.key?(:detail) @finish_timestamp = args[:finish_timestamp] if args.key?(:finish_timestamp) @job_ids = args[:job_ids] if args.key?(:job_ids) @job_tag = args[:job_tag] if args.key?(:job_tag) @operation_id = args[:operation_id] if args.key?(:operation_id) @session_id = args[:session_id] if args.key?(:session_id) @spark_session_tags = args[:spark_session_tags] if args.key?(:spark_session_tags) @sql_exec_ids = args[:sql_exec_ids] if args.key?(:sql_exec_ids) @start_timestamp = args[:start_timestamp] if args.key?(:start_timestamp) @state = args[:state] if args.key?(:state) @statement = args[:statement] if args.key?(:statement) @user_id = args[:user_id] if args.key?(:user_id) end |