Class: Google::Apis::DataprocV1::SparkConnectExecutionInfo
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::SparkConnectExecutionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Represents the lifecycle and details of an Execution via Spark Connect
Instance Attribute Summary collapse
-
#close_timestamp ⇒ Fixnum
Timestamp when the execution was closed.
-
#detail ⇒ String
Detailed information about the execution.
-
#finish_timestamp ⇒ Fixnum
Timestamp when the execution finished.
-
#job_ids ⇒ Array<String>
Optional.
-
#job_tag ⇒ String
Required.
-
#operation_id ⇒ String
Unique identifier for the operation.
-
#session_id ⇒ String
Required.
-
#spark_session_tags ⇒ Array<String>
Optional.
-
#sql_exec_ids ⇒ Array<String>
Optional.
-
#start_timestamp ⇒ Fixnum
Timestamp when the execution started.
-
#state ⇒ String
Output only.
-
#statement ⇒ String
statement of the execution.
-
#user_id ⇒ String
User ID of the user who started the execution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SparkConnectExecutionInfo
constructor
A new instance of SparkConnectExecutionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SparkConnectExecutionInfo
Returns a new instance of SparkConnectExecutionInfo.
8870 8871 8872 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8870 def initialize(**args) update!(**args) end |
Instance Attribute Details
#close_timestamp ⇒ Fixnum
Timestamp when the execution was closed.
Corresponds to the JSON property closeTimestamp
8808 8809 8810 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8808 def @close_timestamp end |
#detail ⇒ String
Detailed information about the execution.
Corresponds to the JSON property detail
8813 8814 8815 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8813 def detail @detail end |
#finish_timestamp ⇒ Fixnum
Timestamp when the execution finished.
Corresponds to the JSON property finishTimestamp
8818 8819 8820 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8818 def @finish_timestamp end |
#job_ids ⇒ Array<String>
Optional. List of job ids associated with the execution.
Corresponds to the JSON property jobIds
8823 8824 8825 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8823 def job_ids @job_ids end |
#job_tag ⇒ String
Required. Job tag of the execution.
Corresponds to the JSON property jobTag
8828 8829 8830 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8828 def job_tag @job_tag end |
#operation_id ⇒ String
Unique identifier for the operation.
Corresponds to the JSON property operationId
8833 8834 8835 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8833 def operation_id @operation_id end |
#session_id ⇒ String
Required. Session ID, ties the execution to a specific Spark Connect session.
Corresponds to the JSON property sessionId
8838 8839 8840 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8838 def session_id @session_id end |
#spark_session_tags ⇒ Array<String>
Optional. Tags associated with the Spark session.
Corresponds to the JSON property sparkSessionTags
8843 8844 8845 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8843 def @spark_session_tags end |
#sql_exec_ids ⇒ Array<String>
Optional. List of sql execution ids associated with the execution.
Corresponds to the JSON property sqlExecIds
8848 8849 8850 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8848 def sql_exec_ids @sql_exec_ids end |
#start_timestamp ⇒ Fixnum
Timestamp when the execution started.
Corresponds to the JSON property startTimestamp
8853 8854 8855 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8853 def @start_timestamp end |
#state ⇒ String
Output only. Current state of the execution.
Corresponds to the JSON property state
8858 8859 8860 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8858 def state @state end |
#statement ⇒ String
statement of the execution.
Corresponds to the JSON property statement
8863 8864 8865 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8863 def statement @statement end |
#user_id ⇒ String
User ID of the user who started the execution.
Corresponds to the JSON property userId
8868 8869 8870 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8868 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8875 def update!(**args) @close_timestamp = args[:close_timestamp] if args.key?(:close_timestamp) @detail = args[:detail] if args.key?(:detail) @finish_timestamp = args[:finish_timestamp] if args.key?(:finish_timestamp) @job_ids = args[:job_ids] if args.key?(:job_ids) @job_tag = args[:job_tag] if args.key?(:job_tag) @operation_id = args[:operation_id] if args.key?(:operation_id) @session_id = args[:session_id] if args.key?(:session_id) @spark_session_tags = args[:spark_session_tags] if args.key?(:spark_session_tags) @sql_exec_ids = args[:sql_exec_ids] if args.key?(:sql_exec_ids) @start_timestamp = args[:start_timestamp] if args.key?(:start_timestamp) @state = args[:state] if args.key?(:state) @statement = args[:statement] if args.key?(:statement) @user_id = args[:user_id] if args.key?(:user_id) end |