Class: Google::Apis::DataprocV1::SparkConnectExecutionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Represents the lifecycle and details of an Execution via Spark Connect

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SparkConnectExecutionInfo

Returns a new instance of SparkConnectExecutionInfo.



8861
8862
8863
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8861

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#close_timestampFixnum

Timestamp when the execution was closed. Corresponds to the JSON property closeTimestamp

Returns:

  • (Fixnum)


8799
8800
8801
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8799

def close_timestamp
  @close_timestamp
end

#detailString

Detailed information about the execution. Corresponds to the JSON property detail

Returns:

  • (String)


8804
8805
8806
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8804

def detail
  @detail
end

#finish_timestampFixnum

Timestamp when the execution finished. Corresponds to the JSON property finishTimestamp

Returns:

  • (Fixnum)


8809
8810
8811
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8809

def finish_timestamp
  @finish_timestamp
end

#job_idsArray<String>

Optional. List of job ids associated with the execution. Corresponds to the JSON property jobIds

Returns:

  • (Array<String>)


8814
8815
8816
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8814

def job_ids
  @job_ids
end

#job_tagString

Required. Job tag of the execution. Corresponds to the JSON property jobTag

Returns:

  • (String)


8819
8820
8821
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8819

def job_tag
  @job_tag
end

#operation_idString

Unique identifier for the operation. Corresponds to the JSON property operationId

Returns:

  • (String)


8824
8825
8826
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8824

def operation_id
  @operation_id
end

#session_idString

Required. Session ID, ties the execution to a specific Spark Connect session. Corresponds to the JSON property sessionId

Returns:

  • (String)


8829
8830
8831
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8829

def session_id
  @session_id
end

#spark_session_tagsArray<String>

Optional. Tags associated with the Spark session. Corresponds to the JSON property sparkSessionTags

Returns:

  • (Array<String>)


8834
8835
8836
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8834

def spark_session_tags
  @spark_session_tags
end

#sql_exec_idsArray<String>

Optional. List of sql execution ids associated with the execution. Corresponds to the JSON property sqlExecIds

Returns:

  • (Array<String>)


8839
8840
8841
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8839

def sql_exec_ids
  @sql_exec_ids
end

#start_timestampFixnum

Timestamp when the execution started. Corresponds to the JSON property startTimestamp

Returns:

  • (Fixnum)


8844
8845
8846
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8844

def start_timestamp
  @start_timestamp
end

#stateString

Output only. Current state of the execution. Corresponds to the JSON property state

Returns:

  • (String)


8849
8850
8851
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8849

def state
  @state
end

#statementString

statement of the execution. Corresponds to the JSON property statement

Returns:

  • (String)


8854
8855
8856
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8854

def statement
  @statement
end

#user_idString

User ID of the user who started the execution. Corresponds to the JSON property userId

Returns:

  • (String)


8859
8860
8861
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8859

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8866
8867
8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
8880
# File 'lib/google/apis/dataproc_v1/classes.rb', line 8866

def update!(**args)
  @close_timestamp = args[:close_timestamp] if args.key?(:close_timestamp)
  @detail = args[:detail] if args.key?(:detail)
  @finish_timestamp = args[:finish_timestamp] if args.key?(:finish_timestamp)
  @job_ids = args[:job_ids] if args.key?(:job_ids)
  @job_tag = args[:job_tag] if args.key?(:job_tag)
  @operation_id = args[:operation_id] if args.key?(:operation_id)
  @session_id = args[:session_id] if args.key?(:session_id)
  @spark_session_tags = args[:spark_session_tags] if args.key?(:spark_session_tags)
  @sql_exec_ids = args[:sql_exec_ids] if args.key?(:sql_exec_ids)
  @start_timestamp = args[:start_timestamp] if args.key?(:start_timestamp)
  @state = args[:state] if args.key?(:state)
  @statement = args[:statement] if args.key?(:statement)
  @user_id = args[:user_id] if args.key?(:user_id)
end