Class: Google::Apis::DataprocV1::SparkSqlJob
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::SparkSqlJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A Dataproc job for running Apache Spark SQL (https://spark.apache.org/sql/) queries.
Instance Attribute Summary collapse
-
#jar_file_uris ⇒ Array<String>
Optional.
-
#logging_config ⇒ Google::Apis::DataprocV1::LoggingConfig
The runtime logging config of the job.
-
#properties ⇒ Hash<String,String>
Optional.
-
#query_file_uri ⇒ String
The HCFS URI of the script that contains SQL queries.
-
#query_list ⇒ Google::Apis::DataprocV1::QueryList
A list of queries to run on a cluster.
-
#script_variables ⇒ Hash<String,String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SparkSqlJob
constructor
A new instance of SparkSqlJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SparkSqlJob
Returns a new instance of SparkSqlJob.
9424 9425 9426 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9424 def initialize(**args) update!(**args) end |
Instance Attribute Details
#jar_file_uris ⇒ Array<String>
Optional. HCFS URIs of jar files to be added to the Spark CLASSPATH.
Corresponds to the JSON property jarFileUris
9394 9395 9396 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9394 def jar_file_uris @jar_file_uris end |
#logging_config ⇒ Google::Apis::DataprocV1::LoggingConfig
The runtime logging config of the job.
Corresponds to the JSON property loggingConfig
9399 9400 9401 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9399 def logging_config @logging_config end |
#properties ⇒ Hash<String,String>
Optional. A mapping of property names to values, used to configure Spark SQL's
SparkConf. Properties that conflict with values set by the Dataproc API might
be overwritten.
Corresponds to the JSON property properties
9406 9407 9408 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9406 def properties @properties end |
#query_file_uri ⇒ String
The HCFS URI of the script that contains SQL queries.
Corresponds to the JSON property queryFileUri
9411 9412 9413 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9411 def query_file_uri @query_file_uri end |
#query_list ⇒ Google::Apis::DataprocV1::QueryList
A list of queries to run on a cluster.
Corresponds to the JSON property queryList
9416 9417 9418 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9416 def query_list @query_list end |
#script_variables ⇒ Hash<String,String>
Optional. Mapping of query variable names to values (equivalent to the Spark
SQL command: SET name="value";).
Corresponds to the JSON property scriptVariables
9422 9423 9424 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9422 def script_variables @script_variables end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9429 9430 9431 9432 9433 9434 9435 9436 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9429 def update!(**args) @jar_file_uris = args[:jar_file_uris] if args.key?(:jar_file_uris) @logging_config = args[:logging_config] if args.key?(:logging_config) @properties = args[:properties] if args.key?(:properties) @query_file_uri = args[:query_file_uri] if args.key?(:query_file_uri) @query_list = args[:query_list] if args.key?(:query_list) @script_variables = args[:script_variables] if args.key?(:script_variables) end |