Class: Google::Apis::DataprocV1::SparkSqlJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A Dataproc job for running Apache Spark SQL (https://spark.apache.org/sql/) queries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SparkSqlJob

Returns a new instance of SparkSqlJob.



9417
9418
9419
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9417

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#jar_file_urisArray<String>

Optional. HCFS URIs of jar files to be added to the Spark CLASSPATH. Corresponds to the JSON property jarFileUris

Returns:

  • (Array<String>)


9387
9388
9389
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9387

def jar_file_uris
  @jar_file_uris
end

#logging_configGoogle::Apis::DataprocV1::LoggingConfig

The runtime logging config of the job. Corresponds to the JSON property loggingConfig



9392
9393
9394
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9392

def logging_config
  @logging_config
end

#propertiesHash<String,String>

Optional. A mapping of property names to values, used to configure Spark SQL's SparkConf. Properties that conflict with values set by the Dataproc API might be overwritten. Corresponds to the JSON property properties

Returns:

  • (Hash<String,String>)


9399
9400
9401
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9399

def properties
  @properties
end

#query_file_uriString

The HCFS URI of the script that contains SQL queries. Corresponds to the JSON property queryFileUri

Returns:

  • (String)


9404
9405
9406
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9404

def query_file_uri
  @query_file_uri
end

#query_listGoogle::Apis::DataprocV1::QueryList

A list of queries to run on a cluster. Corresponds to the JSON property queryList



9409
9410
9411
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9409

def query_list
  @query_list
end

#script_variablesHash<String,String>

Optional. Mapping of query variable names to values (equivalent to the Spark SQL command: SET name="value";). Corresponds to the JSON property scriptVariables

Returns:

  • (Hash<String,String>)


9415
9416
9417
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9415

def script_variables
  @script_variables
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9422
9423
9424
9425
9426
9427
9428
9429
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9422

def update!(**args)
  @jar_file_uris = args[:jar_file_uris] if args.key?(:jar_file_uris)
  @logging_config = args[:logging_config] if args.key?(:logging_config)
  @properties = args[:properties] if args.key?(:properties)
  @query_file_uri = args[:query_file_uri] if args.key?(:query_file_uri)
  @query_list = args[:query_list] if args.key?(:query_list)
  @script_variables = args[:script_variables] if args.key?(:script_variables)
end