Class: Google::Apis::DataprocV1::SparkSqlJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A Dataproc job for running Apache Spark SQL (https://spark.apache.org/sql/) queries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SparkSqlJob

Returns a new instance of SparkSqlJob.



9403
9404
9405
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9403

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#jar_file_urisArray<String>

Optional. HCFS URIs of jar files to be added to the Spark CLASSPATH. Corresponds to the JSON property jarFileUris

Returns:

  • (Array<String>)


9373
9374
9375
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9373

def jar_file_uris
  @jar_file_uris
end

#logging_configGoogle::Apis::DataprocV1::LoggingConfig

The runtime logging config of the job. Corresponds to the JSON property loggingConfig



9378
9379
9380
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9378

def logging_config
  @logging_config
end

#propertiesHash<String,String>

Optional. A mapping of property names to values, used to configure Spark SQL's SparkConf. Properties that conflict with values set by the Dataproc API might be overwritten. Corresponds to the JSON property properties

Returns:

  • (Hash<String,String>)


9385
9386
9387
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9385

def properties
  @properties
end

#query_file_uriString

The HCFS URI of the script that contains SQL queries. Corresponds to the JSON property queryFileUri

Returns:

  • (String)


9390
9391
9392
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9390

def query_file_uri
  @query_file_uri
end

#query_listGoogle::Apis::DataprocV1::QueryList

A list of queries to run on a cluster. Corresponds to the JSON property queryList



9395
9396
9397
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9395

def query_list
  @query_list
end

#script_variablesHash<String,String>

Optional. Mapping of query variable names to values (equivalent to the Spark SQL command: SET name="value";). Corresponds to the JSON property scriptVariables

Returns:

  • (Hash<String,String>)


9401
9402
9403
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9401

def script_variables
  @script_variables
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9408
9409
9410
9411
9412
9413
9414
9415
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9408

def update!(**args)
  @jar_file_uris = args[:jar_file_uris] if args.key?(:jar_file_uris)
  @logging_config = args[:logging_config] if args.key?(:logging_config)
  @properties = args[:properties] if args.key?(:properties)
  @query_file_uri = args[:query_file_uri] if args.key?(:query_file_uri)
  @query_list = args[:query_list] if args.key?(:query_list)
  @script_variables = args[:script_variables] if args.key?(:script_variables)
end