Class: Google::Apis::DataprocV1::SparkSqlJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A Dataproc job for running Apache Spark SQL (https://spark.apache.org/sql/) queries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SparkSqlJob

Returns a new instance of SparkSqlJob.



9404
9405
9406
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9404

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#jar_file_urisArray<String>

Optional. HCFS URIs of jar files to be added to the Spark CLASSPATH. Corresponds to the JSON property jarFileUris

Returns:

  • (Array<String>)


9374
9375
9376
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9374

def jar_file_uris
  @jar_file_uris
end

#logging_configGoogle::Apis::DataprocV1::LoggingConfig

The runtime logging config of the job. Corresponds to the JSON property loggingConfig



9379
9380
9381
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9379

def logging_config
  @logging_config
end

#propertiesHash<String,String>

Optional. A mapping of property names to values, used to configure Spark SQL's SparkConf. Properties that conflict with values set by the Dataproc API might be overwritten. Corresponds to the JSON property properties

Returns:

  • (Hash<String,String>)


9386
9387
9388
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9386

def properties
  @properties
end

#query_file_uriString

The HCFS URI of the script that contains SQL queries. Corresponds to the JSON property queryFileUri

Returns:

  • (String)


9391
9392
9393
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9391

def query_file_uri
  @query_file_uri
end

#query_listGoogle::Apis::DataprocV1::QueryList

A list of queries to run on a cluster. Corresponds to the JSON property queryList



9396
9397
9398
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9396

def query_list
  @query_list
end

#script_variablesHash<String,String>

Optional. Mapping of query variable names to values (equivalent to the Spark SQL command: SET name="value";). Corresponds to the JSON property scriptVariables

Returns:

  • (Hash<String,String>)


9402
9403
9404
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9402

def script_variables
  @script_variables
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9409
9410
9411
9412
9413
9414
9415
9416
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9409

def update!(**args)
  @jar_file_uris = args[:jar_file_uris] if args.key?(:jar_file_uris)
  @logging_config = args[:logging_config] if args.key?(:logging_config)
  @properties = args[:properties] if args.key?(:properties)
  @query_file_uri = args[:query_file_uri] if args.key?(:query_file_uri)
  @query_list = args[:query_list] if args.key?(:query_list)
  @script_variables = args[:script_variables] if args.key?(:script_variables)
end