Class: Google::Apis::DataprocV1::SparkStandaloneAutoscalingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Basic autoscaling configurations for Spark Standalone.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SparkStandaloneAutoscalingConfig

Returns a new instance of SparkStandaloneAutoscalingConfig.



9473
9474
9475
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9473

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#graceful_decommission_timeoutString

Required. Timeout for Spark graceful decommissioning of spark workers. Specifies the duration to wait for spark worker to complete spark decommissioning tasks before forcefully removing workers. Only applicable to downscaling operations.Bounds: 0s, 1d. Corresponds to the JSON property gracefulDecommissionTimeout

Returns:

  • (String)


9429
9430
9431
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9429

def graceful_decommission_timeout
  @graceful_decommission_timeout
end

#remove_only_idle_workersBoolean Also known as: remove_only_idle_workers?

Optional. Remove only idle workers when scaling down cluster Corresponds to the JSON property removeOnlyIdleWorkers

Returns:

  • (Boolean)


9434
9435
9436
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9434

def remove_only_idle_workers
  @remove_only_idle_workers
end

#scale_down_factorFloat

Required. Fraction of required executors to remove from Spark Serverless clusters. A scale-down factor of 1.0 will result in scaling down so that there are no more executors for the Spark Job.(more aggressive scaling). A scale- down factor closer to 0 will result in a smaller magnitude of scaling donw ( less aggressive scaling).Bounds: 0.0, 1.0. Corresponds to the JSON property scaleDownFactor

Returns:

  • (Float)


9444
9445
9446
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9444

def scale_down_factor
  @scale_down_factor
end

#scale_down_min_worker_fractionFloat

Optional. Minimum scale-down threshold as a fraction of total cluster size before scaling occurs. For example, in a 20-worker cluster, a threshold of 0.1 means the autoscaler must recommend at least a 2 worker scale-down for the cluster to scale. A threshold of 0 means the autoscaler will scale down on any recommended change.Bounds: 0.0, 1.0. Default: 0.0. Corresponds to the JSON property scaleDownMinWorkerFraction

Returns:

  • (Float)


9453
9454
9455
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9453

def scale_down_min_worker_fraction
  @scale_down_min_worker_fraction
end

#scale_up_factorFloat

Required. Fraction of required workers to add to Spark Standalone clusters. A scale-up factor of 1.0 will result in scaling up so that there are no more required workers for the Spark Job (more aggressive scaling). A scale-up factor closer to 0 will result in a smaller magnitude of scaling up (less aggressive scaling).Bounds: 0.0, 1.0. Corresponds to the JSON property scaleUpFactor

Returns:

  • (Float)


9462
9463
9464
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9462

def scale_up_factor
  @scale_up_factor
end

#scale_up_min_worker_fractionFloat

Optional. Minimum scale-up threshold as a fraction of total cluster size before scaling occurs. For example, in a 20-worker cluster, a threshold of 0.1 means the autoscaler must recommend at least a 2-worker scale-up for the cluster to scale. A threshold of 0 means the autoscaler will scale up on any recommended change.Bounds: 0.0, 1.0. Default: 0.0. Corresponds to the JSON property scaleUpMinWorkerFraction

Returns:

  • (Float)


9471
9472
9473
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9471

def scale_up_min_worker_fraction
  @scale_up_min_worker_fraction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9478
9479
9480
9481
9482
9483
9484
9485
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9478

def update!(**args)
  @graceful_decommission_timeout = args[:graceful_decommission_timeout] if args.key?(:graceful_decommission_timeout)
  @remove_only_idle_workers = args[:remove_only_idle_workers] if args.key?(:remove_only_idle_workers)
  @scale_down_factor = args[:scale_down_factor] if args.key?(:scale_down_factor)
  @scale_down_min_worker_fraction = args[:scale_down_min_worker_fraction] if args.key?(:scale_down_min_worker_fraction)
  @scale_up_factor = args[:scale_up_factor] if args.key?(:scale_up_factor)
  @scale_up_min_worker_fraction = args[:scale_up_min_worker_fraction] if args.key?(:scale_up_min_worker_fraction)
end