Class: Google::Apis::DataprocV1::SparkWrapperObject

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Outer message that contains the data obtained from spark listener, packaged with information that is required to process it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SparkWrapperObject

Returns a new instance of SparkWrapperObject.



9619
9620
9621
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9619

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_summaryGoogle::Apis::DataprocV1::AppSummary

Corresponds to the JSON property appSummary



9496
9497
9498
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9496

def app_summary
  @app_summary
end

#application_environment_infoGoogle::Apis::DataprocV1::ApplicationEnvironmentInfo

Details about the Environment that the application is running in. Corresponds to the JSON property applicationEnvironmentInfo



9501
9502
9503
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9501

def application_environment_info
  @application_environment_info
end

#application_idString

Application Id created by Spark. Corresponds to the JSON property applicationId

Returns:

  • (String)


9506
9507
9508
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9506

def application_id
  @application_id
end

#application_infoGoogle::Apis::DataprocV1::ApplicationInfo

High level information corresponding to an application. Corresponds to the JSON property applicationInfo



9511
9512
9513
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9511

def application_info
  @application_info
end

#event_timestampString

VM Timestamp associated with the data object. Corresponds to the JSON property eventTimestamp

Returns:

  • (String)


9516
9517
9518
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9516

def event_timestamp
  @event_timestamp
end

#executor_stage_summaryGoogle::Apis::DataprocV1::ExecutorStageSummary

Executor resources consumed by a stage. Corresponds to the JSON property executorStageSummary



9521
9522
9523
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9521

def executor_stage_summary
  @executor_stage_summary
end

#executor_summaryGoogle::Apis::DataprocV1::ExecutorSummary

Details about executors used by the application. Corresponds to the JSON property executorSummary



9526
9527
9528
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9526

def executor_summary
  @executor_summary
end

#job_dataGoogle::Apis::DataprocV1::JobData

Data corresponding to a spark job. Corresponds to the JSON property jobData



9531
9532
9533
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9531

def job_data
  @job_data
end

#native_build_info_ui_dataGoogle::Apis::DataprocV1::NativeBuildInfoUiData

Native Build Info Corresponds to the JSON property nativeBuildInfoUiData



9536
9537
9538
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9536

def native_build_info_ui_data
  @native_build_info_ui_data
end

#native_sql_execution_ui_dataGoogle::Apis::DataprocV1::NativeSqlExecutionUiData

Native SQL Execution Data Corresponds to the JSON property nativeSqlExecutionUiData



9541
9542
9543
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9541

def native_sql_execution_ui_data
  @native_sql_execution_ui_data
end

#pool_dataGoogle::Apis::DataprocV1::PoolData

Pool Data Corresponds to the JSON property poolData



9546
9547
9548
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9546

def pool_data
  @pool_data
end

#process_summaryGoogle::Apis::DataprocV1::ProcessSummary

Process Summary Corresponds to the JSON property processSummary



9551
9552
9553
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9551

def process_summary
  @process_summary
end

#rdd_operation_graphGoogle::Apis::DataprocV1::RddOperationGraph

Graph representing RDD dependencies. Consists of edges and a root cluster. Corresponds to the JSON property rddOperationGraph



9556
9557
9558
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9556

def rdd_operation_graph
  @rdd_operation_graph
end

#rdd_storage_infoGoogle::Apis::DataprocV1::RddStorageInfo

Overall data about RDD storage. Corresponds to the JSON property rddStorageInfo



9561
9562
9563
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9561

def rdd_storage_info
  @rdd_storage_info
end

#resource_profile_infoGoogle::Apis::DataprocV1::ResourceProfileInfo

Resource profile that contains information about all the resources required by executors and tasks. Corresponds to the JSON property resourceProfileInfo



9567
9568
9569
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9567

def resource_profile_info
  @resource_profile_info
end

#spark_connect_execution_infoGoogle::Apis::DataprocV1::SparkConnectExecutionInfo

Represents the lifecycle and details of an Execution via Spark Connect Corresponds to the JSON property sparkConnectExecutionInfo



9572
9573
9574
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9572

def spark_connect_execution_info
  @spark_connect_execution_info
end

#spark_connect_session_infoGoogle::Apis::DataprocV1::SparkConnectSessionInfo

Represents session-level information for Spark Connect Corresponds to the JSON property sparkConnectSessionInfo



9577
9578
9579
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9577

def spark_connect_session_info
  @spark_connect_session_info
end

#spark_plan_graphGoogle::Apis::DataprocV1::SparkPlanGraph

A graph used for storing information of an executionPlan of DataFrame. Corresponds to the JSON property sparkPlanGraph



9582
9583
9584
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9582

def spark_plan_graph
  @spark_plan_graph
end

#speculation_stage_summaryGoogle::Apis::DataprocV1::SpeculationStageSummary

Details of the speculation task when speculative execution is enabled. Corresponds to the JSON property speculationStageSummary



9587
9588
9589
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9587

def speculation_stage_summary
  @speculation_stage_summary
end

#sql_execution_ui_dataGoogle::Apis::DataprocV1::SqlExecutionUiData

SQL Execution Data Corresponds to the JSON property sqlExecutionUiData



9592
9593
9594
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9592

def sql_execution_ui_data
  @sql_execution_ui_data
end

#stage_dataGoogle::Apis::DataprocV1::StageData

Data corresponding to a stage. Corresponds to the JSON property stageData



9597
9598
9599
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9597

def stage_data
  @stage_data
end

#stream_block_dataGoogle::Apis::DataprocV1::StreamBlockData

Stream Block Data. Corresponds to the JSON property streamBlockData



9602
9603
9604
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9602

def stream_block_data
  @stream_block_data
end

#streaming_query_dataGoogle::Apis::DataprocV1::StreamingQueryData

Streaming Corresponds to the JSON property streamingQueryData



9607
9608
9609
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9607

def streaming_query_data
  @streaming_query_data
end

#streaming_query_progressGoogle::Apis::DataprocV1::StreamingQueryProgress

Corresponds to the JSON property streamingQueryProgress



9612
9613
9614
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9612

def streaming_query_progress
  @streaming_query_progress
end

#task_dataGoogle::Apis::DataprocV1::TaskData

Data corresponding to tasks created by spark. Corresponds to the JSON property taskData



9617
9618
9619
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9617

def task_data
  @task_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9624
9625
9626
9627
9628
9629
9630
9631
9632
9633
9634
9635
9636
9637
9638
9639
9640
9641
9642
9643
9644
9645
9646
9647
9648
9649
9650
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9624

def update!(**args)
  @app_summary = args[:app_summary] if args.key?(:app_summary)
  @application_environment_info = args[:application_environment_info] if args.key?(:application_environment_info)
  @application_id = args[:application_id] if args.key?(:application_id)
  @application_info = args[:application_info] if args.key?(:application_info)
  @event_timestamp = args[:event_timestamp] if args.key?(:event_timestamp)
  @executor_stage_summary = args[:executor_stage_summary] if args.key?(:executor_stage_summary)
  @executor_summary = args[:executor_summary] if args.key?(:executor_summary)
  @job_data = args[:job_data] if args.key?(:job_data)
  @native_build_info_ui_data = args[:native_build_info_ui_data] if args.key?(:native_build_info_ui_data)
  @native_sql_execution_ui_data = args[:native_sql_execution_ui_data] if args.key?(:native_sql_execution_ui_data)
  @pool_data = args[:pool_data] if args.key?(:pool_data)
  @process_summary = args[:process_summary] if args.key?(:process_summary)
  @rdd_operation_graph = args[:rdd_operation_graph] if args.key?(:rdd_operation_graph)
  @rdd_storage_info = args[:rdd_storage_info] if args.key?(:rdd_storage_info)
  @resource_profile_info = args[:resource_profile_info] if args.key?(:resource_profile_info)
  @spark_connect_execution_info = args[:spark_connect_execution_info] if args.key?(:spark_connect_execution_info)
  @spark_connect_session_info = args[:spark_connect_session_info] if args.key?(:spark_connect_session_info)
  @spark_plan_graph = args[:spark_plan_graph] if args.key?(:spark_plan_graph)
  @speculation_stage_summary = args[:speculation_stage_summary] if args.key?(:speculation_stage_summary)
  @sql_execution_ui_data = args[:sql_execution_ui_data] if args.key?(:sql_execution_ui_data)
  @stage_data = args[:stage_data] if args.key?(:stage_data)
  @stream_block_data = args[:stream_block_data] if args.key?(:stream_block_data)
  @streaming_query_data = args[:streaming_query_data] if args.key?(:streaming_query_data)
  @streaming_query_progress = args[:streaming_query_progress] if args.key?(:streaming_query_progress)
  @task_data = args[:task_data] if args.key?(:task_data)
end