Class: Google::Apis::DataprocV1::SparkWrapperObject
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::SparkWrapperObject
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Outer message that contains the data obtained from spark listener, packaged with information that is required to process it.
Instance Attribute Summary collapse
-
#app_summary ⇒ Google::Apis::DataprocV1::AppSummary
Corresponds to the JSON property
appSummary. -
#application_environment_info ⇒ Google::Apis::DataprocV1::ApplicationEnvironmentInfo
Details about the Environment that the application is running in.
-
#application_id ⇒ String
Application Id created by Spark.
-
#application_info ⇒ Google::Apis::DataprocV1::ApplicationInfo
High level information corresponding to an application.
-
#event_timestamp ⇒ String
VM Timestamp associated with the data object.
-
#executor_stage_summary ⇒ Google::Apis::DataprocV1::ExecutorStageSummary
Executor resources consumed by a stage.
-
#executor_summary ⇒ Google::Apis::DataprocV1::ExecutorSummary
Details about executors used by the application.
-
#job_data ⇒ Google::Apis::DataprocV1::JobData
Data corresponding to a spark job.
-
#native_build_info_ui_data ⇒ Google::Apis::DataprocV1::NativeBuildInfoUiData
Native Build Info Corresponds to the JSON property
nativeBuildInfoUiData. -
#native_sql_execution_ui_data ⇒ Google::Apis::DataprocV1::NativeSqlExecutionUiData
Native SQL Execution Data Corresponds to the JSON property
nativeSqlExecutionUiData. -
#pool_data ⇒ Google::Apis::DataprocV1::PoolData
Pool Data Corresponds to the JSON property
poolData. -
#process_summary ⇒ Google::Apis::DataprocV1::ProcessSummary
Process Summary Corresponds to the JSON property
processSummary. -
#rdd_operation_graph ⇒ Google::Apis::DataprocV1::RddOperationGraph
Graph representing RDD dependencies.
-
#rdd_storage_info ⇒ Google::Apis::DataprocV1::RddStorageInfo
Overall data about RDD storage.
-
#resource_profile_info ⇒ Google::Apis::DataprocV1::ResourceProfileInfo
Resource profile that contains information about all the resources required by executors and tasks.
-
#spark_plan_graph ⇒ Google::Apis::DataprocV1::SparkPlanGraph
A graph used for storing information of an executionPlan of DataFrame.
-
#speculation_stage_summary ⇒ Google::Apis::DataprocV1::SpeculationStageSummary
Details of the speculation task when speculative execution is enabled.
-
#sql_execution_ui_data ⇒ Google::Apis::DataprocV1::SqlExecutionUiData
SQL Execution Data Corresponds to the JSON property
sqlExecutionUiData. -
#stage_data ⇒ Google::Apis::DataprocV1::StageData
Data corresponding to a stage.
-
#stream_block_data ⇒ Google::Apis::DataprocV1::StreamBlockData
Stream Block Data.
-
#streaming_query_data ⇒ Google::Apis::DataprocV1::StreamingQueryData
Streaming Corresponds to the JSON property
streamingQueryData. -
#streaming_query_progress ⇒ Google::Apis::DataprocV1::StreamingQueryProgress
Corresponds to the JSON property
streamingQueryProgress. -
#task_data ⇒ Google::Apis::DataprocV1::TaskData
Data corresponding to tasks created by spark.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SparkWrapperObject
constructor
A new instance of SparkWrapperObject.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SparkWrapperObject
Returns a new instance of SparkWrapperObject.
9303 9304 9305 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9303 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_summary ⇒ Google::Apis::DataprocV1::AppSummary
Corresponds to the JSON property appSummary
9190 9191 9192 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9190 def app_summary @app_summary end |
#application_environment_info ⇒ Google::Apis::DataprocV1::ApplicationEnvironmentInfo
Details about the Environment that the application is running in.
Corresponds to the JSON property applicationEnvironmentInfo
9195 9196 9197 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9195 def application_environment_info @application_environment_info end |
#application_id ⇒ String
Application Id created by Spark.
Corresponds to the JSON property applicationId
9200 9201 9202 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9200 def application_id @application_id end |
#application_info ⇒ Google::Apis::DataprocV1::ApplicationInfo
High level information corresponding to an application.
Corresponds to the JSON property applicationInfo
9205 9206 9207 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9205 def application_info @application_info end |
#event_timestamp ⇒ String
VM Timestamp associated with the data object.
Corresponds to the JSON property eventTimestamp
9210 9211 9212 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9210 def @event_timestamp end |
#executor_stage_summary ⇒ Google::Apis::DataprocV1::ExecutorStageSummary
Executor resources consumed by a stage.
Corresponds to the JSON property executorStageSummary
9215 9216 9217 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9215 def executor_stage_summary @executor_stage_summary end |
#executor_summary ⇒ Google::Apis::DataprocV1::ExecutorSummary
Details about executors used by the application.
Corresponds to the JSON property executorSummary
9220 9221 9222 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9220 def executor_summary @executor_summary end |
#job_data ⇒ Google::Apis::DataprocV1::JobData
Data corresponding to a spark job.
Corresponds to the JSON property jobData
9225 9226 9227 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9225 def job_data @job_data end |
#native_build_info_ui_data ⇒ Google::Apis::DataprocV1::NativeBuildInfoUiData
Native Build Info
Corresponds to the JSON property nativeBuildInfoUiData
9230 9231 9232 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9230 def native_build_info_ui_data @native_build_info_ui_data end |
#native_sql_execution_ui_data ⇒ Google::Apis::DataprocV1::NativeSqlExecutionUiData
Native SQL Execution Data
Corresponds to the JSON property nativeSqlExecutionUiData
9235 9236 9237 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9235 def native_sql_execution_ui_data @native_sql_execution_ui_data end |
#pool_data ⇒ Google::Apis::DataprocV1::PoolData
Pool Data
Corresponds to the JSON property poolData
9240 9241 9242 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9240 def pool_data @pool_data end |
#process_summary ⇒ Google::Apis::DataprocV1::ProcessSummary
Process Summary
Corresponds to the JSON property processSummary
9245 9246 9247 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9245 def process_summary @process_summary end |
#rdd_operation_graph ⇒ Google::Apis::DataprocV1::RddOperationGraph
Graph representing RDD dependencies. Consists of edges and a root cluster.
Corresponds to the JSON property rddOperationGraph
9250 9251 9252 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9250 def rdd_operation_graph @rdd_operation_graph end |
#rdd_storage_info ⇒ Google::Apis::DataprocV1::RddStorageInfo
Overall data about RDD storage.
Corresponds to the JSON property rddStorageInfo
9255 9256 9257 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9255 def rdd_storage_info @rdd_storage_info end |
#resource_profile_info ⇒ Google::Apis::DataprocV1::ResourceProfileInfo
Resource profile that contains information about all the resources required by
executors and tasks.
Corresponds to the JSON property resourceProfileInfo
9261 9262 9263 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9261 def resource_profile_info @resource_profile_info end |
#spark_plan_graph ⇒ Google::Apis::DataprocV1::SparkPlanGraph
A graph used for storing information of an executionPlan of DataFrame.
Corresponds to the JSON property sparkPlanGraph
9266 9267 9268 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9266 def spark_plan_graph @spark_plan_graph end |
#speculation_stage_summary ⇒ Google::Apis::DataprocV1::SpeculationStageSummary
Details of the speculation task when speculative execution is enabled.
Corresponds to the JSON property speculationStageSummary
9271 9272 9273 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9271 def speculation_stage_summary @speculation_stage_summary end |
#sql_execution_ui_data ⇒ Google::Apis::DataprocV1::SqlExecutionUiData
SQL Execution Data
Corresponds to the JSON property sqlExecutionUiData
9276 9277 9278 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9276 def sql_execution_ui_data @sql_execution_ui_data end |
#stage_data ⇒ Google::Apis::DataprocV1::StageData
Data corresponding to a stage.
Corresponds to the JSON property stageData
9281 9282 9283 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9281 def stage_data @stage_data end |
#stream_block_data ⇒ Google::Apis::DataprocV1::StreamBlockData
Stream Block Data.
Corresponds to the JSON property streamBlockData
9286 9287 9288 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9286 def stream_block_data @stream_block_data end |
#streaming_query_data ⇒ Google::Apis::DataprocV1::StreamingQueryData
Streaming
Corresponds to the JSON property streamingQueryData
9291 9292 9293 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9291 def streaming_query_data @streaming_query_data end |
#streaming_query_progress ⇒ Google::Apis::DataprocV1::StreamingQueryProgress
Corresponds to the JSON property streamingQueryProgress
9296 9297 9298 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9296 def streaming_query_progress @streaming_query_progress end |
#task_data ⇒ Google::Apis::DataprocV1::TaskData
Data corresponding to tasks created by spark.
Corresponds to the JSON property taskData
9301 9302 9303 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9301 def task_data @task_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9308 9309 9310 9311 9312 9313 9314 9315 9316 9317 9318 9319 9320 9321 9322 9323 9324 9325 9326 9327 9328 9329 9330 9331 9332 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9308 def update!(**args) @app_summary = args[:app_summary] if args.key?(:app_summary) @application_environment_info = args[:application_environment_info] if args.key?(:application_environment_info) @application_id = args[:application_id] if args.key?(:application_id) @application_info = args[:application_info] if args.key?(:application_info) @event_timestamp = args[:event_timestamp] if args.key?(:event_timestamp) @executor_stage_summary = args[:executor_stage_summary] if args.key?(:executor_stage_summary) @executor_summary = args[:executor_summary] if args.key?(:executor_summary) @job_data = args[:job_data] if args.key?(:job_data) @native_build_info_ui_data = args[:native_build_info_ui_data] if args.key?(:native_build_info_ui_data) @native_sql_execution_ui_data = args[:native_sql_execution_ui_data] if args.key?(:native_sql_execution_ui_data) @pool_data = args[:pool_data] if args.key?(:pool_data) @process_summary = args[:process_summary] if args.key?(:process_summary) @rdd_operation_graph = args[:rdd_operation_graph] if args.key?(:rdd_operation_graph) @rdd_storage_info = args[:rdd_storage_info] if args.key?(:rdd_storage_info) @resource_profile_info = args[:resource_profile_info] if args.key?(:resource_profile_info) @spark_plan_graph = args[:spark_plan_graph] if args.key?(:spark_plan_graph) @speculation_stage_summary = args[:speculation_stage_summary] if args.key?(:speculation_stage_summary) @sql_execution_ui_data = args[:sql_execution_ui_data] if args.key?(:sql_execution_ui_data) @stage_data = args[:stage_data] if args.key?(:stage_data) @stream_block_data = args[:stream_block_data] if args.key?(:stream_block_data) @streaming_query_data = args[:streaming_query_data] if args.key?(:streaming_query_data) @streaming_query_progress = args[:streaming_query_progress] if args.key?(:streaming_query_progress) @task_data = args[:task_data] if args.key?(:task_data) end |