Class: Google::Apis::DataprocV1::StageData
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::StageData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Data corresponding to a stage.
Instance Attribute Summary collapse
-
#accumulator_updates ⇒ Array<Google::Apis::DataprocV1::AccumulableInfo>
Corresponds to the JSON property
accumulatorUpdates. -
#completion_time ⇒ String
Corresponds to the JSON property
completionTime. -
#description ⇒ String
Corresponds to the JSON property
description. -
#details ⇒ String
Corresponds to the JSON property
details. -
#executor_metrics_distributions ⇒ Google::Apis::DataprocV1::ExecutorMetricsDistributions
Corresponds to the JSON property
executorMetricsDistributions. -
#executor_summary ⇒ Hash<String,Google::Apis::DataprocV1::ExecutorStageSummary>
Corresponds to the JSON property
executorSummary. -
#failure_reason ⇒ String
Corresponds to the JSON property
failureReason. -
#first_task_launched_time ⇒ String
Corresponds to the JSON property
firstTaskLaunchedTime. -
#is_shuffle_push_enabled ⇒ Boolean
(also: #is_shuffle_push_enabled?)
Corresponds to the JSON property
isShufflePushEnabled. -
#job_ids ⇒ Array<Fixnum>
Corresponds to the JSON property
jobIds. -
#killed_tasks_summary ⇒ Hash<String,Fixnum>
Corresponds to the JSON property
killedTasksSummary. -
#locality ⇒ Hash<String,Fixnum>
Corresponds to the JSON property
locality. -
#name ⇒ String
Corresponds to the JSON property
name. -
#num_active_tasks ⇒ Fixnum
Corresponds to the JSON property
numActiveTasks. -
#num_complete_tasks ⇒ Fixnum
Corresponds to the JSON property
numCompleteTasks. -
#num_completed_indices ⇒ Fixnum
Corresponds to the JSON property
numCompletedIndices. -
#num_failed_tasks ⇒ Fixnum
Corresponds to the JSON property
numFailedTasks. -
#num_killed_tasks ⇒ Fixnum
Corresponds to the JSON property
numKilledTasks. -
#num_tasks ⇒ Fixnum
Corresponds to the JSON property
numTasks. -
#parent_stage_ids ⇒ Array<Fixnum>
Corresponds to the JSON property
parentStageIds. -
#peak_executor_metrics ⇒ Google::Apis::DataprocV1::ExecutorMetrics
Corresponds to the JSON property
peakExecutorMetrics. -
#rdd_ids ⇒ Array<Fixnum>
Corresponds to the JSON property
rddIds. -
#resource_profile_id ⇒ Fixnum
Corresponds to the JSON property
resourceProfileId. -
#scheduling_pool ⇒ String
Corresponds to the JSON property
schedulingPool. -
#shuffle_mergers_count ⇒ Fixnum
Corresponds to the JSON property
shuffleMergersCount. -
#speculation_summary ⇒ Google::Apis::DataprocV1::SpeculationStageSummary
Details of the speculation task when speculative execution is enabled.
-
#stage_attempt_id ⇒ Fixnum
Corresponds to the JSON property
stageAttemptId. -
#stage_id ⇒ Fixnum
Corresponds to the JSON property
stageId. -
#stage_metrics ⇒ Google::Apis::DataprocV1::StageMetrics
Stage Level Aggregated Metrics Corresponds to the JSON property
stageMetrics. -
#status ⇒ String
Corresponds to the JSON property
status. -
#submission_time ⇒ String
Corresponds to the JSON property
submissionTime. -
#task_quantile_metrics ⇒ Google::Apis::DataprocV1::TaskQuantileMetrics
Summary metrics fields.
-
#tasks ⇒ Hash<String,Google::Apis::DataprocV1::TaskData>
Corresponds to the JSON property
tasks.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StageData
constructor
A new instance of StageData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StageData
Returns a new instance of StageData.
10316 10317 10318 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10316 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accumulator_updates ⇒ Array<Google::Apis::DataprocV1::AccumulableInfo>
Corresponds to the JSON property accumulatorUpdates
10152 10153 10154 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10152 def accumulator_updates @accumulator_updates end |
#completion_time ⇒ String
Corresponds to the JSON property completionTime
10157 10158 10159 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10157 def completion_time @completion_time end |
#description ⇒ String
Corresponds to the JSON property description
10162 10163 10164 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10162 def description @description end |
#details ⇒ String
Corresponds to the JSON property details
10167 10168 10169 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10167 def details @details end |
#executor_metrics_distributions ⇒ Google::Apis::DataprocV1::ExecutorMetricsDistributions
Corresponds to the JSON property executorMetricsDistributions
10172 10173 10174 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10172 def executor_metrics_distributions @executor_metrics_distributions end |
#executor_summary ⇒ Hash<String,Google::Apis::DataprocV1::ExecutorStageSummary>
Corresponds to the JSON property executorSummary
10177 10178 10179 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10177 def executor_summary @executor_summary end |
#failure_reason ⇒ String
Corresponds to the JSON property failureReason
10182 10183 10184 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10182 def failure_reason @failure_reason end |
#first_task_launched_time ⇒ String
Corresponds to the JSON property firstTaskLaunchedTime
10187 10188 10189 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10187 def first_task_launched_time @first_task_launched_time end |
#is_shuffle_push_enabled ⇒ Boolean Also known as: is_shuffle_push_enabled?
Corresponds to the JSON property isShufflePushEnabled
10192 10193 10194 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10192 def is_shuffle_push_enabled @is_shuffle_push_enabled end |
#job_ids ⇒ Array<Fixnum>
Corresponds to the JSON property jobIds
10198 10199 10200 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10198 def job_ids @job_ids end |
#killed_tasks_summary ⇒ Hash<String,Fixnum>
Corresponds to the JSON property killedTasksSummary
10203 10204 10205 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10203 def killed_tasks_summary @killed_tasks_summary end |
#locality ⇒ Hash<String,Fixnum>
Corresponds to the JSON property locality
10208 10209 10210 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10208 def locality @locality end |
#name ⇒ String
Corresponds to the JSON property name
10213 10214 10215 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10213 def name @name end |
#num_active_tasks ⇒ Fixnum
Corresponds to the JSON property numActiveTasks
10218 10219 10220 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10218 def num_active_tasks @num_active_tasks end |
#num_complete_tasks ⇒ Fixnum
Corresponds to the JSON property numCompleteTasks
10223 10224 10225 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10223 def num_complete_tasks @num_complete_tasks end |
#num_completed_indices ⇒ Fixnum
Corresponds to the JSON property numCompletedIndices
10228 10229 10230 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10228 def num_completed_indices @num_completed_indices end |
#num_failed_tasks ⇒ Fixnum
Corresponds to the JSON property numFailedTasks
10233 10234 10235 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10233 def num_failed_tasks @num_failed_tasks end |
#num_killed_tasks ⇒ Fixnum
Corresponds to the JSON property numKilledTasks
10238 10239 10240 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10238 def num_killed_tasks @num_killed_tasks end |
#num_tasks ⇒ Fixnum
Corresponds to the JSON property numTasks
10243 10244 10245 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10243 def num_tasks @num_tasks end |
#parent_stage_ids ⇒ Array<Fixnum>
Corresponds to the JSON property parentStageIds
10248 10249 10250 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10248 def parent_stage_ids @parent_stage_ids end |
#peak_executor_metrics ⇒ Google::Apis::DataprocV1::ExecutorMetrics
Corresponds to the JSON property peakExecutorMetrics
10253 10254 10255 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10253 def peak_executor_metrics @peak_executor_metrics end |
#rdd_ids ⇒ Array<Fixnum>
Corresponds to the JSON property rddIds
10258 10259 10260 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10258 def rdd_ids @rdd_ids end |
#resource_profile_id ⇒ Fixnum
Corresponds to the JSON property resourceProfileId
10263 10264 10265 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10263 def resource_profile_id @resource_profile_id end |
#scheduling_pool ⇒ String
Corresponds to the JSON property schedulingPool
10268 10269 10270 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10268 def scheduling_pool @scheduling_pool end |
#shuffle_mergers_count ⇒ Fixnum
Corresponds to the JSON property shuffleMergersCount
10273 10274 10275 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10273 def shuffle_mergers_count @shuffle_mergers_count end |
#speculation_summary ⇒ Google::Apis::DataprocV1::SpeculationStageSummary
Details of the speculation task when speculative execution is enabled.
Corresponds to the JSON property speculationSummary
10278 10279 10280 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10278 def speculation_summary @speculation_summary end |
#stage_attempt_id ⇒ Fixnum
Corresponds to the JSON property stageAttemptId
10283 10284 10285 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10283 def stage_attempt_id @stage_attempt_id end |
#stage_id ⇒ Fixnum
Corresponds to the JSON property stageId
10288 10289 10290 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10288 def stage_id @stage_id end |
#stage_metrics ⇒ Google::Apis::DataprocV1::StageMetrics
Stage Level Aggregated Metrics
Corresponds to the JSON property stageMetrics
10293 10294 10295 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10293 def stage_metrics @stage_metrics end |
#status ⇒ String
Corresponds to the JSON property status
10298 10299 10300 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10298 def status @status end |
#submission_time ⇒ String
Corresponds to the JSON property submissionTime
10303 10304 10305 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10303 def submission_time @submission_time end |
#task_quantile_metrics ⇒ Google::Apis::DataprocV1::TaskQuantileMetrics
Summary metrics fields. These are included in response only if present in
summary_metrics_mask field in request
Corresponds to the JSON property taskQuantileMetrics
10309 10310 10311 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10309 def task_quantile_metrics @task_quantile_metrics end |
#tasks ⇒ Hash<String,Google::Apis::DataprocV1::TaskData>
Corresponds to the JSON property tasks
10314 10315 10316 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10314 def tasks @tasks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10321 10322 10323 10324 10325 10326 10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 10344 10345 10346 10347 10348 10349 10350 10351 10352 10353 10354 10355 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10321 def update!(**args) @accumulator_updates = args[:accumulator_updates] if args.key?(:accumulator_updates) @completion_time = args[:completion_time] if args.key?(:completion_time) @description = args[:description] if args.key?(:description) @details = args[:details] if args.key?(:details) @executor_metrics_distributions = args[:executor_metrics_distributions] if args.key?(:executor_metrics_distributions) @executor_summary = args[:executor_summary] if args.key?(:executor_summary) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @first_task_launched_time = args[:first_task_launched_time] if args.key?(:first_task_launched_time) @is_shuffle_push_enabled = args[:is_shuffle_push_enabled] if args.key?(:is_shuffle_push_enabled) @job_ids = args[:job_ids] if args.key?(:job_ids) @killed_tasks_summary = args[:killed_tasks_summary] if args.key?(:killed_tasks_summary) @locality = args[:locality] if args.key?(:locality) @name = args[:name] if args.key?(:name) @num_active_tasks = args[:num_active_tasks] if args.key?(:num_active_tasks) @num_complete_tasks = args[:num_complete_tasks] if args.key?(:num_complete_tasks) @num_completed_indices = args[:num_completed_indices] if args.key?(:num_completed_indices) @num_failed_tasks = args[:num_failed_tasks] if args.key?(:num_failed_tasks) @num_killed_tasks = args[:num_killed_tasks] if args.key?(:num_killed_tasks) @num_tasks = args[:num_tasks] if args.key?(:num_tasks) @parent_stage_ids = args[:parent_stage_ids] if args.key?(:parent_stage_ids) @peak_executor_metrics = args[:peak_executor_metrics] if args.key?(:peak_executor_metrics) @rdd_ids = args[:rdd_ids] if args.key?(:rdd_ids) @resource_profile_id = args[:resource_profile_id] if args.key?(:resource_profile_id) @scheduling_pool = args[:scheduling_pool] if args.key?(:scheduling_pool) @shuffle_mergers_count = args[:shuffle_mergers_count] if args.key?(:shuffle_mergers_count) @speculation_summary = args[:speculation_summary] if args.key?(:speculation_summary) @stage_attempt_id = args[:stage_attempt_id] if args.key?(:stage_attempt_id) @stage_id = args[:stage_id] if args.key?(:stage_id) @stage_metrics = args[:stage_metrics] if args.key?(:stage_metrics) @status = args[:status] if args.key?(:status) @submission_time = args[:submission_time] if args.key?(:submission_time) @task_quantile_metrics = args[:task_quantile_metrics] if args.key?(:task_quantile_metrics) @tasks = args[:tasks] if args.key?(:tasks) end |