Class: Google::Apis::DataprocV1::StageData
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::StageData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Data corresponding to a stage.
Instance Attribute Summary collapse
-
#accumulator_updates ⇒ Array<Google::Apis::DataprocV1::AccumulableInfo>
Corresponds to the JSON property
accumulatorUpdates. -
#completion_time ⇒ String
Corresponds to the JSON property
completionTime. -
#description ⇒ String
Corresponds to the JSON property
description. -
#details ⇒ String
Corresponds to the JSON property
details. -
#executor_metrics_distributions ⇒ Google::Apis::DataprocV1::ExecutorMetricsDistributions
Corresponds to the JSON property
executorMetricsDistributions. -
#executor_summary ⇒ Hash<String,Google::Apis::DataprocV1::ExecutorStageSummary>
Corresponds to the JSON property
executorSummary. -
#failure_reason ⇒ String
Corresponds to the JSON property
failureReason. -
#first_task_launched_time ⇒ String
Corresponds to the JSON property
firstTaskLaunchedTime. -
#is_shuffle_push_enabled ⇒ Boolean
(also: #is_shuffle_push_enabled?)
Corresponds to the JSON property
isShufflePushEnabled. -
#job_ids ⇒ Array<Fixnum>
Corresponds to the JSON property
jobIds. -
#killed_tasks_summary ⇒ Hash<String,Fixnum>
Corresponds to the JSON property
killedTasksSummary. -
#locality ⇒ Hash<String,Fixnum>
Corresponds to the JSON property
locality. -
#name ⇒ String
Corresponds to the JSON property
name. -
#num_active_tasks ⇒ Fixnum
Corresponds to the JSON property
numActiveTasks. -
#num_complete_tasks ⇒ Fixnum
Corresponds to the JSON property
numCompleteTasks. -
#num_completed_indices ⇒ Fixnum
Corresponds to the JSON property
numCompletedIndices. -
#num_failed_tasks ⇒ Fixnum
Corresponds to the JSON property
numFailedTasks. -
#num_killed_tasks ⇒ Fixnum
Corresponds to the JSON property
numKilledTasks. -
#num_tasks ⇒ Fixnum
Corresponds to the JSON property
numTasks. -
#parent_stage_ids ⇒ Array<Fixnum>
Corresponds to the JSON property
parentStageIds. -
#peak_executor_metrics ⇒ Google::Apis::DataprocV1::ExecutorMetrics
Corresponds to the JSON property
peakExecutorMetrics. -
#rdd_ids ⇒ Array<Fixnum>
Corresponds to the JSON property
rddIds. -
#resource_profile_id ⇒ Fixnum
Corresponds to the JSON property
resourceProfileId. -
#scheduling_pool ⇒ String
Corresponds to the JSON property
schedulingPool. -
#shuffle_mergers_count ⇒ Fixnum
Corresponds to the JSON property
shuffleMergersCount. -
#speculation_summary ⇒ Google::Apis::DataprocV1::SpeculationStageSummary
Details of the speculation task when speculative execution is enabled.
-
#stage_attempt_id ⇒ Fixnum
Corresponds to the JSON property
stageAttemptId. -
#stage_id ⇒ Fixnum
Corresponds to the JSON property
stageId. -
#stage_metrics ⇒ Google::Apis::DataprocV1::StageMetrics
Stage Level Aggregated Metrics Corresponds to the JSON property
stageMetrics. -
#status ⇒ String
Corresponds to the JSON property
status. -
#submission_time ⇒ String
Corresponds to the JSON property
submissionTime. -
#task_quantile_metrics ⇒ Google::Apis::DataprocV1::TaskQuantileMetrics
Summary metrics fields.
-
#tasks ⇒ Hash<String,Google::Apis::DataprocV1::TaskData>
Corresponds to the JSON property
tasks.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StageData
constructor
A new instance of StageData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StageData
Returns a new instance of StageData.
10095 10096 10097 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10095 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accumulator_updates ⇒ Array<Google::Apis::DataprocV1::AccumulableInfo>
Corresponds to the JSON property accumulatorUpdates
9931 9932 9933 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9931 def accumulator_updates @accumulator_updates end |
#completion_time ⇒ String
Corresponds to the JSON property completionTime
9936 9937 9938 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9936 def completion_time @completion_time end |
#description ⇒ String
Corresponds to the JSON property description
9941 9942 9943 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9941 def description @description end |
#details ⇒ String
Corresponds to the JSON property details
9946 9947 9948 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9946 def details @details end |
#executor_metrics_distributions ⇒ Google::Apis::DataprocV1::ExecutorMetricsDistributions
Corresponds to the JSON property executorMetricsDistributions
9951 9952 9953 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9951 def executor_metrics_distributions @executor_metrics_distributions end |
#executor_summary ⇒ Hash<String,Google::Apis::DataprocV1::ExecutorStageSummary>
Corresponds to the JSON property executorSummary
9956 9957 9958 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9956 def executor_summary @executor_summary end |
#failure_reason ⇒ String
Corresponds to the JSON property failureReason
9961 9962 9963 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9961 def failure_reason @failure_reason end |
#first_task_launched_time ⇒ String
Corresponds to the JSON property firstTaskLaunchedTime
9966 9967 9968 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9966 def first_task_launched_time @first_task_launched_time end |
#is_shuffle_push_enabled ⇒ Boolean Also known as: is_shuffle_push_enabled?
Corresponds to the JSON property isShufflePushEnabled
9971 9972 9973 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9971 def is_shuffle_push_enabled @is_shuffle_push_enabled end |
#job_ids ⇒ Array<Fixnum>
Corresponds to the JSON property jobIds
9977 9978 9979 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9977 def job_ids @job_ids end |
#killed_tasks_summary ⇒ Hash<String,Fixnum>
Corresponds to the JSON property killedTasksSummary
9982 9983 9984 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9982 def killed_tasks_summary @killed_tasks_summary end |
#locality ⇒ Hash<String,Fixnum>
Corresponds to the JSON property locality
9987 9988 9989 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9987 def locality @locality end |
#name ⇒ String
Corresponds to the JSON property name
9992 9993 9994 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9992 def name @name end |
#num_active_tasks ⇒ Fixnum
Corresponds to the JSON property numActiveTasks
9997 9998 9999 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9997 def num_active_tasks @num_active_tasks end |
#num_complete_tasks ⇒ Fixnum
Corresponds to the JSON property numCompleteTasks
10002 10003 10004 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10002 def num_complete_tasks @num_complete_tasks end |
#num_completed_indices ⇒ Fixnum
Corresponds to the JSON property numCompletedIndices
10007 10008 10009 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10007 def num_completed_indices @num_completed_indices end |
#num_failed_tasks ⇒ Fixnum
Corresponds to the JSON property numFailedTasks
10012 10013 10014 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10012 def num_failed_tasks @num_failed_tasks end |
#num_killed_tasks ⇒ Fixnum
Corresponds to the JSON property numKilledTasks
10017 10018 10019 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10017 def num_killed_tasks @num_killed_tasks end |
#num_tasks ⇒ Fixnum
Corresponds to the JSON property numTasks
10022 10023 10024 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10022 def num_tasks @num_tasks end |
#parent_stage_ids ⇒ Array<Fixnum>
Corresponds to the JSON property parentStageIds
10027 10028 10029 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10027 def parent_stage_ids @parent_stage_ids end |
#peak_executor_metrics ⇒ Google::Apis::DataprocV1::ExecutorMetrics
Corresponds to the JSON property peakExecutorMetrics
10032 10033 10034 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10032 def peak_executor_metrics @peak_executor_metrics end |
#rdd_ids ⇒ Array<Fixnum>
Corresponds to the JSON property rddIds
10037 10038 10039 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10037 def rdd_ids @rdd_ids end |
#resource_profile_id ⇒ Fixnum
Corresponds to the JSON property resourceProfileId
10042 10043 10044 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10042 def resource_profile_id @resource_profile_id end |
#scheduling_pool ⇒ String
Corresponds to the JSON property schedulingPool
10047 10048 10049 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10047 def scheduling_pool @scheduling_pool end |
#shuffle_mergers_count ⇒ Fixnum
Corresponds to the JSON property shuffleMergersCount
10052 10053 10054 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10052 def shuffle_mergers_count @shuffle_mergers_count end |
#speculation_summary ⇒ Google::Apis::DataprocV1::SpeculationStageSummary
Details of the speculation task when speculative execution is enabled.
Corresponds to the JSON property speculationSummary
10057 10058 10059 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10057 def speculation_summary @speculation_summary end |
#stage_attempt_id ⇒ Fixnum
Corresponds to the JSON property stageAttemptId
10062 10063 10064 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10062 def stage_attempt_id @stage_attempt_id end |
#stage_id ⇒ Fixnum
Corresponds to the JSON property stageId
10067 10068 10069 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10067 def stage_id @stage_id end |
#stage_metrics ⇒ Google::Apis::DataprocV1::StageMetrics
Stage Level Aggregated Metrics
Corresponds to the JSON property stageMetrics
10072 10073 10074 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10072 def stage_metrics @stage_metrics end |
#status ⇒ String
Corresponds to the JSON property status
10077 10078 10079 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10077 def status @status end |
#submission_time ⇒ String
Corresponds to the JSON property submissionTime
10082 10083 10084 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10082 def submission_time @submission_time end |
#task_quantile_metrics ⇒ Google::Apis::DataprocV1::TaskQuantileMetrics
Summary metrics fields. These are included in response only if present in
summary_metrics_mask field in request
Corresponds to the JSON property taskQuantileMetrics
10088 10089 10090 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10088 def task_quantile_metrics @task_quantile_metrics end |
#tasks ⇒ Hash<String,Google::Apis::DataprocV1::TaskData>
Corresponds to the JSON property tasks
10093 10094 10095 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10093 def tasks @tasks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10100 10101 10102 10103 10104 10105 10106 10107 10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 10133 10134 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10100 def update!(**args) @accumulator_updates = args[:accumulator_updates] if args.key?(:accumulator_updates) @completion_time = args[:completion_time] if args.key?(:completion_time) @description = args[:description] if args.key?(:description) @details = args[:details] if args.key?(:details) @executor_metrics_distributions = args[:executor_metrics_distributions] if args.key?(:executor_metrics_distributions) @executor_summary = args[:executor_summary] if args.key?(:executor_summary) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @first_task_launched_time = args[:first_task_launched_time] if args.key?(:first_task_launched_time) @is_shuffle_push_enabled = args[:is_shuffle_push_enabled] if args.key?(:is_shuffle_push_enabled) @job_ids = args[:job_ids] if args.key?(:job_ids) @killed_tasks_summary = args[:killed_tasks_summary] if args.key?(:killed_tasks_summary) @locality = args[:locality] if args.key?(:locality) @name = args[:name] if args.key?(:name) @num_active_tasks = args[:num_active_tasks] if args.key?(:num_active_tasks) @num_complete_tasks = args[:num_complete_tasks] if args.key?(:num_complete_tasks) @num_completed_indices = args[:num_completed_indices] if args.key?(:num_completed_indices) @num_failed_tasks = args[:num_failed_tasks] if args.key?(:num_failed_tasks) @num_killed_tasks = args[:num_killed_tasks] if args.key?(:num_killed_tasks) @num_tasks = args[:num_tasks] if args.key?(:num_tasks) @parent_stage_ids = args[:parent_stage_ids] if args.key?(:parent_stage_ids) @peak_executor_metrics = args[:peak_executor_metrics] if args.key?(:peak_executor_metrics) @rdd_ids = args[:rdd_ids] if args.key?(:rdd_ids) @resource_profile_id = args[:resource_profile_id] if args.key?(:resource_profile_id) @scheduling_pool = args[:scheduling_pool] if args.key?(:scheduling_pool) @shuffle_mergers_count = args[:shuffle_mergers_count] if args.key?(:shuffle_mergers_count) @speculation_summary = args[:speculation_summary] if args.key?(:speculation_summary) @stage_attempt_id = args[:stage_attempt_id] if args.key?(:stage_attempt_id) @stage_id = args[:stage_id] if args.key?(:stage_id) @stage_metrics = args[:stage_metrics] if args.key?(:stage_metrics) @status = args[:status] if args.key?(:status) @submission_time = args[:submission_time] if args.key?(:submission_time) @task_quantile_metrics = args[:task_quantile_metrics] if args.key?(:task_quantile_metrics) @tasks = args[:tasks] if args.key?(:tasks) end |