Class: Google::Apis::DataprocV1::StageData
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::StageData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Data corresponding to a stage.
Instance Attribute Summary collapse
-
#accumulator_updates ⇒ Array<Google::Apis::DataprocV1::AccumulableInfo>
Corresponds to the JSON property
accumulatorUpdates. -
#completion_time ⇒ String
Corresponds to the JSON property
completionTime. -
#description ⇒ String
Corresponds to the JSON property
description. -
#details ⇒ String
Corresponds to the JSON property
details. -
#executor_metrics_distributions ⇒ Google::Apis::DataprocV1::ExecutorMetricsDistributions
Corresponds to the JSON property
executorMetricsDistributions. -
#executor_summary ⇒ Hash<String,Google::Apis::DataprocV1::ExecutorStageSummary>
Corresponds to the JSON property
executorSummary. -
#failure_reason ⇒ String
Corresponds to the JSON property
failureReason. -
#first_task_launched_time ⇒ String
Corresponds to the JSON property
firstTaskLaunchedTime. -
#is_shuffle_push_enabled ⇒ Boolean
(also: #is_shuffle_push_enabled?)
Corresponds to the JSON property
isShufflePushEnabled. -
#job_ids ⇒ Array<Fixnum>
Corresponds to the JSON property
jobIds. -
#killed_tasks_summary ⇒ Hash<String,Fixnum>
Corresponds to the JSON property
killedTasksSummary. -
#locality ⇒ Hash<String,Fixnum>
Corresponds to the JSON property
locality. -
#name ⇒ String
Corresponds to the JSON property
name. -
#num_active_tasks ⇒ Fixnum
Corresponds to the JSON property
numActiveTasks. -
#num_complete_tasks ⇒ Fixnum
Corresponds to the JSON property
numCompleteTasks. -
#num_completed_indices ⇒ Fixnum
Corresponds to the JSON property
numCompletedIndices. -
#num_failed_tasks ⇒ Fixnum
Corresponds to the JSON property
numFailedTasks. -
#num_killed_tasks ⇒ Fixnum
Corresponds to the JSON property
numKilledTasks. -
#num_tasks ⇒ Fixnum
Corresponds to the JSON property
numTasks. -
#parent_stage_ids ⇒ Array<Fixnum>
Corresponds to the JSON property
parentStageIds. -
#peak_executor_metrics ⇒ Google::Apis::DataprocV1::ExecutorMetrics
Corresponds to the JSON property
peakExecutorMetrics. -
#rdd_ids ⇒ Array<Fixnum>
Corresponds to the JSON property
rddIds. -
#resource_profile_id ⇒ Fixnum
Corresponds to the JSON property
resourceProfileId. -
#scheduling_pool ⇒ String
Corresponds to the JSON property
schedulingPool. -
#shuffle_mergers_count ⇒ Fixnum
Corresponds to the JSON property
shuffleMergersCount. -
#speculation_summary ⇒ Google::Apis::DataprocV1::SpeculationStageSummary
Details of the speculation task when speculative execution is enabled.
-
#stage_attempt_id ⇒ Fixnum
Corresponds to the JSON property
stageAttemptId. -
#stage_id ⇒ Fixnum
Corresponds to the JSON property
stageId. -
#stage_metrics ⇒ Google::Apis::DataprocV1::StageMetrics
Stage Level Aggregated Metrics Corresponds to the JSON property
stageMetrics. -
#status ⇒ String
Corresponds to the JSON property
status. -
#submission_time ⇒ String
Corresponds to the JSON property
submissionTime. -
#task_quantile_metrics ⇒ Google::Apis::DataprocV1::TaskQuantileMetrics
Summary metrics fields.
-
#tasks ⇒ Hash<String,Google::Apis::DataprocV1::TaskData>
Corresponds to the JSON property
tasks.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StageData
constructor
A new instance of StageData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StageData
Returns a new instance of StageData.
10088 10089 10090 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10088 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accumulator_updates ⇒ Array<Google::Apis::DataprocV1::AccumulableInfo>
Corresponds to the JSON property accumulatorUpdates
9924 9925 9926 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9924 def accumulator_updates @accumulator_updates end |
#completion_time ⇒ String
Corresponds to the JSON property completionTime
9929 9930 9931 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9929 def completion_time @completion_time end |
#description ⇒ String
Corresponds to the JSON property description
9934 9935 9936 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9934 def description @description end |
#details ⇒ String
Corresponds to the JSON property details
9939 9940 9941 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9939 def details @details end |
#executor_metrics_distributions ⇒ Google::Apis::DataprocV1::ExecutorMetricsDistributions
Corresponds to the JSON property executorMetricsDistributions
9944 9945 9946 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9944 def executor_metrics_distributions @executor_metrics_distributions end |
#executor_summary ⇒ Hash<String,Google::Apis::DataprocV1::ExecutorStageSummary>
Corresponds to the JSON property executorSummary
9949 9950 9951 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9949 def executor_summary @executor_summary end |
#failure_reason ⇒ String
Corresponds to the JSON property failureReason
9954 9955 9956 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9954 def failure_reason @failure_reason end |
#first_task_launched_time ⇒ String
Corresponds to the JSON property firstTaskLaunchedTime
9959 9960 9961 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9959 def first_task_launched_time @first_task_launched_time end |
#is_shuffle_push_enabled ⇒ Boolean Also known as: is_shuffle_push_enabled?
Corresponds to the JSON property isShufflePushEnabled
9964 9965 9966 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9964 def is_shuffle_push_enabled @is_shuffle_push_enabled end |
#job_ids ⇒ Array<Fixnum>
Corresponds to the JSON property jobIds
9970 9971 9972 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9970 def job_ids @job_ids end |
#killed_tasks_summary ⇒ Hash<String,Fixnum>
Corresponds to the JSON property killedTasksSummary
9975 9976 9977 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9975 def killed_tasks_summary @killed_tasks_summary end |
#locality ⇒ Hash<String,Fixnum>
Corresponds to the JSON property locality
9980 9981 9982 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9980 def locality @locality end |
#name ⇒ String
Corresponds to the JSON property name
9985 9986 9987 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9985 def name @name end |
#num_active_tasks ⇒ Fixnum
Corresponds to the JSON property numActiveTasks
9990 9991 9992 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9990 def num_active_tasks @num_active_tasks end |
#num_complete_tasks ⇒ Fixnum
Corresponds to the JSON property numCompleteTasks
9995 9996 9997 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9995 def num_complete_tasks @num_complete_tasks end |
#num_completed_indices ⇒ Fixnum
Corresponds to the JSON property numCompletedIndices
10000 10001 10002 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10000 def num_completed_indices @num_completed_indices end |
#num_failed_tasks ⇒ Fixnum
Corresponds to the JSON property numFailedTasks
10005 10006 10007 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10005 def num_failed_tasks @num_failed_tasks end |
#num_killed_tasks ⇒ Fixnum
Corresponds to the JSON property numKilledTasks
10010 10011 10012 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10010 def num_killed_tasks @num_killed_tasks end |
#num_tasks ⇒ Fixnum
Corresponds to the JSON property numTasks
10015 10016 10017 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10015 def num_tasks @num_tasks end |
#parent_stage_ids ⇒ Array<Fixnum>
Corresponds to the JSON property parentStageIds
10020 10021 10022 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10020 def parent_stage_ids @parent_stage_ids end |
#peak_executor_metrics ⇒ Google::Apis::DataprocV1::ExecutorMetrics
Corresponds to the JSON property peakExecutorMetrics
10025 10026 10027 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10025 def peak_executor_metrics @peak_executor_metrics end |
#rdd_ids ⇒ Array<Fixnum>
Corresponds to the JSON property rddIds
10030 10031 10032 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10030 def rdd_ids @rdd_ids end |
#resource_profile_id ⇒ Fixnum
Corresponds to the JSON property resourceProfileId
10035 10036 10037 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10035 def resource_profile_id @resource_profile_id end |
#scheduling_pool ⇒ String
Corresponds to the JSON property schedulingPool
10040 10041 10042 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10040 def scheduling_pool @scheduling_pool end |
#shuffle_mergers_count ⇒ Fixnum
Corresponds to the JSON property shuffleMergersCount
10045 10046 10047 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10045 def shuffle_mergers_count @shuffle_mergers_count end |
#speculation_summary ⇒ Google::Apis::DataprocV1::SpeculationStageSummary
Details of the speculation task when speculative execution is enabled.
Corresponds to the JSON property speculationSummary
10050 10051 10052 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10050 def speculation_summary @speculation_summary end |
#stage_attempt_id ⇒ Fixnum
Corresponds to the JSON property stageAttemptId
10055 10056 10057 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10055 def stage_attempt_id @stage_attempt_id end |
#stage_id ⇒ Fixnum
Corresponds to the JSON property stageId
10060 10061 10062 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10060 def stage_id @stage_id end |
#stage_metrics ⇒ Google::Apis::DataprocV1::StageMetrics
Stage Level Aggregated Metrics
Corresponds to the JSON property stageMetrics
10065 10066 10067 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10065 def stage_metrics @stage_metrics end |
#status ⇒ String
Corresponds to the JSON property status
10070 10071 10072 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10070 def status @status end |
#submission_time ⇒ String
Corresponds to the JSON property submissionTime
10075 10076 10077 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10075 def submission_time @submission_time end |
#task_quantile_metrics ⇒ Google::Apis::DataprocV1::TaskQuantileMetrics
Summary metrics fields. These are included in response only if present in
summary_metrics_mask field in request
Corresponds to the JSON property taskQuantileMetrics
10081 10082 10083 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10081 def task_quantile_metrics @task_quantile_metrics end |
#tasks ⇒ Hash<String,Google::Apis::DataprocV1::TaskData>
Corresponds to the JSON property tasks
10086 10087 10088 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10086 def tasks @tasks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10093 10094 10095 10096 10097 10098 10099 10100 10101 10102 10103 10104 10105 10106 10107 10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10093 def update!(**args) @accumulator_updates = args[:accumulator_updates] if args.key?(:accumulator_updates) @completion_time = args[:completion_time] if args.key?(:completion_time) @description = args[:description] if args.key?(:description) @details = args[:details] if args.key?(:details) @executor_metrics_distributions = args[:executor_metrics_distributions] if args.key?(:executor_metrics_distributions) @executor_summary = args[:executor_summary] if args.key?(:executor_summary) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @first_task_launched_time = args[:first_task_launched_time] if args.key?(:first_task_launched_time) @is_shuffle_push_enabled = args[:is_shuffle_push_enabled] if args.key?(:is_shuffle_push_enabled) @job_ids = args[:job_ids] if args.key?(:job_ids) @killed_tasks_summary = args[:killed_tasks_summary] if args.key?(:killed_tasks_summary) @locality = args[:locality] if args.key?(:locality) @name = args[:name] if args.key?(:name) @num_active_tasks = args[:num_active_tasks] if args.key?(:num_active_tasks) @num_complete_tasks = args[:num_complete_tasks] if args.key?(:num_complete_tasks) @num_completed_indices = args[:num_completed_indices] if args.key?(:num_completed_indices) @num_failed_tasks = args[:num_failed_tasks] if args.key?(:num_failed_tasks) @num_killed_tasks = args[:num_killed_tasks] if args.key?(:num_killed_tasks) @num_tasks = args[:num_tasks] if args.key?(:num_tasks) @parent_stage_ids = args[:parent_stage_ids] if args.key?(:parent_stage_ids) @peak_executor_metrics = args[:peak_executor_metrics] if args.key?(:peak_executor_metrics) @rdd_ids = args[:rdd_ids] if args.key?(:rdd_ids) @resource_profile_id = args[:resource_profile_id] if args.key?(:resource_profile_id) @scheduling_pool = args[:scheduling_pool] if args.key?(:scheduling_pool) @shuffle_mergers_count = args[:shuffle_mergers_count] if args.key?(:shuffle_mergers_count) @speculation_summary = args[:speculation_summary] if args.key?(:speculation_summary) @stage_attempt_id = args[:stage_attempt_id] if args.key?(:stage_attempt_id) @stage_id = args[:stage_id] if args.key?(:stage_id) @stage_metrics = args[:stage_metrics] if args.key?(:stage_metrics) @status = args[:status] if args.key?(:status) @submission_time = args[:submission_time] if args.key?(:submission_time) @task_quantile_metrics = args[:task_quantile_metrics] if args.key?(:task_quantile_metrics) @tasks = args[:tasks] if args.key?(:tasks) end |