Class: Google::Apis::DataprocV1::StageData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Data corresponding to a stage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StageData

Returns a new instance of StageData.



10072
10073
10074
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10072

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accumulator_updatesArray<Google::Apis::DataprocV1::AccumulableInfo>

Corresponds to the JSON property accumulatorUpdates



9908
9909
9910
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9908

def accumulator_updates
  @accumulator_updates
end

#completion_timeString

Corresponds to the JSON property completionTime

Returns:

  • (String)


9913
9914
9915
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9913

def completion_time
  @completion_time
end

#descriptionString

Corresponds to the JSON property description

Returns:

  • (String)


9918
9919
9920
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9918

def description
  @description
end

#detailsString

Corresponds to the JSON property details

Returns:

  • (String)


9923
9924
9925
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9923

def details
  @details
end

#executor_metrics_distributionsGoogle::Apis::DataprocV1::ExecutorMetricsDistributions

Corresponds to the JSON property executorMetricsDistributions



9928
9929
9930
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9928

def executor_metrics_distributions
  @executor_metrics_distributions
end

#executor_summaryHash<String,Google::Apis::DataprocV1::ExecutorStageSummary>

Corresponds to the JSON property executorSummary



9933
9934
9935
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9933

def executor_summary
  @executor_summary
end

#failure_reasonString

Corresponds to the JSON property failureReason

Returns:

  • (String)


9938
9939
9940
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9938

def failure_reason
  @failure_reason
end

#first_task_launched_timeString

Corresponds to the JSON property firstTaskLaunchedTime

Returns:

  • (String)


9943
9944
9945
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9943

def first_task_launched_time
  @first_task_launched_time
end

#is_shuffle_push_enabledBoolean Also known as: is_shuffle_push_enabled?

Corresponds to the JSON property isShufflePushEnabled

Returns:

  • (Boolean)


9948
9949
9950
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9948

def is_shuffle_push_enabled
  @is_shuffle_push_enabled
end

#job_idsArray<Fixnum>

Corresponds to the JSON property jobIds

Returns:

  • (Array<Fixnum>)


9954
9955
9956
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9954

def job_ids
  @job_ids
end

#killed_tasks_summaryHash<String,Fixnum>

Corresponds to the JSON property killedTasksSummary

Returns:

  • (Hash<String,Fixnum>)


9959
9960
9961
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9959

def killed_tasks_summary
  @killed_tasks_summary
end

#localityHash<String,Fixnum>

Corresponds to the JSON property locality

Returns:

  • (Hash<String,Fixnum>)


9964
9965
9966
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9964

def locality
  @locality
end

#nameString

Corresponds to the JSON property name

Returns:

  • (String)


9969
9970
9971
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9969

def name
  @name
end

#num_active_tasksFixnum

Corresponds to the JSON property numActiveTasks

Returns:

  • (Fixnum)


9974
9975
9976
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9974

def num_active_tasks
  @num_active_tasks
end

#num_complete_tasksFixnum

Corresponds to the JSON property numCompleteTasks

Returns:

  • (Fixnum)


9979
9980
9981
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9979

def num_complete_tasks
  @num_complete_tasks
end

#num_completed_indicesFixnum

Corresponds to the JSON property numCompletedIndices

Returns:

  • (Fixnum)


9984
9985
9986
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9984

def num_completed_indices
  @num_completed_indices
end

#num_failed_tasksFixnum

Corresponds to the JSON property numFailedTasks

Returns:

  • (Fixnum)


9989
9990
9991
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9989

def num_failed_tasks
  @num_failed_tasks
end

#num_killed_tasksFixnum

Corresponds to the JSON property numKilledTasks

Returns:

  • (Fixnum)


9994
9995
9996
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9994

def num_killed_tasks
  @num_killed_tasks
end

#num_tasksFixnum

Corresponds to the JSON property numTasks

Returns:

  • (Fixnum)


9999
10000
10001
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9999

def num_tasks
  @num_tasks
end

#parent_stage_idsArray<Fixnum>

Corresponds to the JSON property parentStageIds

Returns:

  • (Array<Fixnum>)


10004
10005
10006
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10004

def parent_stage_ids
  @parent_stage_ids
end

#peak_executor_metricsGoogle::Apis::DataprocV1::ExecutorMetrics

Corresponds to the JSON property peakExecutorMetrics



10009
10010
10011
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10009

def peak_executor_metrics
  @peak_executor_metrics
end

#rdd_idsArray<Fixnum>

Corresponds to the JSON property rddIds

Returns:

  • (Array<Fixnum>)


10014
10015
10016
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10014

def rdd_ids
  @rdd_ids
end

#resource_profile_idFixnum

Corresponds to the JSON property resourceProfileId

Returns:

  • (Fixnum)


10019
10020
10021
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10019

def resource_profile_id
  @resource_profile_id
end

#scheduling_poolString

Corresponds to the JSON property schedulingPool

Returns:

  • (String)


10024
10025
10026
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10024

def scheduling_pool
  @scheduling_pool
end

#shuffle_mergers_countFixnum

Corresponds to the JSON property shuffleMergersCount

Returns:

  • (Fixnum)


10029
10030
10031
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10029

def shuffle_mergers_count
  @shuffle_mergers_count
end

#speculation_summaryGoogle::Apis::DataprocV1::SpeculationStageSummary

Details of the speculation task when speculative execution is enabled. Corresponds to the JSON property speculationSummary



10034
10035
10036
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10034

def speculation_summary
  @speculation_summary
end

#stage_attempt_idFixnum

Corresponds to the JSON property stageAttemptId

Returns:

  • (Fixnum)


10039
10040
10041
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10039

def stage_attempt_id
  @stage_attempt_id
end

#stage_idFixnum

Corresponds to the JSON property stageId

Returns:

  • (Fixnum)


10044
10045
10046
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10044

def stage_id
  @stage_id
end

#stage_metricsGoogle::Apis::DataprocV1::StageMetrics

Stage Level Aggregated Metrics Corresponds to the JSON property stageMetrics



10049
10050
10051
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10049

def stage_metrics
  @stage_metrics
end

#statusString

Corresponds to the JSON property status

Returns:

  • (String)


10054
10055
10056
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10054

def status
  @status
end

#submission_timeString

Corresponds to the JSON property submissionTime

Returns:

  • (String)


10059
10060
10061
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10059

def submission_time
  @submission_time
end

#task_quantile_metricsGoogle::Apis::DataprocV1::TaskQuantileMetrics

Summary metrics fields. These are included in response only if present in summary_metrics_mask field in request Corresponds to the JSON property taskQuantileMetrics



10065
10066
10067
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10065

def task_quantile_metrics
  @task_quantile_metrics
end

#tasksHash<String,Google::Apis::DataprocV1::TaskData>

Corresponds to the JSON property tasks

Returns:



10070
10071
10072
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10070

def tasks
  @tasks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10077
10078
10079
10080
10081
10082
10083
10084
10085
10086
10087
10088
10089
10090
10091
10092
10093
10094
10095
10096
10097
10098
10099
10100
10101
10102
10103
10104
10105
10106
10107
10108
10109
10110
10111
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10077

def update!(**args)
  @accumulator_updates = args[:accumulator_updates] if args.key?(:accumulator_updates)
  @completion_time = args[:completion_time] if args.key?(:completion_time)
  @description = args[:description] if args.key?(:description)
  @details = args[:details] if args.key?(:details)
  @executor_metrics_distributions = args[:executor_metrics_distributions] if args.key?(:executor_metrics_distributions)
  @executor_summary = args[:executor_summary] if args.key?(:executor_summary)
  @failure_reason = args[:failure_reason] if args.key?(:failure_reason)
  @first_task_launched_time = args[:first_task_launched_time] if args.key?(:first_task_launched_time)
  @is_shuffle_push_enabled = args[:is_shuffle_push_enabled] if args.key?(:is_shuffle_push_enabled)
  @job_ids = args[:job_ids] if args.key?(:job_ids)
  @killed_tasks_summary = args[:killed_tasks_summary] if args.key?(:killed_tasks_summary)
  @locality = args[:locality] if args.key?(:locality)
  @name = args[:name] if args.key?(:name)
  @num_active_tasks = args[:num_active_tasks] if args.key?(:num_active_tasks)
  @num_complete_tasks = args[:num_complete_tasks] if args.key?(:num_complete_tasks)
  @num_completed_indices = args[:num_completed_indices] if args.key?(:num_completed_indices)
  @num_failed_tasks = args[:num_failed_tasks] if args.key?(:num_failed_tasks)
  @num_killed_tasks = args[:num_killed_tasks] if args.key?(:num_killed_tasks)
  @num_tasks = args[:num_tasks] if args.key?(:num_tasks)
  @parent_stage_ids = args[:parent_stage_ids] if args.key?(:parent_stage_ids)
  @peak_executor_metrics = args[:peak_executor_metrics] if args.key?(:peak_executor_metrics)
  @rdd_ids = args[:rdd_ids] if args.key?(:rdd_ids)
  @resource_profile_id = args[:resource_profile_id] if args.key?(:resource_profile_id)
  @scheduling_pool = args[:scheduling_pool] if args.key?(:scheduling_pool)
  @shuffle_mergers_count = args[:shuffle_mergers_count] if args.key?(:shuffle_mergers_count)
  @speculation_summary = args[:speculation_summary] if args.key?(:speculation_summary)
  @stage_attempt_id = args[:stage_attempt_id] if args.key?(:stage_attempt_id)
  @stage_id = args[:stage_id] if args.key?(:stage_id)
  @stage_metrics = args[:stage_metrics] if args.key?(:stage_metrics)
  @status = args[:status] if args.key?(:status)
  @submission_time = args[:submission_time] if args.key?(:submission_time)
  @task_quantile_metrics = args[:task_quantile_metrics] if args.key?(:task_quantile_metrics)
  @tasks = args[:tasks] if args.key?(:tasks)
end