Class: Google::Apis::DataprocV1::StageData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Data corresponding to a stage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StageData

Returns a new instance of StageData.



10074
10075
10076
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10074

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accumulator_updatesArray<Google::Apis::DataprocV1::AccumulableInfo>

Corresponds to the JSON property accumulatorUpdates



9910
9911
9912
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9910

def accumulator_updates
  @accumulator_updates
end

#completion_timeString

Corresponds to the JSON property completionTime

Returns:

  • (String)


9915
9916
9917
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9915

def completion_time
  @completion_time
end

#descriptionString

Corresponds to the JSON property description

Returns:

  • (String)


9920
9921
9922
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9920

def description
  @description
end

#detailsString

Corresponds to the JSON property details

Returns:

  • (String)


9925
9926
9927
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9925

def details
  @details
end

#executor_metrics_distributionsGoogle::Apis::DataprocV1::ExecutorMetricsDistributions

Corresponds to the JSON property executorMetricsDistributions



9930
9931
9932
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9930

def executor_metrics_distributions
  @executor_metrics_distributions
end

#executor_summaryHash<String,Google::Apis::DataprocV1::ExecutorStageSummary>

Corresponds to the JSON property executorSummary



9935
9936
9937
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9935

def executor_summary
  @executor_summary
end

#failure_reasonString

Corresponds to the JSON property failureReason

Returns:

  • (String)


9940
9941
9942
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9940

def failure_reason
  @failure_reason
end

#first_task_launched_timeString

Corresponds to the JSON property firstTaskLaunchedTime

Returns:

  • (String)


9945
9946
9947
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9945

def first_task_launched_time
  @first_task_launched_time
end

#is_shuffle_push_enabledBoolean Also known as: is_shuffle_push_enabled?

Corresponds to the JSON property isShufflePushEnabled

Returns:

  • (Boolean)


9950
9951
9952
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9950

def is_shuffle_push_enabled
  @is_shuffle_push_enabled
end

#job_idsArray<Fixnum>

Corresponds to the JSON property jobIds

Returns:

  • (Array<Fixnum>)


9956
9957
9958
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9956

def job_ids
  @job_ids
end

#killed_tasks_summaryHash<String,Fixnum>

Corresponds to the JSON property killedTasksSummary

Returns:

  • (Hash<String,Fixnum>)


9961
9962
9963
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9961

def killed_tasks_summary
  @killed_tasks_summary
end

#localityHash<String,Fixnum>

Corresponds to the JSON property locality

Returns:

  • (Hash<String,Fixnum>)


9966
9967
9968
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9966

def locality
  @locality
end

#nameString

Corresponds to the JSON property name

Returns:

  • (String)


9971
9972
9973
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9971

def name
  @name
end

#num_active_tasksFixnum

Corresponds to the JSON property numActiveTasks

Returns:

  • (Fixnum)


9976
9977
9978
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9976

def num_active_tasks
  @num_active_tasks
end

#num_complete_tasksFixnum

Corresponds to the JSON property numCompleteTasks

Returns:

  • (Fixnum)


9981
9982
9983
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9981

def num_complete_tasks
  @num_complete_tasks
end

#num_completed_indicesFixnum

Corresponds to the JSON property numCompletedIndices

Returns:

  • (Fixnum)


9986
9987
9988
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9986

def num_completed_indices
  @num_completed_indices
end

#num_failed_tasksFixnum

Corresponds to the JSON property numFailedTasks

Returns:

  • (Fixnum)


9991
9992
9993
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9991

def num_failed_tasks
  @num_failed_tasks
end

#num_killed_tasksFixnum

Corresponds to the JSON property numKilledTasks

Returns:

  • (Fixnum)


9996
9997
9998
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9996

def num_killed_tasks
  @num_killed_tasks
end

#num_tasksFixnum

Corresponds to the JSON property numTasks

Returns:

  • (Fixnum)


10001
10002
10003
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10001

def num_tasks
  @num_tasks
end

#parent_stage_idsArray<Fixnum>

Corresponds to the JSON property parentStageIds

Returns:

  • (Array<Fixnum>)


10006
10007
10008
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10006

def parent_stage_ids
  @parent_stage_ids
end

#peak_executor_metricsGoogle::Apis::DataprocV1::ExecutorMetrics

Corresponds to the JSON property peakExecutorMetrics



10011
10012
10013
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10011

def peak_executor_metrics
  @peak_executor_metrics
end

#rdd_idsArray<Fixnum>

Corresponds to the JSON property rddIds

Returns:

  • (Array<Fixnum>)


10016
10017
10018
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10016

def rdd_ids
  @rdd_ids
end

#resource_profile_idFixnum

Corresponds to the JSON property resourceProfileId

Returns:

  • (Fixnum)


10021
10022
10023
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10021

def resource_profile_id
  @resource_profile_id
end

#scheduling_poolString

Corresponds to the JSON property schedulingPool

Returns:

  • (String)


10026
10027
10028
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10026

def scheduling_pool
  @scheduling_pool
end

#shuffle_mergers_countFixnum

Corresponds to the JSON property shuffleMergersCount

Returns:

  • (Fixnum)


10031
10032
10033
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10031

def shuffle_mergers_count
  @shuffle_mergers_count
end

#speculation_summaryGoogle::Apis::DataprocV1::SpeculationStageSummary

Details of the speculation task when speculative execution is enabled. Corresponds to the JSON property speculationSummary



10036
10037
10038
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10036

def speculation_summary
  @speculation_summary
end

#stage_attempt_idFixnum

Corresponds to the JSON property stageAttemptId

Returns:

  • (Fixnum)


10041
10042
10043
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10041

def stage_attempt_id
  @stage_attempt_id
end

#stage_idFixnum

Corresponds to the JSON property stageId

Returns:

  • (Fixnum)


10046
10047
10048
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10046

def stage_id
  @stage_id
end

#stage_metricsGoogle::Apis::DataprocV1::StageMetrics

Stage Level Aggregated Metrics Corresponds to the JSON property stageMetrics



10051
10052
10053
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10051

def stage_metrics
  @stage_metrics
end

#statusString

Corresponds to the JSON property status

Returns:

  • (String)


10056
10057
10058
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10056

def status
  @status
end

#submission_timeString

Corresponds to the JSON property submissionTime

Returns:

  • (String)


10061
10062
10063
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10061

def submission_time
  @submission_time
end

#task_quantile_metricsGoogle::Apis::DataprocV1::TaskQuantileMetrics

Summary metrics fields. These are included in response only if present in summary_metrics_mask field in request Corresponds to the JSON property taskQuantileMetrics



10067
10068
10069
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10067

def task_quantile_metrics
  @task_quantile_metrics
end

#tasksHash<String,Google::Apis::DataprocV1::TaskData>

Corresponds to the JSON property tasks

Returns:



10072
10073
10074
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10072

def tasks
  @tasks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10079
10080
10081
10082
10083
10084
10085
10086
10087
10088
10089
10090
10091
10092
10093
10094
10095
10096
10097
10098
10099
10100
10101
10102
10103
10104
10105
10106
10107
10108
10109
10110
10111
10112
10113
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10079

def update!(**args)
  @accumulator_updates = args[:accumulator_updates] if args.key?(:accumulator_updates)
  @completion_time = args[:completion_time] if args.key?(:completion_time)
  @description = args[:description] if args.key?(:description)
  @details = args[:details] if args.key?(:details)
  @executor_metrics_distributions = args[:executor_metrics_distributions] if args.key?(:executor_metrics_distributions)
  @executor_summary = args[:executor_summary] if args.key?(:executor_summary)
  @failure_reason = args[:failure_reason] if args.key?(:failure_reason)
  @first_task_launched_time = args[:first_task_launched_time] if args.key?(:first_task_launched_time)
  @is_shuffle_push_enabled = args[:is_shuffle_push_enabled] if args.key?(:is_shuffle_push_enabled)
  @job_ids = args[:job_ids] if args.key?(:job_ids)
  @killed_tasks_summary = args[:killed_tasks_summary] if args.key?(:killed_tasks_summary)
  @locality = args[:locality] if args.key?(:locality)
  @name = args[:name] if args.key?(:name)
  @num_active_tasks = args[:num_active_tasks] if args.key?(:num_active_tasks)
  @num_complete_tasks = args[:num_complete_tasks] if args.key?(:num_complete_tasks)
  @num_completed_indices = args[:num_completed_indices] if args.key?(:num_completed_indices)
  @num_failed_tasks = args[:num_failed_tasks] if args.key?(:num_failed_tasks)
  @num_killed_tasks = args[:num_killed_tasks] if args.key?(:num_killed_tasks)
  @num_tasks = args[:num_tasks] if args.key?(:num_tasks)
  @parent_stage_ids = args[:parent_stage_ids] if args.key?(:parent_stage_ids)
  @peak_executor_metrics = args[:peak_executor_metrics] if args.key?(:peak_executor_metrics)
  @rdd_ids = args[:rdd_ids] if args.key?(:rdd_ids)
  @resource_profile_id = args[:resource_profile_id] if args.key?(:resource_profile_id)
  @scheduling_pool = args[:scheduling_pool] if args.key?(:scheduling_pool)
  @shuffle_mergers_count = args[:shuffle_mergers_count] if args.key?(:shuffle_mergers_count)
  @speculation_summary = args[:speculation_summary] if args.key?(:speculation_summary)
  @stage_attempt_id = args[:stage_attempt_id] if args.key?(:stage_attempt_id)
  @stage_id = args[:stage_id] if args.key?(:stage_id)
  @stage_metrics = args[:stage_metrics] if args.key?(:stage_metrics)
  @status = args[:status] if args.key?(:status)
  @submission_time = args[:submission_time] if args.key?(:submission_time)
  @task_quantile_metrics = args[:task_quantile_metrics] if args.key?(:task_quantile_metrics)
  @tasks = args[:tasks] if args.key?(:tasks)
end