Class: Google::Apis::DataprocV1::StageData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

Data corresponding to a stage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StageData

Returns a new instance of StageData.



10066
10067
10068
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10066

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accumulator_updatesArray<Google::Apis::DataprocV1::AccumulableInfo>

Corresponds to the JSON property accumulatorUpdates



9902
9903
9904
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9902

def accumulator_updates
  @accumulator_updates
end

#completion_timeString

Corresponds to the JSON property completionTime

Returns:

  • (String)


9907
9908
9909
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9907

def completion_time
  @completion_time
end

#descriptionString

Corresponds to the JSON property description

Returns:

  • (String)


9912
9913
9914
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9912

def description
  @description
end

#detailsString

Corresponds to the JSON property details

Returns:

  • (String)


9917
9918
9919
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9917

def details
  @details
end

#executor_metrics_distributionsGoogle::Apis::DataprocV1::ExecutorMetricsDistributions

Corresponds to the JSON property executorMetricsDistributions



9922
9923
9924
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9922

def executor_metrics_distributions
  @executor_metrics_distributions
end

#executor_summaryHash<String,Google::Apis::DataprocV1::ExecutorStageSummary>

Corresponds to the JSON property executorSummary



9927
9928
9929
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9927

def executor_summary
  @executor_summary
end

#failure_reasonString

Corresponds to the JSON property failureReason

Returns:

  • (String)


9932
9933
9934
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9932

def failure_reason
  @failure_reason
end

#first_task_launched_timeString

Corresponds to the JSON property firstTaskLaunchedTime

Returns:

  • (String)


9937
9938
9939
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9937

def first_task_launched_time
  @first_task_launched_time
end

#is_shuffle_push_enabledBoolean Also known as: is_shuffle_push_enabled?

Corresponds to the JSON property isShufflePushEnabled

Returns:

  • (Boolean)


9942
9943
9944
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9942

def is_shuffle_push_enabled
  @is_shuffle_push_enabled
end

#job_idsArray<Fixnum>

Corresponds to the JSON property jobIds

Returns:

  • (Array<Fixnum>)


9948
9949
9950
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9948

def job_ids
  @job_ids
end

#killed_tasks_summaryHash<String,Fixnum>

Corresponds to the JSON property killedTasksSummary

Returns:

  • (Hash<String,Fixnum>)


9953
9954
9955
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9953

def killed_tasks_summary
  @killed_tasks_summary
end

#localityHash<String,Fixnum>

Corresponds to the JSON property locality

Returns:

  • (Hash<String,Fixnum>)


9958
9959
9960
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9958

def locality
  @locality
end

#nameString

Corresponds to the JSON property name

Returns:

  • (String)


9963
9964
9965
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9963

def name
  @name
end

#num_active_tasksFixnum

Corresponds to the JSON property numActiveTasks

Returns:

  • (Fixnum)


9968
9969
9970
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9968

def num_active_tasks
  @num_active_tasks
end

#num_complete_tasksFixnum

Corresponds to the JSON property numCompleteTasks

Returns:

  • (Fixnum)


9973
9974
9975
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9973

def num_complete_tasks
  @num_complete_tasks
end

#num_completed_indicesFixnum

Corresponds to the JSON property numCompletedIndices

Returns:

  • (Fixnum)


9978
9979
9980
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9978

def num_completed_indices
  @num_completed_indices
end

#num_failed_tasksFixnum

Corresponds to the JSON property numFailedTasks

Returns:

  • (Fixnum)


9983
9984
9985
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9983

def num_failed_tasks
  @num_failed_tasks
end

#num_killed_tasksFixnum

Corresponds to the JSON property numKilledTasks

Returns:

  • (Fixnum)


9988
9989
9990
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9988

def num_killed_tasks
  @num_killed_tasks
end

#num_tasksFixnum

Corresponds to the JSON property numTasks

Returns:

  • (Fixnum)


9993
9994
9995
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9993

def num_tasks
  @num_tasks
end

#parent_stage_idsArray<Fixnum>

Corresponds to the JSON property parentStageIds

Returns:

  • (Array<Fixnum>)


9998
9999
10000
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9998

def parent_stage_ids
  @parent_stage_ids
end

#peak_executor_metricsGoogle::Apis::DataprocV1::ExecutorMetrics

Corresponds to the JSON property peakExecutorMetrics



10003
10004
10005
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10003

def peak_executor_metrics
  @peak_executor_metrics
end

#rdd_idsArray<Fixnum>

Corresponds to the JSON property rddIds

Returns:

  • (Array<Fixnum>)


10008
10009
10010
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10008

def rdd_ids
  @rdd_ids
end

#resource_profile_idFixnum

Corresponds to the JSON property resourceProfileId

Returns:

  • (Fixnum)


10013
10014
10015
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10013

def resource_profile_id
  @resource_profile_id
end

#scheduling_poolString

Corresponds to the JSON property schedulingPool

Returns:

  • (String)


10018
10019
10020
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10018

def scheduling_pool
  @scheduling_pool
end

#shuffle_mergers_countFixnum

Corresponds to the JSON property shuffleMergersCount

Returns:

  • (Fixnum)


10023
10024
10025
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10023

def shuffle_mergers_count
  @shuffle_mergers_count
end

#speculation_summaryGoogle::Apis::DataprocV1::SpeculationStageSummary

Details of the speculation task when speculative execution is enabled. Corresponds to the JSON property speculationSummary



10028
10029
10030
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10028

def speculation_summary
  @speculation_summary
end

#stage_attempt_idFixnum

Corresponds to the JSON property stageAttemptId

Returns:

  • (Fixnum)


10033
10034
10035
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10033

def stage_attempt_id
  @stage_attempt_id
end

#stage_idFixnum

Corresponds to the JSON property stageId

Returns:

  • (Fixnum)


10038
10039
10040
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10038

def stage_id
  @stage_id
end

#stage_metricsGoogle::Apis::DataprocV1::StageMetrics

Stage Level Aggregated Metrics Corresponds to the JSON property stageMetrics



10043
10044
10045
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10043

def stage_metrics
  @stage_metrics
end

#statusString

Corresponds to the JSON property status

Returns:

  • (String)


10048
10049
10050
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10048

def status
  @status
end

#submission_timeString

Corresponds to the JSON property submissionTime

Returns:

  • (String)


10053
10054
10055
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10053

def submission_time
  @submission_time
end

#task_quantile_metricsGoogle::Apis::DataprocV1::TaskQuantileMetrics

Summary metrics fields. These are included in response only if present in summary_metrics_mask field in request Corresponds to the JSON property taskQuantileMetrics



10059
10060
10061
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10059

def task_quantile_metrics
  @task_quantile_metrics
end

#tasksHash<String,Google::Apis::DataprocV1::TaskData>

Corresponds to the JSON property tasks

Returns:



10064
10065
10066
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10064

def tasks
  @tasks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10071
10072
10073
10074
10075
10076
10077
10078
10079
10080
10081
10082
10083
10084
10085
10086
10087
10088
10089
10090
10091
10092
10093
10094
10095
10096
10097
10098
10099
10100
10101
10102
10103
10104
10105
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10071

def update!(**args)
  @accumulator_updates = args[:accumulator_updates] if args.key?(:accumulator_updates)
  @completion_time = args[:completion_time] if args.key?(:completion_time)
  @description = args[:description] if args.key?(:description)
  @details = args[:details] if args.key?(:details)
  @executor_metrics_distributions = args[:executor_metrics_distributions] if args.key?(:executor_metrics_distributions)
  @executor_summary = args[:executor_summary] if args.key?(:executor_summary)
  @failure_reason = args[:failure_reason] if args.key?(:failure_reason)
  @first_task_launched_time = args[:first_task_launched_time] if args.key?(:first_task_launched_time)
  @is_shuffle_push_enabled = args[:is_shuffle_push_enabled] if args.key?(:is_shuffle_push_enabled)
  @job_ids = args[:job_ids] if args.key?(:job_ids)
  @killed_tasks_summary = args[:killed_tasks_summary] if args.key?(:killed_tasks_summary)
  @locality = args[:locality] if args.key?(:locality)
  @name = args[:name] if args.key?(:name)
  @num_active_tasks = args[:num_active_tasks] if args.key?(:num_active_tasks)
  @num_complete_tasks = args[:num_complete_tasks] if args.key?(:num_complete_tasks)
  @num_completed_indices = args[:num_completed_indices] if args.key?(:num_completed_indices)
  @num_failed_tasks = args[:num_failed_tasks] if args.key?(:num_failed_tasks)
  @num_killed_tasks = args[:num_killed_tasks] if args.key?(:num_killed_tasks)
  @num_tasks = args[:num_tasks] if args.key?(:num_tasks)
  @parent_stage_ids = args[:parent_stage_ids] if args.key?(:parent_stage_ids)
  @peak_executor_metrics = args[:peak_executor_metrics] if args.key?(:peak_executor_metrics)
  @rdd_ids = args[:rdd_ids] if args.key?(:rdd_ids)
  @resource_profile_id = args[:resource_profile_id] if args.key?(:resource_profile_id)
  @scheduling_pool = args[:scheduling_pool] if args.key?(:scheduling_pool)
  @shuffle_mergers_count = args[:shuffle_mergers_count] if args.key?(:shuffle_mergers_count)
  @speculation_summary = args[:speculation_summary] if args.key?(:speculation_summary)
  @stage_attempt_id = args[:stage_attempt_id] if args.key?(:stage_attempt_id)
  @stage_id = args[:stage_id] if args.key?(:stage_id)
  @stage_metrics = args[:stage_metrics] if args.key?(:stage_metrics)
  @status = args[:status] if args.key?(:status)
  @submission_time = args[:submission_time] if args.key?(:submission_time)
  @task_quantile_metrics = args[:task_quantile_metrics] if args.key?(:task_quantile_metrics)
  @tasks = args[:tasks] if args.key?(:tasks)
end