Class: Google::Apis::DataprocV1::StageData
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::StageData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Data corresponding to a stage.
Instance Attribute Summary collapse
-
#accumulator_updates ⇒ Array<Google::Apis::DataprocV1::AccumulableInfo>
Corresponds to the JSON property
accumulatorUpdates. -
#completion_time ⇒ String
Corresponds to the JSON property
completionTime. -
#description ⇒ String
Corresponds to the JSON property
description. -
#details ⇒ String
Corresponds to the JSON property
details. -
#executor_metrics_distributions ⇒ Google::Apis::DataprocV1::ExecutorMetricsDistributions
Corresponds to the JSON property
executorMetricsDistributions. -
#executor_summary ⇒ Hash<String,Google::Apis::DataprocV1::ExecutorStageSummary>
Corresponds to the JSON property
executorSummary. -
#failure_reason ⇒ String
Corresponds to the JSON property
failureReason. -
#first_task_launched_time ⇒ String
Corresponds to the JSON property
firstTaskLaunchedTime. -
#is_shuffle_push_enabled ⇒ Boolean
(also: #is_shuffle_push_enabled?)
Corresponds to the JSON property
isShufflePushEnabled. -
#job_ids ⇒ Array<Fixnum>
Corresponds to the JSON property
jobIds. -
#killed_tasks_summary ⇒ Hash<String,Fixnum>
Corresponds to the JSON property
killedTasksSummary. -
#locality ⇒ Hash<String,Fixnum>
Corresponds to the JSON property
locality. -
#name ⇒ String
Corresponds to the JSON property
name. -
#num_active_tasks ⇒ Fixnum
Corresponds to the JSON property
numActiveTasks. -
#num_complete_tasks ⇒ Fixnum
Corresponds to the JSON property
numCompleteTasks. -
#num_completed_indices ⇒ Fixnum
Corresponds to the JSON property
numCompletedIndices. -
#num_failed_tasks ⇒ Fixnum
Corresponds to the JSON property
numFailedTasks. -
#num_killed_tasks ⇒ Fixnum
Corresponds to the JSON property
numKilledTasks. -
#num_tasks ⇒ Fixnum
Corresponds to the JSON property
numTasks. -
#parent_stage_ids ⇒ Array<Fixnum>
Corresponds to the JSON property
parentStageIds. -
#peak_executor_metrics ⇒ Google::Apis::DataprocV1::ExecutorMetrics
Corresponds to the JSON property
peakExecutorMetrics. -
#rdd_ids ⇒ Array<Fixnum>
Corresponds to the JSON property
rddIds. -
#resource_profile_id ⇒ Fixnum
Corresponds to the JSON property
resourceProfileId. -
#scheduling_pool ⇒ String
Corresponds to the JSON property
schedulingPool. -
#shuffle_mergers_count ⇒ Fixnum
Corresponds to the JSON property
shuffleMergersCount. -
#speculation_summary ⇒ Google::Apis::DataprocV1::SpeculationStageSummary
Details of the speculation task when speculative execution is enabled.
-
#stage_attempt_id ⇒ Fixnum
Corresponds to the JSON property
stageAttemptId. -
#stage_id ⇒ Fixnum
Corresponds to the JSON property
stageId. -
#stage_metrics ⇒ Google::Apis::DataprocV1::StageMetrics
Stage Level Aggregated Metrics Corresponds to the JSON property
stageMetrics. -
#status ⇒ String
Corresponds to the JSON property
status. -
#submission_time ⇒ String
Corresponds to the JSON property
submissionTime. -
#task_quantile_metrics ⇒ Google::Apis::DataprocV1::TaskQuantileMetrics
Summary metrics fields.
-
#tasks ⇒ Hash<String,Google::Apis::DataprocV1::TaskData>
Corresponds to the JSON property
tasks.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StageData
constructor
A new instance of StageData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StageData
Returns a new instance of StageData.
9757 9758 9759 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9757 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accumulator_updates ⇒ Array<Google::Apis::DataprocV1::AccumulableInfo>
Corresponds to the JSON property accumulatorUpdates
9593 9594 9595 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9593 def accumulator_updates @accumulator_updates end |
#completion_time ⇒ String
Corresponds to the JSON property completionTime
9598 9599 9600 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9598 def completion_time @completion_time end |
#description ⇒ String
Corresponds to the JSON property description
9603 9604 9605 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9603 def description @description end |
#details ⇒ String
Corresponds to the JSON property details
9608 9609 9610 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9608 def details @details end |
#executor_metrics_distributions ⇒ Google::Apis::DataprocV1::ExecutorMetricsDistributions
Corresponds to the JSON property executorMetricsDistributions
9613 9614 9615 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9613 def executor_metrics_distributions @executor_metrics_distributions end |
#executor_summary ⇒ Hash<String,Google::Apis::DataprocV1::ExecutorStageSummary>
Corresponds to the JSON property executorSummary
9618 9619 9620 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9618 def executor_summary @executor_summary end |
#failure_reason ⇒ String
Corresponds to the JSON property failureReason
9623 9624 9625 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9623 def failure_reason @failure_reason end |
#first_task_launched_time ⇒ String
Corresponds to the JSON property firstTaskLaunchedTime
9628 9629 9630 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9628 def first_task_launched_time @first_task_launched_time end |
#is_shuffle_push_enabled ⇒ Boolean Also known as: is_shuffle_push_enabled?
Corresponds to the JSON property isShufflePushEnabled
9633 9634 9635 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9633 def is_shuffle_push_enabled @is_shuffle_push_enabled end |
#job_ids ⇒ Array<Fixnum>
Corresponds to the JSON property jobIds
9639 9640 9641 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9639 def job_ids @job_ids end |
#killed_tasks_summary ⇒ Hash<String,Fixnum>
Corresponds to the JSON property killedTasksSummary
9644 9645 9646 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9644 def killed_tasks_summary @killed_tasks_summary end |
#locality ⇒ Hash<String,Fixnum>
Corresponds to the JSON property locality
9649 9650 9651 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9649 def locality @locality end |
#name ⇒ String
Corresponds to the JSON property name
9654 9655 9656 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9654 def name @name end |
#num_active_tasks ⇒ Fixnum
Corresponds to the JSON property numActiveTasks
9659 9660 9661 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9659 def num_active_tasks @num_active_tasks end |
#num_complete_tasks ⇒ Fixnum
Corresponds to the JSON property numCompleteTasks
9664 9665 9666 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9664 def num_complete_tasks @num_complete_tasks end |
#num_completed_indices ⇒ Fixnum
Corresponds to the JSON property numCompletedIndices
9669 9670 9671 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9669 def num_completed_indices @num_completed_indices end |
#num_failed_tasks ⇒ Fixnum
Corresponds to the JSON property numFailedTasks
9674 9675 9676 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9674 def num_failed_tasks @num_failed_tasks end |
#num_killed_tasks ⇒ Fixnum
Corresponds to the JSON property numKilledTasks
9679 9680 9681 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9679 def num_killed_tasks @num_killed_tasks end |
#num_tasks ⇒ Fixnum
Corresponds to the JSON property numTasks
9684 9685 9686 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9684 def num_tasks @num_tasks end |
#parent_stage_ids ⇒ Array<Fixnum>
Corresponds to the JSON property parentStageIds
9689 9690 9691 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9689 def parent_stage_ids @parent_stage_ids end |
#peak_executor_metrics ⇒ Google::Apis::DataprocV1::ExecutorMetrics
Corresponds to the JSON property peakExecutorMetrics
9694 9695 9696 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9694 def peak_executor_metrics @peak_executor_metrics end |
#rdd_ids ⇒ Array<Fixnum>
Corresponds to the JSON property rddIds
9699 9700 9701 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9699 def rdd_ids @rdd_ids end |
#resource_profile_id ⇒ Fixnum
Corresponds to the JSON property resourceProfileId
9704 9705 9706 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9704 def resource_profile_id @resource_profile_id end |
#scheduling_pool ⇒ String
Corresponds to the JSON property schedulingPool
9709 9710 9711 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9709 def scheduling_pool @scheduling_pool end |
#shuffle_mergers_count ⇒ Fixnum
Corresponds to the JSON property shuffleMergersCount
9714 9715 9716 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9714 def shuffle_mergers_count @shuffle_mergers_count end |
#speculation_summary ⇒ Google::Apis::DataprocV1::SpeculationStageSummary
Details of the speculation task when speculative execution is enabled.
Corresponds to the JSON property speculationSummary
9719 9720 9721 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9719 def speculation_summary @speculation_summary end |
#stage_attempt_id ⇒ Fixnum
Corresponds to the JSON property stageAttemptId
9724 9725 9726 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9724 def stage_attempt_id @stage_attempt_id end |
#stage_id ⇒ Fixnum
Corresponds to the JSON property stageId
9729 9730 9731 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9729 def stage_id @stage_id end |
#stage_metrics ⇒ Google::Apis::DataprocV1::StageMetrics
Stage Level Aggregated Metrics
Corresponds to the JSON property stageMetrics
9734 9735 9736 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9734 def stage_metrics @stage_metrics end |
#status ⇒ String
Corresponds to the JSON property status
9739 9740 9741 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9739 def status @status end |
#submission_time ⇒ String
Corresponds to the JSON property submissionTime
9744 9745 9746 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9744 def submission_time @submission_time end |
#task_quantile_metrics ⇒ Google::Apis::DataprocV1::TaskQuantileMetrics
Summary metrics fields. These are included in response only if present in
summary_metrics_mask field in request
Corresponds to the JSON property taskQuantileMetrics
9750 9751 9752 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9750 def task_quantile_metrics @task_quantile_metrics end |
#tasks ⇒ Hash<String,Google::Apis::DataprocV1::TaskData>
Corresponds to the JSON property tasks
9755 9756 9757 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9755 def tasks @tasks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9762 9763 9764 9765 9766 9767 9768 9769 9770 9771 9772 9773 9774 9775 9776 9777 9778 9779 9780 9781 9782 9783 9784 9785 9786 9787 9788 9789 9790 9791 9792 9793 9794 9795 9796 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 9762 def update!(**args) @accumulator_updates = args[:accumulator_updates] if args.key?(:accumulator_updates) @completion_time = args[:completion_time] if args.key?(:completion_time) @description = args[:description] if args.key?(:description) @details = args[:details] if args.key?(:details) @executor_metrics_distributions = args[:executor_metrics_distributions] if args.key?(:executor_metrics_distributions) @executor_summary = args[:executor_summary] if args.key?(:executor_summary) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @first_task_launched_time = args[:first_task_launched_time] if args.key?(:first_task_launched_time) @is_shuffle_push_enabled = args[:is_shuffle_push_enabled] if args.key?(:is_shuffle_push_enabled) @job_ids = args[:job_ids] if args.key?(:job_ids) @killed_tasks_summary = args[:killed_tasks_summary] if args.key?(:killed_tasks_summary) @locality = args[:locality] if args.key?(:locality) @name = args[:name] if args.key?(:name) @num_active_tasks = args[:num_active_tasks] if args.key?(:num_active_tasks) @num_complete_tasks = args[:num_complete_tasks] if args.key?(:num_complete_tasks) @num_completed_indices = args[:num_completed_indices] if args.key?(:num_completed_indices) @num_failed_tasks = args[:num_failed_tasks] if args.key?(:num_failed_tasks) @num_killed_tasks = args[:num_killed_tasks] if args.key?(:num_killed_tasks) @num_tasks = args[:num_tasks] if args.key?(:num_tasks) @parent_stage_ids = args[:parent_stage_ids] if args.key?(:parent_stage_ids) @peak_executor_metrics = args[:peak_executor_metrics] if args.key?(:peak_executor_metrics) @rdd_ids = args[:rdd_ids] if args.key?(:rdd_ids) @resource_profile_id = args[:resource_profile_id] if args.key?(:resource_profile_id) @scheduling_pool = args[:scheduling_pool] if args.key?(:scheduling_pool) @shuffle_mergers_count = args[:shuffle_mergers_count] if args.key?(:shuffle_mergers_count) @speculation_summary = args[:speculation_summary] if args.key?(:speculation_summary) @stage_attempt_id = args[:stage_attempt_id] if args.key?(:stage_attempt_id) @stage_id = args[:stage_id] if args.key?(:stage_id) @stage_metrics = args[:stage_metrics] if args.key?(:stage_metrics) @status = args[:status] if args.key?(:status) @submission_time = args[:submission_time] if args.key?(:submission_time) @task_quantile_metrics = args[:task_quantile_metrics] if args.key?(:task_quantile_metrics) @tasks = args[:tasks] if args.key?(:tasks) end |