Class: Google::Apis::DataprocV1::SubmitJobRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::SubmitJobRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A request to submit a job.
Instance Attribute Summary collapse
-
#job ⇒ Google::Apis::DataprocV1::Job
A Dataproc job resource.
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubmitJobRequest
constructor
A new instance of SubmitJobRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubmitJobRequest
Returns a new instance of SubmitJobRequest.
10984 10985 10986 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10984 def initialize(**args) update!(**args) end |
Instance Attribute Details
#job ⇒ Google::Apis::DataprocV1::Job
A Dataproc job resource.
Corresponds to the JSON property job
10970 10971 10972 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10970 def job @job end |
#request_id ⇒ String
Optional. A unique id used to identify the request. If the server receives two
SubmitJobRequest (https://cloud.google.com/dataproc/docs/reference/rpc/google.
cloud.dataproc.v1#google.cloud.dataproc.v1.SubmitJobRequest)s with the same id,
then the second request will be ignored and the first Job created and stored
in the backend is returned.It is recommended to always set this value to a
UUID (https://en.wikipedia.org/wiki/Universally_unique_identifier).The id must
contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-
). The maximum length is 40 characters.
Corresponds to the JSON property requestId
10982 10983 10984 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10982 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10989 10990 10991 10992 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10989 def update!(**args) @job = args[:job] if args.key?(:job) @request_id = args[:request_id] if args.key?(:request_id) end |