Class: Google::Apis::DataprocV1::SubmitJobRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A request to submit a job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubmitJobRequest

Returns a new instance of SubmitJobRequest.



10964
10965
10966
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10964

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#jobGoogle::Apis::DataprocV1::Job

A Dataproc job resource. Corresponds to the JSON property job



10950
10951
10952
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10950

def job
  @job
end

#request_idString

Optional. A unique id used to identify the request. If the server receives two SubmitJobRequest (https://cloud.google.com/dataproc/docs/reference/rpc/google. cloud.dataproc.v1#google.cloud.dataproc.v1.SubmitJobRequest)s with the same id, then the second request will be ignored and the first Job created and stored in the backend is returned.It is recommended to always set this value to a UUID (https://en.wikipedia.org/wiki/Universally_unique_identifier).The id must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (- ). The maximum length is 40 characters. Corresponds to the JSON property requestId

Returns:

  • (String)


10962
10963
10964
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10962

def request_id
  @request_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10969
10970
10971
10972
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10969

def update!(**args)
  @job = args[:job] if args.key?(:job)
  @request_id = args[:request_id] if args.key?(:request_id)
end