Class: Google::Apis::DataprocV1::SubmitJobRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::SubmitJobRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A request to submit a job.
Instance Attribute Summary collapse
-
#job ⇒ Google::Apis::DataprocV1::Job
A Dataproc job resource.
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubmitJobRequest
constructor
A new instance of SubmitJobRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubmitJobRequest
Returns a new instance of SubmitJobRequest.
10955 10956 10957 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10955 def initialize(**args) update!(**args) end |
Instance Attribute Details
#job ⇒ Google::Apis::DataprocV1::Job
A Dataproc job resource.
Corresponds to the JSON property job
10941 10942 10943 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10941 def job @job end |
#request_id ⇒ String
Optional. A unique id used to identify the request. If the server receives two
SubmitJobRequest (https://cloud.google.com/dataproc/docs/reference/rpc/google.
cloud.dataproc.v1#google.cloud.dataproc.v1.SubmitJobRequest)s with the same id,
then the second request will be ignored and the first Job created and stored
in the backend is returned.It is recommended to always set this value to a
UUID (https://en.wikipedia.org/wiki/Universally_unique_identifier).The id must
contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-
). The maximum length is 40 characters.
Corresponds to the JSON property requestId
10953 10954 10955 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10953 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10960 10961 10962 10963 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 10960 def update!(**args) @job = args[:job] if args.key?(:job) @request_id = args[:request_id] if args.key?(:request_id) end |