Class: Google::Apis::DataprocV1::UsageSnapshot

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

The usage snapshot represents the resources consumed by a workload at a specified time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsageSnapshot

Returns a new instance of UsageSnapshot.



11833
11834
11835
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11833

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_typeString

Optional. Accelerator type being used, if any Corresponds to the JSON property acceleratorType

Returns:

  • (String)


11794
11795
11796
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11794

def accelerator_type
  @accelerator_type
end

#milli_acceleratorFixnum

Optional. Milli (one-thousandth) accelerator. (see Dataproc Serverless pricing (https://cloud.google.com/dataproc-serverless/pricing)) Corresponds to the JSON property milliAccelerator

Returns:

  • (Fixnum)


11800
11801
11802
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11800

def milli_accelerator
  @milli_accelerator
end

#milli_dcuFixnum

Optional. Milli (one-thousandth) Dataproc Compute Units (DCUs) (see Dataproc Serverless pricing (https://cloud.google.com/dataproc-serverless/pricing)). Corresponds to the JSON property milliDcu

Returns:

  • (Fixnum)


11806
11807
11808
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11806

def milli_dcu
  @milli_dcu
end

#milli_dcu_premiumFixnum

Optional. Milli (one-thousandth) Dataproc Compute Units (DCUs) charged at premium tier (see Dataproc Serverless pricing (https://cloud.google.com/ dataproc-serverless/pricing)). Corresponds to the JSON property milliDcuPremium

Returns:

  • (Fixnum)


11813
11814
11815
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11813

def milli_dcu_premium
  @milli_dcu_premium
end

#shuffle_storage_gbFixnum

Optional. Shuffle Storage in gigabytes (GB). (see Dataproc Serverless pricing ( https://cloud.google.com/dataproc-serverless/pricing)) Corresponds to the JSON property shuffleStorageGb

Returns:

  • (Fixnum)


11819
11820
11821
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11819

def shuffle_storage_gb
  @shuffle_storage_gb
end

#shuffle_storage_gb_premiumFixnum

Optional. Shuffle Storage in gigabytes (GB) charged at premium tier. (see Dataproc Serverless pricing (https://cloud.google.com/dataproc-serverless/ pricing)) Corresponds to the JSON property shuffleStorageGbPremium

Returns:

  • (Fixnum)


11826
11827
11828
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11826

def shuffle_storage_gb_premium
  @shuffle_storage_gb_premium
end

#snapshot_timeString

Optional. The timestamp of the usage snapshot. Corresponds to the JSON property snapshotTime

Returns:

  • (String)


11831
11832
11833
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11831

def snapshot_time
  @snapshot_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11838
11839
11840
11841
11842
11843
11844
11845
11846
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11838

def update!(**args)
  @accelerator_type = args[:accelerator_type] if args.key?(:accelerator_type)
  @milli_accelerator = args[:milli_accelerator] if args.key?(:milli_accelerator)
  @milli_dcu = args[:milli_dcu] if args.key?(:milli_dcu)
  @milli_dcu_premium = args[:milli_dcu_premium] if args.key?(:milli_dcu_premium)
  @shuffle_storage_gb = args[:shuffle_storage_gb] if args.key?(:shuffle_storage_gb)
  @shuffle_storage_gb_premium = args[:shuffle_storage_gb_premium] if args.key?(:shuffle_storage_gb_premium)
  @snapshot_time = args[:snapshot_time] if args.key?(:snapshot_time)
end