Class: Google::Apis::DataprocV1::UsageSnapshot

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

The usage snapshot represents the resources consumed by a workload at a specified time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsageSnapshot

Returns a new instance of UsageSnapshot.



11524
11525
11526
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11524

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_typeString

Optional. Accelerator type being used, if any Corresponds to the JSON property acceleratorType

Returns:

  • (String)


11485
11486
11487
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11485

def accelerator_type
  @accelerator_type
end

#milli_acceleratorFixnum

Optional. Milli (one-thousandth) accelerator. (see Dataproc Serverless pricing (https://cloud.google.com/dataproc-serverless/pricing)) Corresponds to the JSON property milliAccelerator

Returns:

  • (Fixnum)


11491
11492
11493
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11491

def milli_accelerator
  @milli_accelerator
end

#milli_dcuFixnum

Optional. Milli (one-thousandth) Dataproc Compute Units (DCUs) (see Dataproc Serverless pricing (https://cloud.google.com/dataproc-serverless/pricing)). Corresponds to the JSON property milliDcu

Returns:

  • (Fixnum)


11497
11498
11499
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11497

def milli_dcu
  @milli_dcu
end

#milli_dcu_premiumFixnum

Optional. Milli (one-thousandth) Dataproc Compute Units (DCUs) charged at premium tier (see Dataproc Serverless pricing (https://cloud.google.com/ dataproc-serverless/pricing)). Corresponds to the JSON property milliDcuPremium

Returns:

  • (Fixnum)


11504
11505
11506
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11504

def milli_dcu_premium
  @milli_dcu_premium
end

#shuffle_storage_gbFixnum

Optional. Shuffle Storage in gigabytes (GB). (see Dataproc Serverless pricing ( https://cloud.google.com/dataproc-serverless/pricing)) Corresponds to the JSON property shuffleStorageGb

Returns:

  • (Fixnum)


11510
11511
11512
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11510

def shuffle_storage_gb
  @shuffle_storage_gb
end

#shuffle_storage_gb_premiumFixnum

Optional. Shuffle Storage in gigabytes (GB) charged at premium tier. (see Dataproc Serverless pricing (https://cloud.google.com/dataproc-serverless/ pricing)) Corresponds to the JSON property shuffleStorageGbPremium

Returns:

  • (Fixnum)


11517
11518
11519
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11517

def shuffle_storage_gb_premium
  @shuffle_storage_gb_premium
end

#snapshot_timeString

Optional. The timestamp of the usage snapshot. Corresponds to the JSON property snapshotTime

Returns:

  • (String)


11522
11523
11524
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11522

def snapshot_time
  @snapshot_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11529
11530
11531
11532
11533
11534
11535
11536
11537
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11529

def update!(**args)
  @accelerator_type = args[:accelerator_type] if args.key?(:accelerator_type)
  @milli_accelerator = args[:milli_accelerator] if args.key?(:milli_accelerator)
  @milli_dcu = args[:milli_dcu] if args.key?(:milli_dcu)
  @milli_dcu_premium = args[:milli_dcu_premium] if args.key?(:milli_dcu_premium)
  @shuffle_storage_gb = args[:shuffle_storage_gb] if args.key?(:shuffle_storage_gb)
  @shuffle_storage_gb_premium = args[:shuffle_storage_gb_premium] if args.key?(:shuffle_storage_gb_premium)
  @snapshot_time = args[:snapshot_time] if args.key?(:snapshot_time)
end