Class: Google::Apis::DataprocV1::ValueInfo
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::ValueInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
Annotatated property value.
Instance Attribute Summary collapse
-
#annotation ⇒ String
Annotation, comment or explanation why the property was set.
-
#overridden_value ⇒ String
Optional.
-
#value ⇒ String
Property value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ValueInfo
constructor
A new instance of ValueInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ValueInfo
Returns a new instance of ValueInfo.
11559 11560 11561 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11559 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotation ⇒ String
Annotation, comment or explanation why the property was set.
Corresponds to the JSON property annotation
11547 11548 11549 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11547 def annotation @annotation end |
#overridden_value ⇒ String
Optional. Value which was replaced by the corresponding component.
Corresponds to the JSON property overriddenValue
11552 11553 11554 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11552 def overridden_value @overridden_value end |
#value ⇒ String
Property value.
Corresponds to the JSON property value
11557 11558 11559 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11557 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11564 11565 11566 11567 11568 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11564 def update!(**args) @annotation = args[:annotation] if args.key?(:annotation) @overridden_value = args[:overridden_value] if args.key?(:overridden_value) @value = args[:value] if args.key?(:value) end |