Class: Google::Apis::DataprocV1::WorkflowMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::WorkflowMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A Dataproc workflow template resource.
Instance Attribute Summary collapse
-
#cluster_name ⇒ String
Output only.
-
#cluster_uuid ⇒ String
Output only.
-
#create_cluster ⇒ Google::Apis::DataprocV1::ClusterOperation
The cluster operation triggered by a workflow.
-
#dag_end_time ⇒ String
Output only.
-
#dag_start_time ⇒ String
Output only.
-
#dag_timeout ⇒ String
Output only.
-
#delete_cluster ⇒ Google::Apis::DataprocV1::ClusterOperation
The cluster operation triggered by a workflow.
-
#end_time ⇒ String
Output only.
-
#graph ⇒ Google::Apis::DataprocV1::WorkflowGraph
The workflow graph.
-
#parameters ⇒ Hash<String,String>
Map from parameter names to values that were used for those parameters.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#template ⇒ String
Output only.
-
#version ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkflowMetadata
constructor
A new instance of WorkflowMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkflowMetadata
Returns a new instance of WorkflowMetadata.
12051 12052 12053 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12051 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_name ⇒ String
Output only. The name of the target cluster.
Corresponds to the JSON property clusterName
11974 11975 11976 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11974 def cluster_name @cluster_name end |
#cluster_uuid ⇒ String
Output only. The UUID of target cluster.
Corresponds to the JSON property clusterUuid
11979 11980 11981 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11979 def cluster_uuid @cluster_uuid end |
#create_cluster ⇒ Google::Apis::DataprocV1::ClusterOperation
The cluster operation triggered by a workflow.
Corresponds to the JSON property createCluster
11984 11985 11986 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11984 def create_cluster @create_cluster end |
#dag_end_time ⇒ String
Output only. DAG end time, only set for workflows with dag_timeout when DAG
ends.
Corresponds to the JSON property dagEndTime
11990 11991 11992 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11990 def dag_end_time @dag_end_time end |
#dag_start_time ⇒ String
Output only. DAG start time, only set for workflows with dag_timeout when DAG
begins.
Corresponds to the JSON property dagStartTime
11996 11997 11998 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 11996 def dag_start_time @dag_start_time end |
#dag_timeout ⇒ String
Output only. The timeout duration for the DAG of jobs, expressed in seconds (
see JSON representation of duration (https://developers.google.com/protocol-
buffers/docs/proto3#json)).
Corresponds to the JSON property dagTimeout
12003 12004 12005 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12003 def dag_timeout @dag_timeout end |
#delete_cluster ⇒ Google::Apis::DataprocV1::ClusterOperation
The cluster operation triggered by a workflow.
Corresponds to the JSON property deleteCluster
12008 12009 12010 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12008 def delete_cluster @delete_cluster end |
#end_time ⇒ String
Output only. Workflow end time.
Corresponds to the JSON property endTime
12013 12014 12015 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12013 def end_time @end_time end |
#graph ⇒ Google::Apis::DataprocV1::WorkflowGraph
The workflow graph.
Corresponds to the JSON property graph
12018 12019 12020 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12018 def graph @graph end |
#parameters ⇒ Hash<String,String>
Map from parameter names to values that were used for those parameters.
Corresponds to the JSON property parameters
12023 12024 12025 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12023 def parameters @parameters end |
#start_time ⇒ String
Output only. Workflow start time.
Corresponds to the JSON property startTime
12028 12029 12030 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12028 def start_time @start_time end |
#state ⇒ String
Output only. The workflow state.
Corresponds to the JSON property state
12033 12034 12035 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12033 def state @state end |
#template ⇒ String
Output only. The resource name of the workflow template as described in https:/
/cloud.google.com/apis/design/resource_names. For projects.regions.
workflowTemplates, the resource name of the template has the following format:
projects/project_id/regions/region/workflowTemplates/template_id For
projects.locations.workflowTemplates, the resource name of the template has
the following format: projects/project_id/locations/location/
workflowTemplates/template_id
Corresponds to the JSON property template
12044 12045 12046 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12044 def template @template end |
#version ⇒ Fixnum
Output only. The version of template at the time of workflow instantiation.
Corresponds to the JSON property version
12049 12050 12051 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12049 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12056 12057 12058 12059 12060 12061 12062 12063 12064 12065 12066 12067 12068 12069 12070 12071 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12056 def update!(**args) @cluster_name = args[:cluster_name] if args.key?(:cluster_name) @cluster_uuid = args[:cluster_uuid] if args.key?(:cluster_uuid) @create_cluster = args[:create_cluster] if args.key?(:create_cluster) @dag_end_time = args[:dag_end_time] if args.key?(:dag_end_time) @dag_start_time = args[:dag_start_time] if args.key?(:dag_start_time) @dag_timeout = args[:dag_timeout] if args.key?(:dag_timeout) @delete_cluster = args[:delete_cluster] if args.key?(:delete_cluster) @end_time = args[:end_time] if args.key?(:end_time) @graph = args[:graph] if args.key?(:graph) @parameters = args[:parameters] if args.key?(:parameters) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @template = args[:template] if args.key?(:template) @version = args[:version] if args.key?(:version) end |