Class: Google::Apis::DataprocV1::WorkflowTemplate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A Dataproc workflow template resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkflowTemplate

Returns a new instance of WorkflowTemplate.



12202
12203
12204
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12202

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time template was created. Corresponds to the JSON property createTime

Returns:

  • (String)


12124
12125
12126
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12124

def create_time
  @create_time
end

#dag_timeoutString

Optional. Timeout duration for the DAG of jobs, expressed in seconds (see JSON representation of duration (https://developers.google.com/protocol-buffers/ docs/proto3#json)). The timeout duration must be from 10 minutes ("600s") to 24 hours ("86400s"). The timer begins when the first job is submitted. If the workflow is running at the end of the timeout period, any remaining jobs are cancelled, the workflow is ended, and if the workflow was running on a managed cluster, the cluster is deleted. Corresponds to the JSON property dagTimeout

Returns:

  • (String)


12135
12136
12137
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12135

def dag_timeout
  @dag_timeout
end

#encryption_configGoogle::Apis::DataprocV1::GoogleCloudDataprocV1WorkflowTemplateEncryptionConfig

Encryption settings for encrypting workflow template job arguments. Corresponds to the JSON property encryptionConfig



12140
12141
12142
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12140

def encryption_config
  @encryption_config
end

#idString

Corresponds to the JSON property id

Returns:

  • (String)


12145
12146
12147
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12145

def id
  @id
end

#jobsArray<Google::Apis::DataprocV1::OrderedJob>

Required. The Directed Acyclic Graph of Jobs to submit. Corresponds to the JSON property jobs



12150
12151
12152
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12150

def jobs
  @jobs
end

#labelsHash<String,String>

Optional. The labels to associate with this template. These labels will be propagated to all jobs and clusters created by the workflow instance.Label keys must contain 1 to 63 characters, and must conform to RFC 1035 (https:// www.ietf.org/rfc/rfc1035.txt).Label values may be empty, but, if present, must contain 1 to 63 characters, and must conform to RFC 1035 (https://www.ietf.org/ rfc/rfc1035.txt).No more than 32 labels can be associated with a template. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


12160
12161
12162
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12160

def labels
  @labels
end

#nameString

Output only. The resource name of the workflow template, as described in https: //cloud.google.com/apis/design/resource_names. For projects.regions. workflowTemplates, the resource name of the template has the following format: projects/project_id/regions/region/workflowTemplates/template_id For projects.locations.workflowTemplates, the resource name of the template has the following format: projects/project_id/locations/location/ workflowTemplates/template_id Corresponds to the JSON property name

Returns:

  • (String)


12171
12172
12173
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12171

def name
  @name
end

#parametersArray<Google::Apis::DataprocV1::TemplateParameter>

Optional. Template parameters whose values are substituted into the template. Values for parameters must be provided when the template is instantiated. Corresponds to the JSON property parameters



12177
12178
12179
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12177

def parameters
  @parameters
end

#placementGoogle::Apis::DataprocV1::WorkflowTemplatePlacement

Specifies workflow execution target.Either managed_cluster or cluster_selector is required. Corresponds to the JSON property placement



12183
12184
12185
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12183

def placement
  @placement
end

#update_timeString

Output only. The time template was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


12188
12189
12190
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12188

def update_time
  @update_time
end

#versionFixnum

Optional. Used to perform a consistent read-modify-write.This field should be left blank for a CreateWorkflowTemplate request. It is required for an UpdateWorkflowTemplate request, and must match the current server version. A typical update template flow would fetch the current template with a GetWorkflowTemplate request, which will return the current template with the version field filled in with the current server version. The user updates other fields in the template, then returns it as part of the UpdateWorkflowTemplate request. Corresponds to the JSON property version

Returns:

  • (Fixnum)


12200
12201
12202
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12200

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12207
12208
12209
12210
12211
12212
12213
12214
12215
12216
12217
12218
12219
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12207

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dag_timeout = args[:dag_timeout] if args.key?(:dag_timeout)
  @encryption_config = args[:encryption_config] if args.key?(:encryption_config)
  @id = args[:id] if args.key?(:id)
  @jobs = args[:jobs] if args.key?(:jobs)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @parameters = args[:parameters] if args.key?(:parameters)
  @placement = args[:placement] if args.key?(:placement)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version = args[:version] if args.key?(:version)
end