Class: Google::Apis::DataprocV1::YarnApplication

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A YARN application created by a job. Application information is a subset of org.apache.hadoop.yarn.proto.YarnProtos.ApplicationReportProto.Beta Feature: This report is available for testing purposes only. It may be changed before final release.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YarnApplication

Returns a new instance of YarnApplication.



12416
12417
12418
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12416

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#memory_mb_secondsFixnum

Optional. The cumulative memory usage of the application for a job, measured in mb-seconds. Corresponds to the JSON property memoryMbSeconds

Returns:

  • (Fixnum)


12385
12386
12387
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12385

def memory_mb_seconds
  @memory_mb_seconds
end

#nameString

Required. The application name. Corresponds to the JSON property name

Returns:

  • (String)


12390
12391
12392
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12390

def name
  @name
end

#progressFloat

Required. The numerical progress of the application, from 1 to 100. Corresponds to the JSON property progress

Returns:

  • (Float)


12395
12396
12397
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12395

def progress
  @progress
end

#stateString

Required. The application state. Corresponds to the JSON property state

Returns:

  • (String)


12400
12401
12402
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12400

def state
  @state
end

#tracking_urlString

Optional. The HTTP URL of the ApplicationMaster, HistoryServer, or TimelineServer that provides application-specific information. The URL uses the internal hostname, and requires a proxy server for resolution and, possibly, access. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


12408
12409
12410
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12408

def tracking_url
  @tracking_url
end

#vcore_secondsFixnum

Optional. The cumulative CPU time consumed by the application for a job, measured in vcore-seconds. Corresponds to the JSON property vcoreSeconds

Returns:

  • (Fixnum)


12414
12415
12416
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12414

def vcore_seconds
  @vcore_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12421
12422
12423
12424
12425
12426
12427
12428
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12421

def update!(**args)
  @memory_mb_seconds = args[:memory_mb_seconds] if args.key?(:memory_mb_seconds)
  @name = args[:name] if args.key?(:name)
  @progress = args[:progress] if args.key?(:progress)
  @state = args[:state] if args.key?(:state)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @vcore_seconds = args[:vcore_seconds] if args.key?(:vcore_seconds)
end