Class: Google::Apis::DataprocV1::YarnApplication

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A YARN application created by a job. Application information is a subset of org.apache.hadoop.yarn.proto.YarnProtos.ApplicationReportProto.Beta Feature: This report is available for testing purposes only. It may be changed before final release.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YarnApplication

Returns a new instance of YarnApplication.



12367
12368
12369
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12367

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#memory_mb_secondsFixnum

Optional. The cumulative memory usage of the application for a job, measured in mb-seconds. Corresponds to the JSON property memoryMbSeconds

Returns:

  • (Fixnum)


12336
12337
12338
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12336

def memory_mb_seconds
  @memory_mb_seconds
end

#nameString

Required. The application name. Corresponds to the JSON property name

Returns:

  • (String)


12341
12342
12343
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12341

def name
  @name
end

#progressFloat

Required. The numerical progress of the application, from 1 to 100. Corresponds to the JSON property progress

Returns:

  • (Float)


12346
12347
12348
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12346

def progress
  @progress
end

#stateString

Required. The application state. Corresponds to the JSON property state

Returns:

  • (String)


12351
12352
12353
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12351

def state
  @state
end

#tracking_urlString

Optional. The HTTP URL of the ApplicationMaster, HistoryServer, or TimelineServer that provides application-specific information. The URL uses the internal hostname, and requires a proxy server for resolution and, possibly, access. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


12359
12360
12361
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12359

def tracking_url
  @tracking_url
end

#vcore_secondsFixnum

Optional. The cumulative CPU time consumed by the application for a job, measured in vcore-seconds. Corresponds to the JSON property vcoreSeconds

Returns:

  • (Fixnum)


12365
12366
12367
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12365

def vcore_seconds
  @vcore_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12372
12373
12374
12375
12376
12377
12378
12379
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12372

def update!(**args)
  @memory_mb_seconds = args[:memory_mb_seconds] if args.key?(:memory_mb_seconds)
  @name = args[:name] if args.key?(:name)
  @progress = args[:progress] if args.key?(:progress)
  @state = args[:state] if args.key?(:state)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @vcore_seconds = args[:vcore_seconds] if args.key?(:vcore_seconds)
end