Class: Google::Apis::DataprocV1::YarnApplication

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb

Overview

A YARN application created by a job. Application information is a subset of org.apache.hadoop.yarn.proto.YarnProtos.ApplicationReportProto.Beta Feature: This report is available for testing purposes only. It may be changed before final release.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YarnApplication

Returns a new instance of YarnApplication.



12358
12359
12360
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12358

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#memory_mb_secondsFixnum

Optional. The cumulative memory usage of the application for a job, measured in mb-seconds. Corresponds to the JSON property memoryMbSeconds

Returns:

  • (Fixnum)


12327
12328
12329
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12327

def memory_mb_seconds
  @memory_mb_seconds
end

#nameString

Required. The application name. Corresponds to the JSON property name

Returns:

  • (String)


12332
12333
12334
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12332

def name
  @name
end

#progressFloat

Required. The numerical progress of the application, from 1 to 100. Corresponds to the JSON property progress

Returns:

  • (Float)


12337
12338
12339
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12337

def progress
  @progress
end

#stateString

Required. The application state. Corresponds to the JSON property state

Returns:

  • (String)


12342
12343
12344
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12342

def state
  @state
end

#tracking_urlString

Optional. The HTTP URL of the ApplicationMaster, HistoryServer, or TimelineServer that provides application-specific information. The URL uses the internal hostname, and requires a proxy server for resolution and, possibly, access. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


12350
12351
12352
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12350

def tracking_url
  @tracking_url
end

#vcore_secondsFixnum

Optional. The cumulative CPU time consumed by the application for a job, measured in vcore-seconds. Corresponds to the JSON property vcoreSeconds

Returns:

  • (Fixnum)


12356
12357
12358
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12356

def vcore_seconds
  @vcore_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12363
12364
12365
12366
12367
12368
12369
12370
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12363

def update!(**args)
  @memory_mb_seconds = args[:memory_mb_seconds] if args.key?(:memory_mb_seconds)
  @name = args[:name] if args.key?(:name)
  @progress = args[:progress] if args.key?(:progress)
  @state = args[:state] if args.key?(:state)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @vcore_seconds = args[:vcore_seconds] if args.key?(:vcore_seconds)
end