Class: Google::Apis::DataprocV1::YarnApplication
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::YarnApplication
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataproc_v1/classes.rb,
lib/google/apis/dataproc_v1/representations.rb,
lib/google/apis/dataproc_v1/representations.rb
Overview
A YARN application created by a job. Application information is a subset of org.apache.hadoop.yarn.proto.YarnProtos.ApplicationReportProto.Beta Feature: This report is available for testing purposes only. It may be changed before final release.
Instance Attribute Summary collapse
-
#memory_mb_seconds ⇒ Fixnum
Optional.
-
#name ⇒ String
Required.
-
#progress ⇒ Float
Required.
-
#state ⇒ String
Required.
-
#tracking_url ⇒ String
Optional.
-
#vcore_seconds ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ YarnApplication
constructor
A new instance of YarnApplication.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ YarnApplication
Returns a new instance of YarnApplication.
12049 12050 12051 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12049 def initialize(**args) update!(**args) end |
Instance Attribute Details
#memory_mb_seconds ⇒ Fixnum
Optional. The cumulative memory usage of the application for a job, measured
in mb-seconds.
Corresponds to the JSON property memoryMbSeconds
12018 12019 12020 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12018 def memory_mb_seconds @memory_mb_seconds end |
#name ⇒ String
Required. The application name.
Corresponds to the JSON property name
12023 12024 12025 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12023 def name @name end |
#progress ⇒ Float
Required. The numerical progress of the application, from 1 to 100.
Corresponds to the JSON property progress
12028 12029 12030 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12028 def progress @progress end |
#state ⇒ String
Required. The application state.
Corresponds to the JSON property state
12033 12034 12035 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12033 def state @state end |
#tracking_url ⇒ String
Optional. The HTTP URL of the ApplicationMaster, HistoryServer, or
TimelineServer that provides application-specific information. The URL uses
the internal hostname, and requires a proxy server for resolution and,
possibly, access.
Corresponds to the JSON property trackingUrl
12041 12042 12043 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12041 def tracking_url @tracking_url end |
#vcore_seconds ⇒ Fixnum
Optional. The cumulative CPU time consumed by the application for a job,
measured in vcore-seconds.
Corresponds to the JSON property vcoreSeconds
12047 12048 12049 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12047 def vcore_seconds @vcore_seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12054 12055 12056 12057 12058 12059 12060 12061 |
# File 'lib/google/apis/dataproc_v1/classes.rb', line 12054 def update!(**args) @memory_mb_seconds = args[:memory_mb_seconds] if args.key?(:memory_mb_seconds) @name = args[:name] if args.key?(:name) @progress = args[:progress] if args.key?(:progress) @state = args[:state] if args.key?(:state) @tracking_url = args[:tracking_url] if args.key?(:tracking_url) @vcore_seconds = args[:vcore_seconds] if args.key?(:vcore_seconds) end |